@@ -42,7 +42,8 @@
 
 #ifdef FC_OS_WIN32
 # include <Shlobj.h>
-# ifdef _MSC_VER
+// Doesn't seem to work with VS2010
+# if (defined(_MSC_VER) && (_MSC_VER < 1800))
 # include <Shfolder.h>
 # endif
 #endif
@@ -78,7 +79,7 @@
 #include "ComplexGeoData.h"
 #include "Property.h"
 #include "PropertyContainer.h"
-#include "PropertyStandard.h"
+#include "PropertyUnits.h"
 #include "PropertyFile.h"
 #include "PropertyLinks.h"
 #include "PropertyPythonObject.h"
@@ -90,8 +91,9 @@
 #include "Annotation.h"
 #include "MeasureDistance.h"
 
-// If you stumble here, run the target "BuildExtractRevision" on Windows systems or the Python script "SubWCRev.py" on Linux based systems
-// which builds src/Build/Version.h. Or create your own from src/Build/Version.h.in!
+// If you stumble here, run the target "BuildExtractRevision" on Windows systems
+// or the Python script "SubWCRev.py" on Linux based systems which builds
+// src/Build/Version.h. Or create your own from src/Build/Version.h.in!
 #include <Build/Version.h>
 
 #include <boost/tokenizer.hpp>
@@ -106,7 +108,7 @@ using namespace boost;
 using namespace boost::program_options;
 
 
-// scriptings (scripts are build in but can be overriden by command line option)
+// scriptings (scripts are build in but can be overridden by command line option)
 #include "InitScript.h"
 #include "TestScript.h"
 
@@ -313,6 +315,9 @@ bool Application::closeDocument(const char* name)
     auto_ptr<Document> delDoc (pos->second);
     DocMap.erase( pos );
 
+    // Trigger observers after removing the document from the internal map.
+    signalDeletedDocument();
+
     return true;
 }
 
@@ -1001,6 +1006,7 @@ void Application::initTypes(void)
     App ::GeometryPython            ::init();
     App ::Document                  ::init();
     App ::DocumentObjectGroup       ::init();
+    App ::DocumentObjectGroupPython ::init();
     App ::DocumentObjectFileIncluded::init();
     App ::InventorObject            ::init();
     App ::VRMLObject                ::init();
@@ -1124,9 +1130,9 @@ void Application::initApplication(void)
     Application::_pcSingleton = new Application(0,0,mConfig);
 
     // set up Unit system default
-    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath
-       ("User parameter:BaseApp/Preferences/Units");
-    UnitsApi::setSchema((UnitSystem)hGrp->GetInt("UserSchema",0));
+    //ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath
+    //   ("User parameter:BaseApp/Preferences/Units");
+    //UnitsApi::setSchema((UnitSystem)hGrp->GetInt("UserSchema",0));
 
     // starting the init script
     Interpreter().runString(Base::ScriptFactory().ProduceScript("FreeCADInit"));
@@ -1171,7 +1177,7 @@ void Application::processCmdLineFiles(void)
                     Base::Interpreter().loadModule(mods.front().c_str());
                     Base::Interpreter().runStringArg("import %s",mods.front().c_str());
                     Base::Interpreter().runStringArg("%s.open(\"%s\")",mods.front().c_str(),File.filePath().c_str());
-                    Base::Console().Log("Command line open: %s.Open(\"%s\")",mods.front().c_str(),File.filePath().c_str());
+                    Base::Console().Log("Command line open: %s.Open(\"%s\")\n",mods.front().c_str(),File.filePath().c_str());
                 }
                 else {
                     Console().Warning("File format not supported: %s \n", File.filePath().c_str());
@@ -1275,7 +1281,7 @@ void Application::LoadParameters(void)
 }
 
 
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
+#if (defined(_MSC_VER) && (_MSC_VER != 1600))
 // fix weird error while linking boost (all versions of VC)
 namespace boost { namespace program_options { std::string arg="arg"; } }
 #if (defined (BOOST_VERSION) && (BOOST_VERSION == 104100))
@@ -1285,6 +1291,7 @@ namespace boost { namespace program_options {
 #endif
 #endif
 
+#if 0 // it seemse the SUSE has fixed the broken boost package
 // reported for SUSE in issue #0000208
 #if defined(__GNUC__)
 #if BOOST_VERSION == 104400
@@ -1293,6 +1300,7 @@ namespace boost { namespace filesystem {
 } }
 #endif
 #endif
+#endif
 
 pair<string, string> customSyntax(const string& s)
 {
