@@ -139,6 +139,8 @@ struct DocumentP
     bool rollback;
     bool closable;
     int iUndoMode;
+    unsigned int UndoMemSize;
+    unsigned int UndoMaxStackSize;
 
     DocumentP() {
         activeObject = 0;
@@ -149,6 +151,8 @@ struct DocumentP
         rollback = false;
         closable = true;
         iUndoMode = 0;
+        UndoMemSize = 0;
+        UndoMaxStackSize = 20;
     }
 };
 
@@ -225,7 +229,7 @@ bool Document::undo(void)
         d->activeUndoTransaction->Name = mUndoTransactions.back()->Name;
 
         // applying the undo
-        mUndoTransactions.back()->apply(*this/*,DocChange*/);
+        mUndoTransactions.back()->apply(*this,false);
 
         // save the redo
         mRedoTransactions.push_back(d->activeUndoTransaction);
@@ -251,7 +255,7 @@ bool Document::redo(void)
         d->activeUndoTransaction->Name = mRedoTransactions.back()->Name;
 
         // do the redo
-        mRedoTransactions.back()->apply(*this/*,DocChange*/);
+        mRedoTransactions.back()->apply(*this,true);
         mUndoTransactions.push_back(d->activeUndoTransaction);
         d->activeUndoTransaction = 0;
 
@@ -306,6 +310,11 @@ void Document::commitTransaction()
     if (d->activeUndoTransaction) {
         mUndoTransactions.push_back(d->activeUndoTransaction);
         d->activeUndoTransaction = 0;
+        // check the stack for the limits
+        if(mUndoTransactions.size() > d->UndoMaxStackSize){
+            delete mUndoTransactions.front();
+            mUndoTransactions.pop_front();
+        }
     }
 }
 
@@ -313,8 +322,8 @@ void Document::abortTransaction()
 {
     if (d->activeUndoTransaction) {
         d->rollback = true;
-        // applieing the so far made changes
-        d->activeUndoTransaction->apply(*this);
+        // applying the so far made changes
+        d->activeUndoTransaction->apply(*this,false);
         d->rollback = false;
 
         // destroy the undo
@@ -374,7 +383,22 @@ int Document::getUndoMode(void) const
 
 unsigned int Document::getUndoMemSize (void) const
 {
-    return 0;
+    return d->UndoMemSize;
+}
+
+void Document::setUndoLimit(unsigned int UndoMemSize)
+{
+    d->UndoMemSize = UndoMemSize;
+}
+
+void Document::setMaxUndoStackSize(unsigned int UndoMaxStackSize)
+{
+     d->UndoMaxStackSize = UndoMaxStackSize;
+}
+
+unsigned int Document::getMaxUndoStackSize(void)const
+{
+    return d->UndoMaxStackSize;
 }
 
 void Document::onChanged(const Property* prop)
@@ -1063,8 +1087,15 @@ void Document::recompute()
 
     std::list<Vertex> make_order;
     DependencyList::out_edge_iterator j, jend;
-    // this sort gives the execute
-    boost::topological_sort(DepList, std::front_inserter(make_order));
+
+    try {
+        // this sort gives the execute
+        boost::topological_sort(DepList, std::front_inserter(make_order));
+    }
+    catch (const std::exception& e) {
+        std::cerr << "Document::recompute: " << e.what() << std::endl;
+        return;
+    }
 
     // caching vertex to DocObject
     for (std::map<DocumentObject*,Vertex>::const_iterator It1= VertexObjectList.begin();It1 != VertexObjectList.end(); ++It1)
@@ -1215,15 +1246,18 @@ DocumentObject * Document::addObject(const char* sType, const char* pObjectName)
     App::DocumentObject* pcObject = static_cast<App::DocumentObject*>(base);
     pcObject->setDocument(this);
 
-    // Transaction stuff
-    if (d->activeTransaction)
-        d->activeTransaction->addObjectNew(pcObject);
-    // Undo stuff
-    if (d->activeUndoTransaction)
-        d->activeUndoTransaction->addObjectDel(pcObject);
+    // do no transactions if we do a rollback!
+    if(!d->rollback){
+        // Transaction stuff
+        if (d->activeTransaction)
+            d->activeTransaction->addObjectNew(pcObject);
+        // Undo stuff
+        if (d->activeUndoTransaction)
+            d->activeUndoTransaction->addObjectDel(pcObject);
+    }
 
     // get Unique name
-    if (pObjectName)
+    if (pObjectName && pObjectName[0] != '\0')
         ObjectName = getUniqueObjectName(pObjectName);
     else
         ObjectName = getUniqueObjectName(sType);
@@ -1258,13 +1292,15 @@ void Document::_addObject(DocumentObject* pcObject, const char* pObjectName)
     // cache the pointer to the name string in the Object (for performance of DocumentObject::getNameInDocument())
     pcObject->pcNameInDocument = &(d->objectMap.find(pObjectName)->first);
 
-    // Transaction stuff
-    if (d->activeTransaction)
-        d->activeTransaction->addObjectNew(pcObject);
-    // Undo stuff
-    if (d->activeUndoTransaction)
-        d->activeUndoTransaction->addObjectDel(pcObject);
-
+    // do no transactions if we do a rollback!
+    if(!d->rollback){
+        // Transaction stuff
+        if (d->activeTransaction)
+            d->activeTransaction->addObjectNew(pcObject);
+        // Undo stuff
+        if (d->activeUndoTransaction)
+            d->activeUndoTransaction->addObjectDel(pcObject);
+    }
     // send the signal
     signalNewObject(*pcObject);
 }
@@ -1295,21 +1331,24 @@ void Document::remObject(const char* sName)
     // Before deleting we must nullify all dependant objects
     breakDependency(pos->second, true);
 
-    // Transaction stuff
-    if (d->activeTransaction)
-        d->activeTransaction->addObjectDel(pos->second);
+    // do no transactions if we do a rollback!
+    if(!d->rollback){
 
-    // Undo stuff
-    if (d->activeUndoTransaction) {
-        // in this case transaction delete or save the object
-        d->activeUndoTransaction->addObjectNew(pos->second);
-        // set name cache false
-        //pos->second->pcNameInDocument = 0;
+        // Transaction stuff
+        if (d->activeTransaction)
+            d->activeTransaction->addObjectDel(pos->second);
+
+        // Undo stuff
+        if (d->activeUndoTransaction) {
+            // in this case transaction delete or save the object
+            d->activeUndoTransaction->addObjectNew(pos->second);
+            // set name cache false
+            //pos->second->pcNameInDocument = 0;
+        }
+        else
+            // if not saved in undo -> delete object
+            delete pos->second;
     }
-    else
-        // if not saved in undo -> delete object
-        delete pos->second;
-
 
     for (std::vector<DocumentObject*>::iterator obj = d->objectArray.begin(); obj != d->objectArray.end(); ++obj) {
         if (*obj == pos->second) {
@@ -1333,14 +1372,16 @@ void Document::_remObject(DocumentObject* pcObject)
 
     signalDeletedObject(*pcObject);
 
-    // Transaction stuff
-    if (d->activeTransaction)
-        d->activeTransaction->addObjectDel(pcObject);
-
-    // Undo stuff
-    if (d->activeUndoTransaction)
-        d->activeUndoTransaction->addObjectNew(pcObject);
+    // do no transactions if we do a rollback!
+    if(!d->rollback){
+        // Transaction stuff
+        if (d->activeTransaction)
+            d->activeTransaction->addObjectDel(pcObject);
 
+        // Undo stuff
+        if (d->activeUndoTransaction)
+            d->activeUndoTransaction->addObjectNew(pcObject);
+    }
     // remove from map
     d->objectMap.erase(pos);
     //// set name cache false
@@ -1369,6 +1410,13 @@ void Document::breakDependency(DocumentObject* pcObject, bool clear)
                 else if (link->getContainer() == pcObject && clear)
                     link->setValue(0);
             }
+            else if (pt->second->getTypeId().isDerivedFrom(PropertyLinkSub::getClassTypeId())) {
+                PropertyLinkSub* link = static_cast<PropertyLinkSub*>(pt->second);
+                if (link->getValue() == pcObject)
+                    link->setValue(0);
+                else if (link->getContainer() == pcObject && clear)
+                    link->setValue(0);
+            }
             else if (pt->second->getTypeId().isDerivedFrom(PropertyLinkList::getClassTypeId())) {
                 PropertyLinkList* link = static_cast<PropertyLinkList*>(pt->second);
                 if (link->getContainer() == pcObject && clear) {
@@ -1395,8 +1443,15 @@ DocumentObject* Document::_copyObject(DocumentObject* obj, std::map<DocumentObje
                                       DocumentObject*>& copy_map, bool recursive)
 {
     if (!obj) return 0;
-    DocumentObject* copy = addObject(obj->getTypeId().getName(),obj->getNameInDocument());
+    // remove number from end to avoid lengthy names
+    std::string objname = obj->getNameInDocument();
+    size_t lastpos = objname.length()-1;
+    while (objname[lastpos] >= 48 && objname[lastpos] <= 57)
+        lastpos--;
+    objname = objname.substr(0, lastpos+1);
+    DocumentObject* copy = addObject(obj->getTypeId().getName(),objname.c_str());
     if (!copy) return 0;
+    copy->addDynamicProperties(obj);
 
     copy_map[obj] = copy;
 
