@@ -873,61 +873,6 @@ void PropertyFloatConstraint::setPyObject(PyObject *value)
     }
 }
 
-//**************************************************************************
-//**************************************************************************
-// PropertyDistance
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-TYPESYSTEM_SOURCE(App::PropertyDistance, App::PropertyFloat);
-
-//**************************************************************************
-//**************************************************************************
-// PropertySpeed
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-TYPESYSTEM_SOURCE(App::PropertySpeed, App::PropertyFloat);
-
-//**************************************************************************
-//**************************************************************************
-// PropertyAcceleration
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-TYPESYSTEM_SOURCE(App::PropertyAcceleration, App::PropertyFloat);
-
-//**************************************************************************
-//**************************************************************************
-// PropertyLength
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-TYPESYSTEM_SOURCE(App::PropertyLength, App::PropertyFloat);
-
-void PropertyLength::setPyObject(PyObject *value)
-{
-    float val=0.0f;
-    if (PyFloat_Check(value)) {
-        val = (float) PyFloat_AsDouble(value);
-    }
-    else if(PyInt_Check(value)) {
-        val = (float) PyInt_AsLong(value);
-    }
-    else {
-        std::string error = std::string("type must be float or int, not ");
-        error += value->ob_type->tp_name;
-        throw Py::TypeError(error);
-    }
-
-    if (val < 0.0f)
-        throw Py::ValueError("value must be nonnegative");
-    setValue(val);
-}
-
-//**************************************************************************
-//**************************************************************************
-// PropertyAngle
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-TYPESYSTEM_SOURCE(App::PropertyAngle, App::PropertyFloatConstraint);
-
 
 //**************************************************************************
 // PropertyFloatList
@@ -1254,9 +1199,13 @@ PyObject *PropertyStringList::getPyObject(void)
 {
     PyObject* list = PyList_New(getSize());
 
-    for(int i = 0;i<getSize(); i++) {
-        PyObject* item = PyString_FromString(_lValueList[i].c_str());
-        PyList_SetItem( list, i, item );
+    for (int i = 0;i<getSize(); i++) {
+        PyObject* item = PyUnicode_DecodeUTF8(_lValueList[i].c_str(), _lValueList[i].size(), 0);
+        if (!item) {
+            Py_DECREF(list);
+            throw Base::Exception("UTF8 conversion failure at PropertyStringList::getPyObject()");
+        }
+        PyList_SetItem(list, i, item);
     }
 
     return list;
@@ -1271,13 +1220,19 @@ void PropertyStringList::setPyObject(PyObject *value)
 
         for (Py_ssize_t i=0; i<nSize;++i) {
             PyObject* item = PyList_GetItem(value, i);
-            if (!PyString_Check(item)) {
-                std::string error = std::string("type in list must be str, not ");
+            if (PyUnicode_Check(item)) {
+                PyObject* unicode = PyUnicode_AsUTF8String(item);
+                values[i] = PyString_AsString(unicode);
+                Py_DECREF(unicode);
+            }
+            else if (PyString_Check(item)) {
+                values[i] = PyString_AsString(item);
+            }
+            else {
+                std::string error = std::string("type in list must be str or unicode, not ");
                 error += item->ob_type->tp_name;
                 throw Py::TypeError(error);
             }
-
-            values[i] = PyString_AsString(item);
         }
         
         setValues(values);
