@@ -374,15 +374,22 @@ PyObject *ConsoleSingleton::sPyMessage(PyObject * /*self*/, PyObject *args, PyOb
     const char* string=0;
     PyObject* unicode=0;
     if (PyUnicode_Check(output)) {
-        unicode = PyUnicode_AsUTF8String(output);
-        string = PyString_AsString(unicode);
+        unicode = PyUnicode_AsEncodedObject(output, "utf-8", "strict");
+        if (unicode)
+            string = PyString_AsString(unicode);
     }
     else if (PyString_Check(output)) {
         string = PyString_AsString(output);
     }
+    else {
+        unicode = PyObject_Str(output);
+        if (unicode)
+            string = PyString_AsString(unicode);
+    }
 
     PY_TRY {
-        Instance().Message("%s",string);            // process message
+        if (string)
+            Instance().Message("%s",string);            // process message
     } PY_CATCH;
 
     Py_XDECREF(unicode);
@@ -400,15 +407,22 @@ PyObject *ConsoleSingleton::sPyWarning(PyObject * /*self*/, PyObject *args, PyOb
     const char* string=0;
     PyObject* unicode=0;
     if (PyUnicode_Check(output)) {
-        unicode = PyUnicode_AsUTF8String(output);
-        string = PyString_AsString(unicode);
+        unicode = PyUnicode_AsEncodedObject(output, "utf-8", "strict");
+        if (unicode)
+            string = PyString_AsString(unicode);
     }
     else if (PyString_Check(output)) {
         string = PyString_AsString(output);
     }
+    else {
+        unicode = PyObject_Str(output);
+        if (unicode)
+            string = PyString_AsString(unicode);
+    }
 
     PY_TRY {
-        Instance().Warning("%s",string);            // process message
+        if (string)
+            Instance().Warning("%s",string);            // process message
     } PY_CATCH;
 
     Py_XDECREF(unicode);
@@ -426,15 +440,22 @@ PyObject *ConsoleSingleton::sPyError(PyObject * /*self*/, PyObject *args, PyObje
     const char* string=0;
     PyObject* unicode=0;
     if (PyUnicode_Check(output)) {
-        unicode = PyUnicode_AsUTF8String(output);
-        string = PyString_AsString(unicode);
+        unicode = PyUnicode_AsEncodedObject(output, "utf-8", "strict");
+        if (unicode)
+            string = PyString_AsString(unicode);
     }
     else if (PyString_Check(output)) {
         string = PyString_AsString(output);
     }
+    else {
+        unicode = PyObject_Str(output);
+        if (unicode)
+            string = PyString_AsString(unicode);
+    }
 
     PY_TRY {
-        Instance().Error("%s",string);            // process message
+        if (string)
+            Instance().Error("%s",string);            // process message
     } PY_CATCH;
 
     Py_XDECREF(unicode);
@@ -452,15 +473,22 @@ PyObject *ConsoleSingleton::sPyLog(PyObject * /*self*/, PyObject *args, PyObject
     const char* string=0;
     PyObject* unicode=0;
     if (PyUnicode_Check(output)) {
-        unicode = PyUnicode_AsUTF8String(output);
-        string = PyString_AsString(unicode);
+        unicode = PyUnicode_AsEncodedObject(output, "utf-8", "strict");
+        if (unicode)
+            string = PyString_AsString(unicode);
     }
     else if (PyString_Check(output)) {
         string = PyString_AsString(output);
     }
+    else {
+        unicode = PyObject_Str(output);
+        if (unicode)
+            string = PyString_AsString(unicode);
+    }
 
     PY_TRY {
-        Instance().Log("%s",string);            // process message
+        if (string)
+            Instance().Log("%s",string);            // process message
     } PY_CATCH;
 
     Py_XDECREF(unicode);
