@@ -23,7 +23,9 @@
 
 #include "PreCompiled.h"
 
-#include "Base/Rotation.h"
+#include <Base/Rotation.h>
+#include <Base/Tools.h>
+#include <Base/GeometryPyCXX.h>
 
 // inclusion of the generated files (generated out of RotationPy.xml)
 #include "VectorPy.h"
@@ -69,7 +71,7 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
     double angle;
     if (PyArg_ParseTuple(args, "O!d", &(Base::VectorPy::Type), &o, &angle)) {
         // NOTE: The last parameter defines the rotation angle in degree.
-        getRotationPtr()->setValue(static_cast<Base::VectorPy*>(o)->value(), angle/180.0*D_PI);
+        getRotationPtr()->setValue(static_cast<Base::VectorPy*>(o)->value(), Base::toRadians<double>(angle));
         return 0;
     }
 
@@ -87,6 +89,16 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
         return 0;
     }
 
+    PyErr_Clear();
+    PyObject *v1, *v2;
+    if (PyArg_ParseTuple(args, "O!O!", &(Base::VectorPy::Type), &v1,
+                                       &(Base::VectorPy::Type), &v2)) {
+        Py::Vector from(v1, false);
+        Py::Vector to(v2, false);
+        getRotationPtr()->setValue(from.toVector(), to.toVector());
+        return 0;
+    }
+
     PyErr_SetString(PyExc_Exception, "empty parameter list, four floats or Vector and float");
     return -1;
 }
@@ -154,6 +166,20 @@ void RotationPy::setQ(Py::Tuple arg)
     this->getRotationPtr()->setValue(q0,q1,q2,q3);
 }
 
+Py::Object RotationPy::getAxis(void) const
+{
+    Base::Vector3d axis; double angle;
+    this->getRotationPtr()->getValue(axis, angle);
+    return Py::Vector(axis);
+}
+
+Py::Float RotationPy::getAngle(void) const
+{
+    Base::Vector3d axis; double angle;
+    this->getRotationPtr()->getValue(axis, angle);
+    return Py::Float(angle);
+}
+
 PyObject *RotationPy::getCustomAttributes(const char* /*attr*/) const
 {
     return 0;
