@@ -601,7 +601,7 @@ Streambuf::seekoff(std::streambuf::off_type off,
 
 std::streambuf::pos_type
 Streambuf::seekpos(std::streambuf::pos_type pos,
-                   std::ios_base::openmode /*mode*/)
+                   std::ios_base::openmode which/*mode*/)
 {
     return seekoff(pos, std::ios_base::beg);
 }
