@@ -26,6 +26,8 @@
 # include <sstream>
 #endif
 
+# include <QTime>
+
 #include "Tools.h"
 
 namespace Base {
@@ -119,3 +121,53 @@ std::string Base::Tools::getIdentifier(const std::string& name)
 
     return CleanName;
 }
+
+// ----------------------------------------------------------------------------
+
+using namespace Base;
+
+struct StopWatch::Private
+{
+    QTime t;
+};
+
+StopWatch::StopWatch() : d(new Private)
+{
+}
+
+StopWatch::~StopWatch()
+{
+    delete d;
+}
+
+void StopWatch::start()
+{
+    d->t.start();
+}
+
+int StopWatch::elapsed()
+{
+    return d->t.elapsed();
+}
+
+std::string StopWatch::toString(int ms) const
+{
+    int total = ms;
+    int msec = total % 1000;
+    total = total / 1000;
+    int secs = total % 60;
+    total = total / 60;
+    int mins = total % 60;
+    int hour = total / 60;
+    std::stringstream str;
+    str << "Needed time: ";
+    if (hour > 0)
+        str << hour << "h " << mins << "m " << secs << "s";
+    else if (mins > 0)
+        str << mins << "m " << secs << "s";
+    else if (secs > 0)
+        str << secs << "s";
+    else
+        str << msec << "ms";
+    return str.str();
+}
