@@ -95,22 +95,55 @@ inline T clamp (T num, T lower, T upper)
     return std::max<T>(std::min<T>(upper,num),lower);
 }
 
+template<class T>
+inline T sgn (T t)
+{
+    if (t == 0)
+        return T(0);
+    else
+        return (t > 0) ? T(1) : T(-1);
+}
+
 #ifndef M_PI
 #define M_PI       3.14159265358979323846
 #endif
 
 template<class T>
-inline T radians(T d)
+inline T toRadians(T d)
 {
     return static_cast<T>((d*M_PI)/180.0);
 }
 
 template<class T>
-inline T degrees(T r)
+inline T toDegrees(T r)
 {
     return static_cast<T>((r/M_PI)*180.0);
 }
 
+template<class T>
+inline T fmod(T numerator, T denominator)
+{
+    T modulo = std::fmod(numerator, denominator);
+    return (modulo >= T(0)) ? modulo : modulo + denominator;
+}
+
+// ----------------------------------------------------------------------------
+
+class BaseExport StopWatch
+{
+public:
+    StopWatch();
+    ~StopWatch();
+
+    void start();
+    int elapsed();
+    std::string toString(int ms) const;
+
+private:
+    struct Private;
+    Private* d;
+};
+
 // ----------------------------------------------------------------------------
 
 struct BaseExport Tools
