@@ -51,7 +51,6 @@
 
 
 namespace Base {
-class Matrix4D;
 template <class numT>
 struct float_traits { };
 
@@ -111,7 +110,6 @@ public:
     Vector3 & operator -= (const Vector3<_Precision>& rcVct);
     /// Vector scaling
     Vector3 operator * (_Precision fScale) const;
-    Vector3 operator * (const Base::Matrix4D &dMtrx4D) const;
     Vector3 operator / (_Precision fDiv) const;
     Vector3 & operator *= (_Precision fScale);
     Vector3 & operator /= (_Precision fDiv);
@@ -152,7 +150,7 @@ public:
     _Precision Sqr (void) const;
     /// Set length to 1.
     Vector3 & Normalize (void);
-    /// Get angle between both vectors.
+    /// Get angle between both vectors. The returned value lies in the interval [0,pi].
     _Precision GetAngle (const Vector3 &rcVect) const;
     /** Transforms this point to the coordinate system defined by origin \a rclBase, 
     * vector \a vector rclDirX and vector \a vector rclDirY. 
@@ -219,6 +217,43 @@ inline Vector3<_Pr1> toVector(const Vector3<_Pr2>& v)
 typedef Vector3<float>  Vector3f;
 typedef Vector3<double> Vector3d;
 
+template <class vecT>
+struct vec_traits { };
+
+template <>
+struct vec_traits<Vector3f> {
+    typedef Vector3f vec_type;
+    typedef float float_type;
+    vec_traits(const vec_type& v) : v(v){}
+    inline float_type x() { return v.x; }
+    inline float_type y() { return v.y; }
+    inline float_type z() { return v.z; }
+private:
+    const vec_type& v;
+};
+
+template <>
+struct vec_traits<Vector3d> {
+    typedef Vector3d vec_type;
+    typedef double float_type;
+    vec_traits(const vec_type& v) : v(v){}
+    inline float_type x() { return v.x; }
+    inline float_type y() { return v.y; }
+    inline float_type z() { return v.z; }
+private:
+    const vec_type& v;
+};
+
+template <class _Vec1, class _Vec2>
+inline _Vec1 convertTo(const _Vec2& v)
+{
+    typedef _Vec2 vec_type;
+    typedef vec_traits<vec_type> traits_type;
+    typedef typename traits_type::float_type float_type;
+    traits_type t(v);
+    return _Vec1((float_type)t.x(),(float_type)t.y(),(float_type)t.z());
+};
+
 
 } // namespace Base
 
