@@ -62,27 +62,27 @@ int VectorPy::PyInit(PyObject* args, PyObject* /*kwd*/)
     VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
     if (PyArg_ParseTuple(args, "|ddd", &x,&y,&z)) {
         ptr->Set(x,y,z);
+        return 0;
     }
-    else if (PyArg_ParseTuple(args,"O!",&(Base::VectorPy::Type), &object)) {
-        PyErr_Clear(); // set by PyArg_ParseTuple()
+    PyErr_Clear(); // set by PyArg_ParseTuple()
+    if (PyArg_ParseTuple(args,"O!",&(Base::VectorPy::Type), &object)) {
         // Note: must be static_cast, not reinterpret_cast
         *ptr = *(static_cast<Base::VectorPy*>(object)->getVectorPtr());
+        return 0;
     }
-    else if (PyArg_ParseTuple(args,"O!",&(PyTuple_Type), &object)) {
-        PyErr_Clear(); // set by PyArg_ParseTuple()
+    PyErr_Clear(); // set by PyArg_ParseTuple()
+    if (PyArg_ParseTuple(args,"O!",&(PyTuple_Type), &object)) {
         try {
             *ptr = getVectorFromTuple<double>(object);
+            return 0;
         }
         catch (const Py::Exception&) {
             return -1;
         }
     }
-    else {
-        PyErr_SetString(PyExc_TypeError, "Either three floats, tuple or Vector expected");
-        return -1;
-    }
 
-    return 0;
+    PyErr_SetString(PyExc_TypeError, "Either three floats, tuple or Vector expected");
+    return -1;
 }
 
 PyObject* VectorPy::number_add_handler(PyObject *self, PyObject *other)
@@ -121,15 +121,65 @@ PyObject* VectorPy::number_multiply_handler(PyObject *self, PyObject *other)
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
         return 0;
     }
-    if (!PyObject_TypeCheck(other, &(VectorPy::Type))) {
-        PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
+
+    if (PyObject_TypeCheck(other, &(VectorPy::Type))) {
+        Base::Vector3d a = static_cast<VectorPy*>(self) ->value();
+        Base::Vector3d b = static_cast<VectorPy*>(other)->value();
+        Py::Float mult(a * b);
+        return Py::new_reference_to(mult);
+    }
+    else if (PyFloat_Check(other)) {
+        Base::Vector3d a = static_cast<VectorPy*>(self) ->value();
+        double b = PyFloat_AsDouble(other);
+        return new VectorPy(a * b);
+    }
+    else {
+        PyErr_SetString(PyExc_TypeError, "A Vector can only be multiplied by Vector or number");
         return 0;
     }
-    Base::Vector3d a = static_cast<VectorPy*>(self)->value();
-    Base::Vector3d b = static_cast<VectorPy*>(other)->value();
+}
 
-    Py::Float mult(a * b);
-    return Py::new_reference_to(mult);
+Py_ssize_t VectorPy::sequence_length(PyObject *)
+{
+    return 3;
+}
+
+PyObject * VectorPy::sequence_item (PyObject *self, Py_ssize_t index)
+{
+    if (!PyObject_TypeCheck(self, &(VectorPy::Type))) {
+        PyErr_SetString(PyExc_TypeError, "first arg must be Vector");
+        return 0;
+    }
+    if (index < 0 || index > 2) {
+        PyErr_SetString(PyExc_IndexError, "index out of range");
+        return 0;
+    }
+
+    Base::Vector3d a = static_cast<VectorPy*>(self)->value();
+    return Py_BuildValue("d", a[index]);
+}
+
+int VectorPy::sequence_ass_item(PyObject *self, Py_ssize_t index, PyObject *value)
+{
+    if (!PyObject_TypeCheck(self, &(VectorPy::Type))) {
+        PyErr_SetString(PyExc_TypeError, "first arg must be Vector");
+        return -1;
+    }
+    if (index < 0 || index > 2) {
+        PyErr_SetString(PyExc_IndexError, "index out of range");
+        return -1;
+    }
+
+    if (PyFloat_Check(value)) {
+        VectorPy::PointerType ptr = static_cast<VectorPy*>(self)->getVectorPtr();
+        (*ptr)[index] = PyFloat_AsDouble(value);
+    }
+    else {
+        PyErr_SetString(PyExc_ValueError, "value must be float");
+        return -1;
+    }
+
+    return 0;
 }
 
 PyObject*  VectorPy::add(PyObject *args)
@@ -199,7 +249,8 @@ PyObject*  VectorPy::scale(PyObject *args)
         return 0;
     VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
     ptr->Scale(factorX, factorY, factorZ);
-    Py_Return;
+
+    return Py::new_reference_to(this);
 }
 
 PyObject*  VectorPy::multiply(PyObject *args)
@@ -209,7 +260,8 @@ PyObject*  VectorPy::multiply(PyObject *args)
         return 0;
     VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
     ptr->Scale(factor, factor, factor);
-    Py_Return;
+
+    return Py::new_reference_to(this);
 }
 
 PyObject*  VectorPy::dot(PyObject *args)
@@ -268,7 +320,8 @@ PyObject*  VectorPy::normalize(PyObject *args)
     }
 
     ptr->Normalize();
-    Py_Return;
+
+    return Py::new_reference_to(this);
 }
 
 PyObject*  VectorPy::projectToLine(PyObject *args)
@@ -293,7 +346,8 @@ PyObject*  VectorPy::projectToLine(PyObject *args)
     VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
 
     this_ptr->ProjToLine(*base_ptr, *line_ptr);
-    Py_Return;
+
+    return Py::new_reference_to(this);
 }
 
 PyObject*  VectorPy::projectToPlane(PyObject *args)
@@ -318,7 +372,8 @@ PyObject*  VectorPy::projectToPlane(PyObject *args)
     VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
 
     this_ptr->ProjToPlane(*base_ptr, *line_ptr);
-    Py_Return;
+
+    return Py::new_reference_to(this);
 }
 
 PyObject*  VectorPy::distanceToLine(PyObject *args)
