@@ -51,14 +51,14 @@
 #	if HAVE_CONFIG_H
 #	include <config.h>
 #	endif // HAVE_CONFIG_H
-#	define HAVE_INT8_T
-#	define HAVE_UINT8_T
-#	define HAVE_INT16_T
-#	define HAVE_UINT16_T
-#	define HAVE_INT32_T
-#	define HAVE_UINT32_T
-#	define HAVE_INT64_T
-#	define HAVE_UINT64_T
+//#	define HAVE_INT8_T
+//#	define HAVE_UINT8_T
+//#	define HAVE_INT16_T
+//#	define HAVE_UINT16_T
+//#	define HAVE_INT32_T
+//#	define HAVE_UINT32_T
+//#	define HAVE_INT64_T
+//#	define HAVE_UINT64_T
 //#	define HAVE_INTPTR_T
 //#	define HAVE_UINTPTR_T
 #	endif
@@ -66,10 +66,18 @@
 #	ifndef FC_OS_WIN32
 #	define FC_OS_WIN32
 #	endif
-#elif defined(linux) || defined(__linux) || defined(__linux__)
+#elif defined(__APPLE__)
+#	ifndef FC_OS_MACOSX
+#	define FC_OS_MACOSX
+#	endif
+#elif defined(linux) || defined(__linux) || defined(__linux__) || defined(__GLIBC__)
 #	ifndef FC_OS_LINUX
 #	define FC_OS_LINUX
 #	endif
+#elif defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__)
+#	ifndef FC_OS_BSD
+#	define FC_OS_BSD
+#	endif
 #elif defined(__CYGWIN__)
 #	ifndef FC_OS_CYGWIN
 #	define FC_OS_CYGWIN
@@ -105,10 +113,6 @@
 //#	define FC_OS_AIX
 //#elif defined(__GNU__)
 //#	define FC_OS_GNU
-#elif defined(__APPLE__)
-#	ifndef FC_OS_MACOSX
-#	define FC_OS_MACOSX
-#	endif
 #else
 #	error "FreeCAD is not ported to this OS yet. For help see free-cad.sourceforge.net"
 #endif
@@ -122,7 +126,9 @@
 //**************************************************************************
 // Standard types for Windows
 
-#if defined (FC_OS_WIN64) || defined (FC_OS_WIN32)
+#if defined(__MINGW32__)
+// nothing specific here
+#elif defined (FC_OS_WIN64) || defined (FC_OS_WIN32)
 
 #ifndef HAVE_INT8_T
 #define HAVE_INT8_T
