@@ -54,6 +54,7 @@
 #include <App/DocumentObjectPy.h>
 
 #include "Application.h"
+#include "GuiApplicationNativeEventAware.h"
 #include "MainWindow.h"
 #include "Document.h"
 #include "View.h"
@@ -75,6 +76,7 @@
 #include "PythonDebugger.h"
 #include "View3DPy.h"
 #include "DlgOnlineHelpImp.h"
+#include "SpaceballEvent.h"
 
 #include "View3DInventor.h"
 #include "ViewProvider.h"
@@ -89,6 +91,7 @@
 #include "ViewProviderMeasureDistance.h"
 
 #include "Language/Translator.h"
+#include "TaskView/TaskDialogPython.h"
 #include "GuiInitScript.h"
 
 
@@ -107,8 +110,7 @@ struct ApplicationP
     ApplicationP() : 
     activeDocument(0L), 
     isClosing(false), 
-    startingUp(true), 
-    _stderr(0)
+    startingUp(true)
     {
         // create the macro manager
         macroMngr = new MacroManager();
@@ -130,7 +132,6 @@ struct ApplicationP
     bool startingUp;
     /// Handles all commands 
     CommandManager commandManager;
-    PyObject *_stderr;
 };
 
 /** Observer that watches relabeled objects and make sure that the labels inside
@@ -184,32 +185,35 @@ void ObjectLabelObserver::slotRelabelObject(const App::DocumentObject& obj, cons
         if (current) {
             return;
         }
-        // only if Label differ from internal name it can happen to have non-unique label
+
         std::string label = obj.Label.getValue();
-        if (label != obj.getNameInDocument()) {
-            App::Document* doc = obj.getDocument();
-            if (doc && !_hPGrp->GetBool("DuplicateLabels")) {
-                std::vector<std::string> objectLabels;
-                std::vector<App::DocumentObject*>::const_iterator it;
-                std::vector<App::DocumentObject*> objs = doc->getObjects();
-                bool match = false;
+        App::Document* doc = obj.getDocument();
+        if (doc && !_hPGrp->GetBool("DuplicateLabels")) {
+            std::vector<std::string> objectLabels;
+            std::vector<App::DocumentObject*>::const_iterator it;
+            std::vector<App::DocumentObject*> objs = doc->getObjects();
+            bool match = false;
 
-                for (it = objs.begin();it != objs.end();++it) {
-                    if (*it == &obj)
-                        continue; // don't compare object with itself
-                    std::string objLabel = (*it)->Label.getValue();
-                    if (!match && objLabel == label)
-                        match = true;
-                    objectLabels.push_back(objLabel);
-                }
+            for (it = objs.begin();it != objs.end();++it) {
+                if (*it == &obj)
+                    continue; // don't compare object with itself
+                std::string objLabel = (*it)->Label.getValue();
+                if (!match && objLabel == label)
+                    match = true;
+                objectLabels.push_back(objLabel);
+            }
 
-                // make sure that there is a name conflict otherwise we don't have to do anything
-                if (match) {
-                    label = Base::Tools::getUniqueName(label, objectLabels, 3);
-                    this->current = &obj;
-                    const_cast<App::DocumentObject&>(obj).Label.setValue(label);
-                    this->current = 0;
-                }
+            // make sure that there is a name conflict otherwise we don't have to do anything
+            if (match) {
+                // remove number from end to avoid lengthy names
+                size_t lastpos = label.length()-1;
+                while (label[lastpos] >= 48 && label[lastpos] <= 57)
+                    lastpos--;
+                label = label.substr(0, lastpos+1);
+                label = Base::Tools::getUniqueName(label, objectLabels, 3);
+                this->current = &obj;
+                const_cast<App::DocumentObject&>(obj).Label.setValue(label);
+                this->current = 0;
             }
         }
     }
@@ -343,6 +347,10 @@ Application::Application(bool GUIenabled)
         SelectionFilterPy::init_type();
         Base::Interpreter().addType(SelectionFilterPy::type_object(),
             pSelectionModule,"Filter");
+
+        Gui::TaskView::ControlPy::init_type();
+        Py::Module(module).setAttr(std::string("Control"),
+            Py::Object(Gui::TaskView::ControlPy::getInstance(), true));
     }
 
     Base::PyGILStateLocker lock;
@@ -363,17 +371,12 @@ Application::Application(bool GUIenabled)
     PythonDebugModule   ::init_module();
     PythonStdout        ::init_type();
     PythonStderr        ::init_type();
+    OutputStdout        ::init_type();
     OutputStderr        ::init_type();
     PythonStdin         ::init_type();
     View3DInventorPy    ::init_type();
 
     d = new ApplicationP;
-    bool redir = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/OutputWindow")->
-                              GetBool("RedirectPythonErrors", false);
-    if (redir) {
-        d->_stderr = new OutputStderr();
-        PySys_SetObject("stderr", d->_stderr);
-    }
 
     // global access 
     Instance = this;
@@ -414,7 +417,6 @@ Application::~Application()
     {
     Base::PyGILStateLocker lock;
     Py_DECREF(_pcWorkbenchDictionary);
-    Py_XDECREF(d->_stderr);
     }
 
     // save macros
@@ -493,6 +495,7 @@ void Application::importFrom(const char* FileName, const char* DocName, const ch
             else {
                 Command::doCommand(Command::App, "%s.insert(\"%s\",\"%s\")"
                                                , Module, File.filePath().c_str(), DocName);
+                Command::doCommand(Command::Gui, "Gui.SendMsgToActiveView(\"ViewFit\")");
                 if (getDocument(DocName))
                     getDocument(DocName)->setModified(true);
             }
@@ -577,6 +580,15 @@ void Application::slotNewDocument(const App::Document& Doc)
 #endif
     Gui::Document* pDoc = new Gui::Document(const_cast<App::Document*>(&Doc),this);
     d->documents[&Doc] = pDoc;
+
+    // connect the signals to the application for the new document
+    pDoc->signalNewObject.connect(boost::bind(&Gui::Application::slotNewObject, this, _1));
+    pDoc->signalDeletedObject.connect(boost::bind(&Gui::Application::slotDeletedObject, this, _1));
+    pDoc->signalChangedObject.connect(boost::bind(&Gui::Application::slotChangedObject, this, _1, _2));
+    pDoc->signalRenamedObject.connect(boost::bind(&Gui::Application::slotRenamedObject, this, _1));
+    pDoc->signalActivatedObject.connect(boost::bind(&Gui::Application::slotActivatedObject, this, _1));
+
+
     signalNewDocument(*pDoc);
     pDoc->createView("View3DIv");
     qApp->processEvents(); // make sure to show the window stuff on the right place
@@ -633,6 +645,31 @@ void Application::slotActiveDocument(const App::Document& Doc)
         signalActiveDocument(*doc->second);
 }
 
+void Application::slotNewObject(const ViewProvider& vp)
+{
+    this->signalNewObject(vp);
+}
+
+void Application::slotDeletedObject(const ViewProvider& vp)
+{
+    this->signalDeletedObject(vp);
+}
+
+void Application::slotChangedObject(const ViewProvider& vp, const App::Property& prop)
+{
+    this->signalChangedObject(vp,prop);
+}
+
+void Application::slotRenamedObject(const ViewProvider& vp)
+{
+    this->signalRenamedObject(vp);
+}
+
+void Application::slotActivatedObject(const ViewProvider& vp)
+{
+    this->signalActivatedObject(vp);
+}
+
 void Application::onLastWindowClosed(Gui::Document* pcDoc)
 {
     if (!d->isClosing && pcDoc) {
@@ -1214,7 +1251,7 @@ void Application::runCommand(bool bForce, const char* sCmd,...)
     free (format);
 }
 
-bool Application::runPythonCode(const char* cmd, bool gui)
+bool Application::runPythonCode(const char* cmd, bool gui, bool pyexc)
 {
     if (gui)
         d->macroMngr->addLine(MacroManager::Gui,cmd);
@@ -1226,8 +1263,13 @@ bool Application::runPythonCode(const char* cmd, bool gui)
         return true;
     }
     catch (Base::PyException &e) {
-        e.ReportException();
-        Base::Console().Error("Stack Trace: %s\n",e.getStackTrace().c_str());
+        if (pyexc) {
+            e.ReportException();
+            Base::Console().Error("Stack Trace: %s\n",e.getStackTrace().c_str());
+        }
+        else {
+            throw; // re-throw to handle in calling instance
+        }
     }
     catch (Base::AbortException&) {
     }
@@ -1318,14 +1360,20 @@ void messageHandlerSoQt(const SbString errmsg, SoQt::FatalErrors errcode, void *
 }
 #endif
 
+// To fix bug #0000345 move Q_INIT_RESOURCE() outside initApplication()
+static void init_resources()
+{
+    // init resources
+    Q_INIT_RESOURCE(resource);
+    Q_INIT_RESOURCE(translation);
+}
+
 void Application::initApplication(void)
 {
     try {
         initTypes();
         new Base::ScriptProducer( "FreeCADGuiInit", FreeCADGuiInit );
-        // add resources
-        Q_INIT_RESOURCE(resource);
-        Q_INIT_RESOURCE(translation);
+        init_resources();
         old_qtmsg_handler = qInstallMsgHandler(messageHandler);
     }
     catch (...) {
@@ -1370,11 +1418,11 @@ namespace Gui {
 /** Override QCoreApplication::notify() to fetch exceptions in Qt widgets
  * properly that are not handled in the event handler or slot.
  */
-class GUIApplication : public QApplication
+class GUIApplication : public GUIApplicationNativeEventAware
 {
 public:
     GUIApplication(int & argc, char ** argv)
-        : QApplication(argc, argv)
+        : GUIApplicationNativeEventAware(argc, argv)
     {
     }
 
@@ -1389,7 +1437,10 @@ public:
                 (int)event->type());
         }
         try {
-            return QApplication::notify(receiver, event);
+            if (event->type() == Spaceball::ButtonEvent::ButtonEventType)
+                return processSpaceballEvent(receiver, event);
+            else
+                return QApplication::notify(receiver, event);
         }
         catch (const Base::Exception& e) {
             Base::Console().Error("Unhandled Base::Exception caught in GUIApplication::notify.\n"
@@ -1504,11 +1555,41 @@ void Application::runApplication(void)
     MainWindow mw;
     mw.setWindowTitle(mainApp.applicationName());
 
+    // set toolbar icon size
+    ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("General");
+    int size = hGrp->GetInt("ToolbarIconSize", 0);
+    if (size >= 16) // must not be lower than this
+        mw.setIconSize(QSize(size,size));
+
     // init the Inventor subsystem
     SoDB::init();
     SoQt::init(&mw);
     SoFCDB::init();
 
+    const std::map<std::string,std::string>& cfg = App::Application::Config();
+    std::map<std::string,std::string>::const_iterator it;
+    it = cfg.find("WindowTitle");
+    if (it != cfg.end()) {
+        QString title = QString::fromUtf8(it->second.c_str());
+        mw.setWindowTitle(title);
+    }
+    it = cfg.find("WindowIcon");
+    if (it != cfg.end()) {
+        QString path = QString::fromUtf8(it->second.c_str());
+        QApplication::setWindowIcon(QIcon(path));
+    }
+    it = cfg.find("ProgramLogo");
+    if (it != cfg.end()) {
+        QString path = QString::fromUtf8(it->second.c_str());
+        QPixmap px(path);
+        if (!px.isNull()) {
+            QLabel* logo = new QLabel();
+            logo->setPixmap(px.scaledToHeight(32));
+            mw.statusBar()->addPermanentWidget(logo, 0);
+            logo->setFrameShape(QFrame::NoFrame);
+        }
+    }
+
     // show splasher while initializing the GUI
     mw.startSplasher();
 
@@ -1518,6 +1599,7 @@ void Application::runApplication(void)
     }
     catch (const Base::Exception& e) {
         Base::Console().Error("Error in FreeCADGuiInit.py: %s\n", e.what());
+        mw.stopSplasher();
         throw;
     }
 
@@ -1546,13 +1628,14 @@ void Application::runApplication(void)
     Base::Console().Log("Init: Showing main window\n");
     mw.loadWindowSettings();
 
+    //initialize spaceball.
+    mainApp.initSpaceball(&mw);
+
 #ifdef FC_DEBUG // redirect Coin messages to FreeCAD
     SoDebugError::setHandlerCallback( messageHandlerCoin, 0 );
     SoQt::setFatalErrorHandler( messageHandlerSoQt, 0 );
 #endif
 
-    // open the 'Iip of the day' dialog if needed
-    mw.showTipOfTheDay();
     Instance->d->startingUp = false;
 
 #if 0
@@ -1561,7 +1644,7 @@ void Application::runApplication(void)
 
     // Create new document?
     ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("Document");
-    if (hGrp->GetBool("CreateNewDoc", true)) {
+    if (hGrp->GetBool("CreateNewDoc", false)) {
         App::GetApplication().newDocument();
     }
 #else
