@@ -41,6 +41,7 @@
 #include "WorkbenchManager.h"
 #include "Language/Translator.h"
 #include <App/DocumentObjectPy.h>
+#include <App/PropertyFile.h>
 #include <Base/Interpreter.h>
 #include <Base/Console.h>
 #include <CXX/Objects.hxx>
@@ -67,10 +68,13 @@ PyMethodDef Application::Methods[] = {
   {"activeWorkbench", (PyCFunction) Application::sActiveWorkbenchHandler,   1,
    "activeWorkbench() -> object\n\n"
    "Return the active workbench object"},
-  {"addResourcePath",             (PyCFunction) Application::sAddIconPath,      1,
+  {"addResourcePath",             (PyCFunction) Application::sAddResPath,      1,
    "addResourcePath(string) -> None\n\n"
    "Add a new path to the system where to find resource files\n"
    "like icons or localization files"},
+  {"addLanguagePath",             (PyCFunction) Application::sAddLangPath,      1,
+   "addLanguagePath(string) -> None\n\n"
+   "Add a new path to the system where to find language files"},
   {"addIconPath",             (PyCFunction) Application::sAddIconPath,      1,
    "addIconPath(string) -> None\n\n"
    "Add a new path to the system where to find icon files"},
@@ -83,6 +87,9 @@ PyMethodDef Application::Methods[] = {
   {"updateLocale",            (PyCFunction) Application::sUpdateLocale,     1,
    "updateLocale() -> None\n\n"
    "Update the localization"},
+  {"getLocale",            (PyCFunction) Application::sGetLocale,     1,
+   "getLocale() -> string\n\n"
+   "Returns the locale currently used by FreeCAD"},
   {"createDialog",            (PyCFunction) Application::sCreateDialog,     1,
    "createDialog(string) -- Open a UI file"},
   {"addPreferencePage",       (PyCFunction) Application::sAddPreferencePage,1,
@@ -123,7 +130,7 @@ PyMethodDef Application::Methods[] = {
   {NULL, NULL}		/* Sentinel */
 };
 
-PyObject* Application::sActiveDocument(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
+PyObject* Gui::Application::sActiveDocument(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
 {
     if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C 
         return NULL;                       // NULL triggers exception 
@@ -265,8 +272,8 @@ PyObject* Application::sOpen(PyObject * /*self*/, PyObject *args,PyObject * /*kw
 PyObject* Application::sInsert(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
 {
     const char* Name;
-    const char* DocName;
-    if (!PyArg_ParseTuple(args, "ss",&Name,&DocName))
+    const char* DocName=0;
+    if (!PyArg_ParseTuple(args, "s|s",&Name,&DocName))
         return NULL;
 
     PY_TRY {
@@ -275,26 +282,38 @@ PyObject* Application::sInsert(PyObject * /*self*/, PyObject *args,PyObject * /*
         fi.setFile(fileName);
         QString ext = fi.completeSuffix().toLower();
         if (ext == QLatin1String("iv")) {
-            //QString cmd = QString("Gui.activeDocument().addAnnotation(\"%1\",\"%2\")").arg(fi.baseName()).arg(fi.absoluteFilePath());
-            QString cmd = QString::fromLatin1(
-                "App.ActiveDocument.addObject(\"App::InventorObject\",\"%1\")."
-                "FileName=\"%2\"\n"
-                "App.ActiveDocument.ActiveObject.Label=\"%1\"\n"
-                "App.ActiveDocument.recompute()")
-                .arg(fi.baseName()).arg(fi.absoluteFilePath());
-            Base::Interpreter().runString(cmd.toUtf8());
+            App::Document *doc = 0;
+            if (DocName)
+                doc = App::GetApplication().getDocument(DocName);
+            else
+                doc = App::GetApplication().getActiveDocument();
+            if (!doc)
+                doc = App::GetApplication().newDocument(DocName);
+
+            App::DocumentObject* obj = doc->addObject("App::InventorObject",
+                (const char*)fi.baseName().toUtf8());
+            obj->Label.setValue((const char*)fi.baseName().toUtf8());
+            static_cast<App::PropertyString*>(obj->getPropertyByName("FileName"))
+                ->setValue((const char*)fi.absoluteFilePath().toUtf8());
+            doc->recompute();
         }
         else if (ext == QLatin1String("wrl") ||
                  ext == QLatin1String("vrml") ||
                  ext == QLatin1String("wrz")) {
-            //QString cmd = QString("Gui.activeDocument().addAnnotation(\"%1\",\"%2\")").arg(fi.baseName()).arg(fi.absoluteFilePath());
-            QString cmd = QString::fromLatin1(
-                "App.ActiveDocument.addObject(\"App::VRMLObject\",\"%1\")."
-                "VrmlFile=\"%2\"\n"
-                "App.ActiveDocument.ActiveObject.Label=\"%1\"\n"
-                "App.ActiveDocument.recompute()")
-                .arg(fi.baseName()).arg(fi.absoluteFilePath());
-            Base::Interpreter().runString(cmd.toUtf8());
+            App::Document *doc = 0;
+            if (DocName)
+                doc = App::GetApplication().getDocument(DocName);
+            else
+                doc = App::GetApplication().getActiveDocument();
+            if (!doc)
+                doc = App::GetApplication().newDocument(DocName);
+
+            App::DocumentObject* obj = doc->addObject("App::VRMLObject",
+                (const char*)fi.baseName().toUtf8());
+            obj->Label.setValue((const char*)fi.baseName().toUtf8());
+            static_cast<App::PropertyFileIncluded*>(obj->getPropertyByName("VrmlFile"))
+                ->setValue((const char*)fi.absoluteFilePath().toUtf8());
+            doc->recompute();
         }
         else if (ext == QLatin1String("py") || ext == QLatin1String("fcmacro") ||
                  ext == QLatin1String("fcscript")) {
@@ -390,6 +409,15 @@ PyObject* Application::sUpdateLocale(PyObject * /*self*/, PyObject *args,PyObjec
     return Py_None;
 } 
 
+PyObject* Application::sGetLocale(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
+{
+    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C 
+        return NULL;                                      // NULL triggers exception 
+
+    std::string locale = Translator::instance()->activeLanguage();
+    return PyString_FromString(locale.c_str());
+} 
+
 PyObject* Application::sCreateDialog(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
 {
     char* fn = 0;
@@ -415,7 +443,7 @@ PyObject* Application::sAddPreferencePage(PyObject * /*self*/, PyObject *args,Py
     if (!PyArg_ParseTuple(args, "ss", &fn,&grp))     // convert args: Python->C 
         return NULL;                                      // NULL triggers exception 
 
-    Base::FileInfo fi(fn);
+    QFileInfo fi(QString::fromUtf8(fn));
     if (!fi.exists()) {
         PyErr_SetString(PyExc_RuntimeError, "UI file does not exist");
         return 0;
@@ -572,6 +600,41 @@ PyObject* Application::sActiveWorkbenchHandler(PyObject * /*self*/, PyObject *ar
     return pcWorkbench;
 } 
 
+PyObject* Application::sAddResPath(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
+{
+    char* filePath;
+    if (!PyArg_ParseTuple(args, "s", &filePath))     // convert args: Python->C
+        return NULL;                    // NULL triggers exception
+    QString path = QString::fromUtf8(filePath);
+    if (QDir::isRelativePath(path)) {
+        // Home path ends with '/'
+        QString home = QString::fromUtf8(App::GetApplication().GetHomePath());
+        path = home + path;
+    }
+
+    BitmapFactory().addPath(path);
+    Translator::instance()->addPath(path);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+PyObject* Application::sAddLangPath(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
+{
+    char* filePath;
+    if (!PyArg_ParseTuple(args, "s", &filePath))     // convert args: Python->C
+        return NULL;                    // NULL triggers exception
+    QString path = QString::fromUtf8(filePath);
+    if (QDir::isRelativePath(path)) {
+        // Home path ends with '/'
+        QString home = QString::fromUtf8(App::GetApplication().GetHomePath());
+        path = home + path;
+    }
+
+    Translator::instance()->addPath(path);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 PyObject* Application::sAddIconPath(PyObject * /*self*/, PyObject *args,PyObject * /*kwd*/)
 {
     char* filePath;
@@ -585,7 +648,6 @@ PyObject* Application::sAddIconPath(PyObject * /*self*/, PyObject *args,PyObject
     }
 
     BitmapFactory().addPath(path);
-    Translator::instance()->addPath(path);
     Py_INCREF(Py_None);
     return Py_None;
 }
