@@ -34,6 +34,16 @@
 # include <QPalette>
 # include <QSvgRenderer>
 # include <QStyleOption>
+# include <sstream>
+#endif
+
+#ifdef FC_OS_WIN32
+#define QTWEBKIT
+#endif
+
+#ifdef QTWEBKIT
+#include <QWebView>
+#include <QWebFrame>
 #endif
 
 #include <string>
@@ -88,6 +98,7 @@ void BitmapFactoryInst::destruct (void)
 BitmapFactoryInst::BitmapFactoryInst()
 {
     d = new BitmapFactoryInstP;
+    restoreCustomPaths();
 }
 
 BitmapFactoryInst::~BitmapFactoryInst()
@@ -95,6 +106,26 @@ BitmapFactoryInst::~BitmapFactoryInst()
     delete d;
 }
 
+void BitmapFactoryInst::addCustomPath(const QString& path)
+{
+    Base::Reference<ParameterGrp> group = App::GetApplication().GetParameterGroupByPath
+        ("User parameter:BaseApp/Preferences/Bitmaps");
+    std::vector<std::string> paths = group->GetASCIIs("CustomPath");
+    std::stringstream str;
+    str << "CustomPath" << paths.size();
+    group->SetASCII(str.str().c_str(), (const char*)path.toUtf8());
+}
+
+void BitmapFactoryInst::restoreCustomPaths()
+{
+    Base::Reference<ParameterGrp> group = App::GetApplication().GetParameterGroupByPath
+        ("User parameter:BaseApp/Preferences/Bitmaps");
+    std::vector<std::string> paths = group->GetASCIIs("CustomPath");
+    for (std::vector<std::string>::iterator it = paths.begin(); it != paths.end(); ++it) {
+        addPath(QString::fromUtf8(it->c_str()));
+    }
+}
+
 void BitmapFactoryInst::addPath(const QString& path)
 {
     d->paths.push_back(path);
@@ -169,6 +200,11 @@ QPixmap BitmapFactoryInst::pixmap(const char* name) const
     if (icon.isNull() && QFile(fn).exists())
         icon.load(fn);
 
+    // first check if it's an SVG because Qt's qsvg4 module shouldn't be used therefore
+    if (icon.isNull()) {
+        icon = pixmapFromSvg(name, QSize(24,24));
+    }
+
     // try to find it in the given directories
     if (icon.isNull()) {
         bool found = false;
@@ -194,11 +230,6 @@ QPixmap BitmapFactoryInst::pixmap(const char* name) const
         }
     }
 
-    // as last possibility check if it's an SVG
-    if (icon.isNull()) {
-        icon = pixmapFromSvg(name, QSize(24,24));
-    }
-
     if (!icon.isNull()) {
         d->xpmCache[name] = icon;
         return icon;
@@ -238,18 +269,8 @@ QPixmap BitmapFactoryInst::pixmapFromSvg(const char* name, const QSize& size) co
     if (!iconPath.isEmpty()) {
         QFile file(iconPath);
         if (file.open(QFile::ReadOnly | QFile::Text)) {
-#if QT_VERSION >= 0x040400
-            // SVG graphics can be directly loaded
-            if (icon.load(iconPath))
-                icon = icon.scaled(size);
-            else {
-                QByteArray content = file.readAll();
-                icon = pixmapFromSvg(content, size);
-            }
-#else
             QByteArray content = file.readAll();
             icon = pixmapFromSvg(content, size);
-#endif
         }
     }
 
@@ -258,17 +279,49 @@ QPixmap BitmapFactoryInst::pixmapFromSvg(const char* name, const QSize& size) co
 
 QPixmap BitmapFactoryInst::pixmapFromSvg(const QByteArray& contents, const QSize& size) const
 {
+#ifdef QTWEBKIT
+    QWebView webView;
+    QPalette pal = webView.palette();
+    pal.setColor(QPalette::Background, Qt::transparent);
+    webView.setPalette(pal);
+    webView.setContent(contents, QString::fromAscii("image/svg+xml"));
+    QString node = QString::fromAscii("document.rootElement.nodeName");
+    QString root = webView.page()->mainFrame()->evaluateJavaScript(node).toString();
+    if (root.isEmpty() || root.compare(QLatin1String("svg"), Qt::CaseInsensitive)) {
+        return QPixmap();
+    }
+
+    QString w = QString::fromAscii("document.rootElement.width.baseVal.value");
+    QString h = QString::fromAscii("document.rootElement.height.baseVal.value");
+    double ww = webView.page()->mainFrame()->evaluateJavaScript(w).toDouble();
+    double hh = webView.page()->mainFrame()->evaluateJavaScript(h).toDouble();
+    if (ww == 0.0 || hh == 0.0)
+        return QPixmap();
+#endif
+
     QImage image(size, QImage::Format_ARGB32_Premultiplied);
     image.fill(0x00000000);
 
     QPainter p(&image);
+#ifdef QTWEBKIT
+    qreal xs = size.isValid() ? size.width() / ww : 1.0;
+    qreal ys = size.isValid() ? size.height() / hh : 1.0;
+    p.scale(xs, ys);
+
+    // the best quality
+    p.setRenderHint(QPainter::Antialiasing);
+    p.setRenderHint(QPainter::TextAntialiasing);
+    p.setRenderHint(QPainter::SmoothPixmapTransform);
+    p.setOpacity(0); // important to keep transparent background
+    webView.page()->mainFrame()->render(&p);
+#else
     // tmp. disable the report window to suppress some bothering warnings
     Base::Console().SetEnabledMsgType("ReportOutput", ConsoleMsgType::MsgType_Wrn, false);
-    QSvgRenderer* svg = new QSvgRenderer(contents);
+    QSvgRenderer svg(contents);
     Base::Console().SetEnabledMsgType("ReportOutput", ConsoleMsgType::MsgType_Wrn, true);
-    svg->render(&p);
+    svg.render(&p);
+#endif
     p.end();
-    delete svg;
 
     return QPixmap::fromImage(image);
 }
