@@ -39,8 +39,10 @@ using namespace Gui;
 using namespace Gui::DockWnd;
 
 
+/* TRANSLATOR Gui::DockWnd::CombiView */
+
 CombiView::CombiView(Gui::Document* pcDocument, QWidget *parent)
-  : DockWindow(pcDocument,parent)
+  : DockWindow(pcDocument,parent), oldTabIndex(0)
 {
     setWindowTitle(tr("CombiView"));
 
@@ -82,6 +84,7 @@ CombiView::~CombiView()
 void CombiView::showDialog(Gui::TaskView::TaskDialog *dlg)
 {
     // switch to the TaskView tab
+    oldTabIndex = tabs->currentIndex();
     tabs->setCurrentIndex(1);
     // set the dialog
     taskPanel->showDialog(dlg);
@@ -93,11 +96,33 @@ void CombiView::closeDialog()
     taskPanel->removeDialog();
 }
 
+void CombiView::closedDialog()
+{
+    // dialog has been closed
+    tabs->setCurrentIndex(oldTabIndex);
+}
+
 void CombiView::showTreeView()
 {
-    // switch to the TreeView tab
+    // switch to the tree view
     tabs->setCurrentIndex(0);
 }
 
+void CombiView::showTaskView()
+{
+    // switch to the task view
+    tabs->setCurrentIndex(1);
+}
+
+void CombiView::changeEvent(QEvent *e)
+{
+    if (e->type() == QEvent::LanguageChange) {
+        tabs->setTabText(0, trUtf8("Project"));
+        tabs->setTabText(1, trUtf8("Tasks"));
+    }
+
+    DockWindow::changeEvent(e);
+}
+
 
 #include "moc_CombiView.cpp"
