@@ -99,7 +99,7 @@ using namespace Gui::DockWnd;
  *     sWhatsThis    = "Open a file";
  *     sStatusTip    = "Open a file";
  *     sPixmap       = "Open"; // name of a registered pixmap
- *     iAccel        = Qt::CTRL+Qt::Key_O;
+ *     sAccel        = "Shift+P"; // or "P" or "P, L" or "Ctrl+X, Ctrl+C" for a sequence
  *   }
  * protected:
  *   void activated(int)
@@ -119,9 +119,9 @@ using namespace Gui::DockWnd;
  */
 
 CommandBase::CommandBase( const char* sMenu, const char* sToolTip, const char* sWhat,
-                          const char* sStatus, const char* sPixmap, int iAcc)
+                          const char* sStatus, const char* sPixmap, const char* sAcc)
         : sMenuText(sMenu), sToolTipText(sToolTip), sWhatsThis(sWhat?sWhat:sToolTip),
-        sStatusTip(sStatus?sStatus:sToolTip), sPixmap(sPixmap), iAccel(iAcc), _pcAction(0)
+        sStatusTip(sStatus?sStatus:sToolTip), sPixmap(sPixmap), sAccel(sAcc), _pcAction(0)
 {
 }
 
@@ -188,9 +188,13 @@ void CommandBase::setPixmap(const char* s)
 #endif
 }
 
-void CommandBase::setAccel(int i)
+void CommandBase::setAccel(const char* s)
 {
-    iAccel = i;
+#if defined (_MSC_VER)
+    this->sAccel = _strdup(s);
+#else
+    this->sAccel = strdup(s);
+#endif
 }
 
 //===========================================================================
@@ -420,6 +424,15 @@ void Command::doCommand(DoCmd_Type eType,const char* sCmd,...)
     free (format);
 }
 
+void Command::copyVisual(const char* to, const char* attr, const char* from)
+{
+    doCommand(Gui,"Gui.ActiveDocument.%s.%s=Gui.ActiveDocument.%s.%s", to, attr, from, attr);
+}
+
+void Command::copyVisual(const char* to, const char* attr_to, const char* from, const char* attr_from)
+{
+    doCommand(Gui,"Gui.ActiveDocument.%s.%s=Gui.ActiveDocument.%s.%s", to, attr_to, from, attr_from);
+}
 
 const std::string Command::strToPython(const char* Str)
 {
@@ -430,9 +443,17 @@ const std::string Command::strToPython(const char* Str)
 void Command::updateActive(void)
 {
     WaitCursor wc;
+    doCommand(Gui,"App.ActiveDocument.recompute()");
+}
 
-    Gui::Application::Instance->activeDocument()->getDocument()->recompute();
-    //getGuiApplication()->UpdateActive();
+bool Command::isActiveObjectValid(void)
+{
+    Gui::Document* active = Gui::Application::Instance->activeDocument();
+    assert(active);
+    App::Document* document = active->getDocument();
+    App::DocumentObject* object = document->getActiveObject();
+    assert(object);
+    return object->isValid();
 }
 
 /// Updates the (all or listed) documents (propagate changes)
@@ -495,12 +516,17 @@ void Command::applyCommandData(Action* action)
             QCoreApplication::CodecForTr));
 }
 
-int Command::keySequenceToAccel(int sk) const
+const char* Command::keySequenceToAccel(int sk) const
 {
     QKeySequence::StandardKey type = (QKeySequence::StandardKey)sk;
     QKeySequence ks(type);
-    QVariant v = QVariant::fromValue<QKeySequence>(ks);
-    return v.toInt();
+    QString qs = ks.toString();
+    QByteArray data = qs.toAscii();
+#if defined (_MSC_VER)
+    return _strdup((const char*)data);
+#else
+    return strdup((const char*)data);
+#endif
 }
 
 void Command::adjustCameraPosition()
@@ -551,7 +577,7 @@ Action * Command::createAction(void)
     applyCommandData(pcAction);
     if (sPixmap)
         pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(iAccel);
+      pcAction->setShortcut(QString::fromAscii(sAccel));
 
     return pcAction;
 }
@@ -603,7 +629,7 @@ Action * MacroCommand::createAction(void)
     pcAction->setWhatsThis(QString::fromUtf8(sWhatsThis));
     if ( sPixmap )
         pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(iAccel);
+      pcAction->setShortcut(QString::fromAscii(sAccel));
     return pcAction;
 }
 
@@ -632,7 +658,7 @@ void MacroCommand::load()
             macro->setStatusTip   ( (*it)->GetASCII( "Statustip"  ).c_str() );
             if ((*it)->GetASCII("Pixmap", "nix") != "nix")
                 macro->setPixmap    ( (*it)->GetASCII( "Pixmap"     ).c_str() );
-            macro->setAccel       ( (*it)->GetInt  ( "Accel",0    )         );
+            macro->setAccel       ( (*it)->GetASCII( "Accel",0    ).c_str() );
             Application::Instance->commandManager().addCommand( macro );
         }
     }
@@ -654,7 +680,7 @@ void MacroCommand::save()
             hMacro->SetASCII( "WhatsThis", macro->getWhatsThis  () );
             hMacro->SetASCII( "Statustip", macro->getStatusTip  () );
             hMacro->SetASCII( "Pixmap",    macro->getPixmap     () );
-            hMacro->SetInt  ( "Accel",     macro->getAccel      () );
+            hMacro->SetASCII( "Accel",     macro->getAccel      () );
         }
     }
 }
@@ -773,6 +799,7 @@ Action * PythonCommand::createAction(void)
         pcAction->setStatusTip(qApp->translate(getName(), getToolTipText()));
     if (strcmp(getResource("Pixmap"),"") != 0)
         pcAction->setIcon(Gui::BitmapFactory().pixmap(getResource("Pixmap")));
+    pcAction->setShortcut     (QString::fromAscii(getAccel()));
 
     return pcAction;
 }
@@ -805,9 +832,9 @@ const char* PythonCommand::getPixmap() const
     return getResource("Pixmap");
 }
 
-int PythonCommand::getAccel() const
+const char* PythonCommand::getAccel() const
 {
-    return 0;
+    return getResource("Accel");
 }
 
 //===========================================================================
