@@ -33,6 +33,7 @@
 #include <Base/Type.h>
 
 class QWidget;
+typedef struct _object PyObject;
 
 namespace App
 {
@@ -70,7 +71,7 @@ class GuiExport CommandBase
 {
 public:
     CommandBase(const char* sMenu, const char* sToolTip=0, const char* sWhat=0, 
-                const char* sStatus=0, const char* sPixmap=0, int accel=0);
+                const char* sStatus=0, const char* sPixmap=0, const char* sAccel=0);
     virtual ~CommandBase();
 
     /**
@@ -97,7 +98,7 @@ public:
     virtual const char* getStatusTip  () const { return sStatusTip;   }
     virtual const char* getWhatsThis  () const { return sWhatsThis;   }
     virtual const char* getPixmap     () const { return sPixmap;      }
-    virtual int         getAccel      () const { return iAccel;       }
+    virtual const char* getAccel      () const { return sAccel;       }
     //@}
 
     /** @name Methods to set the properties of the command */
@@ -107,7 +108,7 @@ public:
     void setToolTipText(const char*);
     void setStatusTip  (const char*);
     void setPixmap     (const char*);
-    void setAccel      (int        );
+    void setAccel      (const char*);
     //@}
 
 protected:
@@ -123,7 +124,7 @@ protected:
     const char* sWhatsThis;
     const char* sStatusTip;
     const char* sPixmap;
-    int         iAccel;
+    const char* sAccel;
     //@}
 protected:
     Action *_pcAction; /**< The Action item. */
@@ -160,7 +161,7 @@ protected:
     virtual Action * createAction(void);
     /// Applies the menu text, tool and status tip to the passed action object
     void applyCommandData(Action* );
-    int keySequenceToAccel(int) const;
+    const char* keySequenceToAccel(int) const;
     void adjustCameraPosition();
     //@}
 
@@ -212,6 +213,8 @@ public:
     static void updateActive(void);
     /// Updates the (all or listed) documents (propagate changes)
     static void updateAll(std::list<Gui::Document*> cList);
+    /// Checks if the active object of the active document is valid
+    static bool isActiveObjectValid(void);
     /// Translate command
     void languageChange();
     //@}
@@ -231,6 +234,8 @@ public:
     static void blockCommand(bool);
     /// Run a App level Action 
     static void doCommand(DoCmd_Type eType,const char* sCmd,...);
+    static void copyVisual(const char* to, const char* attr, const char* from);
+    static void copyVisual(const char* to, const char* attr_to, const char* from, const char* attr_from);
     /// import an external module only once 
     //static void addModule(const char* sModuleName);
     /// translate a string to a python string literal (needed e.g. in file names for windows...)
@@ -330,7 +335,7 @@ public:
     const char* getToolTipText() const;
     const char* getStatusTip  () const;
     const char* getPixmap     () const;
-    int         getAccel      () const;
+    const char* getAccel      () const;
     //@}
 
 protected:
