@@ -47,6 +47,7 @@
 #include "BitmapFactory.h"
 #include "Selection.h"
 #include "DlgProjectInformationImp.h"
+#include "DlgProjectUtility.h"
 #include "Transform.h"
 #include "Placement.h"
 #include "WaitCursor.h"
@@ -72,7 +73,7 @@ StdCmdOpen::StdCmdOpen()
     sWhatsThis    = "Std_Open";
     sStatusTip    = QT_TR_NOOP("Open a document or import files");
     sPixmap       = "document-open";
-    iAccel        = keySequenceToAccel(QKeySequence::Open);
+    sAccel        = keySequenceToAccel(QKeySequence::Open);
 }
 
 void StdCmdOpen::activated(int iMsg)
@@ -142,7 +143,7 @@ StdCmdImport::StdCmdImport()
     sWhatsThis    = "Std_Import";
     sStatusTip    = QT_TR_NOOP("Import a file in the active document");
     //sPixmap       = "Open";
-    iAccel        = Qt::CTRL+Qt::Key_I;
+    sAccel        = "Ctrl+I";
 }
 
 void StdCmdImport::activated(int iMsg)
@@ -211,7 +212,8 @@ StdCmdExport::StdCmdExport()
     sWhatsThis    = "Std_Export";
     sStatusTip    = QT_TR_NOOP("Export an object in the active document");
     //sPixmap       = "Open";
-    iAccel        = Qt::CTRL+Qt::Key_E;
+    sAccel        = "Ctrl+E";
+    eType         = 0;
 }
 
 void StdCmdExport::activated(int iMsg)
@@ -329,7 +331,7 @@ StdCmdNew::StdCmdNew()
   sWhatsThis    = "Std_New";
   sStatusTip    = QT_TR_NOOP("Create a new empty document");
   sPixmap       = "document-new";
-  iAccel        = keySequenceToAccel(QKeySequence::New);
+  sAccel        = keySequenceToAccel(QKeySequence::New);
 }
 
 void StdCmdNew::activated(int iMsg)
@@ -351,7 +353,8 @@ StdCmdSave::StdCmdSave()
   sWhatsThis    = "Std_Save";
   sStatusTip    = QT_TR_NOOP("Save the active document");
   sPixmap       = "document-save";
-  iAccel        = keySequenceToAccel(QKeySequence::Save);
+  sAccel        = keySequenceToAccel(QKeySequence::Save);
+  eType         = 0;
 }
 
 void StdCmdSave::activated(int iMsg)
@@ -391,7 +394,7 @@ StdCmdSaveAs::StdCmdSaveAs()
 #if QT_VERSION >= 0x040200
   sPixmap       = "document-save-as";
 #endif
-  iAccel        = 0;
+  sAccel        = keySequenceToAccel(QKeySequence::SaveAs);
 }
 
 void StdCmdSaveAs::activated(int iMsg)
@@ -446,6 +449,34 @@ bool StdCmdProjectInfo::isActive(void)
   return ( getActiveGuiDocument() ? true : false );
 }
 
+//===========================================================================
+// Std_ProjectUtil
+//===========================================================================
+
+DEF_STD_CMD_A(StdCmdProjectUtil);
+
+StdCmdProjectUtil::StdCmdProjectUtil()
+  :Command("Std_ProjectUtil")
+{
+    // seting the 
+    sGroup        = QT_TR_NOOP("Tools");
+    sWhatsThis    = "Std_ProjectUtil";
+    sMenuText     = QT_TR_NOOP("Project utility...");
+    sToolTipText  = QT_TR_NOOP("Utility to extract or create project files");
+    sStatusTip    = QT_TR_NOOP("Utility to extract or create project files");
+}
+
+void StdCmdProjectUtil::activated(int iMsg)
+{
+    Gui::Dialog::DlgProjectUtility dlg(getMainWindow());
+    dlg.exec();
+}
+
+bool StdCmdProjectUtil::isActive(void)
+{
+    return true;
+}
+
 //===========================================================================
 // Std_Print
 //===========================================================================
@@ -460,7 +491,7 @@ StdCmdPrint::StdCmdPrint()
     sWhatsThis    = "Std_Print";
     sStatusTip    = QT_TR_NOOP("Print the document");
     sPixmap       = "document-print";
-    iAccel        = keySequenceToAccel(QKeySequence::Print);
+    sAccel        = keySequenceToAccel(QKeySequence::Print);
 }
 
 void StdCmdPrint::activated(int iMsg)
@@ -476,6 +507,33 @@ bool StdCmdPrint::isActive(void)
     return getGuiApplication()->sendHasMsgToActiveView("Print");
 }
 
+//===========================================================================
+// Std_PrintPreview
+//===========================================================================
+DEF_STD_CMD_A(StdCmdPrintPreview);
+
+StdCmdPrintPreview::StdCmdPrintPreview()
+  :Command("Std_PrintPreview")
+{
+    sGroup        = QT_TR_NOOP("File");
+    sMenuText     = QT_TR_NOOP("&Print preview...");
+    sToolTipText  = QT_TR_NOOP("Print the document");
+    sWhatsThis    = "Std_PrintPreview";
+    sStatusTip    = QT_TR_NOOP("Print preview");
+}
+
+void StdCmdPrintPreview::activated(int iMsg)
+{
+    if (getMainWindow()->activeWindow()) {
+        getMainWindow()->activeWindow()->printPreview();
+    }
+}
+
+bool StdCmdPrintPreview::isActive(void)
+{
+    return getGuiApplication()->sendHasMsgToActiveView("PrintPreview");
+}
+
 //===========================================================================
 // Std_PrintPdf
 //===========================================================================
@@ -521,7 +579,7 @@ StdCmdQuit::StdCmdQuit()
 #if QT_VERSION >= 0x040200
   sPixmap       = "system-log-out";
 #endif
-  iAccel        = Qt::ALT+Qt::Key_F4;
+  sAccel        = "Alt+F4";
 }
 
 void StdCmdQuit::activated(int iMsg)
@@ -545,7 +603,8 @@ StdCmdUndo::StdCmdUndo()
   sWhatsThis    = "Std_Undo";
   sStatusTip    = QT_TR_NOOP("Undo exactly one action");
   sPixmap       = "edit-undo";
-  iAccel        = keySequenceToAccel(QKeySequence::Undo);
+  sAccel        = keySequenceToAccel(QKeySequence::Undo);
+  eType         = ForEdit;
 }
 
 void StdCmdUndo::activated(int iMsg)
@@ -567,7 +626,7 @@ Action * StdCmdUndo::createAction(void)
     applyCommandData(pcAction);
     if (sPixmap)
         pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(iAccel);
+    pcAction->setShortcut(QString::fromAscii(sAccel));
 
     return pcAction;
 }
@@ -587,7 +646,8 @@ StdCmdRedo::StdCmdRedo()
   sWhatsThis    = "Std_Redo";
   sStatusTip    = QT_TR_NOOP("Redoes a previously undone action");
   sPixmap       = "edit-redo";
-  iAccel        = keySequenceToAccel(QKeySequence::Redo);
+  sAccel        = keySequenceToAccel(QKeySequence::Redo);
+  eType         = ForEdit;
 }
 
 void StdCmdRedo::activated(int iMsg)
@@ -609,7 +669,7 @@ Action * StdCmdRedo::createAction(void)
     applyCommandData(pcAction);
     if (sPixmap)
         pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(iAccel);
+    pcAction->setShortcut(QString::fromAscii(sAccel));
 
     return pcAction;
 }
@@ -628,7 +688,7 @@ StdCmdCut::StdCmdCut()
     sWhatsThis    = "Std_Cut";
     sStatusTip    = QT_TR_NOOP("Cut out");
     sPixmap       = "edit-cut";
-    iAccel        = keySequenceToAccel(QKeySequence::Cut);
+    sAccel        = keySequenceToAccel(QKeySequence::Cut);
 }
 
 void StdCmdCut::activated(int iMsg)
@@ -655,7 +715,7 @@ StdCmdCopy::StdCmdCopy()
     sWhatsThis    = "Std_Copy";
     sStatusTip    = QT_TR_NOOP("Copy operation");
     sPixmap       = "edit-copy";
-    iAccel        = keySequenceToAccel(QKeySequence::Copy);
+    sAccel        = keySequenceToAccel(QKeySequence::Copy);
 }
 
 void StdCmdCopy::activated(int iMsg)
@@ -690,7 +750,7 @@ StdCmdPaste::StdCmdPaste()
     sWhatsThis    = "Std_Paste";
     sStatusTip    = QT_TR_NOOP("Paste operation");
     sPixmap       = "edit-paste";
-    iAccel        = keySequenceToAccel(QKeySequence::Paste);
+    sAccel        = keySequenceToAccel(QKeySequence::Paste);
 }
 
 void StdCmdPaste::activated(int iMsg)
@@ -764,6 +824,7 @@ void StdCmdDDuplicateSelection::activated(int iMsg)
         // copy the properties of the associated view providers
         Gui::ViewProvider* view = parent->getViewProvider(it->pObject);
         Gui::ViewProvider* copy_view = doc->getViewProvider(copy);
+        copy_view->addDynamicProperties(view);
         if (!view || !copy_view)
             continue; // should not happen
 
@@ -807,7 +868,7 @@ StdCmdSelectAll::StdCmdSelectAll()
 #if QT_VERSION >= 0x040200
     sPixmap       = "edit-select-all";
 #endif
-    //iAccel        = Qt::CTRL+Qt::Key_A; // superseeds shortcuts for text edits
+    //sAccel        = "Ctrl+A"; // superseeds shortcuts for text edits
 }
 
 void StdCmdSelectAll::activated(int iMsg)
@@ -839,7 +900,8 @@ StdCmdDelete::StdCmdDelete()
 #if QT_VERSION >= 0x040200
   sPixmap       = "edit-delete";
 #endif
-  iAccel        = keySequenceToAccel(QKeySequence::Delete);
+  sAccel        = keySequenceToAccel(QKeySequence::Delete);
+  eType         = ForEdit;
 }
 
 void StdCmdDelete::activated(int iMsg)
@@ -847,16 +909,19 @@ void StdCmdDelete::activated(int iMsg)
     // go through all documents
     const SelectionSingleton& rSel = Selection();
     const std::vector<App::Document*> docs = App::GetApplication().getDocuments();
-    for ( std::vector<App::Document*>::const_iterator it = docs.begin(); it != docs.end(); ++it ) {
-        const std::vector<App::DocumentObject*> sel = rSel.getObjectsOfType(App::DocumentObject::getClassTypeId(), (*it)->getName());
+    for (std::vector<App::Document*>::const_iterator it = docs.begin(); it != docs.end(); ++it) {
+        Gui::Document* pGuiDoc = Gui::Application::Instance->getDocument(*it);
+        std::vector<Gui::SelectionObject> sel = rSel.getSelectionEx((*it)->getName());
         if (!sel.empty()) {
             (*it)->openTransaction("Delete");
-            for(std::vector<App::DocumentObject*>::const_iterator ft=sel.begin();ft!=sel.end();ft++) {
-                if ((*ft)->getTypeId().isDerivedFrom(App::DocumentObjectGroup::getClassTypeId()))
-                doCommand(Doc,"App.getDocument(\"%s\").getObject(\"%s\").removeObjectsFromDocument()"
-                             ,(*it)->getName(), (*ft)->getNameInDocument());
-                doCommand(Doc,"App.getDocument(\"%s\").removeObject(\"%s\")"
-                             ,(*it)->getName(), (*ft)->getNameInDocument());
+            for (std::vector<Gui::SelectionObject>::iterator ft = sel.begin(); ft != sel.end(); ++ft) {
+                Gui::ViewProvider* vp = pGuiDoc->getViewProvider(ft->getObject());
+                if (vp) {
+                    // ask the ViewProvider if its want to do some clean up
+                    if (vp->onDelete(ft->getSubNames()))
+                        doCommand(Doc,"App.getDocument(\"%s\").removeObject(\"%s\")"
+                                 ,(*it)->getName(), ft->getFeatName());
+                }
             }
             (*it)->commitTransaction();
         }
@@ -865,7 +930,7 @@ void StdCmdDelete::activated(int iMsg)
 
 bool StdCmdDelete::isActive(void)
 {
-  return Selection().getCompleteSelection().size() > 0;
+    return Selection().getCompleteSelection().size() > 0;
 }
 
 //===========================================================================
@@ -882,7 +947,7 @@ StdCmdRefresh::StdCmdRefresh()
   sWhatsThis    = "Std_Refresh";
   sStatusTip    = QT_TR_NOOP("Recomputes the current active document");
   sPixmap       = "view-refresh";
-  iAccel        = keySequenceToAccel(QKeySequence::Refresh);
+  sAccel        = keySequenceToAccel(QKeySequence::Refresh);
 }
 
 void StdCmdRefresh::activated(int iMsg)
@@ -973,9 +1038,11 @@ void CreateDocCommands(void)
     rcCmdMgr.addCommand(new StdCmdSave());
     rcCmdMgr.addCommand(new StdCmdSaveAs());
     rcCmdMgr.addCommand(new StdCmdProjectInfo());
+    rcCmdMgr.addCommand(new StdCmdProjectUtil());
     rcCmdMgr.addCommand(new StdCmdUndo());
     rcCmdMgr.addCommand(new StdCmdRedo());
     rcCmdMgr.addCommand(new StdCmdPrint());
+    rcCmdMgr.addCommand(new StdCmdPrintPreview());
     rcCmdMgr.addCommand(new StdCmdPrintPdf());
     rcCmdMgr.addCommand(new StdCmdQuit());
     rcCmdMgr.addCommand(new StdCmdCut());
