@@ -25,6 +25,7 @@
 #ifndef _PreComp_
 # include <QApplication>
 # include <QMessageBox>
+# include <QSharedPointer>
 # include <QWhatsThis>
 #if QT_VERSION >= 0x040200
 # include <QDesktopServices>
@@ -79,7 +80,6 @@ StdCmdWorkbench::StdCmdWorkbench()
     sWhatsThis    = "Std_Workbench";
     sStatusTip    = QT_TR_NOOP("Switch between workbenches");
     sPixmap       = "freecad";
-    iAccel        = 0;
     eType         = 0;
 }
 
@@ -125,7 +125,7 @@ Action * StdCmdWorkbench::createAction(void)
     applyCommandData(pcAction);
     if (sPixmap)
         pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(iAccel);
+      pcAction->setShortcut(QString::fromAscii(sAccel));
 
     return pcAction;
 }
@@ -144,7 +144,6 @@ StdCmdRecentFiles::StdCmdRecentFiles()
     sToolTipText  = QT_TR_NOOP("Recent file list");
     sWhatsThis    = "Std_RecentFiles";
     sStatusTip    = QT_TR_NOOP("Recent file list");
-    iAccel        = 0;
     eType         = 0;
 }
 
@@ -192,7 +191,13 @@ Action * StdCmdAbout::createAction(void)
 {
     Action *pcAction;
 
-    QString exe = QString::fromUtf8(App::GetApplication().getExecutableName());
+    QString exe;
+    std::map<std::string,std::string>& cfg = App::Application::Config();
+    std::map<std::string,std::string>::iterator it = cfg.find("WindowTitle");
+    if (it != cfg.end())
+        exe = QString::fromUtf8(it->second.c_str());
+    else
+        exe = QString::fromUtf8(App::GetApplication().getExecutableName());
     pcAction = new Action(this,getMainWindow());
     pcAction->setText(QCoreApplication::translate(
         this->className(), sMenuText, 0,
@@ -205,7 +210,7 @@ Action * StdCmdAbout::createAction(void)
         QCoreApplication::CodecForTr).arg(exe));
     pcAction->setWhatsThis(QLatin1String(sWhatsThis));
     pcAction->setIcon(QApplication::windowIcon());
-    pcAction->setShortcut(iAccel);
+      pcAction->setShortcut(QString::fromAscii(sAccel));
 
     return pcAction;
 }
@@ -220,14 +225,21 @@ bool StdCmdAbout::isActive()
  */
 void StdCmdAbout::activated(int iMsg)
 {
-    Gui::Dialog::AboutDialog dlg( getMainWindow() );
-    dlg.exec();
+    const Gui::Dialog::AboutDialogFactory* f = Gui::Dialog::AboutDialogFactory::defaultFactory();
+    QSharedPointer <QDialog> dlg(f->create(getMainWindow()));
+    dlg->exec();
 }
 
 void StdCmdAbout::languageChange()
 {
     if (_pcAction) {
-        QString exe = QString::fromUtf8(App::GetApplication().getExecutableName());
+        QString exe;
+        std::map<std::string,std::string>& cfg = App::Application::Config();
+        std::map<std::string,std::string>::iterator it = cfg.find("WindowTitle");
+        if (it != cfg.end())
+            exe = QString::fromUtf8(it->second.c_str());
+        else
+            exe = QString::fromUtf8(App::GetApplication().getExecutableName());
         _pcAction->setText(QCoreApplication::translate(
             this->className(), sMenuText, 0,
             QCoreApplication::CodecForTr).arg(exe));
@@ -262,27 +274,6 @@ void StdCmdAboutQt::activated(int iMsg)
   qApp->aboutQt();
 }
 
-//===========================================================================
-// Std_TipOfTheDay
-//===========================================================================
-DEF_STD_CMD(StdCmdTipOfTheDay);
-
-StdCmdTipOfTheDay::StdCmdTipOfTheDay()
-  :Command("Std_TipOfTheDay")
-{
-  sGroup        = QT_TR_NOOP("Help");
-  sMenuText     = QT_TR_NOOP("&Tip of the day...");
-  sToolTipText  = QT_TR_NOOP("Tip of the day");
-  sWhatsThis    = "Std_TipOfTheDay";
-  sStatusTip    = QT_TR_NOOP("Tip of the day");
-  eType         = 0;
-}
-
-void StdCmdTipOfTheDay::activated(int iMsg)
-{
-  getMainWindow()->showTipOfTheDay( true );
-}
-
 //===========================================================================
 // Std_WhatsThis
 //===========================================================================
@@ -296,7 +287,7 @@ StdCmdWhatsThis::StdCmdWhatsThis()
     sToolTipText  = QT_TR_NOOP("What's This");
     sWhatsThis    = "Std_WhatsThis";
     sStatusTip    = QT_TR_NOOP("What's This");
-    iAccel        = keySequenceToAccel(QKeySequence::WhatsThis);
+    sAccel        = keySequenceToAccel(QKeySequence::WhatsThis);
     sPixmap       = "WhatsThis";
     eType         = 0;
 }
@@ -320,7 +311,6 @@ StdCmdDlgParameter::StdCmdDlgParameter()
   sWhatsThis    = "Std_DlgParameter";
   sStatusTip    = QT_TR_NOOP("Opens a Dialog to edit the parameters");
   //sPixmap     = "settings";
-  iAccel        = 0;
   eType         = 0;
 }
 
@@ -345,7 +335,6 @@ StdCmdDlgPreferences::StdCmdDlgPreferences()
     sWhatsThis    = "Std_DlgPreferences";
     sStatusTip    = QT_TR_NOOP("Opens a Dialog to edit the preferences");
     sPixmap     = "preferences-system";
-    iAccel        = 0;
     eType         = 0;
 }
 
@@ -369,7 +358,6 @@ StdCmdDlgCustomize::StdCmdDlgCustomize()
     sWhatsThis    = "Std_DlgCustomize";
     sStatusTip    = QT_TR_NOOP("Customize toolbars and command bars");
     sPixmap       = "applications-accessories";
-    iAccel        = 0;
     eType         = 0;
 }
 
@@ -396,7 +384,6 @@ StdCmdCommandLine::StdCmdCommandLine()
     sWhatsThis    = "Std_CommandLine";
     sStatusTip    = QT_TR_NOOP("Opens the command line in the console");
     sPixmap       = "utilities-terminal";
-    iAccel        = 0;
     eType         = 0;
 }
 
@@ -444,7 +431,7 @@ StdCmdOnlineHelp::StdCmdOnlineHelp()
     sWhatsThis    = "Std_OnlineHelp";
     sStatusTip    = QT_TR_NOOP("Help");
     sPixmap       = "help-browser";
-    iAccel        = keySequenceToAccel(QKeySequence::HelpContents);
+    sAccel        = keySequenceToAccel(QKeySequence::HelpContents);
     eType         = 0;
 }
 
@@ -638,7 +625,6 @@ void CreateStdCommands(void)
     rcCmdMgr.addCommand(new StdCmdPythonWebsite());
     rcCmdMgr.addCommand(new StdCmdMeasurementSimple());
     //rcCmdMgr.addCommand(new StdCmdDownloadOnlineHelp());
-    rcCmdMgr.addCommand(new StdCmdTipOfTheDay());
     //rcCmdMgr.addCommand(new StdCmdDescription());
 }
 
