@@ -23,13 +23,16 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <QApplication>
 # include <QEventLoop>
+# include <QFileDialog>
 # include <QMutex>
 # include <QThread>
 # include <QTimer>
 # include <QMdiArea>
 # include <QMdiSubWindow>
 # include <QWaitCondition>
+# include <QTranslator>
 #endif
 
 #include <Base/Console.h>
@@ -37,6 +40,7 @@
 #include "MainWindow.h"
 #include "MDIView.h"
 #include "Command.h"
+#include "Language/Translator.h"
 
 #include "ProgressBar.h"
 
@@ -45,6 +49,43 @@ using namespace Gui;
 
 //++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
+//===========================================================================
+// Std_TestQM
+//===========================================================================
+DEF_STD_CMD(Std_TestQM);
+
+Std_TestQM::Std_TestQM()
+  : Command("Std_TestQM")
+{
+    sGroup        = "Standard-Test";
+    sMenuText     = "Test translation files...";
+    sToolTipText  = "Test function to check .qm translation files";
+    sWhatsThis    = sToolTipText;
+    sStatusTip    = sToolTipText;
+}
+
+void Std_TestQM::activated(int iMsg)
+{
+    QStringList files = QFileDialog::getOpenFileNames(getMainWindow(),
+        QString::fromAscii("Test translation"), QString(),
+        QString::fromAscii("Translation (*.qm)"));
+    if (!files.empty()) {
+        Translator::instance()->activateLanguage("English");
+        QList<QTranslator*> i18n = qApp->findChildren<QTranslator*>();
+        for (QList<QTranslator*>::Iterator it = i18n.begin(); it != i18n.end(); ++it)
+            qApp->removeTranslator(*it);
+        for (QStringList::Iterator it = files.begin(); it != files.end(); ++it) {
+            QTranslator* translator = new QTranslator(qApp);
+            if (translator->load(*it)) {
+                qApp->installTranslator(translator);
+            }
+            else {
+                delete translator;
+            }
+        }
+    }
+}
+
 //===========================================================================
 // Std_Test1
 //===========================================================================
@@ -59,7 +100,7 @@ FCCmdTest1::FCCmdTest1()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Std_Tool1";
-    iAccel        = Qt::CTRL+Qt::Key_T;
+    sAccel        = "Ctrl+T";
 }
 
 void FCCmdTest1::activated(int iMsg)
@@ -87,7 +128,6 @@ FCCmdTest2::FCCmdTest2()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool2";
-    iAccel          = 0;
 }
 
 
@@ -116,7 +156,6 @@ FCCmdTest3::FCCmdTest3()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool3";
-    iAccel          = 0;
 }
 
 void FCCmdTest3::activated(int iMsg)
@@ -146,7 +185,6 @@ FCCmdTest4::FCCmdTest4()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool4";
-    iAccel          = 0;
 }
 
 void FCCmdTest4::activated(int iMsg)
@@ -175,7 +213,6 @@ FCCmdTest5::FCCmdTest5()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool5";
-    iAccel          = 0;
 }
 
 void FCCmdTest5::activated(int iMsg)
@@ -204,7 +241,6 @@ FCCmdTest6::FCCmdTest6()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool6";
-    iAccel          = 0;
 }
 
 void FCCmdTest6::activated(int iMsg)
@@ -232,7 +268,6 @@ CmdTestProgress1::CmdTestProgress1()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool7";
-    iAccel          = 0;
 }
 
 void CmdTestProgress1::activated(int iMsg)
@@ -276,7 +311,6 @@ CmdTestProgress2::CmdTestProgress2()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool7";
-    iAccel          = 0;
 }
 
 void CmdTestProgress2::activated(int iMsg)
@@ -318,7 +352,6 @@ CmdTestProgress3::CmdTestProgress3()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool8";
-    iAccel          = 0;
 }
 
 void CmdTestProgress3::activated(int iMsg)
@@ -387,7 +420,6 @@ CmdTestProgress4::CmdTestProgress4()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool7";
-    iAccel          = 0;
 }
 
 void CmdTestProgress4::activated(int iMsg)
@@ -441,7 +473,6 @@ CmdTestProgress5::CmdTestProgress5()
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Std_Tool7";
-    iAccel          = 0;
 }
 
 class BarThread : public QThread
@@ -520,7 +551,6 @@ CmdTestMDI1::CmdTestMDI1()
     sToolTipText    = "Remove MDI from main window";
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
-    iAccel          = 0;
 }
 
 void CmdTestMDI1::activated(int iMsg)
@@ -544,7 +574,6 @@ CmdTestMDI2::CmdTestMDI2()
     sToolTipText    = "Remove view from MDI area";
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
-    iAccel          = 0;
 }
 
 void CmdTestMDI2::activated(int iMsg)
@@ -572,7 +601,6 @@ CmdTestMDI3::CmdTestMDI3()
     sToolTipText    = "Unset parent and remove from main window";
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
-    iAccel          = 0;
 }
 
 void CmdTestMDI3::activated(int iMsg)
@@ -597,6 +625,7 @@ void CreateTestCommands(void)
 {
     CommandManager &rcCmdMgr = Application::Instance->commandManager();
 
+    rcCmdMgr.addCommand(new Std_TestQM());
     rcCmdMgr.addCommand(new FCCmdTest1());
     rcCmdMgr.addCommand(new FCCmdTest2());
     rcCmdMgr.addCommand(new FCCmdTest3());
