@@ -24,9 +24,12 @@
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QDir>
+# include <QFileDialog>
 # include <QFileInfo>
 # include <QHeaderView>
+# include <QImageReader>
 # include <QMessageBox>
+# include <QTextStream>
 #endif
 
 #include "DlgActionsImp.h"
@@ -191,8 +194,7 @@ void DlgCustomActionsImp::on_actionListWidget_itemActivated(QTreeWidgetItem *ite
         actionMenu      -> setText(QString::fromUtf8(pScript->getMenuText()));
         actionToolTip   -> setText(QString::fromUtf8(pScript->getToolTipText()));
         actionStatus    -> setText(QString::fromUtf8(pScript->getStatusTip()));
-        QKeySequence shortcut(pScript->getAccel());
-        actionAccel     -> setText(shortcut.toString());
+        actionAccel     -> setText(QString::fromAscii(pScript->getAccel()));
         pixmapLabel->clear();
         m_sPixmap = QString::null;
         const char* name = pScript->getPixmap();
@@ -260,11 +262,7 @@ void DlgCustomActionsImp::on_buttonAddAction_clicked()
     m_sPixmap = QString::null;
 
     if (!actionAccel->text().isEmpty()) {
-        QKeySequence shortcut(actionAccel->text());
-        int key=0;
-        for (uint i=0; i<shortcut.count(); i++)
-            key += shortcut[i];
-        macro->setAccel(key);
+      macro->setAccel(actionAccel->text().toAscii());
     }
     actionAccel->clear();
 
@@ -319,11 +317,7 @@ void DlgCustomActionsImp::on_buttonReplaceAction_clicked()
     m_sPixmap = QString::null;
 
     if (!actionAccel->text().isEmpty()) {
-        QKeySequence shortcut(actionAccel->text());
-        int key=0;
-        for (uint i=0; i<shortcut.count(); i++)
-            key += shortcut[i];
-        macro->setAccel(key);
+        macro->setAccel(actionAccel->text().toAscii());
     }
     actionAccel->clear();
 
@@ -338,7 +332,7 @@ void DlgCustomActionsImp::on_buttonReplaceAction_clicked()
         action->setStatusTip(QString::fromUtf8(macro->getStatusTip()));
         if( macro->getPixmap() )
             action->setIcon(Gui::BitmapFactory().pixmap(macro->getPixmap()));
-        action->setShortcut(macro->getAccel());
+        action->setShortcut(QString::fromAscii(macro->getAccel()));
     }
 
     // emit signal to notify the container widget
@@ -376,50 +370,78 @@ void DlgCustomActionsImp::on_buttonRemoveAction_clicked()
     }
 }
 
-namespace Gui { namespace Dialog {
-class IconDialog : public QDialog
+IconDialog::IconDialog(QWidget* parent)
+  : QDialog(parent), ui(new Ui_DlgChooseIcon)
 {
-public:
-    IconDialog(Ui_DlgChooseIcon* ui, QWidget* parent) : QDialog(parent), _ui(ui) {
+    ui->setupUi(this);
+    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    // signals and slots connections
+    connect(ui->listWidget, SIGNAL(itemClicked (QListWidgetItem *)),
+            this, SLOT(accept()));
+    connect(ui->addButton, SIGNAL(clicked()),
+            this, SLOT(onAddIconPath()));
+
+    QListWidgetItem* item;
+    QStringList names = BitmapFactory().findIconFiles();
+    for (QStringList::Iterator it = names.begin(); it != names.end(); ++it) {
+        item = new QListWidgetItem(ui->listWidget);
+        item->setIcon(QIcon(*it));
+        item->setText(QFileInfo(*it).baseName());
+        item->setToolTip(*it);
     }
-    ~IconDialog() {
-    }
-    void resizeEvent(QResizeEvent*) {
-        _ui->listWidget->setFlow(QListView::LeftToRight);
-    }
-private:
-    Ui_DlgChooseIcon *_ui;
-};
 }
+
+IconDialog::~IconDialog()
+{
+    delete ui;
+}
+
+QListWidgetItem* IconDialog::currentItem() const
+{
+    return ui->listWidget->currentItem();
+}
+
+void IconDialog::resizeEvent(QResizeEvent*)
+{
+    ui->listWidget->setFlow(QListView::LeftToRight);
+}
+
+void IconDialog::onAddIconPath()
+{
+    QString dir = QFileDialog::getExistingDirectory(this, IconDialog::tr("Add icon"), QString());
+    if (!dir.isEmpty()) {
+        QStringList filters;
+        QList<QByteArray> formats = QImageReader::supportedImageFormats();
+        for (QList<QByteArray>::iterator it = formats.begin(); it != formats.end(); ++it)
+            filters << QString::fromAscii("*.%1").arg(QString::fromAscii(*it).toLower());
+        QDir d(dir);
+        d.setNameFilters(filters);
+        QFileInfoList fi = d.entryInfoList();
+        for (QFileInfoList::iterator it = fi.begin(); it != fi.end(); ++it) {
+            QListWidgetItem* item;
+            QString file = it->absoluteFilePath();
+            item = new QListWidgetItem(ui->listWidget);
+            item->setIcon(QIcon(file));
+            item->setText(it->baseName());
+            item->setToolTip(file);
+        }
+
+        BitmapFactory().addPath(dir);
+        BitmapFactory().addCustomPath(dir);
+    }
 }
 
 void DlgCustomActionsImp::on_buttonChoosePixmap_clicked()
 {
     // create a dialog showing all pixmaps
-    Gui::Dialog::Ui_DlgChooseIcon ui;
-    Gui::Dialog::IconDialog dlg(&ui, this);
+    Gui::Dialog::IconDialog dlg(this);
     dlg.setModal(true);
-    ui.setupUi(&dlg);
-    ui.listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    // signals and slots connections
-    connect(ui.listWidget, SIGNAL(itemClicked (QListWidgetItem *)),
-            &dlg, SLOT(accept()));
-
-    QListWidgetItem* item;
-    QStringList names = BitmapFactory().findIconFiles();
-    for (QStringList::Iterator it = names.begin(); it != names.end(); ++it) {
-        item = new QListWidgetItem(ui.listWidget);
-        item->setIcon(QIcon(*it));
-        item->setText(QFileInfo(*it).baseName());
-        item->setToolTip(*it);
-    }
-
     dlg.exec();
 
     pixmapLabel->clear();
     m_sPixmap = QString::null;
     if (dlg.result() == QDialog::Accepted) {
-        QListWidgetItem* item = ui.listWidget->currentItem();
+        QListWidgetItem* item = dlg.currentItem();
         if (item) {
             m_sPixmap = item->text();
             pixmapLabel->setPixmap(item->icon().pixmap(QSize(32,32)));
