@@ -41,6 +41,8 @@ DlgSettingsViewColor::DlgSettingsViewColor(QWidget* parent)
     : PreferencePage(parent)
 {
     this->setupUi(this);
+    this->HighlightColor->setEnabled(this->checkBoxPreselection->isChecked());
+    this->SelectionColor->setEnabled(this->checkBoxSelection->isChecked());
 }
 
 /** 
@@ -64,6 +66,10 @@ void DlgSettingsViewColor::saveSettings()
     checkBoxSelection->onSave();
     HighlightColor->onSave();
     SelectionColor->onSave();
+    EditedEdgeColor->onSave();
+    EditedVertexColor->onSave();
+    ConstructionColor->onSave();
+    FullyConstrainedColor->onSave();
 }
 
 void DlgSettingsViewColor::loadSettings()
@@ -79,6 +85,10 @@ void DlgSettingsViewColor::loadSettings()
     checkBoxSelection->onRestore();
     HighlightColor->onRestore();
     SelectionColor->onRestore();
+    EditedEdgeColor->onRestore();
+    EditedVertexColor->onRestore();
+    ConstructionColor->onRestore();
+    FullyConstrainedColor->onRestore();
 }
 
 /**
@@ -95,3 +105,4 @@ void DlgSettingsViewColor::changeEvent(QEvent *e)
 }
 
 #include "moc_DlgSettingsViewColor.cpp"
+
