@@ -137,8 +137,11 @@ Document::Document(App::Document* pcDocument,Application * app)
     _pcDocPy = new Gui::DocumentPy(this);
 
     if (App::GetApplication().GetParameterGroupByPath
-        ("User parameter:BaseApp/Preferences/Document")->GetBool("UsingUndo",true))
+        ("User parameter:BaseApp/Preferences/Document")->GetBool("UsingUndo",true)){
         d->_pcDocument->setUndoMode(1);
+        // set the maximum stack size
+        d->_pcDocument->setMaxUndoStackSize(App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Document")->GetInt("MaxUndoSize",20));
+    }
 }
 
 Document::~Document()
@@ -920,7 +923,10 @@ bool Document::canClose ()
     else if (!Gui::Control().isAllowedAlterDocument()) {
         QMessageBox::warning(getActiveView(),
             QObject::tr("Document not closable"),
-            QObject::tr("The document is not closable for the moment."));
+            QObject::tr("The document is in editing mode and thus cannot be closed for the moment.\n"
+                        "You either have to finish or cancel the editing in the task panel."));
+        Gui::TaskView::TaskDialog* dlg = Gui::Control().activeDialog();
+        if (dlg) Gui::Control().showDialog(dlg);
         return false;
     }
 
