@@ -33,9 +33,6 @@
 #include <Base/Persistence.h>
 #include <App/Document.h>
 
-class SoSelection;
-class SoPath;
-
 namespace Base
 {
   class Matrix4D;
@@ -71,6 +68,7 @@ protected:
     void slotChangedObject(const App::DocumentObject&, const App::Property&);
     void slotRenamedObject(const App::DocumentObject&);
     void slotActivatedObject(const App::DocumentObject&);
+    void slotRestoredDocument(const App::Document&);
     //@}
 
 public:
