@@ -33,7 +33,8 @@
 # include <QPrinter>
 # include <QPrintDialog>
 # include <QScrollBar>
-# include <QTextEdit>
+# include <QPlainTextEdit>
+# include <QPrintPreviewDialog>
 # include <QTextBlock>
 # include <QTextCodec>
 # include <QTextStream>
@@ -54,8 +55,7 @@ using namespace Gui;
 namespace Gui {
 class EditorViewP {
 public:
-    LineMarker* lineMarker;
-    QTextEdit* textEdit;
+    QPlainTextEdit* textEdit;
     QString fileName;
     QTimer*  activityTimer;
     uint timeStamp;
@@ -65,53 +65,6 @@ public:
 };
 }
 
-LineMarker::LineMarker(EditorView* ev, QWidget* parent)
-    : QWidget(parent), view(ev)
-{
-    setFixedWidth(fontMetrics().width(QLatin1String("0000"))+10);
-}
-
-LineMarker::~LineMarker()
-{
-}
-
-void LineMarker::setTextEdit(QTextEdit *edit)
-{
-    this->edit = edit;
-    connect(edit->document()->documentLayout(), SIGNAL(update(const QRectF &)),
-            this, SLOT(update()));
-    connect(edit->verticalScrollBar(), SIGNAL(valueChanged(int)),
-            this, SLOT(update()));
-}
-
-void LineMarker::paintEvent(QPaintEvent*)
-{
-    QAbstractTextDocumentLayout *layout = edit->document()->documentLayout();
-    int contentsY = edit->verticalScrollBar()->value();
-    qreal pageBottom = contentsY + edit->viewport()->height();
-    const QFontMetrics fm = fontMetrics();
-    const int ascent = fontMetrics().ascent() + 1; // height = ascent + descent + 1
-    int lineCount = 1;
-
-    QPainter p(this);
-
-    for (QTextBlock block = edit->document()->begin();
-        block.isValid(); block = block.next(), ++lineCount) {
-
-        const QRectF boundingRect = layout->blockBoundingRect(block);
-
-        QPointF position = boundingRect.topLeft();
-        if (position.y() + boundingRect.height() < contentsY)
-            continue;
-        if (position.y() > pageBottom)
-            break;
-
-        const QString txt = QString::number(lineCount);
-        p.drawText(width() - fm.width(txt), qRound(position.y()) - contentsY + ascent, txt);
-        view->drawMarker(lineCount, 1, qRound(position.y()) - contentsY, &p);
-    }
-}
-
 // -------------------------------------------------------
 
 /* TRANSLATOR Gui::EditorView */
@@ -120,7 +73,7 @@ void LineMarker::paintEvent(QPaintEvent*)
  *  Constructs a EditorView which is a child of 'parent', with the
  *  name 'name'.
  */
-EditorView::EditorView(QTextEdit* editor, QWidget* parent)
+EditorView::EditorView(QPlainTextEdit* editor, QWidget* parent)
     : MDIView(0,parent,0), WindowParameter( "Editor" )
 {
     d = new EditorViewP;
@@ -128,16 +81,13 @@ EditorView::EditorView(QTextEdit* editor, QWidget* parent)
 
     // create the editor first
     d->textEdit = editor;
-    d->textEdit->setLineWrapMode(QTextEdit::NoWrap);
-    d->lineMarker = new LineMarker(this);
-    d->lineMarker->setTextEdit(d->textEdit);
+    d->textEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
 
     // Create the layout containing the workspace and a tab bar
     QFrame* hbox = new QFrame(this);
     hbox->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     QHBoxLayout* layout = new QHBoxLayout();
     layout->setMargin(1);
-    layout->addWidget(d->lineMarker);
     layout->addWidget(d->textEdit);
     d->textEdit->setParent(hbox);
     hbox->setLayout(layout);
@@ -178,25 +128,16 @@ void EditorView::drawMarker(int line, int x, int y, QPainter*)
 {
 }
 
-QTextEdit* EditorView::getEditor() const
+QPlainTextEdit* EditorView::getEditor() const
 {
     return d->textEdit;
 }
 
-LineMarker* EditorView::getMarker() const
-{
-    return d->lineMarker;
-}
-
 void EditorView::OnChange(Base::Subject<const char*> &rCaller,const char* rcReason)
 {
     ParameterGrp::handle hPrefGrp = getWindowParameter();
     if (strcmp(rcReason, "EnableLineNumber") == 0) {
-        bool show = hPrefGrp->GetBool( "EnableLineNumber", true );
-        if ( show )
-            d->lineMarker->show();
-        else
-            d->lineMarker->hide();
+        //bool show = hPrefGrp->GetBool( "EnableLineNumber", true );
     }
 }
 
@@ -268,6 +209,7 @@ bool EditorView::onHasMsg(const char* pMsg) const
     if (strcmp(pMsg,"DebugStop")==0)  return true;
     if (strcmp(pMsg,"SaveAs")==0)  return true;
     if (strcmp(pMsg,"Print")==0) return true;
+    if (strcmp(pMsg,"PrintPreview")==0) return true;
     if (strcmp(pMsg,"PrintPdf")==0) return true;
     if (strcmp(pMsg,"Save")==0) { 
         return d->textEdit->document()->isModified();
@@ -426,12 +368,26 @@ void EditorView::print()
     }
 }
 
+void EditorView::printPreview()
+{
+    QPrinter printer(QPrinter::HighResolution);
+    QPrintPreviewDialog dlg(&printer, this);
+    connect(&dlg, SIGNAL(paintRequested (QPrinter *)),
+            this, SLOT(print(QPrinter *)));
+    dlg.exec();
+}
+
+void EditorView::print(QPrinter* printer)
+{
+    d->textEdit->document()->print(printer);
+}
+
 /**
  * Prints the document into a Pdf file.
  */
 void EditorView::printPdf()
 {
-    QString filename = QFileDialog::getSaveFileName(this, tr("Export PDF"), QString(), tr("PDF file (*.pdf)"));
+    QString filename = FileDialog::getSaveFileName(this, tr("Export PDF"), QString(), tr("PDF file (*.pdf)"));
     if (!filename.isEmpty()) {
         QPrinter printer(QPrinter::HighResolution);
         printer.setOutputFormat(QPrinter::PdfFormat);
@@ -532,7 +488,7 @@ void EditorView::focusInEvent (QFocusEvent * e)
 
 // ---------------------------------------------------------
 
-PythonEditorView::PythonEditorView(QTextEdit* editor, QWidget* parent)
+PythonEditorView::PythonEditorView(QPlainTextEdit* editor, QWidget* parent)
   : EditorView(editor, parent), m_debugLine(-1),
     breakpoint(QLatin1String(":/icons/breakpoint.png")),
     debugMarker(QLatin1String(":/icons/debug-marker.png"))
@@ -608,14 +564,14 @@ void PythonEditorView::toggleBreakpoint()
 {
     QTextCursor cursor = getEditor()->textCursor();
     int line = cursor.blockNumber() + 1;
-    _dbg->toogleBreakpoint(line, fileName());
-    getMarker()->update();
+    _dbg->toggleBreakpoint(line, fileName());
+//    getMarker()->update();
 }
 
 void PythonEditorView::showDebugMarker(int line)
 {
     m_debugLine = line;
-    getMarker()->update();
+//    getMarker()->update();
     QTextCursor cursor = getEditor()->textCursor();
     cursor.movePosition(QTextCursor::StartOfBlock);
     int cur = cursor.blockNumber() + 1;
@@ -633,7 +589,7 @@ void PythonEditorView::showDebugMarker(int line)
 void PythonEditorView::hideDebugMarker()
 {
     m_debugLine = -1;
-    getMarker()->update();
+//    getMarker()->update();
 }
 
 #include "moc_EditorView.cpp"
