@@ -37,6 +37,7 @@
 using namespace Gui;
 
 /** \defgroup i18n Internationalization with FreeCAD
+ *  \ingroup GUI
  *
  * The internationalization of FreeCAD makes heavy use of the internationalization
  * support of Qt. For more details refer to your Qt documentation.
@@ -82,7 +83,7 @@ using namespace Gui;
  * Command Line: rcc.exe -name $(InputName) $(InputPath) -o "$(InputDir)qrc_$(InputName).cpp"
  * Outputs:      $(InputDir)qrc_$(InputName).cpp
  * 
- * For the gcc build system you just have to add the line <resourcefile>.qrc to the BUILT_SOURCES
+ * For the gcc build system you just have to add the line \<resourcefile\>.qrc to the BUILT_SOURCES
  * sources section of the Makefile.am, run automake and configure (or ./confog.status) afterwards.
  *
  * Finally, you have to add a the line
@@ -128,14 +129,23 @@ Translator::Translator()
 {
     // This is needed for Qt's lupdate
     d = new TranslatorP;
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("English" )] = "en";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("German"  )] = "de";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("French"  )] = "fr";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Italian" )] = "it";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Japanese")] = "jp";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Chinese" )] = "cn";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Korean"  )] = "kr";
-    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Swedish" )] = "se";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("English"   )] = "en";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("German"    )] = "de";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Spanish"   )] = "es";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("French"    )] = "fr";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Italian"   )] = "it";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Japanese"  )] = "jp";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Chinese"   )] = "zh";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Korean"    )] = "kr";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Russian"   )] = "ru";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Swedish"   )] = "se";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Afrikaans" )] = "af";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Norwegian" )] = "no";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Portuguese")] = "pt";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Dutch"     )] = "nl";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Ukrainian" )] = "uk";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Finnish"   )] = "fi";
+    d->mapLanguageTopLevelDomain[QT_TR_NOOP("Croatian"  )] = "hr";
     d->activatedLanguage = "English";
 
     d->paths = directories();
