@@ -40,6 +40,7 @@
 
 #include "MainWindow.h"
 #include "PythonConsole.h"
+#include "PythonConsolePy.h"
 #include "PythonDebugger.h"
 
 using namespace Gui;
@@ -49,7 +50,7 @@ MacroManager::MacroManager()
   : openMacro(false),
     recordGui(true),
     guiAsComment(true),
-    scriptToPyConsole(false),
+    scriptToPyConsole(true),
     pyConsole(0),
     pyDebugger(new PythonDebugger())
 {
@@ -69,7 +70,7 @@ void MacroManager::OnChange(Base::Subject<const char*> &rCaller, const char * sR
 {
     this->recordGui         = this->params->GetBool("RecordGui", true);
     this->guiAsComment      = this->params->GetBool("GuiAsComment", true);
-    this->scriptToPyConsole = this->params->GetBool("ScriptToPyConsole", false);
+    this->scriptToPyConsole = this->params->GetBool("ScriptToPyConsole", true);
 }
 
 void MacroManager::open(MacroType eType,const char *sName)
@@ -190,10 +191,35 @@ void MacroManager::setModule(const char* sModule)
     }
 }
 
+namespace Gui {
+    class PythonRedirector
+    {
+    public:
+        PythonRedirector(const char* type, PyObject* obj) : std_out(type), out(obj)
+        {
+            Base::PyGILStateLocker lock;
+            old = PySys_GetObject(const_cast<char*>(std_out));
+            PySys_SetObject(const_cast<char*>(std_out), obj);
+        }
+        ~PythonRedirector()
+        {
+            Base::PyGILStateLocker lock;
+            PySys_SetObject(const_cast<char*>(std_out), old);
+            Py_XDECREF(out);
+        }
+    private:
+        const char* std_out;
+        PyObject* out;
+        PyObject* old;
+    };
+}
+
 void MacroManager::run(MacroType eType,const char *sName)
 {
     try
     {
+        PythonRedirector std_out("stdout",new OutputStdout);
+        PythonRedirector std_err("stderr",new OutputStderr);
         //The given path name is expected to be Utf-8
         Base::Interpreter().runFile(sName);
     }
