@@ -32,6 +32,7 @@
 # include <QContextMenuEvent>
 # include <QDesktopWidget>
 # include <QDockWidget>
+# include <QFontMetrics>
 # include <QLabel>
 # include <QMdiSubWindow>
 # include <QMessageBox>
@@ -102,6 +103,8 @@
 #include "MergeDocuments.h"
 #include "ViewProviderExtern.h"
 
+#include "SpaceballEvent.h"
+
 #if defined(Q_OS_WIN32)
 #define slots
 #include <private/qmainwindowlayout_p.h>
@@ -383,7 +386,7 @@ MainWindow::MainWindow(QWidget * parent, Qt::WFlags f)
         (QString::fromAscii(QT_TRANSLATE_NOOP("QDockWidget","Report view")));
     pDockMgr->registerDockWindow("Std_ReportView", pcReport);
 #else
-    // Report view
+    // Report view (must be created before PythonConsole!)
     ReportOutput* pcReport = new ReportOutput(this);
     pcReport->setWindowIcon(BitmapFactory().pixmap("MacroEditor"));
     pcReport->setObjectName
@@ -571,6 +574,28 @@ bool MainWindow::event(QEvent *e)
             if (action) action->setIcon(QApplication::windowIcon());
         }
     }
+    else if (e->type() == Spaceball::ButtonEvent::ButtonEventType) {
+        Spaceball::ButtonEvent *buttonEvent = dynamic_cast<Spaceball::ButtonEvent *>(e);
+        if (!buttonEvent)
+            return true;
+        buttonEvent->setHandled(true);
+        //only going to respond to button press events.
+        if (buttonEvent->buttonStatus() != Spaceball::BUTTON_PRESSED)
+            return true;
+        ParameterGrp::handle group = App::GetApplication().GetUserParameter().GetGroup("BaseApp")->
+                GetGroup("Spaceball")->GetGroup("Buttons");
+        QByteArray groupName(QVariant(buttonEvent->buttonNumber()).toByteArray());
+        if (group->HasGroup(groupName.data())) {
+            ParameterGrp::handle commandGroup = group->GetGroup(groupName.data());
+            std::string commandName(commandGroup->GetASCII("Command"));
+            if (commandName.empty())
+                return true;
+            else
+                Application::Instance->commandManager().runCommandByName(commandName.c_str());
+        }
+        else
+            return true;
+    }
     return QMainWindow::event(e);
 }
 
@@ -1103,7 +1128,7 @@ void MainWindow::delayedStartup()
 
     // Create new document?
     ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("Document");
-    if (hGrp->GetBool("CreateNewDoc", true)) {
+    if (hGrp->GetBool("CreateNewDoc", false)) {
         App::GetApplication().newDocument();
     }
 }
@@ -1330,6 +1355,7 @@ QMimeData * MainWindow::createMimeDataFromSelection () const
         mime = QLatin1String("application/x-documentobject");
         Base::ByteArrayOStreambuf buf(res);
         std::ostream str(&buf);
+        // need this instance to call MergeDocuments::Save()
         MergeDocuments mimeView(doc);
         doc->exportObjects(obj, str);
     }
@@ -1337,6 +1363,7 @@ QMimeData * MainWindow::createMimeDataFromSelection () const
         mime = QLatin1String("application/x-documentobject-file");
         static Base::FileInfo fi(Base::FileInfo::getTempFileName());
         Base::ofstream str(fi, std::ios::out | std::ios::binary);
+        // need this instance to call MergeDocuments::Save()
         MergeDocuments mimeView(doc);
         doc->exportObjects(obj, str);
         str.close();
@@ -1442,6 +1469,13 @@ void MainWindow::changeEvent(QEvent *e)
     }
 }
 
+void MainWindow::showMessage (const QString& message, int timeout)
+{
+    QFontMetrics fm(statusBar()->font());
+    QString msg = fm.elidedText(message, Qt::ElideMiddle, this->width()/2);
+    this->statusBar()->showMessage(msg, timeout);
+}
+
 // -------------------------------------------------------------
 
 namespace Gui {
