@@ -35,6 +35,7 @@
 # include <QMetaObject>
 # include <QRegExp>
 #endif
+
 #include <Inventor/sensors/SoTimerSensor.h>
 
 #include <App/Application.h>
@@ -62,6 +63,79 @@ struct NavigationStyleP {
 };
 }
 
+class FCSphereSheetProjector : public SbSphereSheetProjector {
+    typedef SbSphereSheetProjector inherited;
+
+public:
+    enum OrbitStyle {
+        Turntable,
+        Trackball
+    };
+
+    FCSphereSheetProjector(const SbSphere & sph, const SbBool orienttoeye = TRUE)
+        : SbSphereSheetProjector(sph, orienttoeye), orbit(Trackball)
+    {
+    }
+
+    void setViewVolume (const SbViewVolume &vol)
+    {
+        inherited::setViewVolume(vol);
+    }
+
+    void setWorkingSpace (const SbMatrix &space)
+    {
+        //inherited::setWorkingSpace(space);
+        this->worldToScreen = space.inverse();
+    }
+
+    SbVec3f project(const SbVec2f &point)
+    {
+        return inherited::project(point);
+    }
+
+    SbRotation getRotation(const SbVec3f &point1, const SbVec3f &point2)
+    {
+        SbRotation rot = inherited::getRotation(point1, point2);
+        if (orbit == Trackball)
+            return rot;
+
+        // 0000333: Turntable camera rotation
+        SbVec3f axis;
+        float angle;
+        rot.getValue(axis, angle);
+        SbVec3f dif = point1 - point2;
+        if (fabs(dif[1]) > fabs(dif[0])) {
+            SbVec3f xaxis(1,0,0);
+            if (dif[1] < 0)
+                angle = -angle;
+            rot.setValue(xaxis, angle);
+        }
+        else {
+            SbVec3f zaxis(0,0,1);
+            this->worldToScreen.multDirMatrix(zaxis, zaxis);
+            if (dif[0] > 0)
+                angle = -angle;
+            rot.setValue(zaxis, angle);
+        }
+
+        return rot;
+    }
+
+    void setOrbitStyle(OrbitStyle style)
+    {
+        this->orbit = style;
+    }
+
+    OrbitStyle getOrbitStyle() const
+    {
+        return this->orbit;
+    }
+
+private:
+    SbMatrix worldToScreen;
+    OrbitStyle orbit;
+};
+
 NavigationStyleEvent::NavigationStyleEvent(const Base::Type& s)
   : QEvent(QEvent::User), t(s)
 {
@@ -122,7 +196,7 @@ void NavigationStyle::initialize()
     // FIXME: use a smaller sphere than the default one to have a larger
     // area close to the borders that gives us "z-axis rotation"?
     // 19990425 mortene.
-    this->spinprojector = new SbSphereSheetProjector(SbSphere(SbVec3f(0, 0, 0), 0.8f));
+    this->spinprojector = new FCSphereSheetProjector(SbSphere(SbVec3f(0, 0, 0), 0.8f));
     SbViewVolume volume;
     volume.ortho(-1, 1, -1, 1, -1, 1);
     this->spinprojector->setViewVolume(volume);
@@ -165,6 +239,18 @@ int NavigationStyle::getInteractiveCount(void) const
     return viewer->getInteractiveCount();
 }
 
+void NavigationStyle::setOrbitStyle(NavigationStyle::OrbitStyle style)
+{
+    FCSphereSheetProjector* projector = static_cast<FCSphereSheetProjector*>(this->spinprojector);
+    projector->setOrbitStyle(FCSphereSheetProjector::OrbitStyle(style));
+}
+
+NavigationStyle::OrbitStyle NavigationStyle::getOrbitStyle() const
+{
+    FCSphereSheetProjector* projector = static_cast<FCSphereSheetProjector*>(this->spinprojector);
+    return NavigationStyle::OrbitStyle(projector->getOrbitStyle());
+}
+
 SbBool NavigationStyle::isViewing(void) const
 {
     return viewer->isViewing();
@@ -195,6 +281,85 @@ void NavigationStyle::seekToPoint(const SbVec3f& scenepos)
     viewer->seekToPoint(scenepos);
 }
 
+SbBool NavigationStyle::lookAtPoint(const SbVec2s screenpos)
+{
+    SoCamera* cam = viewer->getCamera();
+    if (cam == 0) return FALSE;
+
+    SoRayPickAction rpaction(viewer->getViewportRegion());
+    rpaction.setPoint(screenpos);
+    rpaction.setRadius(2);
+    rpaction.apply(viewer->getSceneManager()->getSceneGraph());
+
+    SoPickedPoint * picked = rpaction.getPickedPoint();
+    if (!picked) {
+        this->interactiveCountInc();
+        return FALSE;
+    }
+
+    SbVec3f hitpoint;
+    hitpoint = picked->getPoint();
+    lookAtPoint(hitpoint);
+    return TRUE;
+}
+
+void NavigationStyle::lookAtPoint(const SbVec3f& pos)
+{
+    SoCamera* cam = viewer->getCamera();
+    if (cam == 0) return;
+
+    // Find global coordinates of focal point.
+    SbVec3f direction;
+    cam->orientation.getValue().multVec(SbVec3f(0, 0, -1), direction);
+    PRIVATE(this)->focal1 = cam->position.getValue() +
+                            cam->focalDistance.getValue() * direction;
+    PRIVATE(this)->focal2 = pos;
+
+    // avoid to interfere with spinning (fixes #3101462)
+    if (this->isAnimating())
+        this->stopAnimating();
+
+    if (PRIVATE(this)->animsensor->isScheduled()) {
+        PRIVATE(this)->animsensor->unschedule();
+        this->interactiveCountDec();
+    }
+
+    if (isAnimationEnabled()) {
+        SbRotation cam_rot = cam->orientation.getValue();
+        // get the amount of movement
+        SbVec3f dir1 = direction, dir2;
+        dir2 = pos - cam->position.getValue();
+        dir2.normalize();
+        SbRotation rot(dir1, dir2);
+        float val = 0.5f*(1.0f + dir1.dot(dir2)); // value in range [0,1]
+        int div = (int)(val * 20.0f);
+        int steps = 20-div; // do it with max. 20 steps
+
+        // check whether a movement is required
+        if (steps > 0) {
+            PRIVATE(this)->endRotation = cam_rot;
+            this->spinRotation = cam_rot;
+            PRIVATE(this)->animationsteps = 5;
+            PRIVATE(this)->animationdelta = std::max<int>(100/steps, 5);
+            PRIVATE(this)->animsensor->setBaseTime(SbTime::getTimeOfDay());
+            PRIVATE(this)->animsensor->schedule();
+            this->interactiveCountInc();
+        }
+        else {
+            // set to the given position
+            SbVec3f direction;
+            cam->orientation.getValue().multVec(SbVec3f(0, 0, -1), direction);
+            cam->position = pos - cam->focalDistance.getValue() * direction;
+        }
+    }
+    else {
+        // set to the given position
+        SbVec3f direction;
+        cam->orientation.getValue().multVec(SbVec3f(0, 0, -1), direction);
+        cam->position = pos - cam->focalDistance.getValue() * direction;
+    }
+}
+
 void NavigationStyle::setCameraOrientation(const SbRotation& rot)
 {
     SoCamera* cam = viewer->getCamera();
@@ -224,6 +389,7 @@ void NavigationStyle::setCameraOrientation(const SbRotation& rot)
 
     if (PRIVATE(this)->animsensor->isScheduled()) {
         PRIVATE(this)->animsensor->unschedule();
+        this->interactiveCountDec();
     }
 
     if (isAnimationEnabled()) {
@@ -244,6 +410,7 @@ void NavigationStyle::setCameraOrientation(const SbRotation& rot)
             PRIVATE(this)->animationdelta = std::max<int>(100/steps, 5);
             PRIVATE(this)->animsensor->setBaseTime(SbTime::getTimeOfDay());
             PRIVATE(this)->animsensor->schedule();
+            this->interactiveCountInc();
         }
         else {
             // due to possible round-off errors make sure that the
@@ -281,6 +448,7 @@ void NavigationStyleP::viewAnimationCB(void * data, SoSensor * sensor)
             // now we have reached the end of the movement
             PRIVATE(that)->animationsteps=0;
             PRIVATE(that)->animsensor->unschedule();
+            that->interactiveCountDec();
             // set to the actual given rotation
             cam->orientation.setValue(PRIVATE(that)->endRotation);
             cam->orientation.getValue().multVec(SbVec3f(0, 0, -1), direction);
@@ -555,6 +723,11 @@ void NavigationStyle::spin(const SbVec2f & pointerpos)
     lastpos[0] = float(this->log.position[1][0]) / float(SoQtMax((int)(glsize[0]-1), 1));
     lastpos[1] = float(this->log.position[1][1]) / float(SoQtMax((int)(glsize[1]-1), 1));
 
+    // 0000333: Turntable camera rotation
+    SbMatrix mat;
+    viewer->getCamera()->orientation.getValue().getValue(mat);
+    this->spinprojector->setWorkingSpace(mat);
+
     this->spinprojector->project(lastpos);
     SbRotation r;
     this->spinprojector->projectAndGetRotation(pointerpos, r);
@@ -935,7 +1108,7 @@ void NavigationStyle::openPopupMenu(const SbVec2s& position)
     subMenuGroup.setExclusive(true);
     subMenu.setTitle(QObject::tr("Navigation styles"));
 
-    MenuManager::getInstance()->setupContextMenu(view,contextMenu);
+    MenuManager::getInstance()->setupContextMenu(view, contextMenu);
     contextMenu.addMenu(&subMenu);
 
     // add submenu at the end to select navigation style
@@ -979,711 +1152,3 @@ void NavigationStyle::openPopupMenu(const SbVec2s& position)
 // ----------------------------------------------------------------------------------
 
 TYPESYSTEM_SOURCE_ABSTRACT(Gui::UserNavigationStyle,Gui::NavigationStyle);
-
-// ----------------------------------------------------------------------------------
-
-/* TRANSLATOR Gui::InventorNavigationStyle */
-
-TYPESYSTEM_SOURCE(Gui::InventorNavigationStyle, Gui::UserNavigationStyle);
-
-InventorNavigationStyle::InventorNavigationStyle()
-{
-}
-
-InventorNavigationStyle::~InventorNavigationStyle()
-{
-}
-
-const char* InventorNavigationStyle::mouseButtons(ViewerMode mode)
-{
-    switch (mode) {
-    case NavigationStyle::SELECTION:
-        return QT_TR_NOOP("Press CTRL and left mouse button");
-    case NavigationStyle::PANNING:
-        return QT_TR_NOOP("Press middle mouse button");
-    case NavigationStyle::DRAGGING:
-        return QT_TR_NOOP("Press left mouse button");
-    case NavigationStyle::ZOOMING:
-        return QT_TR_NOOP("Scroll middle mouse button");
-    default:
-        return "No description";
-    }
-}
-
-SbBool InventorNavigationStyle::processSoEvent(const SoEvent * const ev)
-{
-    // Events when in "ready-to-seek" mode are ignored, except those
-    // which influence the seek mode itself -- these are handled further
-    // up the inheritance hierarchy.
-    if (this->isSeekMode()) { return inherited::processSoEvent(ev); }
-
-    const SoType type(ev->getTypeId());
-
-    const SbViewportRegion & vp = viewer->getViewportRegion();
-    const SbVec2s size(vp.getViewportSizePixels());
-    const SbVec2f prevnormalized = this->lastmouseposition;
-    const SbVec2s pos(ev->getPosition());
-    const SbVec2f posn((float) pos[0] / (float) SoQtMax((int)(size[0] - 1), 1),
-                       (float) pos[1] / (float) SoQtMax((int)(size[1] - 1), 1));
-
-    this->lastmouseposition = posn;
-
-    // Set to TRUE if any event processing happened. Note that it is not
-    // necessary to restrict ourselves to only do one "action" for an
-    // event, we only need this flag to see if any processing happened
-    // at all.
-    SbBool processed = FALSE;
-
-    const ViewerMode curmode = this->currentmode;
-    ViewerMode newmode = curmode;
-
-    // Mismatches in state of the modifier keys happens if the user
-    // presses or releases them outside the viewer window.
-    if (this->ctrldown != ev->wasCtrlDown()) {
-        this->ctrldown = ev->wasCtrlDown();
-    }
-    if (this->shiftdown != ev->wasShiftDown()) {
-        this->shiftdown = ev->wasShiftDown();
-    }
-    if (this->altdown != ev->wasAltDown()) {
-        this->altdown = ev->wasAltDown();
-    }
-
-    // give the nodes in the foreground root the chance to handle events (e.g color bar)
-    if (!processed && !viewer->isEditing()) {
-        processed = handleEventInForeground(ev);
-        if (processed)
-            return TRUE;
-    }
-
-    // Keyboard handling
-    if (type.isDerivedFrom(SoKeyboardEvent::getClassTypeId())) {
-        const SoKeyboardEvent * const event = (const SoKeyboardEvent *) ev;
-        const SbBool press = event->getState() == SoButtonEvent::DOWN ? TRUE : FALSE;
-        switch (event->getKey()) {
-        case SoKeyboardEvent::LEFT_CONTROL:
-        case SoKeyboardEvent::RIGHT_CONTROL:
-            this->ctrldown = press;
-            break;
-        case SoKeyboardEvent::LEFT_SHIFT:
-        case SoKeyboardEvent::RIGHT_SHIFT:
-            this->shiftdown = press;
-            break;
-        case SoKeyboardEvent::LEFT_ALT:
-        case SoKeyboardEvent::RIGHT_ALT:
-            this->altdown = press;
-            break;
-        case SoKeyboardEvent::H:
-            processed = TRUE;
-            viewer->saveHomePosition();
-            break;
-        case SoKeyboardEvent::S:
-        case SoKeyboardEvent::HOME:
-        case SoKeyboardEvent::LEFT_ARROW:
-        case SoKeyboardEvent::UP_ARROW:
-        case SoKeyboardEvent::RIGHT_ARROW:
-        case SoKeyboardEvent::DOWN_ARROW:
-            if (!this->isViewing())
-                this->setViewing(true);
-            break;
-        default:
-            break;
-        }
-    }
-
-    // Mouse Button / Spaceball Button handling
-    if (type.isDerivedFrom(SoMouseButtonEvent::getClassTypeId())) {
-        const SoMouseButtonEvent * const event = (const SoMouseButtonEvent *) ev;
-        const int button = event->getButton();
-        const SbBool press = event->getState() == SoButtonEvent::DOWN ? TRUE : FALSE;
-
-        // SoDebugError::postInfo("processSoEvent", "button = %d", button);
-        switch (button) {
-        case SoMouseButtonEvent::BUTTON1:
-            this->button1down = press;
-            if (press && ev->wasShiftDown() &&
-                (this->currentmode != NavigationStyle::SELECTION)) {
-                this->centerTime = ev->getTime();
-                float ratio = vp.getViewportAspectRatio();
-                SbViewVolume vv = viewer->getCamera()->getViewVolume(ratio);
-                this->panningplane = vv.getPlane(viewer->getCamera()->focalDistance.getValue());
-                this->lockrecenter = FALSE;
-            }
-            else if (!press && ev->wasShiftDown() &&
-                (this->currentmode != NavigationStyle::SELECTION)) {
-                SbTime tmp = (ev->getTime() - this->centerTime);
-                float dci = (float)QApplication::doubleClickInterval()/1000.0f;
-                // is it just a left click?
-                if (tmp.getValue() < dci && !this->lockrecenter) {
-                    if (!this->seekToPoint(pos)) {
-                        panToCenter(panningplane, posn);
-                        this->interactiveCountDec();
-                    }
-                    processed = TRUE;
-                }
-            }
-            else if (press && (this->currentmode == NavigationStyle::SEEK_WAIT_MODE)) {
-                newmode = NavigationStyle::SEEK_MODE;
-                this->seekToPoint(pos); // implicitly calls interactiveCountInc()
-                processed = TRUE;
-            }
-            else if (press && (this->currentmode == NavigationStyle::IDLE)) {
-                this->setViewing(true);
-                processed = TRUE;
-            }
-            else if (!press && (this->currentmode == NavigationStyle::DRAGGING)) {
-                this->setViewing(false);
-                processed = TRUE;
-            }
-            else if (viewer->isEditing() && (this->currentmode == NavigationStyle::SPINNING)) {
-                processed = TRUE;
-            }
-            this->lockrecenter = TRUE;
-            break;
-        case SoMouseButtonEvent::BUTTON2:
-            // If we are in edit mode then simply ignore the RMB events
-            // to pass the event to the base class.
-            this->lockrecenter = TRUE;
-            if (!viewer->isEditing()) {
-                // If we are in zoom or pan mode ignore RMB events otherwise
-                // the canvas doesn't get any release events 
-                if (this->currentmode != NavigationStyle::ZOOMING && 
-                    this->currentmode != NavigationStyle::PANNING) {
-                    if (this->isPopupMenuEnabled()) {
-                        if (!press) { // release right mouse button
-                            this->openPopupMenu(event->getPosition());
-                        }
-                    }
-                }
-            }
-            break;
-        case SoMouseButtonEvent::BUTTON3:
-            if (press) {
-                this->centerTime = ev->getTime();
-                float ratio = vp.getViewportAspectRatio();
-                SbViewVolume vv = viewer->getCamera()->getViewVolume(ratio);
-                this->panningplane = vv.getPlane(viewer->getCamera()->focalDistance.getValue());
-                this->lockrecenter = FALSE;
-            }
-            else {
-                SbTime tmp = (ev->getTime() - this->centerTime);
-                float dci = (float)QApplication::doubleClickInterval()/1000.0f;
-                // is it just a middle click?
-                if (tmp.getValue() < dci && !this->lockrecenter) {
-                    if (!this->seekToPoint(pos)) {
-                        panToCenter(panningplane, posn);
-                        this->interactiveCountDec();
-                    }
-                    processed = TRUE;
-                }
-            }
-            this->button3down = press;
-            break;
-        case SoMouseButtonEvent::BUTTON4:
-            if (this->invertZoom)
-                zoom(viewer->getCamera(), -0.05f);
-            else
-                zoom(viewer->getCamera(), 0.05f);
-            processed = TRUE;
-            break;
-        case SoMouseButtonEvent::BUTTON5:
-            if (this->invertZoom)
-                zoom(viewer->getCamera(), 0.05f);
-            else
-                zoom(viewer->getCamera(), -0.05f);
-            processed = TRUE;
-            break;
-        default:
-            break;
-        }
-    }
-
-    // Mouse Movement handling
-    if (type.isDerivedFrom(SoLocation2Event::getClassTypeId())) {
-        this->lockrecenter = TRUE;
-        const SoLocation2Event * const event = (const SoLocation2Event *) ev;
-        if (this->currentmode == NavigationStyle::ZOOMING) {
-            this->zoomByCursor(posn, prevnormalized);
-            processed = TRUE;
-        }
-        else if (this->currentmode == NavigationStyle::PANNING) {
-            float ratio = vp.getViewportAspectRatio();
-            panCamera(viewer->getCamera(), ratio, this->panningplane, posn, prevnormalized);
-            processed = TRUE;
-        }
-        else if (this->currentmode == NavigationStyle::DRAGGING) {
-            this->addToLog(event->getPosition(), event->getTime());
-            this->spin(posn);
-            processed = TRUE;
-        }
-    }
-
-    // Spaceball & Joystick handling
-    if (type.isDerivedFrom(SoMotion3Event::getClassTypeId())) {
-        SoMotion3Event * const event = (SoMotion3Event *) ev;
-        SoCamera * const camera = viewer->getCamera();
-        if (camera) {
-            SbVec3f dir = event->getTranslation();
-            camera->orientation.getValue().multVec(dir,dir);
-            camera->position = camera->position.getValue() + dir;
-            camera->orientation = 
-                event->getRotation() * camera->orientation.getValue();
-            processed = TRUE;
-        }
-    }
-
-    enum {
-        BUTTON1DOWN = 1 << 0,
-        BUTTON3DOWN = 1 << 1,
-        CTRLDOWN =    1 << 2,
-        SHIFTDOWN =   1 << 3
-    };
-    unsigned int combo =
-        (this->button1down ? BUTTON1DOWN : 0) |
-        (this->button3down ? BUTTON3DOWN : 0) |
-        (this->ctrldown ? CTRLDOWN : 0) |
-        (this->shiftdown ? SHIFTDOWN : 0);
-
-    switch (combo) {
-    case 0:
-        if (curmode == NavigationStyle::SPINNING) { break; }
-        newmode = NavigationStyle::IDLE;
-
-        if (curmode == NavigationStyle::DRAGGING) {
-            if (doSpin())
-                newmode = NavigationStyle::SPINNING;
-        }
-        break;
-    case BUTTON1DOWN:
-        newmode = NavigationStyle::DRAGGING;
-        break;
-    case BUTTON3DOWN:
-    case SHIFTDOWN|BUTTON1DOWN:
-        newmode = NavigationStyle::PANNING;
-        break;
-    case CTRLDOWN:
-    case CTRLDOWN|BUTTON1DOWN:
-    case CTRLDOWN|SHIFTDOWN:
-    case CTRLDOWN|SHIFTDOWN|BUTTON1DOWN:
-        newmode = NavigationStyle::SELECTION;
-        break;
-    case BUTTON1DOWN|BUTTON3DOWN:
-    case CTRLDOWN|BUTTON3DOWN:
-        newmode = NavigationStyle::ZOOMING;
-        break;
-
-        // There are many cases we don't handle that just falls through to
-        // the default case, like SHIFTDOWN, CTRLDOWN, CTRLDOWN|SHIFTDOWN,
-        // SHIFTDOWN|BUTTON3DOWN, SHIFTDOWN|CTRLDOWN|BUTTON3DOWN, etc.
-        // This is a feature, not a bug. :-)
-        //
-        // mortene.
-
-    default:
-        // The default will make a spin stop and otherwise not do
-        // anything.
-        if ((curmode != NavigationStyle::SEEK_WAIT_MODE) &&
-            (curmode != NavigationStyle::SEEK_MODE)) {
-            newmode = NavigationStyle::IDLE;
-        }
-        break;
-    }
-
-    if (newmode != curmode) {
-        this->setViewingMode(newmode);
-    }
-
-    // If not handled in this class, pass on upwards in the inheritance
-    // hierarchy.
-    if ((curmode == NavigationStyle::SELECTION || viewer->isEditing()) && !processed)
-        processed = inherited::processSoEvent(ev);
-    else
-        return TRUE;
-
-    return processed;
-}
-
-// ----------------------------------------------------------------------------------
-
-/* TRANSLATOR Gui::CADNavigationStyle */
-
-TYPESYSTEM_SOURCE(Gui::CADNavigationStyle, Gui::UserNavigationStyle);
-
-CADNavigationStyle::CADNavigationStyle() : lockButton1(FALSE)
-{
-}
-
-CADNavigationStyle::~CADNavigationStyle()
-{
-}
-
-const char* CADNavigationStyle::mouseButtons(ViewerMode mode)
-{
-    switch (mode) {
-    case NavigationStyle::SELECTION:
-        return QT_TR_NOOP("Press left mouse button");
-    case NavigationStyle::PANNING:
-        return QT_TR_NOOP("Press middle mouse button");
-    case NavigationStyle::DRAGGING:
-        return QT_TR_NOOP("Press left and middle mouse button");
-    case NavigationStyle::ZOOMING:
-        return QT_TR_NOOP("Scroll middle mouse button");
-    default:
-        return "No description";
-    }
-}
-
-SbBool CADNavigationStyle::processSoEvent(const SoEvent * const ev)
-{
-#if 0
-    // Events when in "ready-to-seek" mode are ignored, except those
-    // which influence the seek mode itself -- these are handled further
-    // up the inheritance hierarchy.
-    if (this->isSeekMode()) { return inherited::processSoEvent(ev); }
-#else
-    if (!this->isSeekMode() && this->isViewing())
-        this->setViewing(false); // by default disable viewing mode to render the scene
-#endif
-
-    const SoType type(ev->getTypeId());
-
-    const SbViewportRegion & vp = viewer->getViewportRegion();
-    const SbVec2s size(vp.getViewportSizePixels());
-    const SbVec2f prevnormalized = this->lastmouseposition;
-    const SbVec2s pos(ev->getPosition());
-    const SbVec2f posn((float) pos[0] / (float) SoQtMax((int)(size[0] - 1), 1),
-                       (float) pos[1] / (float) SoQtMax((int)(size[1] - 1), 1));
-
-    this->lastmouseposition = posn;
-
-    // Set to TRUE if any event processing happened. Note that it is not
-    // necessary to restrict ourselves to only do one "action" for an
-    // event, we only need this flag to see if any processing happened
-    // at all.
-    SbBool processed = FALSE;
-
-    const ViewerMode curmode = this->currentmode;
-    ViewerMode newmode = curmode;
-
-    // Mismatches in state of the modifier keys happens if the user
-    // presses or releases them outside the viewer window.
-    if (this->ctrldown != ev->wasCtrlDown()) {
-        this->ctrldown = ev->wasCtrlDown();
-    }
-    if (this->shiftdown != ev->wasShiftDown()) {
-        this->shiftdown = ev->wasShiftDown();
-    }
-    if (this->altdown != ev->wasAltDown()) {
-        this->altdown = ev->wasAltDown();
-    }
-
-    // give the nodes in the foreground root the chance to handle events (e.g color bar)
-    if (!processed && !viewer->isEditing()) {
-        processed = handleEventInForeground(ev);
-        if (processed)
-            return TRUE;
-    }
-
-    // Keyboard handling
-    if (type.isDerivedFrom(SoKeyboardEvent::getClassTypeId())) {
-        const SoKeyboardEvent * const event = (const SoKeyboardEvent *) ev;
-        const SbBool press = event->getState() == SoButtonEvent::DOWN ? TRUE : FALSE;
-        switch (event->getKey()) {
-        case SoKeyboardEvent::LEFT_CONTROL:
-        case SoKeyboardEvent::RIGHT_CONTROL:
-            this->ctrldown = press;
-            break;
-        case SoKeyboardEvent::LEFT_SHIFT:
-        case SoKeyboardEvent::RIGHT_SHIFT:
-            this->shiftdown = press;
-            break;
-        case SoKeyboardEvent::LEFT_ALT:
-        case SoKeyboardEvent::RIGHT_ALT:
-            this->altdown = press;
-            break;
-        case SoKeyboardEvent::H:
-            processed = TRUE;
-            viewer->saveHomePosition();
-            break;
-        case SoKeyboardEvent::S:
-        case SoKeyboardEvent::HOME:
-        case SoKeyboardEvent::LEFT_ARROW:
-        case SoKeyboardEvent::UP_ARROW:
-        case SoKeyboardEvent::RIGHT_ARROW:
-        case SoKeyboardEvent::DOWN_ARROW:
-            if (!this->isViewing())
-                this->setViewing(true);
-            break;
-        default:
-            break;
-        }
-    }
-
-    // Mouse Button / Spaceball Button handling
-    if (type.isDerivedFrom(SoMouseButtonEvent::getClassTypeId())) {
-        const SoMouseButtonEvent * const event = (const SoMouseButtonEvent *) ev;
-        const int button = event->getButton();
-        const SbBool press = event->getState() == SoButtonEvent::DOWN ? TRUE : FALSE;
-
-        // SoDebugError::postInfo("processSoEvent", "button = %d", button);
-        switch (button) {
-        case SoMouseButtonEvent::BUTTON1:
-            this->lockrecenter = TRUE;
-            this->button1down = press;
-#if 0 // disable to avoid interferences where this key combination is used, too
-            if (press && ev->wasShiftDown() &&
-                (this->currentmode != NavigationStyle::SELECTION)) {
-                this->centerTime = ev->getTime();
-                float ratio = vp.getViewportAspectRatio();
-                SbViewVolume vv = viewer->getCamera()->getViewVolume(ratio);
-                this->panningplane = vv.getPlane(viewer->getCamera()->focalDistance.getValue());
-                this->lockrecenter = FALSE;
-            }
-            else if (!press && ev->wasShiftDown() &&
-                (this->currentmode != NavigationStyle::SELECTION)) {
-                SbTime tmp = (ev->getTime() - this->centerTime);
-                float dci = (float)QApplication::doubleClickInterval()/1000.0f;
-                // is it just a left click?
-                if (tmp.getValue() < dci && !this->lockrecenter) {
-                    if (!this->seekToPoint(pos)) {
-                        panToCenter(panningplane, posn);
-                        this->interactiveCountDec();
-                    }
-                    processed = TRUE;
-                }
-            }
-            else
-#endif
-            if (press && (this->currentmode == NavigationStyle::SEEK_WAIT_MODE)) {
-                newmode = NavigationStyle::SEEK_MODE;
-                this->seekToPoint(pos); // implicitly calls interactiveCountInc()
-                processed = TRUE;
-            }
-            //else if (press && (this->currentmode == NavigationStyle::IDLE)) {
-            //    this->setViewing(true);
-            //    processed = TRUE;
-            //}
-            else if (press && (this->currentmode == NavigationStyle::PANNING ||
-                               this->currentmode == NavigationStyle::ZOOMING)) {
-                newmode = NavigationStyle::DRAGGING;
-                this->centerTime = ev->getTime();
-                processed = TRUE;
-            }
-            else if (!press && (this->currentmode == NavigationStyle::DRAGGING)) {
-                SbTime tmp = (ev->getTime() - this->centerTime);
-                float dci = (float)QApplication::doubleClickInterval()/1000.0f;
-                if (tmp.getValue() < dci) {
-                    newmode = NavigationStyle::ZOOMING;
-                }
-                processed = TRUE;
-            }
-            else if (!press && (this->currentmode == NavigationStyle::DRAGGING)) {
-                this->setViewing(false);
-                processed = TRUE;
-            }
-            else if (viewer->isEditing() && (this->currentmode == NavigationStyle::SPINNING)) {
-                processed = TRUE;
-            }
-            break;
-        case SoMouseButtonEvent::BUTTON2:
-            // If we are in edit mode then simply ignore the RMB events
-            // to pass the event to the base class.
-            this->lockrecenter = TRUE;
-            if (!viewer->isEditing()) {
-                // If we are in zoom or pan mode ignore RMB events otherwise
-                // the canvas doesn't get any release events 
-                if (this->currentmode != NavigationStyle::ZOOMING && 
-                    this->currentmode != NavigationStyle::PANNING &&
-                    this->currentmode != NavigationStyle::DRAGGING) {
-                    if (this->isPopupMenuEnabled()) {
-                        if (!press) { // release right mouse button
-                            this->openPopupMenu(event->getPosition());
-                        }
-                    }
-                }
-            }
-            this->button2down = press;
-            break;
-        case SoMouseButtonEvent::BUTTON3:
-            if (press) {
-                this->centerTime = ev->getTime();
-                float ratio = vp.getViewportAspectRatio();
-                SbViewVolume vv = viewer->getCamera()->getViewVolume(ratio);
-                this->panningplane = vv.getPlane(viewer->getCamera()->focalDistance.getValue());
-                this->lockrecenter = FALSE;
-            }
-            else {
-                SbTime tmp = (ev->getTime() - this->centerTime);
-                float dci = (float)QApplication::doubleClickInterval()/1000.0f;
-                // is it just a middle click?
-                if (tmp.getValue() < dci && !this->lockrecenter) {
-                    if (!this->seekToPoint(pos)) {
-                        panToCenter(panningplane, posn);
-                        this->interactiveCountDec();
-                    }
-                    processed = TRUE;
-                }
-            }
-            this->button3down = press;
-            break;
-        case SoMouseButtonEvent::BUTTON4:
-            if (this->invertZoom)
-                zoom(viewer->getCamera(), -0.05f);
-            else
-                zoom(viewer->getCamera(), 0.05f);
-            processed = TRUE;
-            break;
-        case SoMouseButtonEvent::BUTTON5:
-            if (this->invertZoom)
-                zoom(viewer->getCamera(), 0.05f);
-            else
-                zoom(viewer->getCamera(), -0.05f);
-            processed = TRUE;
-            break;
-        default:
-            break;
-        }
-    }
-
-    // Mouse Movement handling
-    if (type.isDerivedFrom(SoLocation2Event::getClassTypeId())) {
-        this->lockrecenter = TRUE;
-        const SoLocation2Event * const event = (const SoLocation2Event *) ev;
-        if (this->currentmode == NavigationStyle::ZOOMING) {
-            this->zoomByCursor(posn, prevnormalized);
-            processed = TRUE;
-        }
-        else if (this->currentmode == NavigationStyle::PANNING) {
-            float ratio = vp.getViewportAspectRatio();
-            panCamera(viewer->getCamera(), ratio, this->panningplane, posn, prevnormalized);
-            processed = TRUE;
-        }
-        else if (this->currentmode == NavigationStyle::DRAGGING) {
-            this->addToLog(event->getPosition(), event->getTime());
-            this->spin(posn);
-            processed = TRUE;
-        }
-    }
-
-    // Spaceball & Joystick handling
-    if (type.isDerivedFrom(SoMotion3Event::getClassTypeId())) {
-        SoMotion3Event * const event = (SoMotion3Event *) ev;
-        SoCamera * const camera = viewer->getCamera();
-        if (camera) {
-            SbVec3f dir = event->getTranslation();
-            camera->orientation.getValue().multVec(dir,dir);
-            camera->position = camera->position.getValue() + dir;
-            camera->orientation = 
-                event->getRotation() * camera->orientation.getValue();
-            processed = TRUE;
-        }
-    }
-
-    enum {
-        BUTTON1DOWN = 1 << 0,
-        BUTTON3DOWN = 1 << 1,
-        CTRLDOWN =    1 << 2,
-        SHIFTDOWN =   1 << 3,
-        BUTTON2DOWN = 1 << 4
-    };
-    unsigned int combo =
-        (this->button1down ? BUTTON1DOWN : 0) |
-        (this->button2down ? BUTTON2DOWN : 0) |
-        (this->button3down ? BUTTON3DOWN : 0) |
-        (this->ctrldown ? CTRLDOWN : 0) |
-        (this->shiftdown ? SHIFTDOWN : 0);
-
-    switch (combo) {
-    case 0:
-        if (curmode == NavigationStyle::SPINNING) { break; }
-        newmode = NavigationStyle::IDLE;
-        // The left mouse button has been released right now but
-        // we want to avoid that the event is procesed elsewhere
-        if (this->lockButton1) {
-            this->lockButton1 = FALSE;
-            processed = TRUE;
-        }
-
-        //if (curmode == NavigationStyle::DRAGGING) {
-        //    if (doSpin())
-        //        newmode = NavigationStyle::SPINNING;
-        //}
-        break;
-    case BUTTON1DOWN:
-        // make sure not to change the selection when stopping spinning
-        if (curmode == NavigationStyle::SPINNING || this->lockButton1)
-            newmode = NavigationStyle::IDLE;
-        else
-            newmode = NavigationStyle::SELECTION;
-        break;
-    case BUTTON3DOWN:
-        if (curmode == NavigationStyle::SPINNING) { break; }
-        else if (newmode == NavigationStyle::ZOOMING) { break; }
-        newmode = NavigationStyle::PANNING;
-
-        if (curmode == NavigationStyle::DRAGGING) {
-            if (doSpin()) {
-                newmode = NavigationStyle::SPINNING;
-                break;
-            }
-        }
-        break;
-    case CTRLDOWN|BUTTON2DOWN:
-        newmode = NavigationStyle::PANNING;
-        break;
-    case SHIFTDOWN|BUTTON2DOWN:
-        newmode = NavigationStyle::DRAGGING;
-        break;
-    case CTRLDOWN|SHIFTDOWN|BUTTON2DOWN:
-        newmode = NavigationStyle::ZOOMING;
-        break;
-    //case CTRLDOWN:
-    //case CTRLDOWN|BUTTON1DOWN:
-    //case CTRLDOWN|SHIFTDOWN:
-    //case CTRLDOWN|SHIFTDOWN|BUTTON1DOWN:
-    //    newmode = NavigationStyle::SELECTION;
-    //    break;
-    //case BUTTON1DOWN|BUTTON3DOWN:
-    //case CTRLDOWN|BUTTON3DOWN:
-    //    newmode = NavigationStyle::ZOOMING;
-    //    break;
-
-        // There are many cases we don't handle that just falls through to
-        // the default case, like SHIFTDOWN, CTRLDOWN, CTRLDOWN|SHIFTDOWN,
-        // SHIFTDOWN|BUTTON3DOWN, SHIFTDOWN|CTRLDOWN|BUTTON3DOWN, etc.
-        // This is a feature, not a bug. :-)
-        //
-        // mortene.
-
-    default:
-        // The default will make a spin stop and otherwise not do
-        // anything.
-        //if ((curmode != NavigationStyle::SEEK_WAIT_MODE) &&
-        //    (curmode != NavigationStyle::SEEK_MODE)) {
-        //    newmode = NavigationStyle::IDLE;
-        //}
-        break;
-    }
-
-    if (newmode != curmode) {
-        this->setViewingMode(newmode);
-    }
-
-    // If for dragging the buttons 1 and 3 are pressed
-    // but then button 3 is relaesed we shouldn't switch
-    // into selection mode.
-    if (this->button1down && this->button3down)
-        this->lockButton1 = TRUE;
-
-    // If not handled in this class, pass on upwards in the inheritance
-    // hierarchy.
-    if (/*(curmode == NavigationStyle::SELECTION || viewer->isEditing()) && */!processed)
-        processed = inherited::processSoEvent(ev);
-    else
-        return TRUE;
-
-    return processed;
-}
-
-#undef PRIVATE
-#undef PUBLIC
