@@ -61,8 +61,7 @@ struct PythonConsoleP
     enum Output {Error = 20, Message = 21};
     enum CopyType {Normal, History, Command};
     CopyType type;
-    PyObject *_stdoutPy, *_stderrPy, *_stdinPy;
-    PyObject *_stdout, *_stderr, *_stdin;
+    PyObject *_stdoutPy, *_stderrPy, *_stdinPy, *_stdin;
     InteractiveInterpreter* interpreter;
     CallTipsList* callTipsList;
     ConsoleHistory history;
@@ -347,6 +346,7 @@ PythonConsole::PythonConsole(QWidget *parent)
 
     // use the console highlighter
     pythonSyntax = new PythonConsoleHighlighter(this);
+    pythonSyntax->setDocument(this->document());
 
     // create the window for call tips
     d->callTipsList = new CallTipsList(this);
@@ -374,8 +374,6 @@ PythonConsole::PythonConsole(QWidget *parent)
     d->_stdoutPy = new PythonStdout(this);
     d->_stderrPy = new PythonStderr(this);
     d->_stdinPy  = new PythonStdin (this);
-    d->_stdout = PySys_GetObject("stdout");
-    d->_stderr = PySys_GetObject("stderr");
     d->_stdin  = PySys_GetObject("stdin");
     PySys_SetObject("stdin", d->_stdinPy);
 
@@ -596,7 +594,7 @@ void PythonConsole::appendOutput(const QString& output, int state)
     
     // delay rehighlighting
     cursor.beginEditBlock();
-    append(output);
+    appendPlainText(output);
 
     QTextBlock block = this->document()->findBlock(pos);
     while (block.isValid()) {
@@ -613,6 +611,8 @@ void PythonConsole::runSource(const QString& line)
 {
     bool incomplete = false;
     Base::PyGILStateLocker lock;
+    PyObject* default_stdout = PySys_GetObject("stdout");
+    PyObject* default_stderr = PySys_GetObject("stderr");
     PySys_SetObject("stdout", d->_stdoutPy);
     PySys_SetObject("stderr", d->_stderrPy);
     d->interactive = true;
@@ -623,6 +623,9 @@ void PythonConsole::runSource(const QString& line)
         setFocus(); // if focus was lost
     }
     catch (const Base::SystemExitException&) {
+        ParameterGrp::handle hPrefGrp = getWindowParameter();
+        bool check = hPrefGrp->GetBool("CheckSystemExit",true);
+        if (!check)  Base::Interpreter().systemExit();
         int ret = QMessageBox::question(this, tr("System exit"), tr("The application is still running.\nDo you want to exit without saving your data?"),
         QMessageBox::Yes, QMessageBox::No|QMessageBox::Escape|QMessageBox::Default);
         if (ret == QMessageBox::Yes) {
@@ -644,8 +647,8 @@ void PythonConsole::runSource(const QString& line)
         QMessageBox::critical(this, tr("Python console"), tr("Unhandled unknown C++ exception."));
     }
 
-    PySys_SetObject("stdout", d->_stdout);
-    PySys_SetObject("stderr", d->_stderr);
+    PySys_SetObject("stdout", default_stdout);
+    PySys_SetObject("stderr", default_stderr);
     printPrompt(incomplete);
     d->interactive = false;
     for (QStringList::Iterator it = d->statements.begin(); it != d->statements.end(); ++it)
@@ -742,7 +745,7 @@ void PythonConsole::dropEvent (QDropEvent * e)
         e->accept();
     }
     else // this will call insertFromMimeData
-        QTextEdit::dropEvent(e);
+        QPlainTextEdit::dropEvent(e);
 }
 
 /** Dragging of action objects is allowed. */ 
@@ -752,7 +755,7 @@ void PythonConsole::dragMoveEvent( QDragMoveEvent *e )
     if (mimeData->hasFormat(QLatin1String("text/x-action-items")))
         e->accept();
     else // this will call canInsertFromMimeData
-        QTextEdit::dragMoveEvent(e);
+        QPlainTextEdit::dragMoveEvent(e);
 }
 
 /** Dragging of action objects is allowed. */ 
@@ -762,7 +765,7 @@ void PythonConsole::dragEnterEvent (QDragEnterEvent * e)
     if (mimeData->hasFormat(QLatin1String("text/x-action-items")))
         e->accept();
     else // this will call canInsertFromMimeData
-        QTextEdit::dragEnterEvent(e);
+        QPlainTextEdit::dragEnterEvent(e);
 }
 
 bool PythonConsole::canInsertFromMimeData (const QMimeData * source) const
@@ -983,7 +986,7 @@ void PythonConsole::contextMenuEvent ( QContextMenuEvent * e )
     QMenu menu(this);
     QAction *a;
 
-    a = menu.addAction(QTextEdit::tr("&Copy"), this, SLOT(copy()), Qt::CTRL+Qt::Key_C);
+    a = menu.addAction(tr("&Copy"), this, SLOT(copy()), Qt::CTRL+Qt::Key_C);
     a->setEnabled(textCursor().hasSelection());
 
     a = menu.addAction(tr("&Copy command"), this, SLOT(onCopyCommand()));
@@ -996,11 +999,11 @@ void PythonConsole::contextMenuEvent ( QContextMenuEvent * e )
     a->setEnabled(!d->history.isEmpty());
 
     menu.addSeparator();
-    a = menu.addAction(QTextEdit::tr("&Paste"), this, SLOT(paste()), Qt::CTRL+Qt::Key_V);
+    a = menu.addAction(tr("&Paste"), this, SLOT(paste()), Qt::CTRL+Qt::Key_V);
     const QMimeData *md = QApplication::clipboard()->mimeData();
     a->setEnabled(md && canInsertFromMimeData(md));
 
-    a = menu.addAction(QTextEdit::tr("Select All"), this, SLOT(selectAll()), Qt::CTRL+Qt::Key_A);
+    a = menu.addAction(tr("Select All"), this, SLOT(selectAll()), Qt::CTRL+Qt::Key_A);
     a->setEnabled(!document()->isEmpty());
 
     menu.addSeparator();
@@ -1072,8 +1075,8 @@ void PythonConsole::onCopyCommand()
 
 // ---------------------------------------------------------------------
 
-PythonConsoleHighlighter::PythonConsoleHighlighter(QTextEdit* edit)
-  : PythonSyntaxHighlighter(edit)
+PythonConsoleHighlighter::PythonConsoleHighlighter(QObject* parent)
+  : PythonSyntaxHighlighter(parent)
 {
 }
 
