@@ -28,7 +28,7 @@
 
 #include <Base/PyObjectBase.h>
 
-class QTextEdit;
+class QPlainTextEdit;
 class QPushButton;
 
 namespace Gui {
@@ -150,7 +150,7 @@ private:
 class GuiExport PythonConsoleHighlighter : public PythonSyntaxHighlighter
 {
 public:
-    PythonConsoleHighlighter(QTextEdit *);
+    PythonConsoleHighlighter(QObject* parent);
     ~PythonConsoleHighlighter();
 
     void highlightBlock (const QString & text);
@@ -179,7 +179,7 @@ Q_SIGNALS:
 private:
     QPushButton* okButton;
     QPushButton* clearButton;
-    QTextEdit* editField;
+    QPlainTextEdit* editField;
 };
 
 } // namespace Gui
