@@ -76,7 +76,7 @@ PythonEditor::PythonEditor(QWidget* parent)
   : TextEditor(parent)
 {
     d = new PythonEditorP();
-    (void)new PythonSyntaxHighlighter(this);
+    this->setSyntaxHighlighter(new PythonSyntaxHighlighter(this));
 
     // set acelerators
     QShortcut* comment = new QShortcut(this);
@@ -98,6 +98,20 @@ PythonEditor::~PythonEditor()
     delete d;
 }
 
+void PythonEditor::drawMarker(int line, int x, int y, QPainter* p)
+{
+#if 0
+    Breakpoint bp = _dbg->getBreakpoint(fileName());
+    if (bp.checkLine(line)) {
+        p->drawPixmap(x, y, breakpoint);
+    }
+    if (m_debugLine == line) {
+        p->drawPixmap(x, y+2, debugMarker);
+        debugRect = QRect(x, y+2, debugMarker.width(), debugMarker.height());
+    }
+#endif
+}
+
 void PythonEditor::contextMenuEvent ( QContextMenuEvent * e )
 {
     QMenu* menu = createStandardContextMenu();
@@ -190,8 +204,8 @@ public:
 /**
  * Constructs a Python syntax highlighter.
  */
-PythonSyntaxHighlighter::PythonSyntaxHighlighter(QTextEdit* edit)
-    : SyntaxHighlighter(edit)
+PythonSyntaxHighlighter::PythonSyntaxHighlighter(QObject* parent)
+    : SyntaxHighlighter(parent)
 {
     d = new PythonSyntaxHighlighterP;
 }
