@@ -60,6 +60,7 @@ public Q_SLOTS:
 protected:
     /** Pops up the context menu with some extensions */
     void contextMenuEvent ( QContextMenuEvent* e );
+    void drawMarker(int line, int x, int y, QPainter*);
 
 private:
     //PythonSyntaxHighlighter* pythonSyntax;
@@ -73,7 +74,7 @@ private:
 class GuiExport PythonSyntaxHighlighter : public SyntaxHighlighter
 {
 public:
-    PythonSyntaxHighlighter(QTextEdit* );
+    PythonSyntaxHighlighter(QObject* parent);
     virtual ~PythonSyntaxHighlighter();
 
     void highlightBlock (const QString & text);
