@@ -170,18 +170,18 @@ void SplitView3DInventor::OnChange(ParameterGrp::SubjectType &rCaller,ParameterG
             (*it)->getBacklight()->intensity.setValue((float)value/100.0f);
     }
     else if (strcmp(Reason,"EnablePreselection") == 0) {
-        SoFCEnableHighlightAction cAct(rGrp.GetBool("EnablePreselection", false));
+        SoFCEnableHighlightAction cAct(rGrp.GetBool("EnablePreselection", true));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
             cAct.apply((*it)->getSceneGraph());
     }
     else if (strcmp(Reason,"EnableSelection") == 0) {
-        SoFCEnableSelectionAction cAct(rGrp.GetBool("EnableSelection", false));
+        SoFCEnableSelectionAction cAct(rGrp.GetBool("EnableSelection", true));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
             cAct.apply((*it)->getSceneGraph());
     }
     else if (strcmp(Reason,"HighlightColor") == 0) {
         float transparency;
-        SbColor highlightColor(0.1f, 0.1f, 0.8f);
+        SbColor highlightColor(0.8f, 0.1f, 0.1f);
         unsigned long highlight = (unsigned long)(highlightColor.getPackedValue());
         highlight = rGrp.GetUnsigned("HighlightColor", highlight);
         highlightColor.setPackedValue((uint32_t)highlight, transparency);
@@ -192,7 +192,7 @@ void SplitView3DInventor::OnChange(ParameterGrp::SubjectType &rCaller,ParameterG
     }
     else if (strcmp(Reason,"SelectionColor") == 0) {
         float transparency;
-        SbColor selectionColor(0.1f, 0.5f, 0.1f);
+        SbColor selectionColor(0.1f, 0.8f, 0.1f);
         unsigned long selection = (unsigned long)(selectionColor.getPackedValue());
         selection = rGrp.GetUnsigned("SelectionColor", selection);
         selectionColor.setPackedValue((uint32_t)selection, transparency);
@@ -245,10 +245,10 @@ void SplitView3DInventor::OnChange(ParameterGrp::SubjectType &rCaller,ParameterG
         }
     }
     else {
-        unsigned long col1 = rGrp.GetUnsigned("BackgroundColor",0);
-        unsigned long col2 = rGrp.GetUnsigned("BackgroundColor2",2139082239); // default color (purple)
-        unsigned long col3 = rGrp.GetUnsigned("BackgroundColor3",ULONG_MAX); // default color (white)
-        unsigned long col4 = rGrp.GetUnsigned("BackgroundColor4",ULONG_MAX); // default color (white)
+        unsigned long col1 = rGrp.GetUnsigned("BackgroundColor",3940932863UL);
+        unsigned long col2 = rGrp.GetUnsigned("BackgroundColor2",859006463UL); // default color (dark blue)
+        unsigned long col3 = rGrp.GetUnsigned("BackgroundColor3",2880160255UL); // default color (blue/grey)
+        unsigned long col4 = rGrp.GetUnsigned("BackgroundColor4",1869583359UL); // default color (blue/grey)
         float r1,g1,b1,r2,g2,b2,r3,g3,b3,r4,g4,b4;
         r1 = ((col1 >> 24) & 0xff) / 255.0; g1 = ((col1 >> 16) & 0xff) / 255.0; b1 = ((col1 >> 8) & 0xff) / 255.0;
         r2 = ((col2 >> 24) & 0xff) / 255.0; g2 = ((col2 >> 16) & 0xff) / 255.0; b2 = ((col2 >> 8) & 0xff) / 255.0;
@@ -301,7 +301,7 @@ bool SplitView3DInventor::onMsg(const char* pMsg, const char** ppReturn)
     else if (strcmp("ViewLeft",pMsg) == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getCamera();
-            cam->orientation.setValue(0.5, 0.5, 0.5, 0.5);
+            cam->orientation.setValue(-0.5, 0.5, 0.5, -0.5);
             (*it)->viewAll();
         }
         return true;
@@ -318,7 +318,7 @@ bool SplitView3DInventor::onMsg(const char* pMsg, const char** ppReturn)
     else if (strcmp("ViewRight",pMsg) == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getCamera();
-            cam->orientation.setValue(-0.5, 0.5, 0.5, -0.5);
+            cam->orientation.setValue(0.5, 0.5, 0.5, 0.5);
             (*it)->viewAll();
         }
         return true;
