@@ -25,12 +25,13 @@
 #define GUI_TEXTEDIT_H
 
 #include <QListWidget>
-#include <QTextEdit>
+#include <QPlainTextEdit>
 #include "View.h"
 #include "Window.h"
 
 namespace Gui {
 class CompletionBox;
+class SyntaxHighlighter;
 
 /**
  * Completion is a means by which an editor automatically completes words that the user is typing. 
@@ -50,7 +51,7 @@ class CompletionBox;
  * @author Werner Mayer
  */
 class CompletionList;
-class GuiExport TextEdit : public QTextEdit
+class GuiExport TextEdit : public QPlainTextEdit
 {
     Q_OBJECT
 
@@ -81,25 +82,50 @@ class GuiExport TextEditor : public TextEdit, public WindowParameter
 public:
     TextEditor(QWidget *parent = 0);
     ~TextEditor();
+    void setSyntaxHighlighter(SyntaxHighlighter*);
 
     void OnChange(Base::Subject<const char*> &rCaller,const char* rcReason);
 
+    void lineNumberAreaPaintEvent(QPaintEvent* );
+    int lineNumberAreaWidth();
+
 private Q_SLOTS:
-    void onCursorPositionChanged();
+    void updateLineNumberAreaWidth(int newBlockCount);
+    void updateLineNumberArea(const QRect &, int);
+    void highlightCurrentLine();
 
 protected:
     void keyPressEvent (QKeyEvent * e);
-    void insertFromMimeData(const QMimeData *source);
     /** Draw a beam in the line where the cursor is. */
     void paintEvent (QPaintEvent * e);
+    void resizeEvent(QResizeEvent* e);
+    virtual void drawMarker(int line, int x, int y, QPainter*);
 
 private:
     SyntaxHighlighter* highlighter;
+    QWidget* lineNumberArea;
     struct TextEditorP* d;
 
     friend class SyntaxHighlighter;
 };
 
+class LineMarker : public QWidget
+{
+    Q_OBJECT
+
+public:
+    LineMarker(TextEditor* editor);
+    virtual ~LineMarker();
+
+    QSize sizeHint() const;
+
+protected:
+    void paintEvent (QPaintEvent *);
+
+private:
+    TextEditor *textEditor;
+};
+
 /**
  * The CompletionList class provides a list box that pops up in a text edit if the user has pressed
  * an accelerator to complete the current word he is typing in.
@@ -111,7 +137,7 @@ class CompletionList : public QListWidget
 
 public:
     /// Construction
-    CompletionList(QTextEdit* parent);
+    CompletionList(QPlainTextEdit* parent);
     /// Destruction
     ~CompletionList();
 
@@ -124,7 +150,7 @@ private Q_SLOTS:
     void completionItem(QListWidgetItem *item);
 
 private:
-    QTextEdit* textEdit;
+    QPlainTextEdit* textEdit;
 };
 
 } // namespace Gui
