@@ -76,6 +76,7 @@
 # include <QKeyEvent>
 # include <QMessageBox>
 # include <QTimer>
+# include <QStatusBar>
 #endif
 
 #include <sstream>
@@ -94,6 +95,7 @@
 #include "SoFCColorGradient.h"
 #include "SoFCOffscreenRenderer.h"
 #include "SoFCSelection.h"
+#include "SoFCUnifiedSelection.h"
 #include "SoFCInteractiveElement.h"
 #include "SoFCBoundingBox.h"
 #include "Selection.h"
@@ -104,6 +106,7 @@
 #include "MainWindow.h"
 #include "NavigationStyle.h"
 #include "ViewProvider.h"
+#include "SpaceballEvent.h"
 
 #include <Inventor/draggers/SoCenterballDragger.h>
 
@@ -183,37 +186,45 @@ View3DInventorViewer::View3DInventorViewer (QWidget *parent, const char *name,
     cam->nearDistance = 0;
     cam->farDistance = 10;
 
-	// dragger
-	//SoSeparator * draggSep = new SoSeparator();
-	//SoScale *scale = new SoScale();
-	//scale->scaleFactor = SbVec3f  (0.2,0.2,0.2);
-	//draggSep->addChild(scale);
-	//SoCenterballDragger *dragger = new SoCenterballDragger();
-	//dragger->center = SbVec3f  (0.8,0.8,0);
-	////dragger->rotation = SbRotation(rrot[0],rrot[1],rrot[2],rrot[3]);
-	//draggSep->addChild(dragger);
-
+    // dragger
+    //SoSeparator * dragSep = new SoSeparator();
+    //SoScale *scale = new SoScale();
+    //scale->scaleFactor = SbVec3f  (0.2,0.2,0.2);
+    //dragSep->addChild(scale);
+    //SoCenterballDragger *dragger = new SoCenterballDragger();
+    //dragger->center = SbVec3f  (0.8,0.8,0);
+    ////dragger->rotation = SbRotation(rrot[0],rrot[1],rrot[2],rrot[3]);
+    //dragSep->addChild(dragger);
 
     this->foregroundroot->addChild(cam);
     this->foregroundroot->addChild(lm);
     this->foregroundroot->addChild(bc);
-    //this->foregroundroot->addChild(draggSep);
+    //this->foregroundroot->addChild(dragSep);
 
-    // set the ViewProvider root
-    //SoSelection* selectionRoot = new SoSelection();
-    //selectionRoot->addSelectionCallback(View3DInventorViewer::selectCB, this);
-    //selectionRoot->addDeselectionCallback(View3DInventorViewer::deselectCB, this);
-    //pcViewProviderRoot = selectionRoot;
+#if 0
     // NOTE: For every mouse click event the SoSelection searches for the picked
     // point which causes a certain slow-down because for all objects the primitives
     // must be created. Using an SoSeparator avoids this drawback.
-    pcViewProviderRoot = new SoSeparator();
+    SoSelection* selectionRoot = new SoSelection();
+    selectionRoot->addSelectionCallback(View3DInventorViewer::selectCB, this);
+    selectionRoot->addDeselectionCallback(View3DInventorViewer::deselectCB, this);
+    selectionRoot->setPickFilterCallback(View3DInventorViewer::pickFilterCB, this);
+#else
+    // NOTE: For every mouse click event the SoFCUnifiedSelection searches for the picked
+    // point which causes a certain slow-down because for all objects the primitives
+    // must be created. Using an SoSeparator avoids this drawback.
+    Gui::SoFCUnifiedSelection* selectionRoot = new Gui::SoFCUnifiedSelection();
+    selectionRoot->applySettings();
+    selectionRoot->viewer = this;
+#endif
+    // set the ViewProvider root node
+    pcViewProviderRoot = selectionRoot;
 
     // increase refcount before passing it to setScenegraph(), to avoid
     // premature destruction
     pcViewProviderRoot->ref();
     // is not really working with Coin3D. 
-//  redrawOverlayOnSelectionChange(pcSelection);
+    //redrawOverlayOnSelectionChange(pcSelection);
     setSceneGraph(pcViewProviderRoot);
     // Event callback node
     pEventCallback = new SoEventCallback();
@@ -311,7 +322,10 @@ SbBool View3DInventorViewer::hasViewProvider(ViewProvider* pcProvider) const
 void View3DInventorViewer::addViewProvider(ViewProvider* pcProvider)
 {
     SoSeparator* root = pcProvider->getRoot();
-    if (root) pcViewProviderRoot->addChild(root);
+    if (root){
+        pcViewProviderRoot->addChild(root);
+        _ViewProviderMap[root] = pcProvider;
+    }
     SoSeparator* fore = pcProvider->getFrontRoot();
     if (fore) foregroundroot->addChild(fore);
     SoSeparator* back = pcProvider->getBackRoot ();
@@ -326,13 +340,17 @@ void View3DInventorViewer::removeViewProvider(ViewProvider* pcProvider)
         resetEditingViewProvider();
 
     SoSeparator* root = pcProvider->getRoot();
-    if (root) pcViewProviderRoot->removeChild(root);
+    if (root){
+        pcViewProviderRoot->removeChild(root);
+        _ViewProviderMap.erase(root);
+    }
     SoSeparator* fore = pcProvider->getFrontRoot();
     if (fore) foregroundroot->removeChild(fore);
     SoSeparator* back = pcProvider->getBackRoot ();
     if (back) backgroundroot->removeChild(back);
   
     _ViewProviderSet.erase(pcProvider);
+  
 }
 
 SbBool View3DInventorViewer::setEditingViewProvider(Gui::ViewProvider* p, int ModNum)
@@ -344,6 +362,7 @@ SbBool View3DInventorViewer::setEditingViewProvider(Gui::ViewProvider* p, int Mo
     bool ok = p->startEditing(ModNum);
     if (ok) {
         this->editViewProvider = p;
+        this->editViewProvider->setEditViewer(this, ModNum);
         addEventCallback(SoEvent::getClassTypeId(), Gui::ViewProvider::eventCallback,this->editViewProvider);
     }
 
@@ -353,7 +372,8 @@ SbBool View3DInventorViewer::setEditingViewProvider(Gui::ViewProvider* p, int Mo
 /// reset from edit mode
 void View3DInventorViewer::resetEditingViewProvider()
 {
-    if (this->editViewProvider){
+    if (this->editViewProvider) {
+        this->editViewProvider->unsetEditViewer(this);
         this->editViewProvider->finishEditing();
         removeEventCallback(SoEvent::getClassTypeId(), Gui::ViewProvider::eventCallback,this->editViewProvider);
         this->editViewProvider = 0;
@@ -1023,6 +1043,42 @@ void View3DInventorViewer::processEvent(QEvent * event)
     if (!Base::Sequencer().isRunning() ||
         !Base::Sequencer().isBlocking())
         inherited::processEvent(event);
+
+    if (event->type() == Spaceball::ButtonEvent::ButtonEventType){
+        Spaceball::ButtonEvent *buttonEvent = static_cast<Spaceball::ButtonEvent *>(event);
+        if (!buttonEvent){
+            Base::Console().Log("invalid spaceball button event\n");
+            return;
+        }
+    }
+
+    if (event->type() == Spaceball::MotionEvent::MotionEventType) {
+        Spaceball::MotionEvent *motionEvent = static_cast<Spaceball::MotionEvent *>(event);
+        if (!motionEvent){
+            Base::Console().Log("invalid spaceball motion event\n");
+            return;
+        }
+
+        static float translationConstant(-.001f);
+        float xTrans, yTrans, zTrans;
+        xTrans = static_cast<float>(motionEvent->translationX());
+        yTrans = static_cast<float>(motionEvent->translationY());
+        zTrans = static_cast<float>(motionEvent->translationZ());
+        SbVec3f translationVector(xTrans, yTrans, zTrans * -1.0);
+        translationVector *= translationConstant;
+
+        static float rotationConstant(.0001f);
+        SbRotation xRot, yRot, zRot;
+        xRot.setValue(SbVec3f(-1.0, 0.0, 0.0), static_cast<float>(motionEvent->rotationX()) * rotationConstant);
+        yRot.setValue(SbVec3f(0.0, -1.0, 0.0), static_cast<float>(motionEvent->rotationY()) * rotationConstant);
+        zRot.setValue(SbVec3f(0.0, 0.0, 1.0), static_cast<float>(motionEvent->rotationZ()) * rotationConstant);
+
+        SoMotion3Event motion3Event;
+        motion3Event.setTranslation(translationVector);
+        motion3Event.setRotation(xRot * yRot * zRot);
+
+        this->processSoEvent(&motion3Event);
+    }
 }
 
 SbBool View3DInventorViewer::processSoEvent(const SoEvent * const ev)
@@ -1249,6 +1305,20 @@ void View3DInventorViewer::setCameraOrientation(const SbRotation& rot)
     navigation->setCameraOrientation(rot);
 }
 
+void View3DInventorViewer::setCameraType(SoType t)
+{
+    inherited::setCameraType(t);
+    if (t.isDerivedFrom(SoPerspectiveCamera::getClassTypeId())) {
+        // When doing a viewAll() for an orthographic camera and switching
+        // to perspective the scene looks completely srange because of the
+        // heightAngle. Setting it to 45 deg also causes an issue with a too
+        // close camera but we don't have this other ugly effect.
+        SoCamera* cam = this->getCamera();
+        if (cam == 0) return;
+        static_cast<SoPerspectiveCamera*>(cam)->heightAngle = (float)(M_PI / 4.0);
+    }
+}
+
 void View3DInventorViewer::moveCameraTo(const SbRotation& rot, const SbVec3f& pos, int steps, int ms)
 {
     SoCamera* cam = this->getCamera();
@@ -1310,6 +1380,57 @@ void View3DInventorViewer::viewAll()
     //navigation->viewAll();
 }
 
+void View3DInventorViewer::viewAll(float factor)
+{
+    SoCamera * cam = this->getCamera();
+    if (!cam) return;
+    if (factor <= 0.0f) return;
+
+    if (factor != 1.0f) {
+        SoSearchAction sa;
+        sa.setType(SoSkipBoundingGroup::getClassTypeId());
+        sa.setInterest(SoSearchAction::ALL);
+        sa.apply(this->getSceneGraph());
+        const SoPathList & pathlist = sa.getPaths();
+        for (int i = 0; i < pathlist.getLength(); i++ ) {
+            SoPath * path = pathlist[i];
+            SoSkipBoundingGroup * group = static_cast<SoSkipBoundingGroup*>(path->getTail());
+            group->mode = SoSkipBoundingGroup::EXCLUDE_BBOX;
+        }
+
+        SoGetBoundingBoxAction action(this->getViewportRegion());
+        action.apply(this->getSceneGraph());
+        SbBox3f box = action.getBoundingBox();
+        float minx,miny,minz,maxx,maxy,maxz;
+        box.getBounds(minx,miny,minz,maxx,maxy,maxz);
+
+        for (int i = 0; i < pathlist.getLength(); i++ ) {
+            SoPath * path = pathlist[i];
+            SoSkipBoundingGroup * group = static_cast<SoSkipBoundingGroup*>(path->getTail());
+            group->mode = SoSkipBoundingGroup::INCLUDE_BBOX;
+        }
+
+        SoCube * cube = new SoCube();
+        cube->width  = factor*(maxx-minx);
+        cube->height = factor*(maxy-miny);
+        cube->depth  = factor*(maxz-minz);
+
+        // fake a scenegraph with the desired bounding size
+        SoSeparator* graph = new SoSeparator();
+        graph->ref();
+        SoTranslation * tr = new SoTranslation();
+        tr->translation.setValue(box.getCenter());
+
+        graph->addChild(tr);
+        graph->addChild(cube);
+        cam->viewAll(graph, this->getViewportRegion());
+        graph->unref();
+    }
+    else {
+        viewAll();
+    }
+}
+
 void View3DInventorViewer::viewSelection()
 {
     // Search for all SoFCSelection nodes
@@ -1916,14 +2037,34 @@ void View3DInventorViewer::setEditingCursor (const QCursor& cursor)
 
 void View3DInventorViewer::selectCB(void *viewer, SoPath *path)
 {
-    ViewProvider* view = static_cast<View3DInventorViewer*>(viewer)->getViewProviderByPath(path);
-    if (view) view->select(path);
+    ViewProvider* vp = static_cast<View3DInventorViewer*>(viewer)->getViewProviderByPath(path);
+    if (vp && vp->useNewSelectionModel()) {
+    }
 }
 
 void View3DInventorViewer::deselectCB(void *viewer, SoPath *path)
 {
-    ViewProvider* view = static_cast<View3DInventorViewer*>(viewer)->getViewProviderByPath(path);
-    if (view) view->deselect(path);
+    ViewProvider* vp = static_cast<View3DInventorViewer*>(viewer)->getViewProviderByPath(path);
+    if (vp && vp->useNewSelectionModel()) {
+    }
+}
+
+SoPath * View3DInventorViewer::pickFilterCB(void *viewer, const SoPickedPoint * pp)
+{
+    ViewProvider* vp = static_cast<View3DInventorViewer*>(viewer)->getViewProviderByPath(pp->getPath());
+    if (vp && vp->useNewSelectionModel()) {
+        std::string e = vp->getElement(pp);
+        vp->getSelectionShape(e.c_str());
+        static char buf[513];
+        snprintf(buf,512,"Hovered: %s (%f,%f,%f)"
+                                   ,e.c_str()
+                                   ,pp->getPoint()[0]
+                                   ,pp->getPoint()[1]
+                                   ,pp->getPoint()[2]);
+
+        getMainWindow()->statusBar()->showMessage(QString::fromAscii(buf),3000);
+    }
+    return pp->getPath();
 }
 
 void View3DInventorViewer::addEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata)
@@ -1938,6 +2079,7 @@ void View3DInventorViewer::removeEventCallback(SoType eventtype, SoEventCallback
 
 ViewProvider* View3DInventorViewer::getViewProviderByPath(SoPath * path) const
 {
+    // FIXME Use the viewprovider map introduced for the selection
     for (std::set<ViewProvider*>::const_iterator it = _ViewProviderSet.begin(); it != _ViewProviderSet.end(); it++) {
         for (int i = 0; i<path->getLength();i++) {
             SoNode *node = path->getNode(i);
@@ -1950,6 +2092,22 @@ ViewProvider* View3DInventorViewer::getViewProviderByPath(SoPath * path) const
     return 0;
 }
 
+ViewProvider* View3DInventorViewer::getViewProviderByPathFromTail(SoPath * path) const
+{
+    // Make sure I'm the lowest LocHL in the pick path!
+    for (int i = 0; i < path->getLength(); i++) {
+        SoNode *node = path->getNodeFromTail(i);
+        if (node->isOfType(SoSeparator::getClassTypeId())) {
+            std::map<SoSeparator*,ViewProvider*>::const_iterator it = _ViewProviderMap.find(static_cast<SoSeparator*>(node));
+            if (it != _ViewProviderMap.end()){
+                return it->second;
+            }
+         }
+    }
+
+    return 0;
+}
+
 std::vector<ViewProvider*> View3DInventorViewer::getViewProvidersOfType(const Base::Type& typeId) const
 {
     std::vector<ViewProvider*> views;
