@@ -30,9 +30,11 @@
 
 
 #include "View3DPy.h"
+#include "ViewProviderDocumentObject.h"
 #include "ViewProviderExtern.h"
 #include "Application.h"
 #include "Document.h"
+#include "NavigationStyle.h"
 #include "SoFCSelection.h"
 #include "SoFCSelectionAction.h"
 #include "SoFCVectorizeSVGAction.h"
@@ -48,6 +50,8 @@
 #include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
 
+#include <App/Document.h>
+#include <App/DocumentObject.h>
 #include <CXX/Objects.hxx>
 
 using namespace Gui;
@@ -88,6 +92,7 @@ void View3DInventorPy::init_type()
     add_varargs_method("getCameraNode",&View3DInventorPy::getCameraNode,"getCameraNode()");
     add_varargs_method("getViewDirection",&View3DInventorPy::getViewDirection,"getViewDirection()");
     add_varargs_method("setCamera",&View3DInventorPy::setCamera,"setCamera()");
+    add_varargs_method("setCameraOrientation",&View3DInventorPy::setCameraOrientation,"setCameraOrientation()");
     add_varargs_method("getCameraType",&View3DInventorPy::getCameraType,"getCameraType()");
     add_varargs_method("setCameraType",&View3DInventorPy::setCameraType,"setCameraType()");
     add_varargs_method("listCameraTypes",&View3DInventorPy::listCameraTypes,"listCameraTypes()");
@@ -97,12 +102,16 @@ void View3DInventorPy::init_type()
         "Return the current cursor position relative to the coordinate system of the\n"
         "viewport region.\n");
     add_varargs_method("getObjectInfo",&View3DInventorPy::getObjectInfo,
-        "getObjectInfoPos(tuple of integers) -> dictionary or None\n"
+        "getObjectInfo(tuple of integers) -> dictionary or None\n"
         "\n"
         "Return a dictionary with the name of document, object and component. The\n"
         "dictionary also contains the coordinates of the appropriate 3d point of\n"
         "the underlying geometry in the scenegraph.\n"
         "If no geometry was found 'None' is returned, instead.\n");
+    add_varargs_method("getObjectsInfo",&View3DInventorPy::getObjectsInfo,
+        "getObjectsInfo(tuple of integers) -> dictionary or None\n"
+        "\n"
+        "Does the same as getObjectInfo() but returns a list of dictionaries or None.\n");
     add_varargs_method("getSize",&View3DInventorPy::getSize,"getSize()");
     add_varargs_method("getPoint",&View3DInventorPy::getPoint,
         "getPoint(pixel coords (as integer)) -> 3D vector\n"
@@ -121,6 +130,9 @@ void View3DInventorPy::init_type()
         "Deprecated -- use addEventCallbackPivy()");
     add_varargs_method("removeEventCallbackSWIG",&View3DInventorPy::removeEventCallbackPivy,
         "Deprecated -- use removeEventCallbackPivy()");
+    add_varargs_method("listNavigationTypes",&View3DInventorPy::listNavigationTypes,"listNavigationTypes()");
+    add_varargs_method("getNavigationType",&View3DInventorPy::getNavigationType,"getNavigationType()");
+    add_varargs_method("setNavigationType",&View3DInventorPy::setNavigationType,"setNavigationType()");
 }
 
 View3DInventorPy::View3DInventorPy(View3DInventor *vi)
@@ -130,6 +142,9 @@ View3DInventorPy::View3DInventorPy(View3DInventor *vi)
 
 View3DInventorPy::~View3DInventorPy()
 {
+    Base::PyGILStateLocker lock;
+    for (std::list<PyObject*>::iterator it = callbacks.begin(); it != callbacks.end(); ++it)
+        Py_DECREF(*it);
 }
 
 Py::Object View3DInventorPy::repr()
@@ -217,11 +232,12 @@ Py::Object View3DInventorPy::message(const Py::Tuple& args)
 
 Py::Object View3DInventorPy::fitAll(const Py::Tuple& args)
 {
-    if (!PyArg_ParseTuple(args.ptr(), ""))
+    double factor = 1.0;
+    if (!PyArg_ParseTuple(args.ptr(), "|d", &factor))
         throw Py::Exception();
 
     try {
-        _view->viewAll();
+        _view->getViewer()->viewAll((float)factor);
     }
     catch (const Base::Exception& e) {
         throw Py::Exception(e.what());
@@ -369,8 +385,41 @@ Py::Object View3DInventorPy::viewAxometric(const Py::Tuple& args)
         throw Py::Exception();
 
     try {
+        //from math import sqrt, degrees, asin
+        //p1=App.Rotation(App.Vector(1,0,0),90)
+        //p2=App.Rotation(App.Vector(0,0,1),45)
+        //p3=App.Rotation(App.Vector(1,1,0),45)
+        //p3=App.Rotation(App.Vector(1,1,0),degrees(asin(-sqrt(1.0/3.0))))
+        //p4=p3.multiply(p2).multiply(p1)
         _view->getViewer()->setCameraOrientation(SbRotation
-            (-0.353553f, -0.146447f, -0.353553f, -0.853553f));
+            (0.424708f, 0.17592f, 0.339851f, 0.820473f));
+    }
+    catch (const Base::Exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch (const std::exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch(...) {
+        throw Py::Exception("Unknown C++ exception");
+    }
+
+    return Py::None();
+}
+
+Py::Object View3DInventorPy::setCameraOrientation(const Py::Tuple& args)
+{
+    PyObject* o;
+    if (!PyArg_ParseTuple(args.ptr(), "O!", &PyTuple_Type, &o))
+        throw Py::Exception();
+
+    try {
+        Py::Tuple tuple(o);
+        float q0 = (float)Py::Float(tuple[0]);
+        float q1 = (float)Py::Float(tuple[1]);
+        float q2 = (float)Py::Float(tuple[2]);
+        float q3 = (float)Py::Float(tuple[3]);
+        _view->getViewer()->setCameraOrientation(SbRotation(q0, q1, q2, q3));
     }
     catch (const Base::Exception& e) {
         throw Py::Exception(e.what());
@@ -887,19 +936,109 @@ Py::Object View3DInventorPy::getObjectInfo(const Py::Tuple& args)
             dict.setItem("y", Py::Float(pt[1]));
             dict.setItem("z", Py::Float(pt[2]));
 
-            // search for a SoFCSelection node
-            SoFCDocumentObjectAction objaction;
-            objaction.apply(Point->getPath());
-            if (objaction.isHandled()) {
+            ViewProvider *vp = _view->getViewer()->getViewProviderByPath(Point->getPath());
+            if (vp && vp->useNewSelectionModel() && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+                ViewProviderDocumentObject* vpd = static_cast<ViewProviderDocumentObject*>(vp);
                 dict.setItem("Document",
-                    Py::String(objaction.documentName.getString()));
+                    Py::String(vpd->getObject()->getDocument()->getName()));
                 dict.setItem("Object",
-                    Py::String(objaction.objectName.getString()));
+                    Py::String(vpd->getObject()->getNameInDocument()));
                 dict.setItem("Component",
-                    Py::String(objaction.componentName.getString()));
+                    Py::String(vpd->getElement(Point)));
                 // ok, found the node of interest
                 ret = dict;
             }
+            else {
+                // search for a SoFCSelection node
+                SoFCDocumentObjectAction objaction;
+                objaction.apply(Point->getPath());
+                if (objaction.isHandled()) {
+                    dict.setItem("Document",
+                        Py::String(objaction.documentName.getString()));
+                    dict.setItem("Object",
+                        Py::String(objaction.objectName.getString()));
+                    dict.setItem("Component",
+                        Py::String(objaction.componentName.getString()));
+                    // ok, found the node of interest
+                    ret = dict;
+                }
+            }
+        }
+
+        return ret;
+    }
+    catch (const Py::Exception&) {
+        throw;
+    }
+}
+
+Py::Object View3DInventorPy::getObjectsInfo(const Py::Tuple& args)
+{
+    PyObject* object;
+    if (!PyArg_ParseTuple(args.ptr(), "O", &object))
+        throw Py::Exception();
+
+    try {
+        //Note: For gcc (4.2) we need the 'const' keyword to avoid the compiler error:
+        //conversion from 'Py::seqref<Py::Object>' to non-scalar type 'Py::Int' requested
+        //We should report this problem to the PyCXX project as in the documentation an 
+        //example without the 'const' keyword is used.
+        //Or we can also write Py::Int x(tuple[0]);
+        const Py::Tuple tuple(object);
+        Py::Int x(tuple[0]);
+        Py::Int y(tuple[1]);
+
+        // As this method could be called during a SoHandleEventAction scene
+        // graph traversal we must not use a second SoHandleEventAction as
+        // we will get Coin warnings because of multiple scene graph traversals
+        // which is regarded as error-prone.
+        SoRayPickAction action(_view->getViewer()->getViewportRegion());
+        action.setPickAll(true);
+        action.setPoint(SbVec2s((long)x,(long)y));
+        action.apply(_view->getViewer()->getSceneManager()->getSceneGraph());
+        const SoPickedPointList& pp = action.getPickedPointList();
+
+        Py::Object ret = Py::None();
+        if (pp.getLength() > 0) {
+            Py::List list;
+            for (int i=0; i<pp.getLength(); i++) {
+                Py::Dict dict;
+                SoPickedPoint* point = static_cast<SoPickedPoint*>(pp.get(i));
+                SbVec3f pt = point->getPoint();
+                dict.setItem("x", Py::Float(pt[0]));
+                dict.setItem("y", Py::Float(pt[1]));
+                dict.setItem("z", Py::Float(pt[2]));
+
+                ViewProvider *vp = _view->getViewer()->getViewProviderByPath(point->getPath());
+                if (vp && vp->useNewSelectionModel() && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+                    ViewProviderDocumentObject* vpd = static_cast<ViewProviderDocumentObject*>(vp);
+                    dict.setItem("Document",
+                        Py::String(vpd->getObject()->getDocument()->getName()));
+                    dict.setItem("Object",
+                        Py::String(vpd->getObject()->getNameInDocument()));
+                    dict.setItem("Component",
+                        Py::String(vpd->getElement(point)));
+                    // ok, found the node of interest
+                    list.append(dict);
+                }
+                else {
+                    // search for a SoFCSelection node
+                    SoFCDocumentObjectAction objaction;
+                    objaction.apply(point->getPath());
+                    if (objaction.isHandled()) {
+                        dict.setItem("Document",
+                            Py::String(objaction.documentName.getString()));
+                        dict.setItem("Object",
+                            Py::String(objaction.objectName.getString()));
+                        dict.setItem("Component",
+                            Py::String(objaction.componentName.getString()));
+                        // ok, found the node of interest
+                        list.append(dict);
+                    }
+                }
+            }
+
+            ret = list;
         }
 
         return ret;
@@ -946,6 +1085,33 @@ Py::Object View3DInventorPy::getPoint(const Py::Tuple& args)
     }
 }
 
+Py::Object View3DInventorPy::listNavigationTypes(const Py::Tuple&)
+{
+    std::vector<Base::Type> types;
+    Py::List styles;
+    Base::Type::getAllDerivedFrom(UserNavigationStyle::getClassTypeId(), types);
+    for (std::vector<Base::Type>::iterator it = types.begin()+1; it != types.end(); ++it) {
+        styles.append(Py::String(it->getName()));
+    }
+    return styles;
+}
+
+Py::Object View3DInventorPy::getNavigationType(const Py::Tuple&)
+{
+    std::string name = _view->getViewer()->navigationStyle()->getTypeId().getName();
+    return Py::String(name);
+}
+
+Py::Object View3DInventorPy::setNavigationType(const Py::Tuple& args)
+{
+    char* style;
+    if (!PyArg_ParseTuple(args.ptr(), "s", &style))
+        throw Py::Exception();
+    Base::Type type = Base::Type::fromName(style);
+    _view->getViewer()->setNavigationType(type);
+    return Py::None();
+}
+
 void View3DInventorPy::eventCallback(void * ud, SoEventCallback * n)
 {
     Base::PyGILStateLocker lock;
@@ -1320,6 +1486,8 @@ Py::Object View3DInventorPy::addEventCallback(const Py::Tuple& args)
         }
 
         _view->getViewer()->addEventCallback(eventId, View3DInventorPy::eventCallback, method);
+        callbacks.push_back(method);
+        Py_INCREF(method);
         return Py::Callable(method, false);
     }
     catch (const Py::Exception&) {
@@ -1346,6 +1514,8 @@ Py::Object View3DInventorPy::removeEventCallback(const Py::Tuple& args)
         }
 
         _view->getViewer()->removeEventCallback(eventId, View3DInventorPy::eventCallback, method);
+        callbacks.remove(method);
+        Py_DECREF(method);
         return Py::None();
     }
     catch (const Py::Exception&) {
@@ -1732,8 +1902,9 @@ Py::Object View3DInventorPy::addEventCallbackPivy(const Py::Tuple& args)
             View3DInventorPy::eventCallbackPivyEx :
             View3DInventorPy::eventCallbackPivy);
         _view->getViewer()->addEventCallback(*eventId, callback, method);
+        callbacks.push_back(method);
         Py_INCREF(method);
-        return Py::Callable(method, true);
+        return Py::Callable(method, false);
     }
     catch (const Py::Exception&) {
         throw;
@@ -1773,6 +1944,8 @@ Py::Object View3DInventorPy::removeEventCallbackPivy(const Py::Tuple& args)
             View3DInventorPy::eventCallbackPivyEx :
             View3DInventorPy::eventCallbackPivy);
         _view->getViewer()->removeEventCallback(*eventId, callback, method);
+        callbacks.remove(method);
+        Py_DECREF(method);
         return Py::Callable(method, false);
     }
     catch (const Py::Exception&) {
