@@ -189,7 +189,7 @@ void ViewProviderAnnotation::attach(App::DocumentObject* f)
     textsep->addChild(pTranslation);
     textsep->addChild(pRotationXYZ);
     textsep->addChild(pColor);
-    //textsep->addChild(pFont); // causes problems
+    textsep->addChild(pFont); // causes problems
     textsep->addChild(pLabel);
 
     SoFCSelection* textsep3d = new SoFCSelection();
@@ -248,6 +248,7 @@ ViewProviderAnnotationLabel::ViewProviderAnnotationLabel()
     QFont fn;
     ADD_PROPERTY(FontSize,(fn.pointSize()));
     ADD_PROPERTY(FontName,((const char*)fn.family().toAscii()));
+    ADD_PROPERTY(Frame,(true));
 
     pColor = new SoBaseColor();
     pColor->ref();
@@ -281,7 +282,8 @@ void ViewProviderAnnotationLabel::onChanged(const App::Property* prop)
         pColor->rgb.setValue(c.r,c.g,c.b);
     }
     if (prop == &TextColor || prop == &BackgroundColor ||
-        prop == &Justification || prop == &FontSize || prop == &FontName) {
+        prop == &Justification || prop == &FontSize ||
+        prop == &FontName || prop == &Frame) {
         if (getObject()) {
             App::Property* label = getObject()->getPropertyByName("LabelText");
             if (label && label->getTypeId() == App::PropertyStringList::getClassTypeId())
@@ -367,8 +369,7 @@ bool ViewProviderAnnotationLabel::doubleClicked(void)
 
 void ViewProviderAnnotationLabel::setupContextMenu(QMenu* menu, QObject* receiver, const char* member)
 {
-    QAction* act = menu->addAction(QObject::tr("Move annotation"), receiver, member);
-    act->setData(QVariant((int)ViewProvider::Transform));
+    menu->addAction(QObject::tr("Move annotation"), receiver, member);
 }
 
 void ViewProviderAnnotationLabel::dragStartCallback(void *data, SoDragger *)
@@ -444,10 +445,10 @@ void ViewProviderAnnotationLabel::drawImage(const std::vector<std::string>& s)
     int h = fm.height() * s.size();
     const App::Color& b = this->BackgroundColor.getValue();
     QColor brush;
-    brush.setRgbF(255*b.r,255*b.g,255*b.b);
+    brush.setRgbF(b.r,b.g,b.b);
     const App::Color& t = this->TextColor.getValue();
     QColor front;
-    front.setRgbF(255*t.r,255*t.g,255*t.b);
+    front.setRgbF(t.r,t.g,t.b);
 
     QStringList lines;
     for (std::vector<std::string>::const_iterator it = s.begin(); it != s.end(); ++it) {
@@ -461,11 +462,15 @@ void ViewProviderAnnotationLabel::drawImage(const std::vector<std::string>& s)
     QPainter painter(&image);
     painter.setRenderHint(QPainter::Antialiasing);
 
-    painter.setPen(QPen(QColor(0,0,127), 2, Qt::SolidLine, Qt::RoundCap,
-                        Qt::RoundJoin));
-    painter.setBrush(QBrush(brush, Qt::SolidPattern));
-    QRectF rectangle(0.0, 0.0, w+10, h+10);
-    painter.drawRoundedRect(rectangle, 5, 5);
+    bool drawFrame = this->Frame.getValue();
+    if (drawFrame) {
+        painter.setPen(QPen(QColor(0,0,127), 2, Qt::SolidLine, Qt::RoundCap,
+                            Qt::RoundJoin));
+        painter.setBrush(QBrush(brush, Qt::SolidPattern));
+        QRectF rectangle(0.0, 0.0, w+10, h+10);
+        painter.drawRoundedRect(rectangle, 5, 5);
+    }
+
     painter.setPen(front);
 
     Qt::Alignment align = Qt::AlignVCenter;
