@@ -32,6 +32,7 @@
 #include "Application.h"
 #include "Action.h"
 #include "Command.h"
+#include "Control.h"
 #include "ToolBoxManager.h"
 #include "Window.h"
 #include "Selection.h"
@@ -342,21 +343,16 @@ PyObject* Workbench::getPyObject()
 
 void Workbench::addTaskWatcher(std::vector<Gui::TaskView::TaskWatcher*> &Watcher)
 {
-    Gui::DockWnd::CombiView* pcCombiView = qobject_cast<Gui::DockWnd::CombiView*>
-        (Gui::DockWindowManager::instance()->getDockWindow("Combo View"));
-
-    pcCombiView->getTaskPanel()->addTaskWatcher(Watcher); 
+    Gui::TaskView::TaskView* taskView = Control().taskPanel();
+    if (taskView)
+        taskView->addTaskWatcher(Watcher); 
 }
 
 void Workbench::removeTaskWatcher(void)
 {
-    Gui::DockWnd::CombiView* pcCombiView = qobject_cast<Gui::DockWnd::CombiView*>
-        (Gui::DockWindowManager::instance()->getDockWindow("Combo View"));
-
-    std::vector<Gui::TaskView::TaskWatcher*> watcher;
-    pcCombiView->getTaskPanel()->removeTaskWatcher();
-    // make sure to delete the old watchers
-    pcCombiView->getTaskPanel()->addTaskWatcher(watcher); 
+    Gui::TaskView::TaskView* taskView = Control().taskPanel();
+    if (taskView)
+        taskView->clearTaskWatcher();
 }
 
 // --------------------------------------------------------------------
@@ -391,7 +387,7 @@ StdWorkbench::~StdWorkbench()
 {
 }
 
-void StdWorkbench::setupContextMenu(const char* recipient,MenuItem* item) const
+void StdWorkbench::setupContextMenu(const char* recipient, MenuItem* item) const
 {
     if (strcmp(recipient,"View") == 0)
     {
@@ -434,7 +430,7 @@ MenuItem* StdWorkbench::setupMenuBar() const
           << "Std_CloseAllWindows" << "Separator" << "Std_Save" << "Std_SaveAs"
           << "Separator" << "Std_Import" << "Std_Export" 
           << "Std_MergeProjects" << "Std_ProjectInfo" 
-          << "Separator" << "Std_Print" << "Std_PrintPdf"
+          << "Separator" << "Std_Print" << "Std_PrintPreview" << "Std_PrintPdf"
           << "Separator" << "Std_RecentFiles" << "Separator" << "Std_Quit";
 
     // Edit
@@ -477,7 +473,7 @@ MenuItem* StdWorkbench::setupMenuBar() const
     view->setCommand("&View");
     *view << "Std_ViewCreate" << "Std_OrthographicCamera" << "Std_PerspectiveCamera" << "Separator" 
           << stdviews << "Std_FreezeViews" << "Separator" << view3d << zoom
-          << "Std_ViewDockUndockFullscreen" << "Std_ToggleClipPlane"
+          << "Std_ViewDockUndockFullscreen" << "Std_AxisCross" << "Std_ToggleClipPlane"
           << "Std_TextureMapping" << "Separator" << visu
           << "Std_ToggleVisibility" << "Std_ToggleNavigation"
           << "Std_SetAppearance" << "Std_RandomColor" << "Separator" 
@@ -518,7 +514,7 @@ MenuItem* StdWorkbench::setupMenuBar() const
     MenuItem* help = new MenuItem( menuBar );
     help->setCommand("&Help");
     *help << "Std_OnlineHelp" << "Std_OnlineHelpPython" << "Std_PythonHelp"
-          << helpWebsites  << "Std_TipOfTheDay"<< "Separator" << "Std_About"
+          << helpWebsites  << "Separator" << "Std_About"
           << "Std_AboutQt" << "Separator" << "Std_WhatsThis";
 
     return menuBar;
