@@ -31,6 +31,7 @@
 # include <QLocale>
 # include <QPixmap>
 # include <QSpinBox>
+# include <QTextStream>
 #endif
 
 #include <Base/Tools.h>
@@ -40,11 +41,11 @@
 #include <App/DocumentObject.h>
 #include <App/PropertyGeo.h>
 #include <App/PropertyFile.h>
+#include <App/PropertyUnits.h>
 #include <Gui/Application.h>
 #include <Gui/Control.h>
 #include <Gui/Document.h>
 #include <Gui/ViewProviderDocumentObject.h>
-#include <Gui/Widgets.h>
 #include <Gui/Placement.h>
 #include <Gui/FileDialog.h>
 
@@ -227,7 +228,7 @@ void PropertyItem::setPropertyValue(const QString& value)
         App::PropertyContainer* parent = (*it)->getContainer();
         if (parent && !parent->isReadOnly(*it)) {
             QString cmd = QString::fromAscii("%1 = %2").arg(pythonIdentifier(*it)).arg(value);
-            Gui::Application::Instance->runPythonCode((const char*)cmd.toAscii());
+            Gui::Application::Instance->runPythonCode((const char*)cmd.toUtf8());
         }
     }
 }
@@ -624,6 +625,56 @@ QVariant PropertyFloatItem::editorData(QWidget *editor) const
 
 // --------------------------------------------------------------------
 
+
+TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyUnitItem, Gui::PropertyEditor::PropertyItem);
+
+PropertyUnitItem::PropertyUnitItem()
+{
+}
+
+QVariant PropertyUnitItem::value(const App::Property* prop) const
+{
+    assert(prop && prop->getTypeId().isDerivedFrom(App::PropertyLength::getClassTypeId()));
+    //UnitType = Base::Length;
+
+    double value = static_cast<const App::PropertyLength*>(prop)->getValue();
+    QString nbr;
+    nbr = Base::UnitsApi::toStrWithUserPrefs(Base::Length,value);
+
+    return QVariant(nbr);
+}
+
+void PropertyUnitItem::setValue(const QVariant& value)
+{
+    if (!value.canConvert(QVariant::String))
+        return;
+    QString val = value.toString();
+    QString data = QString::fromAscii("\"%1\"").arg(val);
+    setPropertyValue(data);
+}
+
+QWidget* PropertyUnitItem::createEditor(QWidget* parent, const QObject* receiver, const char* method) const
+{
+    QLineEdit *le = new QLineEdit(parent);
+    le->setFrame(false);
+    QObject::connect(le, SIGNAL(textChanged(const QString&)), receiver, method);
+    return le;
+}
+
+void PropertyUnitItem::setEditorData(QWidget *editor, const QVariant& data) const
+{
+    QLineEdit *le = qobject_cast<QLineEdit*>(editor);
+    le->setText(data.toString());
+}
+
+QVariant PropertyUnitItem::editorData(QWidget *editor) const
+{
+    QLineEdit *le = qobject_cast<QLineEdit*>(editor);
+    return QVariant(le->text());
+}
+
+// --------------------------------------------------------------------
+
 TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyFloatConstraintItem, Gui::PropertyEditor::PropertyItem);
 
 PropertyFloatConstraintItem::PropertyFloatConstraintItem()
@@ -986,69 +1037,77 @@ void PropertyDoubleVectorItem::setZ(double z)
 
 // --------------------------------------------------------------------
 
-namespace Gui { namespace PropertyEditor {
-class PlacementEditor : public Gui::LabelButton
+PlacementEditor::PlacementEditor(const QString& name, QWidget * parent)
+    : LabelButton(parent), _task(0)
 {
-public:
-    PlacementEditor(const QString& name, QWidget * parent = 0)
-        : LabelButton(parent), _task(0)
-    {
-        propertyname = name;
-        propertyname.replace(QLatin1String(" "), QLatin1String(""));
-    }
-    ~PlacementEditor()
-    {
-    }
-protected:
-    void browse()
-    {
-        Gui::TaskView::TaskDialog* dlg = Gui::Control().activeDialog();
-        Gui::Dialog::TaskPlacement* task;
-        task = qobject_cast<Gui::Dialog::TaskPlacement*>(dlg);
-        if (dlg && !task) {
-            // there is already another task dialog which must be closed first
-            Gui::Control().showDialog(dlg);
-            return;
-        }
-        if (!task) {
-            task = new Gui::Dialog::TaskPlacement();
-        }
-        if (!_task) {
-            _task = task;
-            connect(task, SIGNAL(placementChanged(const QVariant &, bool, bool)),
-                    this, SLOT(setValue(const QVariant&)));
-        }
-        task->setPlacement(value().value<Base::Placement>());
-        task->setPropertyName(propertyname);
-        Gui::Control().showDialog(task);
-    }
-    void showValue(const QVariant& d)
-    {
-        const Base::Placement& p = d.value<Base::Placement>();
-        double angle;
-        Base::Vector3d dir, pos;
-        p.getRotation().getValue(dir, angle);
-        pos = p.getPosition();
-        QString data = QString::fromAscii("[(%1 %2 %3);%4;(%5 %6 %7)]")
-                        .arg(QLocale::system().toString(dir.x,'f',2))
-                        .arg(QLocale::system().toString(dir.y,'f',2))
-                        .arg(QLocale::system().toString(dir.z,'f',2))
-                        .arg(QLocale::system().toString(angle,'f',2))
-                        .arg(QLocale::system().toString(pos.x,'f',2))
-                        .arg(QLocale::system().toString(pos.y,'f',2))
-                        .arg(QLocale::system().toString(pos.z,'f',2));
-        getLabel()->setText(data);
-    }
-
-    Gui::Dialog::TaskPlacement* _task;
-    QString propertyname;
-};
+    propertyname = name;
+    propertyname.replace(QLatin1String(" "), QLatin1String(""));
 }
+
+PlacementEditor::~PlacementEditor()
+{
+}
+
+void PlacementEditor::browse()
+{
+    Gui::TaskView::TaskDialog* dlg = Gui::Control().activeDialog();
+    Gui::Dialog::TaskPlacement* task;
+    task = qobject_cast<Gui::Dialog::TaskPlacement*>(dlg);
+    if (dlg && !task) {
+        // there is already another task dialog which must be closed first
+        Gui::Control().showDialog(dlg);
+        return;
+    }
+    if (!task) {
+        task = new Gui::Dialog::TaskPlacement();
+    }
+    if (!_task) {
+        _task = task;
+        connect(task, SIGNAL(placementChanged(const QVariant &, bool, bool)),
+                this, SLOT(updateValue(const QVariant&, bool, bool)));
+    }
+    task->setPlacement(value().value<Base::Placement>());
+    task->setPropertyName(propertyname);
+    Gui::Control().showDialog(task);
+}
+
+void PlacementEditor::showValue(const QVariant& d)
+{
+    const Base::Placement& p = d.value<Base::Placement>();
+    double angle;
+    Base::Vector3d dir, pos;
+    p.getRotation().getValue(dir, angle);
+    pos = p.getPosition();
+    QString data = QString::fromAscii("[(%1 %2 %3);%4;(%5 %6 %7)]")
+                    .arg(QLocale::system().toString(dir.x,'f',2))
+                    .arg(QLocale::system().toString(dir.y,'f',2))
+                    .arg(QLocale::system().toString(dir.z,'f',2))
+                    .arg(QLocale::system().toString(angle,'f',2))
+                    .arg(QLocale::system().toString(pos.x,'f',2))
+                    .arg(QLocale::system().toString(pos.y,'f',2))
+                    .arg(QLocale::system().toString(pos.z,'f',2));
+    getLabel()->setText(data);
+}
+
+void PlacementEditor::updateValue(const QVariant& v, bool incr, bool data)
+{
+    if (data) {
+        if (incr) {
+            QVariant u = value();
+            const Base::Placement& plm = u.value<Base::Placement>();
+            const Base::Placement& rel = v.value<Base::Placement>();
+            Base::Placement data = rel * plm;
+            setValue(QVariant::fromValue<Base::Placement>(data));
+        }
+        else {
+            setValue(v);
+        }
+    }
 }
 
 TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyPlacementItem, Gui::PropertyEditor::PropertyItem);
 
-PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), rot_axis(0,0,1)
+PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), changed_value(false), rot_axis(0,0,1)
 {
     m_a = static_cast<PropertyAngleItem*>(PropertyAngleItem::create());
     m_a->setParent(this);
@@ -1066,6 +1125,10 @@ PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), rot_axis(0,0,
     this->appendChild(m_p);
 }
 
+PropertyPlacementItem::~PropertyPlacementItem()
+{
+}
+
 double PropertyPlacementItem::getAngle() const
 {
     QVariant value = data(1, Qt::EditRole);
@@ -1077,7 +1140,7 @@ double PropertyPlacementItem::getAngle() const
     val.getRotation().getValue(dir, angle);
     if (dir * this->rot_axis < 0.0)
         angle = -angle;
-    return Base::degrees<double>(angle);
+    return Base::toDegrees<double>(angle);
 }
 
 void PropertyPlacementItem::setAngle(double angle)
@@ -1088,8 +1151,9 @@ void PropertyPlacementItem::setAngle(double angle)
 
     Base::Placement val = value.value<Base::Placement>();
     Base::Rotation rot;
-    rot.setValue(this->rot_axis, Base::radians<double>(angle));
+    rot.setValue(this->rot_axis, Base::toRadians<double>(angle));
     val.setRotation(rot);
+    changed_value = true;
     setValue(QVariant::fromValue(val));
 }
 
@@ -1116,6 +1180,7 @@ void PropertyPlacementItem::setAxis(const Base::Vector3d& axis)
         angle = -angle;
     rot.setValue(axis, angle);
     val.setRotation(rot);
+    changed_value = true;
     setValue(QVariant::fromValue(val));
 }
 
@@ -1135,6 +1200,7 @@ void PropertyPlacementItem::setPosition(const Base::Vector3d& pos)
         return;
     Base::Placement val = value.value<Base::Placement>();
     val.setPosition(pos);
+    changed_value = true;
     setValue(QVariant::fromValue(val));
 }
 
@@ -1197,6 +1263,11 @@ void PropertyPlacementItem::setValue(const QVariant& value)
 {
     if (!value.canConvert<Base::Placement>())
         return;
+    // Accept this only if the user changed the axis, angle or position but
+    // not if >this< item looses focus
+    if (!changed_value)
+        return;
+    changed_value = false;
     const Base::Placement& val = value.value<Base::Placement>();
     Base::Vector3d pos = val.getPosition();
     const Base::Rotation& rt = val.getRotation();
@@ -1351,7 +1422,7 @@ QVariant PropertyStringListItem::editorData(QWidget *editor) const
 QVariant PropertyStringListItem::toString(const QVariant& prop) const
 {
     QStringList list = prop.toStringList();
-    QString text = QString::fromAscii("[%1]").arg(list.join(QLatin1String(",")));
+    QString text = QString::fromUtf8("[%1]").arg(list.join(QLatin1String(",")));
 
     return QVariant(text);
 }
@@ -1363,7 +1434,7 @@ QVariant PropertyStringListItem::value(const App::Property* prop) const
     QStringList list;
     const std::vector<std::string>& value = ((App::PropertyStringList*)prop)->getValues();
     for ( std::vector<std::string>::const_iterator jt = value.begin(); jt != value.end(); ++jt ) {
-        list << QString::fromAscii(jt->c_str());
+        list << QString::fromUtf8(jt->c_str());
     }
 
     return QVariant(list);
@@ -1374,11 +1445,13 @@ void PropertyStringListItem::setValue(const QVariant& value)
     if (!value.canConvert(QVariant::StringList))
         return;
     QStringList values = value.toStringList();
-    QString data = QString::fromAscii("[");
+    QString data;
+    QTextStream str(&data);
+    str << "[";
     for (QStringList::Iterator it = values.begin(); it != values.end(); ++it) {
-        data += QString::fromAscii("\"%1\",").arg(*it);
+        str << "unicode('" << *it << "', 'utf-8'),";
     }
-    data += QString::fromAscii("]");
+    str << "]";
     setPropertyValue(data);
 }
 
