@@ -53,6 +53,9 @@ using namespace CompleteGui;
     qApp->translate("Workbench", "Parametric");
     qApp->translate("Workbench", "Object appearence");
     qApp->translate("Workbench", "Wire Tools");
+    // taken from TestGui.py
+    qApp->translate("Test_Test", "Self-test...");
+    qApp->translate("Test_Test", "Runs a self-test to check if the application works properly");
 #endif
 
 /// @namespace CompleteGui @class Workbench
@@ -80,15 +83,22 @@ void Workbench::setupContextMenu(const char* recipient,Gui::MenuItem* item) cons
               << "Separator" << "Std_ViewDockUndockFullscreen";
 
         if ( Gui::Selection().countObjectsOfType(App::DocumentObject::getClassTypeId()) > 0 )
+            {
+            Gui::MenuItem* DraftContext = new Gui::MenuItem();
+            DraftContext->setCommand("Display options");
+
+            *DraftContext << "Draft_ApplyStyle" << "Draft_ToggleDisplayMode"
+                          << "Draft_AddToGroup";
             *item << "Separator" << "Std_SetAppearance" << "Std_ToggleVisibility" << "Std_TreeSelection" 
-                  << "Std_RandomColor" << "Separator" << "Std_Delete";
+                  << "Std_RandomColor" << "Separator" << "Std_Delete" << DraftContext;
+            }
     }
     else if (strcmp(recipient,"Tree") == 0)
     {
         if ( Gui::Selection().countObjectsOfType(App::DocumentObject::getClassTypeId()) > 0 )
             {
             Gui::MenuItem* DraftContext = new Gui::MenuItem();
-            DraftContext->setCommand("Draft tools");
+            DraftContext->setCommand("Display options");
 
             *DraftContext << "Draft_ApplyStyle" << "Draft_ToggleDisplayMode"
                           << "Draft_AddToGroup";
@@ -114,7 +124,7 @@ Gui::MenuItem* Workbench::setupMenuBar() const
           << "Std_CloseAllWindows" << "Separator" << "Std_Save" << "Std_SaveAs"
           << "Separator" << "Std_Import" << "Std_Export"
           << "Std_MergeProjects" << "Std_ProjectInfo" 
-          << "Separator" << "Std_Print" << "Std_PrintPdf"
+          << "Separator" << "Std_Print" << "Std_PrintPreview" << "Std_PrintPdf"
           << "Separator" << "Std_RecentFiles" << "Separator" << "Std_Quit";
 
     // Edit
@@ -156,8 +166,8 @@ Gui::MenuItem* Workbench::setupMenuBar() const
     Gui::MenuItem* view = new Gui::MenuItem( menuBar );
     view->setCommand("&View");
     *view << "Std_ViewCreate" << "Std_OrthographicCamera" << "Std_PerspectiveCamera" << "Separator" 
-          << stdviews << "Std_FreezeViews" << "Separator" << view3d << zoom
-          << "Std_ViewDockUndockFullscreen" << "Std_ToggleClipPlane"
+          << stdviews << "Std_FreezeViews" << "Separator" << view3d << "Std_DrawStyle" << zoom
+          << "Std_ViewDockUndockFullscreen" << "Std_AxisCross" << "Std_ToggleClipPlane"
           << "Std_TextureMapping" << "Separator" << visu
           << "Std_ToggleVisibility" << "Std_ToggleNavigation"
           << "Std_SetAppearance" << "Std_RandomColor" << "Separator" 
@@ -172,7 +182,7 @@ Gui::MenuItem* Workbench::setupMenuBar() const
           << "Std_DlgMacroRecord" << "Std_MacroStopRecord"
           << "Std_DlgMacroExecute" << "Std_DlgMacroExecuteDirect" 
           << "Separator" << "Std_ViewScreenShot" << "Std_SceneInspector"
-          << "Std_DemoMode" << "Separator" << "Std_DlgCustomize";
+          << "Std_ProjectUtil" << "Std_DemoMode" << "Separator" << "Std_DlgCustomize";
 
     // Mesh ****************************************************************************************************
     Gui::MenuItem* mesh = new Gui::MenuItem( menuBar );
@@ -234,52 +244,61 @@ Gui::MenuItem* Workbench::setupMenuBar() const
           << "Part_Cone"
           << "Part_Torus"
           << "Part_Primitives";
+
+    Gui::MenuItem* PartDesign = new Gui::MenuItem();
+    PartDesign->setCommand("Part design");
+
+    *PartDesign   << "Sketcher_NewSketch"
+                  << "Sketcher_LeaveSketch"
+                  << "Sketcher_ViewSketch"
+                  << "Sketcher_MapSketch"
+                  << "Separator" 
+                  << "Sketcher_CreateArc"
+                  << "Sketcher_CreateCircle"
+                  << "Sketcher_CreateLine"
+                  << "Sketcher_CreatePolyline"
+                  << "Sketcher_CreateRectangle"
+                  << "Sketcher_CreateFillet"
+                  << "Sketcher_Trimming"
+                  << "Sketcher_ToggleConstruction"
+                  << "Separator" 
+                  << "Sketcher_ConstrainLock"
+                  << "Sketcher_ConstrainCoincident"
+                  << "Sketcher_ConstrainPointOnObject"
+                  << "Sketcher_ConstrainDistanceX"
+                  << "Sketcher_ConstrainDistanceY"
+                  << "Sketcher_ConstrainVertical"
+                  << "Sketcher_ConstrainHorizontal"
+                  << "Sketcher_ConstrainDistance"
+                  << "Sketcher_ConstrainRadius"
+                  << "Sketcher_ConstrainParallel"
+                  << "Sketcher_ConstrainPerpendicular"
+                  << "Sketcher_ConstrainAngle"
+                  << "Sketcher_ConstrainTangent"
+                  << "Sketcher_ConstrainEqual"
+                  << "Sketcher_ConstrainSymmetric"
+                  << "Separator" 
+                  << "PartDesign_Pad" 
+                  << "PartDesign_Pocket"
+                  << "PartDesign_Revolution" 
+                  << "PartDesign_Fillet"
+                  << "PartDesign_Chamfer";
+
+
     *part << para
+          << PartDesign
           << "Part_ShapeFromMesh"
           << "Part_MakeSolid"
           << "Part_ReverseShape"
+          << "Part_SimpleCopy"
           << "Separator"
           << "Part_Boolean"
           << "Part_Extrude"
           << "Part_Revolve"
           << "Part_Mirror"
           << "Part_Fillet"
-          << "PartDesign_Chamfer"
-          << "Separator"
-          << "Part_ShapeInfo";
+          << "PartDesign_Chamfer";
 
-#   ifdef COMPLETE_SHOW_SKETCHER
-    if (mgr.getCommandByName("Sketcher_NewSketch")) {
-        Gui::MenuItem* sketch = new Gui::MenuItem(menuBar);
-        sketch->setCommand("Ske&tch");
-        Gui::MenuItem* geom = new Gui::MenuItem();
-        geom->setCommand("Sketcher geoms");
-        *geom /*<< "Sketcher_CreatePoint"*/
-              /*<< "Sketcher_CreateArc"*/
-              /*<< "Sketcher_CreateCircle"*/
-              << "Sketcher_CreateLine"
-              << "Sketcher_CreatePolyline"
-              << "Sketcher_CreateBox"
-              /*<< "Sketcher_CreateText"*/
-              /*<< "Sketcher_CreateDraftLine"*/;
-        Gui::MenuItem* cons = new Gui::MenuItem();
-        cons->setCommand("Sketcher constraints");
-        *cons /*<< "Sketcher_ConstrainLock"*/
-              << "Sketcher_ConstrainCoincident"
-              << "Sketcher_ConstrainVertical"
-              << "Sketcher_ConstrainHorizontal"
-              << "Sketcher_ConstrainDistance"
-              << "Sketcher_ConstrainParallel";
-        *sketch 
-            << "Sketcher_NewSketch"
-            << geom
-            << cons
-            << "Separator" 
-            << "PartDesign_Pad" 
-            << "PartDesign_Fillet"
-        ;
-    }
-#   endif
 
     // Drawing ****************************************************************************************************
 
@@ -292,6 +311,8 @@ Gui::MenuItem* Workbench::setupMenuBar() const
         << "Drawing_NewA3Landscape"  
         << "Drawing_NewView" 
         << "Drawing_ExportPage"
+        << "Separator"
+        << "Drawing_ProjectShape"
     ;
 
     // Raytracing ****************************************************************************************************
@@ -302,7 +323,11 @@ Gui::MenuItem* Workbench::setupMenuBar() const
     *raytracing 
         << "Raytracing_WriteView" 
         << "Raytracing_WriteCamera" 
-        << "Raytracing_WritePart"; 
+        << "Raytracing_WritePart"
+        << "Separator"
+        << "Raytracing_NewPovrayProject"
+        << "Raytracing_NewPartSegment"
+        << "Raytracing_ExportProject"; 
     ;
 
     // Drafting ****************************************************************************************************
@@ -341,6 +366,7 @@ Gui::MenuItem* Workbench::setupMenuBar() const
             << "Draft_Scale"
             << "Draft_Edit"
             << "Draft_Drawing"
+            << "Draft_Shape2DView"
             << DraftWireTools
             << DraftContext
         ;
@@ -375,7 +401,6 @@ Gui::MenuItem* Workbench::setupMenuBar() const
           << "Std_OnlineHelpPython" 
           << "Std_PythonHelp"
           << helpWebsites  
-          << "Std_TipOfTheDay"
           << "Separator" 
           << "Test_Test" 
           << "Separator" 
@@ -427,7 +452,7 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
 
     // Part Design
     Gui::ToolBarItem* part_design = new Gui::ToolBarItem( root );
-    part_design->setCommand("Part design");
+    part_design->setCommand("Part");
     *part_design
         << "Part_Box"
         << "Part_Cylinder"
@@ -450,19 +475,43 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
     ;
 
     // Sketch based
+    Gui::ToolBarItem* sketch_based = new Gui::ToolBarItem( root );
+    sketch_based->setCommand("Sketch based");
+    *sketch_based
+              << "Sketcher_NewSketch"
+              << "Sketcher_LeaveSketch"
+              << "Separator" 
+              << "Sketcher_CreateArc"
+              << "Sketcher_CreateCircle"
+              << "Sketcher_CreateLine"
+              << "Sketcher_CreatePolyline"
+              << "Sketcher_CreateRectangle"
+              << "Sketcher_CreateFillet"
+              << "Sketcher_Trimming"
+              << "Sketcher_ToggleConstruction"
+              << "Separator" 
+              << "Sketcher_ConstrainLock"
+              << "Sketcher_ConstrainCoincident"
+              << "Sketcher_ConstrainPointOnObject"
+              << "Sketcher_ConstrainDistanceX"
+              << "Sketcher_ConstrainDistanceY"
+              << "Sketcher_ConstrainVertical"
+              << "Sketcher_ConstrainHorizontal"
+              << "Sketcher_ConstrainDistance"
+              << "Sketcher_ConstrainRadius"
+              << "Sketcher_ConstrainParallel"
+              << "Sketcher_ConstrainPerpendicular"
+              << "Sketcher_ConstrainAngle"
+              << "Sketcher_ConstrainTangent"
+              << "Sketcher_ConstrainEqual"
+              << "Sketcher_ConstrainSymmetric"
+              << "Separator" 
+              << "PartDesign_Pad" 
+              << "PartDesign_Pocket"
+              << "PartDesign_Revolution" 
+              << "PartDesign_Fillet"
+              << "PartDesign_Chamfer";
 
-#   ifdef COMPLETE_SHOW_SKETCHER
-    if (mgr.getCommandByName("Sketcher_NewSketch")) {
-        Gui::ToolBarItem* sketch_based = new Gui::ToolBarItem( root );
-        sketch_based->setCommand("Sketch based");
-        *sketch_based 
-            << "Sketcher_NewSketch"
-            << "Separator"
-            << "PartDesign_Pad"
-            << "PartDesign_Fillet"
-        ;
-    }
-#   endif 
 
     // Drawing
     Gui::ToolBarItem* drawing = new Gui::ToolBarItem( root );
@@ -508,6 +557,7 @@ Gui::ToolBarItem* Workbench::setupToolBars() const
             << "Draft_WireToBSpline"
             << "Draft_AddPoint"
             << "Draft_DelPoint"
+            << "Draft_Shape2DView"
         ;
     }
 #   endif
