@@ -115,7 +115,7 @@ class plane:
 		self.position = point.add(offsetVector)
 		self.weak = False
 		# FreeCAD.Console.PrintMessage("(position = " + str(self.position) + ")\n")
-		FreeCAD.Console.PrintMessage("Current workplane: x="+str(fcvec.rounded(self.u))+" y="+str(fcvec.rounded(self.v))+" z="+str(fcvec.rounded(self.axis))+"\n")
+		# FreeCAD.Console.PrintMessage("Current workplane: x="+str(fcvec.rounded(self.u))+" y="+str(fcvec.rounded(self.v))+" z="+str(fcvec.rounded(self.axis))+"\n")
 
 	def alignToCurve(self, shape, offset):
 		if shape.ShapeType == 'Edge':
@@ -142,6 +142,8 @@ class plane:
 		if len(sex) == 0:
 			return False
 		elif len(sex) == 1:
+                        if not sex[0].Object.isDerivedFrom("Part::Shape"):
+                                return False
 			return self.alignToCurve(sex[0].Object.Shape, offset) \
 				or self.alignToFace(sex[0].Object.Shape, offset) \
 				or (len(sex[0].SubObjects) == 1 and self.alignToFace(sex[0].SubObjects[0], offset))
@@ -186,5 +188,58 @@ class plane:
                         self.position = self.stored[3]
                         self.weak = self.stored[4]
                         self.stored = None
+
+        def getLocalCoords(self,point):
+                "returns the coordinates of a given point on the working plane"
+                xv = fcvec.project(point,self.u)
+                x = xv.Length
+                if xv.getAngle(self.u) > 1:
+                        x = -x
+                yv = fcvec.project(point,self.v)
+                y = yv.Length
+                if yv.getAngle(self.v) > 1:
+                        y = -y
+                zv = fcvec.project(point,self.axis)
+                z = zv.Length
+                if zv.getAngle(self.axis) > 1:
+                        z = -z
+                return Vector(x,y,z)
+
+        def getGlobalCoords(self,point):
+                "returns the global coordinates of the given point, taken relatively to this working plane"
+                vx = fcvec.scale(self.u,point.x)
+                vy = fcvec.scale(self.v,point.y)
+                vz = fcvec.scale(self.axis,point.z)
+                return (vx.add(vy)).add(vz)
+
+        def getClosestAxis(self,point):
+                "returns which of the workingplane axes is closest from the given vector"
+                ax = point.getAngle(self.u)
+                ay = point.getAngle(self.v)
+                az = point.getAngle(self.axis)
+                bx = point.getAngle(fcvec.neg(self.u))
+                by = point.getAngle(fcvec.neg(self.v))
+                bz = point.getAngle(fcvec.neg(self.axis))
+                b = min(ax,ay,az)
+                if b in [ax,bx]:
+                        return "x"
+                elif b in [ay,by]:
+                        return "y"
+                elif b in [az,bz]:
+                        return "z"
+                else:
+                        return None
                 
-		
+def getPlacementFromPoints(points):
+        "returns a placement from a list of 3 or 4 vectors"
+        pl = plane()
+        pl.position = points[0]
+        pl.u = (points[1].sub(points[0]).normalize())
+        pl.v = (points[2].sub(points[0]).normalize())
+        if len(points) == 4:
+                pl.axis = (points[3].sub(points[0]).normalize())
+        else:
+                pl.axis = ((pl.u).cross(pl.v)).normalize()
+        p = pl.getPlacement()
+        del pl
+        return p
