@@ -65,6 +65,22 @@ def v1(edge):
 	"v1(edge) -- returns the first point of an edge"
 	return edge.Vertexes[0].Point
 
+def isNull(something):
+        '''returns true if the given shape is null or the given placement is 0 or
+        if the given vector is (0,0,0)'''
+        if isinstance(something,Part.Shape):
+                return something.isNull()
+        elif isinstance(something,FreeCAD.Vector):
+                if something == Vector(0,0,0):
+                        return True
+                else:
+                        return False
+        elif isinstance(something,FreeCAD.Placement):
+                if (something.Base == Vector(0,0,0)) and (something.Rotation.Q == (0,0,0,1)):
+                        return True
+                else:
+                        return False
+
 def isPtOnEdge(pt,edge) :
 	'''isPtOnEdge(Vector,edge) -- Tests if a point is on an edge'''
 	if isinstance(edge.Curve,Part.Line) :
@@ -99,6 +115,12 @@ def isPtOnEdge(pt,edge) :
 						return True
 	return False
 
+def hasCurves(shape):
+        "checks if the given shape has curves"
+        for e in shape.Edges:
+                if not isInstance(e.Curve,Part.Line):
+                        return True
+        return False
 	
 # edge functions *****************************************************************
 
@@ -136,6 +158,12 @@ def findIntersection(edge1,edge2,infinite1=False,infinite2=False,ex1=False,ex2=F
                                       edge2.Vertexes[1].Point]
 
         if pt1:
+                # first check if we don't already have coincident endpoints
+                if (pt1 in [pt3,pt4]):
+                        return [pt1]
+                elif (pt2 in [pt3,pt4]):
+                        return [pt2]
+                
                 #we have 2 straight lines		  
 		if fcvec.isNull(pt2.sub(pt1).cross(pt3.sub(pt1)).cross(pt2.sub(pt4).cross(pt3.sub(pt4)))):
 			vec1 = pt2.sub(pt1) ; vec2 = pt4.sub(pt3)
@@ -176,8 +204,16 @@ def findIntersection(edge1,edge2,infinite1=False,infinite2=False,ex1=False,ex2=F
 		dirVec = vec(line) ; dirVec.normalize()
 		pt1    = line.Vertexes[0].Point
 		pt2    = line.Vertexes[1].Point
+                pt3    = arc.Vertexes[0].Point
+                pt4    = arc.Vertexes[-1].Point
 		center = arc.Curve.Center
-		
+
+                # first check for coincident endpoints
+                if (pt1 in [pt3,pt4]):
+                        return [pt1]
+                elif (pt2 in [pt3,pt4]):
+                        return [pt2]
+                
 		if fcvec.isNull(pt1.sub(center).cross(pt2.sub(center)).cross(arc.Curve.Axis)) :
 			# Line and Arc are on same plane
 			
@@ -327,6 +363,8 @@ def getBoundary(shape):
 	"getBoundary(shape) -- this function returns the boundary edges of a group of faces"
         # make a lookup-table where we get the number of occurrences
 	# to each edge in the fused face
+        if isinstance(shape,list):
+                shape = Part.makeCompound(shape)
 	lut={}
 	for f in shape.Faces:
 		for e in f.Edges:
@@ -340,12 +378,14 @@ def getBoundary(shape):
 	return bound
 
 def sortEdges(lEdges, aVertex=None):
-	"an alternative, more accurate version of Part.__sortEdges__"
+        "an alternative, more accurate version of Part.__sortEdges__"
 
-        for e in lEdges:
-                if not isinstance(e.Curve,Part.Line):
-                        print "Warning: sortedges cannot treat wired containing curves yet."
-                        return lEdges
+        #There is no reason to limit this to lines only because every non-closed edge always
+        #has exactly two vertices (wmayer)
+        #for e in lEdges:
+        #        if not isinstance(e.Curve,Part.Line):
+        #                print "Warning: sortedges cannot treat wired containing curves yet."
+        #                return lEdges
 	
 	def isSameVertex(V1, V2):
 		''' Test if vertexes have same coordinates with precision 10E(-precision)'''
@@ -367,7 +407,23 @@ def sortEdges(lEdges, aVertex=None):
 					linstances += [i,j-1,instance]
 		return [count]+linstances
 	
-	if (len(lEdges) < 2): return lEdges
+	if (len(lEdges) < 2):
+                if aVertex == None:
+                        return lEdges
+                else:
+                        result = lookfor(aVertex,lEdges)
+                        if result[0] != 0:
+                                if isSameVertex(aVertex,result[3].Vertexes[0]):
+                                        return lEdges
+                                else:
+                                        if isinstance(result[3].Curve,Part.Line):
+                                                return [Part.Line(aVertex.Point,result[3].Vertexes[0].Point).toShape()]
+                                        elif isinstance(result[3].Curve,Part.Circle):
+                                                mp = findMidpoint(result[3])
+                                                return [Part.Arc(aVertex.Point,mp,result[3].Vertexes[0].Point).toShape()]
+                                        else:
+                                                return lEdges
+                                        
 	olEdges = [] # ol stands for ordered list 
 	if aVertex == None:
 		for i in range(len(lEdges)*2) :
@@ -386,19 +442,86 @@ def sortEdges(lEdges, aVertex=None):
                         if isSameVertex(aVertex,result[3].Vertexes[0]):
                                 olEdges += [result[3]] + next
                         else:
-                                newedge = Part.Line(aVertex.Point,result[3].Vertexes[0].Point).toShape()
-                                olEdges += [newedge] + next
+                                if isinstance(result[3].Curve,Part.Line):
+                                        newedge = Part.Line(aVertex.Point,result[3].Vertexes[0].Point).toShape()
+                                        olEdges += [newedge] + next
+                                elif isinstance(result[3].Curve,Part.Circle):
+                                        mp = findMidpoint(result[3])
+                                        newedge = Part.Arc(aVertex.Point,mp,result[3].Vertexes[0].Point).toShape()
+                                        olEdges += [newedge] + next
+                                else:
+                                        olEdges += [result[3]] + next                                        
 			return olEdges
 		else :
 			return []
 
+                
+def superWire(edgeslist,closed=False):
+        '''superWire(edges,[closed]): forces a wire between edges that don't necessarily
+        have coincident endpoints. If closed=True, wire will always be closed'''
+        def median(v1,v2):
+                vd = v2.sub(v1)
+                vd.scale(.5,.5,.5)
+                return v1.add(vd)
+        edges = sortEdges(edgeslist)
+        print edges
+        newedges = []
+        for i in range(len(edges)):
+                curr = edges[i]
+                if i == 0:
+                        if closed:
+                                prev = edges[-1]
+                        else:
+                                prev = None
+                else:
+                        prev = edges[i-1]
+                if i == (len(edges)-1):
+                        if closed:
+                                next = edges[0]
+                        else:
+                                next = None
+                else:
+                        next = edges[i+1]
+                print i,prev,curr,next
+                if prev:
+                        if curr.Vertexes[0].Point == prev.Vertexes[-1].Point:
+                                p1 = curr.Vertexes[0].Point
+                        else:
+                                p1 = median(curr.Vertexes[0].Point,prev.Vertexes[-1].Point)
+                else:
+                        p1 = curr.Vertexes[0].Point
+                if next:
+                        if curr.Vertexes[-1].Point == next.Vertexes[0].Point:
+                                p2 = next.Vertexes[0].Point
+                        else:
+                                p2 = median(curr.Vertexes[-1].Point,next.Vertexes[0].Point)
+                else:
+                        p2 = curr.Vertexes[-1].Point
+                if isinstance(curr.Curve,Part.Line):
+                        print "line",p1,p2
+                        newedges.append(Part.Line(p1,p2).toShape())
+                elif isinstance(curr.Curve,Part.Circle):
+                        p3 = findMidpoint(curr)
+                        print "arc",p1,p3,p2
+                        newedges.append(Part.Arc(p1,p3,p2).toShape())
+                else:
+                        print "Cannot superWire edges that are not lines or arcs"
+                        return None
+        print newedges
+        return Part.Wire(newedges)
+
 def findMidpoint(edge):
 	"calculates the midpoint of an edge"
 	first = edge.Vertexes[0].Point
 	last = edge.Vertexes[-1].Point
 	if isinstance(edge.Curve,Part.Circle):
-		center = edge.Curve.Center
+                center = edge.Curve.Center
 		radius = edge.Curve.Radius
+                if len(edge.Vertexes) == 1:
+                        # Circle
+                        dv = first.sub(center)
+                        dv = fcvec.neg(dv)
+                        return center.add(dv)
 		axis = edge.Curve.Axis
 		chord = last.sub(first)
 		perp = chord.cross(axis)
@@ -526,7 +649,7 @@ def getNormal(shape):
         if n.getAngle(vdir) < 0.78: n = fcvec.neg(n)
         return n
 
-def offsetWire(wire,dvec,bind=False):
+def offsetWire(wire,dvec,bind=False,occ=False):
         '''
         offsetWire(wire,vector,[bind]): offsets the given wire along the
         given vector. The vector will be applied at the first vertex of
@@ -537,6 +660,17 @@ def offsetWire(wire,dvec,bind=False):
         norm = getNormal(wire)
         closed = isReallyClosed(wire)
         nedges = []
+        if occ:
+                l=abs(dvec.Length)
+                if not l: return None
+                if not wire.Wires:
+                        wire = Part.Wire(edges)
+                try:
+                        off = wire.makeOffset(l)
+                except:
+                        return None
+                else:
+                        return off
         for i in range(len(edges)):
                 curredge = edges[i]
                 delta = dvec
@@ -561,6 +695,7 @@ def connect(edges,closed=False):
         nedges = []
         for i in range(len(edges)):
                 curr = edges[i]
+                # print "fcgeo.connect edge ",i," : ",curr.Vertexes[0].Point,curr.Vertexes[-1].Point
                 if i > 0:
                         prev = edges[i-1]
                 else:
@@ -575,17 +710,21 @@ def connect(edges,closed=False):
                         else:
                                 next = None
                 if prev:
+                        # print "debug: fcgeo.connect prev : ",prev.Vertexes[0].Point,prev.Vertexes[-1].Point
                         v1 = findIntersection(curr,prev,True,True)[0]
                 else:
                         v1 = curr.Vertexes[0].Point
                 if next:
+                        # print "debug: fcgeo.connect next : ",next.Vertexes[0].Point,next.Vertexes[-1].Point
                         v2 = findIntersection(curr,next,True,True)[0]
                 else:
                         v2 = curr.Vertexes[-1].Point
                 if isinstance(curr.Curve,Part.Line):
-                        nedges.append(Part.Line(v1,v2).toShape())
+                        if v1 != v2:
+                                nedges.append(Part.Line(v1,v2).toShape())
                 elif isinstance(curr.Curve,Part.Circle):
-                        nedges.append(Part.Arc(v1,findMidPoint(curr),v2))
+                        if v1 != v2:
+                                nedges.append(Part.Arc(v1,findMidPoint(curr),v2))
         return Part.Wire(nedges)
 
 def findDistance(point,edge,strict=False):
@@ -734,6 +873,236 @@ def getTangent(edge,frompoint=None):
                         v1 = frompoint.sub(edge.Curve.Center)
                 return v1.cross(edge.Curve.Axis)
         return None
+
+def bind(w1,w2):
+        '''bind(wire1,wire2): binds 2 wires by their endpoints and
+        returns a face'''
+        w3 = Part.Line(w1.Vertexes[0].Point,w2.Vertexes[0].Point).toShape()
+        w4 = Part.Line(w1.Vertexes[-1].Point,w2.Vertexes[-1].Point).toShape()
+        return Part.Face(Part.Wire(w1.Edges+[w3]+w2.Edges+[w4]))
+
+def cleanFaces(shape):
+        "removes inner edges from coplanar faces"
+        faceset = shape.Faces
+        def find(hc):
+                "finds a face with the given hashcode"
+                for f in faceset:
+                        if f.hashCode() == hc:
+                                return f
+
+        def findNeighbour(hface,hfacelist):
+                "finds the first neighbour of a face in a list, and returns its index"
+                eset = []
+                for e in find(hface).Edges:
+                        eset.append(e.hashCode())
+                for i in range(len(hfacelist)):
+                        for ee in find(hfacelist[i]).Edges:
+                                if ee.hashCode() in eset:
+                                        return i
+                return None
+        
+        # build lookup table
+        lut = {}
+        for face in faceset:
+                for edge in face.Edges:
+                        if edge.hashCode() in lut:
+                                lut[edge.hashCode()].append(face.hashCode())
+                        else:
+                                lut[edge.hashCode()] = [face.hashCode()]
+        # print "lut:",lut
+        # take edges shared by 2 faces
+        sharedhedges = []
+        for k,v in lut.iteritems():
+                if len(v) == 2:
+                        sharedhedges.append(k)
+        # print len(sharedhedges)," shared edges:",sharedhedges
+        # find those with same normals
+        targethedges = []
+        for hedge in sharedhedges:
+                faces = lut[hedge]
+                n1 = find(faces[0]).normalAt(0.5,0.5)
+                n2 = find(faces[1]).normalAt(0.5,0.5)
+                if n1 == n2:
+                        targethedges.append(hedge)
+        # print len(targethedges)," target edges:",targethedges
+        # get target faces
+        hfaces = []
+        for hedge in targethedges:
+                for f in lut[hedge]:
+                        if not f in hfaces:
+                                hfaces.append(f)
+
+        # print len(hfaces)," target faces:",hfaces
+        # sort islands
+        islands = [[hfaces.pop(0)]]
+        currentisle = 0
+        currentface = 0
+        found = True
+        while hfaces:
+                if not found:
+                        if len(islands[currentisle]) > (currentface + 1):
+                                currentface += 1
+                                found = True
+                        else:
+                                islands.append([hfaces.pop(0)])
+                                currentisle += 1
+                                currentface = 0
+                                found = True
+                else:
+                        f = findNeighbour(islands[currentisle][currentface],hfaces)
+                        if f != None:
+                                islands[currentisle].append(hfaces.pop(f))
+                        else:
+                                found = False
+        # print len(islands)," islands:",islands
+        # make new faces from islands
+        newfaces = []
+        treated = []
+        for isle in islands:
+                treated.extend(isle)
+                fset = []
+                for i in isle: fset.append(find(i))
+                bounds = getBoundary(fset)
+                shp = Part.Wire(sortEdges(bounds))
+                shp = Part.Face(shp)
+                if shp.normalAt(0.5,0.5) != find(isle[0]).normalAt(0.5,0.5):
+                        shp.reverse()
+                newfaces.append(shp)
+        # print "new faces:",newfaces
+        # add remaining faces
+        for f in faceset:
+                if not f.hashCode() in treated:
+                        newfaces.append(f)
+        # print "final faces"
+        # finishing
+        fshape = Part.makeShell(newfaces)
+        if shape.isClosed():
+                fshape = Part.makeSolid(fshape)
+        return fshape
+
+
+def isCubic(shape):
+    '''isCubic(shape): verifies if a shape is cubic, that is, has
+    8 vertices, 6 faces, and all angles are 90 degrees.'''
+    # first we try fast methods
+    if len(shape.Vertexes) != 8:
+        return False
+    if len(shape.Faces) != 6:
+        return False
+    if len(shape.Edges) != 12:
+        return False
+    for e in shape.Edges:
+        if not isinstance(e.Curve,Part.Line):
+            return False
+    # if ok until now, let's do more advanced testing
+    for f in shape.Faces:
+        if len(f.Edges) != 4: return False
+        for i in range(4):
+            e1 = vec(f.Edges[i])
+            if i < 3:
+                e2 = vec(f.Edges[i+1])
+            else: e2 = vec(f.Edges[0])
+            rpi = [0.0,round(math.pi/2,precision)]
+            if not round(e1.getAngle(e2),precision) in rpi:
+                return False
+    return True
+
+def getCubicDimensions(shape):
+    '''getCubicDimensions(shape): returns a list containing the placement,
+    the length, the width and the height of a cubic shape. If not cubic, nothing
+    is returned. The placement point is the lowest corner of the shape.'''
+    if not isCubic(shape): return None
+    # determine lowest face, which will be our base
+    z = [10,1000000000000]
+    for i in range(len(shape.Faces)):
+        if shape.Faces[i].CenterOfMass.z < z[1]:
+            z = [i,shape.Faces[i].CenterOfMass.z]
+    if z[0] > 5: return None
+    base = shape.Faces[z[0]]
+    basepoint = base.Edges[0].Vertexes[0].Point
+    plpoint = base.CenterOfMass
+    basenorm = base.normalAt(0.5,0.5)
+    # getting length and width
+    vx = vec(base.Edges[0])
+    vy = vec(base.Edges[1])
+    # getting rotations
+    rotZ = fcvec.angle(vx)
+    rotY = fcvec.angle(vx,FreeCAD.Vector(vx.x,vx.y,0))
+    rotX = fcvec.angle(vy,FreeCAD.Vector(vy.x,vy.y,0))
+    # getting height
+    vz = None
+    rpi = round(math.pi/2,precision)
+    for i in range(1,6):
+        for e in shape.Faces[i].Edges:
+            if basepoint in [e.Vertexes[0].Point,e.Vertexes[1].Point]:
+                vtemp = vec(e)
+                # print vtemp
+                if round(vtemp.getAngle(vx),precision) == rpi:
+                    if round(vtemp.getAngle(vy),precision) == rpi:
+                        vz = vtemp
+    if not vz: return None
+    mat = FreeCAD.Matrix()
+    mat.move(plpoint)
+    mat.rotateX(rotX)
+    mat.rotateY(rotY)
+    mat.rotateZ(rotZ)
+    return [FreeCAD.Placement(mat),round(vx.Length,precision),round(vy.Length,precision),round(vz.Length,precision)]
+
+def removeInterVertices(wire):
+        '''removeInterVertices(wire) - remove unneeded vertices (those that
+        are in the middle of a straight line) from a wire, returns a new wire.'''
+        edges = sortEdges(wire.Edges)
+        nverts = []
+        def getvec(v1,v2):
+                if not abs(round(v1.getAngle(v2),precision) in [0,round(math.pi,precision)]):
+                        nverts.append(edges[i].Vertexes[-1].Point)
+        for i in range(len(edges)-1):
+                vA = vec(edges[i])
+                vB = vec(edges[i+1])
+                getvec(vA,vB)
+        vA = vec(edges[-1])
+        vB = vec(edges[0])
+        getvec(vA,vB)
+        if nverts:
+                if wire.isClosed():
+                        nverts.append(nverts[0])
+                w = Part.makePolygon(nverts)
+                return w
+        else:
+                return wire
+
+def arcFromSpline(edge):
+        """arcFromSpline(edge): turns the given edge into an arc, by taking
+        its first point, midpoint and endpoint. Works best with bspline
+        segments such as those from imported svg files. Use this only
+        if you are sure your edge is really an arc..."""
+        if isinstance(edge.Curve,Part.Line):
+                print "This edge is straight, cannot build an arc on it"
+                return None
+        if len(edge.Vertexes) > 1:
+                # 2-point arc
+                p1 = edge.Vertexes[0].Point
+                p2 = edge.Vertexes[-1].Point
+                ml = edge.Length/2
+                p3 = edge.valueAt(ml)
+                try:
+                        return Part.Arc(p1,p3,p2).toShape()
+                except:
+                        print "Couldn't make an arc out of this edge"
+                        return None
+        else:
+                # circle
+                p1 = edge.Vertexes[0].Point
+                ml = edge.Length/2
+                p2 = edge.valueAt(ml)
+                ray = p2.sub(p1)
+                ray.scale(.5,.5,.5)
+                center = p1.add(ray)
+                radius = ray.Length
+                try:
+                        return Part.makeCircle(radius,center)
+                except:
+                        print "couldn't make a circle out of this edge"
    
 # circle functions *********************************************************
 
