@@ -38,7 +38,7 @@ from FreeCAD import Vector
 try: import FreeCADGui
 except: gui = False
 else: gui = True
-try: draftui = FreeCADGui.draftToolBar.ui
+try: draftui = FreeCADGui.draftToolBar
 except: draftui = None
 
 pythonopen = open
@@ -240,6 +240,7 @@ class svgHandler(xml.sax.ContentHandler):
                 self.count = 0
                 self.transform = None
                 self.grouptransform = []
+                self.lastdim = None
 	
 		if gui and draftui:
 			r = float(draftui.color.red()/255.0)
@@ -389,6 +390,21 @@ class svgHandler(xml.sax.ContentHandler):
 							pathdata.append(d[0])
 							pathdata.append(d[1:])
 
+                        # print "debug: pathdata:",pathdata
+
+                        if "freecad:basepoint1" in data:
+                                p1 = data["freecad:basepoint1"]
+                                p1 = Vector(float(p1[0]),-float(p1[1]),0)
+                                p2 = data["freecad:basepoint2"]
+                                p2 = Vector(float(p2[0]),-float(p2[1]),0)
+                                p3 = data["freecad:dimpoint"]
+                                p3 = Vector(float(p3[0]),-float(p3[1]),0)
+                                obj = Draft.makeDimension(p1,p2,p3)
+                                self.applyTrans(obj)
+                                self.format(obj)
+                                pathdata = []
+                                self.lastdim = obj
+
 			for d in pathdata:
 				if (d == "M"):
 					command = "move"
@@ -504,7 +520,14 @@ class svgHandler(xml.sax.ContentHandler):
 					else:
 						currentvec = Vector(point[-2],-point[-1],0)
 					chord = currentvec.sub(lastvec)
-					perp = chord.cross(Vector(0,0,-1))
+					# perp = chord.cross(Vector(0,0,-1))
+                                        # here is a better way to find the perpendicular
+                                        if point[4] == 1:
+                                                # clockwise
+                                                perp = fcvec.rotate2D(chord,-math.pi/2)
+                                        else:
+                                                # anticlockwise
+                                                perp = fcvec.rotate2D(chord,math.pi/2)
 					chord = fcvec.scale(chord,.5)
 					if chord.Length > point[0]: a = 0
 					else: a = math.sqrt(point[0]**2-chord.Length**2)
@@ -515,7 +538,6 @@ class svgHandler(xml.sax.ContentHandler):
 					lastvec = currentvec
 					path.append(seg)
 					point = []
-					command = None
 				elif (command == "close"):
 					if not fcvec.equals(lastvec,firstvec):
 						seg = Part.Line(lastvec,firstvec).toShape()
@@ -533,10 +555,26 @@ class svgHandler(xml.sax.ContentHandler):
 				elif (len(point)==6) and (command=="curve"):
 					if relative:
 						currentvec = lastvec.add(Vector(point[4],-point[5],0))
+                                                pole1 = lastvec.add(Vector(point[0],-point[1],0))
+                                                pole2 = lastvec.add(Vector(point[2],-point[3],0))
 					else:
 						currentvec = Vector(point[4],-point[5],0)
+                                                pole1 = Vector(point[0],point[1],0)
+                                                pole2 = Vector(point[2],point[3],0)
 					if not fcvec.equals(currentvec,lastvec):
-						seg = Part.Line(lastvec,currentvec).toShape()
+                                                mainv = currentvec.sub(lastvec)
+                                                pole1v = lastvec.add(pole1)
+                                                pole2v = currentvec.add(pole2)
+                                                print "curve data:",mainv.normalize(),pole1v.normalize(),pole2v.normalize()
+                                                if (round(mainv.getAngle(pole1v),4) in [0,round(math.pi,4)]) \
+                                                            and (round(mainv.getAngle(pole2v),4) in [0,round(math.pi,4)]):
+                                                        print "straight segment"
+                                                        seg = Part.Line(lastvec,currentvec).toShape()
+                                                else:
+                                                        print "bezier segment"
+                                                        b = Part.BezierCurve()
+                                                        b.setPoles([lastvec,pole1,pole2,currentvec])
+                                                        seg = b.toShape()
 						print "connect ",lastvec,currentvec
 						lastvec = currentvec
 						path.append(seg)
@@ -584,7 +622,7 @@ class svgHandler(xml.sax.ContentHandler):
 
                 # processing circles
 
-                if name == "circle":
+                if (name == "circle") and (not ("freecad:skip" in data)) :
                         if not pathname: pathname = 'Circle'
                         c = Vector(float(data['cx'][0]),-float(data['cy'][0]),0)
                         r = float(data['r'][0])
@@ -600,21 +638,25 @@ class svgHandler(xml.sax.ContentHandler):
 
                 # processing texts
 
-		if (name in ["text","tspan"]):
-                        print "processing a text"
-			if 'x' in data:
-                                self.x = data['x']
+		if name in ["text","tspan"]:
+                        if not("freecad:skip" in data):
+                                print "processing a text"
+                                if 'x' in data:
+                                        self.x = data['x']
+                                else:
+                                        self.x = 0
+                                if 'y' in data:
+                                        self.y = data['y']
+                                else:
+                                        self.y = 0
+                                if 'font-size' in data:
+                                        if data['font-size'] != 'none':
+                                                self.text = getsize(data['font-size'])
+                                else:
+                                        self.text = 1
                         else:
-                                self.x = 0
-                        if 'y' in data:
-                                self.y = data['y']
-                        else:
-                                self.y = 0
-			if 'font-size' in data:
-				if data['font-size'] != 'none':
-					self.text = getsize(data['font-size'])
-                        else:
-                                self.text = 1
+                                if self.lastdim:
+                                        self.lastdim.ViewObject.FontSize = int(getsize(data['font-size']))
 
                 print "done processing element ",self.count
                 
@@ -646,23 +688,28 @@ class svgHandler(xml.sax.ContentHandler):
                         self.grouptransform.pop()
 
         def applyTrans(self,sh):
-                if self.transform:
-                        print "applying transform: ",self.transform
-                        sh = sh.transformGeometry(self.transform)
-                for i in range(len(self.grouptransform)):
-                        sh = sh.transformGeometry(self.grouptransform[-i-1])
-                '''
-                if 'scale' in self.transform:
-                        print "applying scale factor: ",self.transform['scale']
-                        m = FreeCAD.Matrix()
-                        m.scale(self.transform['scale'])
-                        sh = sh.transformGeometry(m)
-                if 'translate' in self.transform:
-                        print "applying translation: ",self.transform['translate']
-                        sh.translate(self.transform['translate'])
-                self.transform = {}
-                '''
-                return sh
+                if isinstance(sh,Part.Shape):
+                        if self.transform:
+                                print "applying object transform: ",self.transform
+                                sh = sh.transformGeometry(self.transform)
+                        for i in range(len(self.grouptransform)):
+                                print "applying group transform: ",self.grouptransform[-i-1]
+                                sh = sh.transformGeometry(self.grouptransform[-i-1])
+                        return sh
+                elif Draft.getType(sh) == "Dimension":
+                        pts = []
+                        for p in [sh.Start,sh.End,sh.Dimline]:
+                                cp = Vector(p)
+                                if self.transform:
+                                        print "applying object transform: ",self.transform
+                                        cp = self.transform.multiply(cp)
+                                for i in range(len(self.grouptransform)):
+                                        print "applying group transform: ",self.grouptransform[-i-1]
+                                        cp = self.grouptransform[-i-1].multiply(cp)
+                                pts.append(cp)
+                        sh.Start = pts[0]
+                        sh.End = pts[1]
+                        sh.Dimline = pts[2]
 
         def translateVec(self,vec,mat):
                 v = Vector(mat.A14,mat.A24,mat.A34)
