@@ -20,6 +20,7 @@
 #include "FeaturePage.h"
 #include "FeatureView.h"
 #include "FeatureViewPart.h"
+#include "FeatureProjection.h"
 #include "PageGroup.h"
 
 extern struct PyMethodDef Drawing_methods[];
@@ -30,7 +31,7 @@ PyDoc_STRVAR(module_drawing_doc,
 
 /* Python entry */
 extern "C" {
-void AppDrawingExport initDrawing()
+void DrawingExport initDrawing()
 {
     // load dependent module
     try {
@@ -53,6 +54,7 @@ void AppDrawingExport initDrawing()
     Drawing::FeatureView            ::init();
     Drawing::FeatureViewPart        ::init();
     Drawing::PageGroup              ::init();
+    Drawing::FeatureProjection      ::init();
     Drawing::FeatureViewPartPython  ::init();
     Drawing::FeatureViewPython      ::init();
 }
