@@ -28,14 +28,12 @@
 
 // Exporting of App classes
 #ifdef FC_OS_WIN32
-# define AppDrawingExport __declspec(dllexport)
-# define AppPartExport  __declspec(dllimport)
+# define DrawingExport  __declspec(dllexport)
 # define PartExport     __declspec(dllimport)
 # define MeshExport     __declspec(dllimport)
 #else // for Linux
-# define AppDrawingExport
-# define AppPartExport 
-# define PartExport   
+# define DrawingExport
+# define PartExport 
 # define MeshExport   
 #endif
 
