@@ -35,7 +35,7 @@ namespace Drawing
 
 /** Algo class for projecting shapes and creating SVG output of it
  */
-class AppDrawingExport ProjectionAlgos
+class DrawingExport ProjectionAlgos
 {
 public:
     /// Constructor
@@ -43,8 +43,7 @@ public:
     virtual ~ProjectionAlgos();
 
     void execute(void);
-
-    std::string Edges2SVG(const TopoDS_Shape &);
+    static TopoDS_Shape invertY(const TopoDS_Shape&);
 
     enum SvgExtractionType { 
         Plain = 0,
@@ -53,6 +52,8 @@ public:
     };
 
     std::string getSVG(SvgExtractionType type, float scale);
+    std::string getDXF(SvgExtractionType type, float scale);//add by Dan Falck 2011/09/25 
+
 
     const TopoDS_Shape &Input;
     const Base::Vector3f &Direction;
@@ -67,9 +68,6 @@ public:
     TopoDS_Shape HN;// contour edges invisibly
     TopoDS_Shape HO;// contours apparents invisibly
     TopoDS_Shape HI;// isoparamtriques   invisibly
-
-private:
-    void printCircle(const BRepAdaptor_Curve&, std::ostream&);
 };
 
 } //namespace Drawing
