@@ -16,8 +16,11 @@
 
 #include <vector>
 
+#include <Gui/Action.h>
 #include <Gui/Application.h>
+#include <Gui/BitmapFactory.h>
 #include <Gui/Command.h>
+#include <Gui/Control.h>
 #include <Gui/Selection.h>
 #include <Gui/MainWindow.h>
 #include <Gui/FileDialog.h>
@@ -27,6 +30,7 @@
 
 
 #include "DrawingView.h"
+#include "TaskDialog.h"
 
 using namespace DrawingGui;
 using namespace std;
@@ -39,7 +43,7 @@ using namespace std;
 DEF_STD_CMD(CmdDrawingOpen);
 
 CmdDrawingOpen::CmdDrawingOpen()
-	:Command("Drawing_Open")
+  : Command("Drawing_Open")
 {
     sAppModule      = "Drawing";
     sGroup          = QT_TR_NOOP("Drawing");
@@ -64,6 +68,122 @@ void CmdDrawingOpen::activated(int iMsg)
     }
 }
 
+//===========================================================================
+// Drawing_NewPage
+//===========================================================================
+
+DEF_STD_CMD_ACL(CmdDrawingNewPage);
+
+CmdDrawingNewPage::CmdDrawingNewPage()
+  : Command("Drawing_NewPage")
+{
+    sAppModule      = "Drawing";
+    sGroup          = QT_TR_NOOP("Drawing");
+    sMenuText       = QT_TR_NOOP("Insert new drawing");
+    sToolTipText    = QT_TR_NOOP("Insert new drawing");
+    sWhatsThis      = "Drawing_NewPage";
+    sStatusTip      = sToolTipText;
+}
+
+void CmdDrawingNewPage::activated(int iMsg)
+{
+    std::string FeatName = getUniqueObjectName("Page");
+
+    if (iMsg == 3) {
+        openCommand("Drawing create page");
+        doCommand(Doc,"App.activeDocument().addObject('Drawing::FeaturePage','%s')",FeatName.c_str());
+        doCommand(Doc,"App.activeDocument().%s.Template = 'A3_Landscape.svg'",FeatName.c_str());
+        commitCommand();
+    }
+    else {
+        QMessageBox::critical(Gui::getMainWindow(),
+            QLatin1String("No template"),
+            QLatin1String("No template available for this page size"));
+    }
+}
+
+Gui::Action * CmdDrawingNewPage::createAction(void)
+{
+    Gui::ActionGroup* pcAction = new Gui::ActionGroup(this, Gui::getMainWindow());
+    pcAction->setDropDownMenu(true);
+    applyCommandData(pcAction);
+
+    QAction* a0 = pcAction->addAction(QString());
+    a0->setIcon(Gui::BitmapFactory().pixmap("actions/drawing-landscape-A0"));
+
+    QAction* a1 = pcAction->addAction(QString());
+    a1->setIcon(Gui::BitmapFactory().pixmap("actions/drawing-landscape-A1"));
+
+    QAction* a2 = pcAction->addAction(QString());
+    a2->setIcon(Gui::BitmapFactory().pixmap("actions/drawing-landscape-A2"));
+
+    QAction* a3 = pcAction->addAction(QString());
+    a3->setIcon(Gui::BitmapFactory().pixmap("actions/drawing-landscape-A3"));
+
+    QAction* a4 = pcAction->addAction(QString());
+    a4->setIcon(Gui::BitmapFactory().pixmap("actions/drawing-landscape-A4"));
+
+    _pcAction = pcAction;
+    languageChange();
+    pcAction->setIcon(a3->icon());
+    pcAction->setProperty("defaultAction", QVariant(3));
+
+    return pcAction;
+}
+
+void CmdDrawingNewPage::languageChange()
+{
+    Command::languageChange();
+
+    if (!_pcAction)
+        return;
+    Gui::ActionGroup* pcAction = qobject_cast<Gui::ActionGroup*>(_pcAction);
+    QList<QAction*> a = pcAction->actions();
+
+    a[0]->setText(QCoreApplication::translate(
+        "Drawing_NewPage", "A0 landscape", 0,
+        QCoreApplication::CodecForTr));
+    a[0]->setToolTip(QCoreApplication::translate(
+        "Drawing_NewPage", "Insert new A0 landscape drawing", 0,
+        QCoreApplication::CodecForTr));
+
+    a[1]->setText(QCoreApplication::translate(
+        "Drawing_NewPage", "A1 landscape", 0,
+        QCoreApplication::CodecForTr));
+    a[1]->setToolTip(QCoreApplication::translate(
+        "Drawing_NewPage", "Insert new A1 landscape drawing", 0,
+        QCoreApplication::CodecForTr));
+
+    a[2]->setText(QCoreApplication::translate(
+        "Drawing_NewPage", "A2 landscape", 0,
+        QCoreApplication::CodecForTr));
+    a[2]->setToolTip(QCoreApplication::translate(
+        "Drawing_NewPage", "Insert new A2 landscape drawing", 0,
+        QCoreApplication::CodecForTr));
+
+    a[3]->setText(QCoreApplication::translate(
+        "Drawing_NewPage", "A3 landscape", 0,
+        QCoreApplication::CodecForTr));
+    a[3]->setToolTip(QCoreApplication::translate(
+        "Drawing_NewPage", "Insert new A3 landscape drawing", 0,
+        QCoreApplication::CodecForTr));
+
+    a[4]->setText(QCoreApplication::translate(
+        "Drawing_NewPage", "A4 landscape", 0,
+        QCoreApplication::CodecForTr));
+    a[4]->setToolTip(QCoreApplication::translate(
+        "Drawing_NewPage", "Insert new A4 landscape drawing", 0,
+        QCoreApplication::CodecForTr));
+}
+
+bool CmdDrawingNewPage::isActive(void)
+{
+    if (getActiveGuiDocument())
+        return true;
+    else
+        return false;
+}
+
 //===========================================================================
 // Drawing_NewA3Landscape
 //===========================================================================
@@ -88,7 +208,7 @@ void CmdDrawingNewA3Landscape::activated(int iMsg)
 
     openCommand("Drawing create page");
     doCommand(Doc,"App.activeDocument().addObject('Drawing::FeaturePage','%s')",FeatName.c_str());
-    doCommand(Doc,"App.activeDocument().%s.Template = App.getResourceDir()+'Mod/Drawing/Templates/A3_Landscape.svg'",FeatName.c_str());
+    doCommand(Doc,"App.activeDocument().%s.Template = 'A3_Landscape.svg'",FeatName.c_str());
     commitCommand();
 }
 
@@ -108,7 +228,7 @@ bool CmdDrawingNewA3Landscape::isActive(void)
 DEF_STD_CMD(CmdDrawingNewView);
 
 CmdDrawingNewView::CmdDrawingNewView()
-	:Command("Drawing_NewView")
+  : Command("Drawing_NewView")
 {
     sAppModule      = "Drawing";
     sGroup          = QT_TR_NOOP("Drawing");
@@ -168,12 +288,11 @@ CmdDrawingExportPage::CmdDrawingExportPage()
     sWhatsThis    = "Drawing_ExportPage";
     sStatusTip    = QT_TR_NOOP("Export a page to an SVG file");
     sPixmap       = "document-save";
-    iAccel        = 0;
 }
 
 void CmdDrawingExportPage::activated(int iMsg)
 {
-	unsigned int n = getSelection().countObjectsOfType(Drawing::FeaturePage::getClassTypeId());
+    unsigned int n = getSelection().countObjectsOfType(Drawing::FeaturePage::getClassTypeId());
     if (n != 1) {
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
             QObject::tr("Select one Page object."));
@@ -186,14 +305,14 @@ void CmdDrawingExportPage::activated(int iMsg)
 
     QString fn = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(), QObject::tr("Export page"), QString(), filter.join(QLatin1String(";;")));
     if (!fn.isEmpty()) {
-  	   std::vector<Gui::SelectionSingleton::SelObj> Sel = getSelection().getSelection();
+        std::vector<Gui::SelectionSingleton::SelObj> Sel = getSelection().getSelection();
         openCommand("Drawing export page");
 
-		doCommand(Doc,"PageFile = open(App.activeDocument().%s.PageResult,'r')",Sel[0].FeatName);
-		std::string fname = (const char*)fn.toAscii();
-		doCommand(Doc,"OutFile = open('%s','w')",fname.c_str());
-		doCommand(Doc,"OutFile.write(PageFile.read())");
-		doCommand(Doc,"del OutFile,PageFile");
+        doCommand(Doc,"PageFile = open(App.activeDocument().%s.PageResult,'r')",Sel[0].FeatName);
+        std::string fname = (const char*)fn.toAscii();
+        doCommand(Doc,"OutFile = open('%s','w')",fname.c_str());
+        doCommand(Doc,"OutFile.write(PageFile.read())");
+        doCommand(Doc,"del OutFile,PageFile");
 
         commitCommand();
     }
@@ -204,6 +323,39 @@ bool CmdDrawingExportPage::isActive(void)
     return (getActiveGuiDocument() ? true : false);
 }
 
+//===========================================================================
+// Drawing_ProjectShape
+//===========================================================================
+
+DEF_STD_CMD_A(CmdDrawingProjectShape);
+
+CmdDrawingProjectShape::CmdDrawingProjectShape()
+  : Command("Drawing_ProjectShape")
+{
+    // seting the
+    sGroup        = QT_TR_NOOP("Drawing");
+    sMenuText     = QT_TR_NOOP("Project shape...");
+    sToolTipText  = QT_TR_NOOP("Project shape onto a user-defined plane");
+    sStatusTip    = QT_TR_NOOP("Project shape onto a user-defined plane");
+    sWhatsThis    = "Drawing_ProjectShape";
+}
+
+void CmdDrawingProjectShape::activated(int iMsg)
+{
+    Gui::TaskView::TaskDialog* dlg = Gui::Control().activeDialog();
+    if (!dlg) {
+        dlg = new DrawingGui::TaskProjection();
+        dlg->setButtonPosition(Gui::TaskView::TaskDialog::South);
+    }
+    Gui::Control().showDialog(dlg);
+}
+
+bool CmdDrawingProjectShape::isActive(void)
+{
+    int ct = Gui::Selection().countObjectsOfType(Part::Feature::getClassTypeId());
+    return (ct > 0 && !Gui::Control().activeDialog());
+}
+
 
 
 void CreateDrawingCommands(void)
@@ -211,7 +363,9 @@ void CreateDrawingCommands(void)
     Gui::CommandManager &rcCmdMgr = Gui::Application::Instance->commandManager();
 
     rcCmdMgr.addCommand(new CmdDrawingOpen());
+    rcCmdMgr.addCommand(new CmdDrawingNewPage());
     rcCmdMgr.addCommand(new CmdDrawingNewA3Landscape());
     rcCmdMgr.addCommand(new CmdDrawingNewView());
     rcCmdMgr.addCommand(new CmdDrawingExportPage());
+    rcCmdMgr.addCommand(new CmdDrawingProjectShape());
 }
