@@ -4,17 +4,15 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+285"/>
       <source>File</source>
       <translation>File</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;Export page...</source>
       <translation>&amp;Esporta pagina...</translation>
     </message>
     <message>
-      <location/>
       <source>Export a page to an SVG file</source>
       <translation>Esporta una pagina in un file SVG</translation>
     </message>
@@ -22,35 +20,36 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
-      <location/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
-      <location/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Inserisci un nuovo disegno A3 orizzontale</translation>
     </message>
   </context>
   <context>
-    <name>CmdDrawingNewView</name>
+    <name>CmdDrawingNewPage</name>
     <message>
-      <location/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
-      <location/>
-      <source>Insert a new View in the active drawing</source>
-      <translation>Inserisci una nuova Vista nel disegno attivo</translation>
+      <source>Insert new drawing</source>
+      <translation>Inserisci nuovo disegno</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdDrawingNewView</name>
+    <message>
+      <source>Drawing</source>
+      <translation>Disegno</translation>
     </message>
     <message>
-      <location/>
       <source>Insert view in drawing</source>
       <translation>Inserisci vista nel disegno</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Inserisce una nuova vista di una parte del disegno attivo</translation>
     </message>
@@ -58,181 +57,261 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
-      <location/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
-      <location/>
       <source>Open SVG...</source>
       <translation>Apri SVG...</translation>
     </message>
     <message>
-      <location/>
       <source>Open a scalable vector graphic</source>
       <translation>Apre una grafica vettoriale scalabile</translation>
     </message>
   </context>
   <context>
-    <name>DrawingGui::DrawingView</name>
+    <name>CmdDrawingProjectShape</name>
     <message>
-      <location/>
-      <source>&amp;Background</source>
-      <translation>&amp;Sfondo</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;Outline</source>
-      <translation>C&amp;ontorno</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;Native</source>
-      <translation>&amp;Nativo</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;OpenGL</source>
-      <translation>&amp;OpenGL</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;Image</source>
-      <translation>&amp;Immagine</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;High Quality Antialiasing</source>
-      <translation>&amp;Antialiasing di qualità elevata</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Open SVG File</source>
-      <translation>Apri file SVG</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Could not open file '%1'.</source>
-      <translation>Impossibile aprire il file '%1'.</translation>
-    </message>
-    <message>
-      <location/>
-      <source>&amp;Renderer</source>
-      <translation>&amp;Render</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Export PDF</source>
-      <translation>Esporta PDF</translation>
-    </message>
-    <message>
-      <location/>
-      <source>PDF file (*.pdf)</source>
-      <translation>File PDF (*.pdf)</translation>
-    </message>
-  </context>
-  <context>
-    <name>DrawingGui::Workbench</name>
-    <message>
-      <location/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
-      <location/>
-      <source>I/O</source>
-      <translation>I/O</translation>
+      <source>Project shape...</source>
+      <translation>Proietta le forme...</translation>
     </message>
     <message>
-      <location/>
-      <source>Drawing types</source>
-      <translation>Tipo di disegno</translation>
+      <source>Project shape onto a user-defined plane</source>
+      <translation>Proietta una forma su di un piano definito dall'utente</translation>
+    </message>
+  </context>
+  <context>
+    <name>DrawingGui::DrawingView</name>
+    <message>
+      <location filename="../../DrawingView.cpp" line="+206"/>
+      <source>&amp;Background</source>
+      <translation>&amp;Sfondo</translation>
     </message>
     <message>
-      <location/>
-      <source>Views</source>
-      <translation>Viste</translation>
+      <source>&amp;Outline</source>
+      <translation>C&amp;ontorno</translation>
+    </message>
+    <message>
+      <source>&amp;Native</source>
+      <translation>&amp;Nativo</translation>
+    </message>
+    <message>
+      <source>&amp;OpenGL</source>
+      <translation>&amp;OpenGL</translation>
+    </message>
+    <message>
+      <source>&amp;Image</source>
+      <translation>&amp;Immagine</translation>
+    </message>
+    <message>
+      <source>&amp;High Quality Antialiasing</source>
+      <translation>&amp;Antialiasing di qualità elevata</translation>
+    </message>
+    <message>
+      <source>Open SVG File</source>
+      <translation>Apri file SVG</translation>
+    </message>
+    <message>
+      <source>Could not open file '%1'.</source>
+      <translation>Impossibile aprire il file '%1'.</translation>
+    </message>
+    <message>
+      <source>&amp;Renderer</source>
+      <translation>&amp;Render</translation>
+    </message>
+    <message>
+      <source>Export PDF</source>
+      <translation>Esporta PDF</translation>
+    </message>
+    <message>
+      <source>PDF file (*.pdf)</source>
+      <translation>File PDF (*.pdf)</translation>
+    </message>
+    <message>
+      <source>Page sizes</source>
+      <translation>Dimensioni pagina</translation>
+    </message>
+    <message>
+      <source>A0</source>
+      <translation>A0</translation>
+    </message>
+    <message>
+      <source>A1</source>
+      <translation>A1</translation>
+    </message>
+    <message>
+      <source>A2</source>
+      <translation>A2</translation>
+    </message>
+    <message>
+      <source>A3</source>
+      <translation>A3</translation>
+    </message>
+    <message>
+      <source>A4</source>
+      <translation>A4</translation>
+    </message>
+    <message>
+      <source>A5</source>
+      <translation>A5</translation>
+    </message>
+  </context>
+  <context>
+    <name>DrawingGui::TaskProjection</name>
+    <message>
+      <location filename="../../TaskDialog.cpp" line="+49"/>
+      <source>Visible sharp edges</source>
+      <translation>mostra gli spigoli vivi</translation>
+    </message>
+    <message>
+      <source>Visible smooth edges</source>
+      <translation>Mostra i bordi smussati</translation>
+    </message>
+    <message>
+      <source>Visible sewn edges</source>
+      <translation>Mostra i bordi cuciti</translation>
+    </message>
+    <message>
+      <source>Visible outline edges</source>
+      <translation>Mostra i bordi esterni</translation>
+    </message>
+    <message>
+      <source>Visible isoparameters</source>
+      <translation>Mostra le isoparametriche</translation>
+    </message>
+    <message>
+      <source>Hidden sharp edges</source>
+      <translation>Nascondi gli spigoli vivi</translation>
+    </message>
+    <message>
+      <source>Hidden smooth edges</source>
+      <translation>Nascondi i bordi smussati</translation>
+    </message>
+    <message>
+      <source>Hidden sewn edges</source>
+      <translation>Nascondi i bordi cuciti</translation>
+    </message>
+    <message>
+      <source>Hidden outline edges</source>
+      <translation>Nascondi i bordi esterni</translation>
+    </message>
+    <message>
+      <source>Hidden isoparameters</source>
+      <translation>Nascondi le isoparametriche</translation>
+    </message>
+    <message>
+      <source>Project shapes</source>
+      <translation>Proietta le forme</translation>
+    </message>
+  </context>
+  <context>
+    <name>Drawing_NewPage</name>
+    <message>
+      <location filename="../../Command.cpp" line="-196"/>
+      <source>A0 landscape</source>
+      <translation>A0 orizzontale</translation>
+    </message>
+    <message>
+      <source>Insert new A0 landscape drawing</source>
+      <translation>Inserisce nuovo disegno A0 orizzontale</translation>
+    </message>
+    <message>
+      <source>A1 landscape</source>
+      <translation>A1 orizzontale</translation>
+    </message>
+    <message>
+      <source>Insert new A1 landscape drawing</source>
+      <translation>Inserisce nuovo disegno A2 orizzontale</translation>
+    </message>
+    <message>
+      <source>A2 landscape</source>
+      <translation>A2 orizzontale</translation>
+    </message>
+    <message>
+      <source>Insert new A2 landscape drawing</source>
+      <translation>Inserisce nuovo disegno A2 orizzontale</translation>
+    </message>
+    <message>
+      <source>A3 landscape</source>
+      <translation>A3 orizzontale</translation>
+    </message>
+    <message>
+      <source>Insert new A3 landscape drawing</source>
+      <translation>Inserisci un nuovo disegno A3 orizzontale</translation>
+    </message>
+    <message>
+      <source>A4 landscape</source>
+      <translation>A4 orizzontale</translation>
+    </message>
+    <message>
+      <source>Insert new A4 landscape drawing</source>
+      <translation>Inserisce nuovo disegno A4 orizzontale</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
-      <location/>
       <source>Choose an SVG file to open</source>
       <translation>Seleziona un file SVG da aprire</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../AppDrawingGuiPy.cpp" line="+61"/>
       <source>Drawing viewer</source>
       <translation>Visualizzatore disegno</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+1"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Grafica Vettoriale Scalabile (*.svg *.svgz)</translation>
     </message>
     <message>
-      <location/>
       <source>Wrong selection</source>
       <translation>Selezione errata</translation>
     </message>
     <message>
-      <location/>
       <source>Select a Part object.</source>
       <translation>Seleziona un oggetto Parte.</translation>
     </message>
     <message>
-      <location/>
       <source>No page to insert</source>
       <translation>Nessuna pagina da inserire</translation>
     </message>
     <message>
-      <location/>
       <source>Create a page to insert.</source>
       <translation>Crea una pagina da inserire.</translation>
     </message>
     <message>
-      <location/>
       <source>Select one Page object.</source>
       <translation>Seleziona un oggetto Pagina.</translation>
     </message>
     <message>
-      <location/>
       <source>SVG(*.svg)</source>
       <translation>SVG (*.svg)</translation>
     </message>
     <message>
-      <location/>
       <source>All Files (*.*)</source>
       <translation>Tutti i file (*.*)</translation>
     </message>
     <message>
-      <location/>
       <source>Export page</source>
       <translation>Esporta pagina</translation>
     </message>
+    <message>
+      <location filename="../../ViewProviderPage.cpp" line="-25"/>
+      <source>Show drawing</source>
+      <translation>Mostra disegno</translation>
+    </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+37"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
-    <message>
-      <location/>
-      <source>I/O</source>
-      <translation>I/O</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Drawing types</source>
-      <translation>Tipo di disegno</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Views</source>
-      <translation>Viste</translation>
-    </message>
   </context>
 </TS>
