@@ -45,6 +45,7 @@
 
 #include <SMESH_Gen.hxx>
 #include <SMESH_Mesh.hxx>
+#include <SMDS_PolyhedralVolumeOfNodes.hxx>
 #include <SMDS_VolumeTool.hxx>
 #include <StdMeshers_MaxLength.hxx>
 #include <StdMeshers_LocalLength.hxx>
@@ -78,6 +79,8 @@ FemMesh::FemMesh(const FemMesh& mesh)
 
 FemMesh::~FemMesh()
 {
+    TopoDS_Shape aNull;
+    myMesh->ShapeToMesh(aNull);
     myMesh->Clear();
     //myMesh->ClearLog();
     delete myMesh;
@@ -279,14 +282,15 @@ void FemMesh::copyMeshData(const FemMesh& mesh)
                 break;
             default:
                 {
-                    std::vector<int> quantities;
-                    std::vector<const SMDS_MeshNode*> aNodes;
-                    for (int i=0; aVol->NbNodes(); i++) {
-                        aNodes.push_back(aVol->GetNode(0));
-                        quantities.push_back(1);
+                    if (aVol->IsPoly()) {
+                        const SMDS_PolyhedralVolumeOfNodes* aPolyVol = dynamic_cast<const SMDS_PolyhedralVolumeOfNodes*>(aVol);
+                        if (!aPolyVol) break;
+                        std::vector<const SMDS_MeshNode*> aNodes;
+                        for (int i=0; i<aPolyVol->NbNodes(); i++)
+                            aNodes.push_back(aPolyVol->GetNode(i));
+                        meshds->AddPolyhedralVolumeWithID(aNodes,
+                            aPolyVol->GetQuanities(), aPolyVol->GetID());
                     }
-                    meshds->AddPolyhedralVolumeWithID(aNodes,
-                        quantities, aVol->GetID());
                 }
                 break;
         }
@@ -596,23 +600,10 @@ unsigned int FemMesh::getMemSize (void) const
 
 void FemMesh::Save (Base::Writer &writer) const
 {
-    if(!writer.isForceXML()) {
-        //See SaveDocFile(), RestoreDocFile()
-        writer.Stream() << writer.ind() << "<FemMesh file=\"" 
-                        << writer.addFile("FemMesh.unv", this)
-                        << "\"/>" << std::endl;
-    }
 }
 
 void FemMesh::Restore(Base::XMLReader &reader)
 {
-    reader.readElement("FemMesh");
-    std::string file (reader.getAttribute("file") );
-
-    if (!file.empty()) {
-        // initate a file read
-        reader.addFile(file.c_str(),this);
-    }
 }
 
 void FemMesh::SaveDocFile (Base::Writer &writer) const
@@ -671,7 +662,7 @@ void FemMesh::transformGeometry(const Base::Matrix4D& rclTrf)
 	for (;aNodeIter->more();) {
 		const SMDS_MeshNode* aNode = aNodeIter->next();
 		current_node.Set(aNode->X(),aNode->Y(),aNode->Z());
-		current_node = current_node * clMatrix;
+		current_node = clMatrix * current_node;
 		myMesh->GetMeshDS()->MoveNode(aNode,current_node.x,current_node.y,current_node.z);
 	}
 }
@@ -722,6 +713,11 @@ std::vector<const char*> FemMesh::getElementTypes(void) const
     return temp;
 }
 
+unsigned long FemMesh::countSubElements(const char* Type) const
+{
+    return 0;
+}
+
 Data::Segment* FemMesh::getSubElement(const char* Type, unsigned long n) const
 {
     // FIXME implement subelement interface 
