@@ -4,17 +4,19 @@
   <context>
     <name>CmdCreateImagePlane</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+93"/>
       <source>Image</source>
       <translation>Immagine</translation>
     </message>
     <message>
-      <location/>
       <source>Create image plane...</source>
       <translation>Crea un piano immagine...</translation>
     </message>
     <message>
-      <location/>
+      <source>Create a planar image in the 3D space</source>
+      <translation>Create a planar image in the 3D space</translation>
+    </message>
+    <message>
       <source>create a planar image in the 3D space</source>
       <translation>crea un'immagine piana nello spazio 3D</translation>
     </message>
@@ -22,17 +24,14 @@
   <context>
     <name>CmdImageOpen</name>
     <message>
-      <location/>
       <source>Image</source>
       <translation>Immagine</translation>
     </message>
     <message>
-      <location/>
       <source>Open...</source>
       <translation>Apri...</translation>
     </message>
     <message>
-      <location/>
       <source>Open image view</source>
       <translation>Apri il visualizzatore di immagini</translation>
     </message>
@@ -40,12 +39,11 @@
   <context>
     <name>ImageGui::GLImageBox</name>
     <message>
-      <location/>
+      <location filename="../../GLImageBox.cpp" line="+308"/>
       <source>Undefined type of colour space for image viewing</source>
       <translation>Tipo di spazio colore indefinito per la visualizzazione delle immagini</translation>
     </message>
     <message>
-      <location/>
       <source>Image pixel format</source>
       <translation>Formato pixel</translation>
     </message>
@@ -53,103 +51,87 @@
   <context>
     <name>ImageGui::ImageView</name>
     <message>
-      <location/>
+      <location filename="../../ImageView.cpp" line="+77"/>
       <source>&amp;Fit image</source>
       <translation>&amp;Adatta immagine</translation>
     </message>
     <message>
-      <location/>
       <source>Stretch the image to fit the view</source>
       <translation>Stira l'immagine per adattarsi alla vista</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;1:1 scale</source>
       <translation>Scala &amp;1:1</translation>
     </message>
     <message>
-      <location/>
       <source>Display the image at a 1:1 scale</source>
       <translation>Visualizza l'immagine in scala 1:1</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;Original color</source>
       <translation>Colori &amp;originali</translation>
     </message>
     <message>
-      <location/>
       <source>Display the image with its original color(s)</source>
       <translation>Visualizza l'immagine con i suoi colori originali</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;Brightened color</source>
       <translation>&amp;Colori più luminosi</translation>
     </message>
     <message>
-      <location/>
       <source>Display the image with brightened color(s)</source>
       <translation>Visualizza l'immagine con colori più luminosi</translation>
     </message>
     <message>
-      <location/>
       <source>Standard</source>
       <translation>Standard</translation>
     </message>
     <message>
-      <location/>
       <source>Ready...</source>
       <translation>Pronto...</translation>
     </message>
     <message>
-      <location/>
       <source>grey</source>
       <translation>grigio</translation>
     </message>
     <message>
-      <location/>
       <source>zoom</source>
       <translation>zoom</translation>
     </message>
     <message>
-      <location/>
       <source>outside image</source>
       <translation>fuori dall'immagine</translation>
     </message>
   </context>
-  <context>
-    <name>ImageGui::Workbench</name>
-    <message>
-      <location/>
-      <source>Image</source>
-      <translation>Immagine</translation>
-    </message>
-  </context>
   <context>
     <name>QObject</name>
     <message>
-      <location/>
       <source>Image viewer</source>
       <translation>Visualizzatore di immagini</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+106"/>
       <source>Images (*.png *.xpm *.jpg *.bmp)</source>
       <translation>Immagini (*.png *.xpm *.jpg *.bmp)</translation>
     </message>
     <message>
-      <location/>
       <source>Choose an image file to open</source>
       <translation>Seleziona un file immagine da aprire</translation>
     </message>
     <message>
-      <location/>
+      <source>Images</source>
+      <translation>Images</translation>
+    </message>
+    <message>
+      <source>All files</source>
+      <translation>All files</translation>
+    </message>
+    <message>
       <source>Error open image</source>
       <translation>Errore durante l'apertura dell'immagine</translation>
     </message>
     <message>
-      <location/>
       <source>Could not load the choosen image</source>
       <translation>Impossibile caricare l'immagine scelta</translation>
     </message>
@@ -157,7 +139,7 @@
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+36"/>
       <source>Image</source>
       <translation>Immagine</translation>
     </message>
