@@ -63,12 +63,16 @@ using namespace InspectionGui;
 
 
 bool ViewProviderInspection::addflag = false;
+App::PropertyFloatConstraint::Constraints ViewProviderInspection::floatRange = {1.0f,64.0f,1.0f};
 
 PROPERTY_SOURCE(InspectionGui::ViewProviderInspection, Gui::ViewProviderDocumentObject)
 
 ViewProviderInspection::ViewProviderInspection() : search_radius(FLT_MAX)
 {
     ADD_PROPERTY_TYPE(OutsideGrayed,(false),"",(App::PropertyType) (App::Prop_Output|App::Prop_Hidden),"");
+    ADD_PROPERTY_TYPE(PointSize,(1.0f),"Display",(App::PropertyType) (App::Prop_None/*App::Prop_Hidden*/),"");
+    PointSize.setConstraints(&floatRange);
+
     pcColorRoot = new SoSeparator();
     pcColorRoot->ref();
     pcMatBinding = new SoMaterialBinding;
@@ -86,6 +90,11 @@ ViewProviderInspection::ViewProviderInspection() : search_radius(FLT_MAX)
     pcColorBar->setRange( -0.1f, 0.1f, 3 );
     pcLinkRoot = new SoGroup;
     pcLinkRoot->ref();
+
+    pcPointStyle = new SoDrawStyle();
+    pcPointStyle->ref();
+    pcPointStyle->style = SoDrawStyle::POINTS;
+    pcPointStyle->pointSize = PointSize.getValue();
 }
 
 ViewProviderInspection::~ViewProviderInspection()
@@ -97,6 +106,7 @@ ViewProviderInspection::~ViewProviderInspection()
     pcColorBar->Detach(this);
     pcColorBar->unref();
     pcLinkRoot->unref();
+    pcPointStyle->unref();
 }
 
 void ViewProviderInspection::onChanged(const App::Property* prop)
@@ -107,6 +117,9 @@ void ViewProviderInspection::onChanged(const App::Property* prop)
             pcColorBar->Notify(0);
         }
     }
+    else if ( prop == &PointSize ) {
+        pcPointStyle->pointSize = PointSize.getValue();
+    }
     else {
         inherited::onChanged(prop);
     }
@@ -209,7 +222,7 @@ void ViewProviderInspection::updateData(const App::Property* prop)
             if (data) {
                 this->pcLinkRoot->removeAllChildren();
                 std::vector<Base::Vector3d> points;
-                std::vector<Data::ComplexGeoData::FacetTopo> faces;
+                std::vector<Data::ComplexGeoData::Facet> faces;
                 data->getFaces(points, faces, accuracy);
 
                 this->pcLinkRoot->addChild(this->pcCoords);
@@ -227,7 +240,7 @@ void ViewProviderInspection::updateData(const App::Property* prop)
                     face->coordIndex.setNum(4*faces.size());
                     int32_t* indices = face->coordIndex.startEditing();
                     unsigned long j=0;
-                    std::vector<Data::ComplexGeoData::FacetTopo>::iterator it;
+                    std::vector<Data::ComplexGeoData::Facet>::iterator it;
                     for (it = faces.begin(); it != faces.end(); ++it,j++) {
                         indices[4*j+0] = it->I1;
                         indices[4*j+1] = it->I2;
@@ -237,12 +250,18 @@ void ViewProviderInspection::updateData(const App::Property* prop)
                     face->coordIndex.finishEditing();
                 }
                 else {
+                    this->pcLinkRoot->addChild(this->pcPointStyle);
                     this->pcLinkRoot->addChild(new SoPointSet());
                 }
             }
         }
     }
     else if (prop->getTypeId() == App::PropertyFloatList::getClassTypeId()) {
+        // force an update of the Inventor data nodes
+        if (this->pcObject) {
+            App::Property* link = this->pcObject->getPropertyByName("Actual");
+            if (link) updateData(link);
+        }
         setDistances();
     }
     else if (prop->getTypeId() == App::PropertyFloat::getClassTypeId()) {
@@ -465,7 +484,7 @@ void ViewProviderInspection::inspectCallback(void * ud, SoEventCallback * n)
             }
         }
     }
-    // toogle between inspection and navigation mode
+    // toggle between inspection and navigation mode
     else if (ev->getTypeId().isDerivedFrom(SoKeyboardEvent::getClassTypeId())) {
         const SoKeyboardEvent * const ke = static_cast<const SoKeyboardEvent *>(ev);
         if (ke->getState() == SoButtonEvent::DOWN &&
