@@ -667,7 +667,8 @@ bool MeshEvalFoldsOnSurface::Evaluate()
                     // is the point projectable onto the facet?
                     rTriangle = _rclMesh.GetFacet(f_beg[*ft]);
                     if (rTriangle.IntersectWithLine(mp,rTriangle.GetNormal(),tmp)) {
-                        this->indices.push_back(*pt);
+                        const std::set<unsigned long>& f = clPt2Facets[*pt];
+                        this->indices.insert(this->indices.end(), f.begin(), f.end());
                         break;
                     }
             }
@@ -692,7 +693,7 @@ bool MeshFixFoldsOnSurface::Fixup()
     MeshEvalFoldsOnSurface eval(_rclMesh);
     if (!eval.Evaluate()) {
         std::vector<unsigned long> inds = eval.GetIndices();
-        _rclMesh.DeletePoints(inds);
+        _rclMesh.DeleteFacets(inds);
     }
 
     return true;
@@ -703,7 +704,7 @@ bool MeshFixFoldsOnSurface::Fixup()
 bool MeshEvalFoldsOnBoundary::Evaluate()
 {
     // remove all boundary facets with two open edges and where
-    // the angle to the neighbour is more that 30 degree
+    // the angle to the neighbour is more than 60 degree
     this->indices.clear();
     const MeshFacetArray& rFacAry = _rclMesh.GetFacets();
     for (MeshFacetArray::_TConstIterator it = rFacAry.begin(); it != rFacAry.end(); ++it) {
@@ -712,8 +713,8 @@ bool MeshEvalFoldsOnBoundary::Evaluate()
                 if (it->_aulNeighbours[i] != ULONG_MAX) {
                     MeshGeomFacet f1 = _rclMesh.GetFacet(*it);
                     MeshGeomFacet f2 = _rclMesh.GetFacet(it->_aulNeighbours[i]);
-                    float angle = f1.GetNormal().GetAngle(f2.GetNormal());
-                    if (angle >= 0.52f) // ~ 30 degree
+                    float cos_angle = f1.GetNormal() * f2.GetNormal();
+                    if (cos_angle <= 0.5f) // ~ 60 degree
                         indices.push_back(it-rFacAry.begin());
                 }
             }
@@ -741,6 +742,66 @@ bool MeshFixFoldsOnBoundary::Fixup()
 
 // ----------------------------------------------------------------------
 
+bool MeshEvalFoldOversOnSurface::Evaluate()
+{
+    this->indices.clear();
+    const MeshCore::MeshFacetArray& facets = _rclMesh.GetFacets();
+    MeshCore::MeshFacetArray::_TConstIterator f_it,
+        f_beg = facets.begin(), f_end = facets.end();
+
+    Base::Vector3f n1, n2;
+    for (f_it = facets.begin(); f_it != f_end; ++f_it) {
+        for (int i=0; i<3; i++) {
+            unsigned long index1 = f_it->_aulNeighbours[i];
+            unsigned long index2 = f_it->_aulNeighbours[(i+1)%3];
+            if (index1 != ULONG_MAX && index2 != ULONG_MAX) {
+                // if the topology is correct but the normals flip from
+                // two neighbours we have a fold
+                if (f_it->HasSameOrientation(f_beg[index1]) &&
+                    f_it->HasSameOrientation(f_beg[index2])) {
+                    n1 = _rclMesh.GetFacet(index1).GetNormal();
+                    n2 = _rclMesh.GetFacet(index2).GetNormal();
+                    if (n1 * n2 < -0.5f) { // angle > 120 deg
+                        this->indices.push_back(f_it-f_beg);
+                        break;
+                    }
+                }
+            }
+        }
+    }
+
+    return this->indices.empty();
+}
+
+// ----------------------------------------------------------------
+
+bool MeshEvalBorderFacet::Evaluate()
+{
+    const MeshCore::MeshFacetArray& facets = _rclMesh.GetFacets();
+    MeshCore::MeshFacetArray::_TConstIterator f_it,
+        f_beg = facets.begin(), f_end = facets.end();
+    MeshCore::MeshRefPointToPoints vv_it(_rclMesh);
+    MeshCore::MeshRefPointToFacets vf_it(_rclMesh);
+
+    for (f_it = facets.begin(); f_it != f_end; ++f_it) {
+        bool ok = true;
+        for (int i=0; i<3; i++) {
+            unsigned long index = f_it->_aulPoints[i];
+            if (vv_it[index].size() == vf_it[index].size()) {
+                ok = false;
+                break;
+            }
+        }
+
+        if (ok)
+            _facets.push_back(f_it-f_beg);
+    }
+
+    return _facets.empty();
+}
+
+// ----------------------------------------------------------------------
+
 bool MeshEvalRangeFacet::Evaluate()
 {
   const MeshFacetArray& rFaces = _rclMesh.GetFacets();
