@@ -355,58 +355,64 @@ bool MeshEvalTopology::Evaluate ()
 
     // search for non-manifold edges
     unsigned long p0 = ULONG_MAX, p1 = ULONG_MAX;
-    _aclManifoldList.clear();
+    nonManifoldList.clear();
+    nonManifoldFacets.clear();
+
     int count = 0;
+    std::vector<unsigned long> facets;
     std::vector<Edge_Index>::iterator pE;
     for (pE = edges.begin(); pE != edges.end(); pE++) {
         if (p0 == pE->p0 && p1 == pE->p1) {
             count++;
+            facets.push_back(pE->f);
         }
         else {
             if (count > 2) {
                 // Edge that is shared by more than 2 facets
-                _aclManifoldList.push_back(std::make_pair
+                nonManifoldList.push_back(std::make_pair
                     <unsigned long, unsigned long>(p0, p1));
+                nonManifoldFacets.push_back(facets);
             }
 
             p0 = pE->p0;
             p1 = pE->p1;
+            facets.clear();
+            facets.push_back(pE->f);
             count = 1;
         }
     }
 
-    return _aclManifoldList.empty();
+    return nonManifoldList.empty();
 }
 
 // generate indexed edge list which tangents non-manifolds
 void MeshEvalTopology::GetFacetManifolds (std::vector<unsigned long> &raclFacetIndList) const
 {
-  raclFacetIndList.clear();
-  const MeshFacetArray& rclFAry = _rclMesh.GetFacets();
-  MeshFacetArray::_TConstIterator pI;
+    raclFacetIndList.clear();
+    const MeshFacetArray& rclFAry = _rclMesh.GetFacets();
+    MeshFacetArray::_TConstIterator pI;
 
-  for (pI = rclFAry.begin(); pI != rclFAry.end(); pI++)
-  {
-    for (int i = 0; i < 3; i++)
-    {
-      unsigned long ulPt0 = std::min<unsigned long>(pI->_aulPoints[i],  pI->_aulPoints[(i+1)%3]);
-      unsigned long ulPt1 = std::max<unsigned long>(pI->_aulPoints[i],  pI->_aulPoints[(i+1)%3]);
-      std::pair<unsigned long, unsigned long> edge = std::make_pair<unsigned long, unsigned long>(ulPt0, ulPt1);
+    for (pI = rclFAry.begin(); pI != rclFAry.end(); pI++) {
+        for (int i = 0; i < 3; i++) {
+            unsigned long ulPt0 = std::min<unsigned long>(pI->_aulPoints[i],  pI->_aulPoints[(i+1)%3]);
+            unsigned long ulPt1 = std::max<unsigned long>(pI->_aulPoints[i],  pI->_aulPoints[(i+1)%3]);
+            std::pair<unsigned long, unsigned long> edge = std::make_pair<unsigned long, unsigned long>(ulPt0, ulPt1);
 
-      if ( std::find(_aclManifoldList.begin(), _aclManifoldList.end(), edge) != _aclManifoldList.end() )
-        raclFacetIndList.push_back( pI - rclFAry.begin() );
+            if (std::find(nonManifoldList.begin(), nonManifoldList.end(), edge) != nonManifoldList.end())
+                raclFacetIndList.push_back(pI - rclFAry.begin());
+        }
     }
-  }
 }
 
 unsigned long MeshEvalTopology::CountManifolds() const
 {
-  return _aclManifoldList.size();
+    return nonManifoldList.size();
 }
 
 bool MeshFixTopology::Fixup ()
 {
     std::vector<unsigned long> indices;
+#if 0
     MeshEvalTopology eval(_rclMesh);
     if (!eval.Evaluate()) {
         eval.GetFacetManifolds(indices);
@@ -417,6 +423,38 @@ bool MeshFixTopology::Fixup ()
 
         _rclMesh.DeleteFacets(indices);
     }
+#else
+    const MeshFacetArray& rFaces = _rclMesh.GetFacets();
+    indices.reserve(3 * nonManifoldList.size()); // allocate some memory
+    std::list<std::vector<unsigned long> >::const_iterator it;
+    for (it = nonManifoldList.begin(); it != nonManifoldList.end(); ++it) {
+        std::vector<unsigned long> non_mf;
+        non_mf.reserve(it->size());
+        for (std::vector<unsigned long>::const_iterator jt = it->begin(); jt != it->end(); ++jt) {
+            // fscet is only connected with one edge and there causes a non-manifold
+            unsigned short numOpenEdges = rFaces[*jt].CountOpenEdges();
+            if (numOpenEdges == 2)
+                non_mf.push_back(*jt);
+            else if (rFaces[*jt].IsDegenerated())
+                non_mf.push_back(*jt);
+        }
+
+        // are we able to repair the non-manifold edge by not removing all facets?
+        if (it->size() - non_mf.size() == 2)
+            indices.insert(indices.end(), non_mf.begin(), non_mf.end());
+        else
+            indices.insert(indices.end(), it->begin(), it->end());
+    }
+
+    if (!indices.empty()) {
+        // remove duplicates
+        std::sort(indices.begin(), indices.end());
+        indices.erase(std::unique(indices.begin(), indices.end()), indices.end());
+
+        _rclMesh.DeleteFacets(indices);
+        _rclMesh.RebuildNeighbours();
+    }
+#endif
 
     return true;
 }
@@ -482,7 +520,7 @@ bool MeshEvalSingleFacet::Evaluate ()
       _aclManifoldList.push_back(aulManifolds);
   }
 */
-  return (_aclManifoldList.size() == 0);
+  return (nonManifoldList.size() == 0);
 }
 
 bool MeshFixSingleFacet::Fixup ()
@@ -491,8 +529,6 @@ bool MeshFixSingleFacet::Fixup ()
 //  MeshFacetArray& raFacets = _rclMesh._aclFacetArray;
   for ( std::vector<std::list<unsigned long> >::const_iterator it=_raclManifoldList.begin();it!=_raclManifoldList.end();++it )
   {
-    unsigned long uFInd1, uFInd2;
-    uFInd1 = uFInd2 = ULONG_MAX;
     for ( std::list<unsigned long>::const_iterator it2 = it->begin(); it2 != it->end(); ++it2 )
     {
       aulInvalids.push_back(*it2);
@@ -519,7 +555,7 @@ bool MeshEvalSelfIntersection::Evaluate ()
     cMeshFacetGrid.GetCtGrids(ulGridX, ulGridY, ulGridZ);
 
     MeshFacetIterator cMFI(_rclMesh);
-    for(cMFI.Begin(); cMFI.More(); cMFI.Next()) {
+    for (cMFI.Begin(); cMFI.More(); cMFI.Next()) {
         boxes.push_back((*cMFI).GetBoundBox());
     }
 
@@ -578,71 +614,25 @@ bool MeshEvalSelfIntersection::Evaluate ()
     return true;
 }
 
-void MeshEvalSelfIntersection::GetIntersections(std::vector<std::pair<Base::Vector3f, Base::Vector3f> >& intersection) const
+void MeshEvalSelfIntersection::GetIntersections(const std::vector<std::pair<unsigned long, unsigned long> >& indices,
+                                                std::vector<std::pair<Base::Vector3f, Base::Vector3f> >& intersection) const
 {
-    // Contains bounding boxes for every facet 
-    std::vector<Base::BoundBox3f> boxes;
-    intersection.clear();
+    intersection.reserve(indices.size());
+    MeshFacetIterator cMF1(_rclMesh);
+    MeshFacetIterator cMF2(_rclMesh);
 
-    // Splits the mesh using grid for speeding up the calculation
-    MeshFacetGrid cMeshFacetGrid(_rclMesh);
-    const MeshFacetArray& rFaces = _rclMesh.GetFacets();
-    MeshGridIterator clGridIter(cMeshFacetGrid);
-    unsigned long ulGridX, ulGridY, ulGridZ;
-    cMeshFacetGrid.GetCtGrids(ulGridX, ulGridY, ulGridZ);
+    Base::Vector3f pt1, pt2;
+    std::vector<std::pair<unsigned long, unsigned long> >::const_iterator it;
+    for (it = indices.begin(); it != indices.end(); ++it) {
+        cMF1.Set(it->first);
+        cMF2.Set(it->second);
 
-    MeshFacetIterator cMFI(_rclMesh);
-    for(cMFI.Begin(); cMFI.More(); cMFI.Next()) {
-        boxes.push_back((*cMFI).GetBoundBox());
-    }
-
-    // Calculates the intersections
-    Base::SequencerLauncher seq("Checking for self-intersections...", ulGridX*ulGridY*ulGridZ);
-    for (clGridIter.Init(); clGridIter.More(); clGridIter.Next()) {
-        //Get the facet indices, belonging to the current grid unit
-        std::vector<unsigned long> aulGridElements;
-        clGridIter.GetElements(aulGridElements);
-
-        seq.next();
-        if (aulGridElements.size()==0)
-            continue;
-
-        MeshGeomFacet facet1, facet2;
-        Base::Vector3f pt1, pt2;
-        for (std::vector<unsigned long>::iterator it = aulGridElements.begin(); it != aulGridElements.end(); ++it) {
-            const Base::BoundBox3f& box1 = boxes[*it];
-            cMFI.Set(*it);
-            facet1 = *cMFI;
-            const MeshFacet& rface1 = rFaces[*it];
-            for (std::vector<unsigned long>::iterator jt = it; jt != aulGridElements.end(); ++jt) {
-                if (jt == it) // the identical facet
-                    continue;
-                // If the facets share a common vertex we do not check for self-intersections because they 
-                // could but usually do not intersect each other and the algorithm below would detect false-positives,
-                // otherwise
-                const MeshFacet& rface2 = rFaces[*jt];
-                if (rface1._aulPoints[0] == rface2._aulPoints[0] || 
-                    rface1._aulPoints[0] == rface2._aulPoints[1] ||
-                    rface1._aulPoints[0] == rface2._aulPoints[2])
-                    continue; // ignore facets sharing a common vertex
-                if (rface1._aulPoints[1] == rface2._aulPoints[0] || 
-                    rface1._aulPoints[1] == rface2._aulPoints[1] ||
-                    rface1._aulPoints[1] == rface2._aulPoints[2])
-                    continue; // ignore facets sharing a common vertex
-                if (rface1._aulPoints[2] == rface2._aulPoints[0] || 
-                    rface1._aulPoints[2] == rface2._aulPoints[1] ||
-                    rface1._aulPoints[2] == rface2._aulPoints[2])
-                    continue; // ignore facets sharing a common vertex
-
-                const Base::BoundBox3f& box2 = boxes[*jt];
-                if (box1 && box2) {
-                    cMFI.Set(*jt);
-                    facet2 = *cMFI;
-                    int ret = facet1.IntersectWithFacet(facet2, pt1, pt2);
-                    if (ret == 2) {
-                        intersection.push_back(std::make_pair(pt1, pt2));
-                    }
-                }
+        Base::BoundBox3f box1 = cMF1->GetBoundBox();
+        Base::BoundBox3f box2 = cMF2->GetBoundBox();
+        if (box1 && box2) {
+            int ret = cMF1->IntersectWithFacet(*cMF2, pt1, pt2);
+            if (ret == 2) {
+                intersection.push_back(std::make_pair(pt1, pt2));
             }
         }
     }
@@ -673,7 +663,7 @@ void MeshEvalSelfIntersection::GetIntersections(std::vector<std::pair<unsigned l
         std::vector<unsigned long> aulGridElements;
         clGridIter.GetElements(aulGridElements);
 
-        seq.next();
+        seq.next(true);
         if (aulGridElements.size()==0)
             continue;
 
@@ -721,14 +711,25 @@ void MeshEvalSelfIntersection::GetIntersections(std::vector<std::pair<unsigned l
 
 bool MeshFixSelfIntersection::Fixup()
 {
-    std::vector<std::pair<unsigned long, unsigned long> > intersection;
-    MeshEvalSelfIntersection(_rclMesh).GetIntersections(intersection);
-
     std::vector<unsigned long> indices;
-    for (std::vector<std::pair<unsigned long, unsigned long> >::iterator
-        it = intersection.begin(); it != intersection.end(); ++it) {
-        indices.push_back(it->first);
-        indices.push_back(it->second);
+    const MeshFacetArray& rFaces = _rclMesh.GetFacets();
+    for (std::vector<std::pair<unsigned long, unsigned long> >::const_iterator
+        it = selfIntersectons.begin(); it != selfIntersectons.end(); ++it) {
+        unsigned short numOpenEdges1 = rFaces[it->first].CountOpenEdges();
+        unsigned short numOpenEdges2 = rFaces[it->second].CountOpenEdges();
+
+        // often we have only single or border facets that intersect other facets
+        // in this case remove only these facets and keep the other one
+        if (numOpenEdges1 == 0 && numOpenEdges2 > 0) {
+            indices.push_back(it->second);
+        }
+        else if (numOpenEdges1 > 0 && numOpenEdges2 == 0) {
+            indices.push_back(it->first);
+        }
+        else {
+            indices.push_back(it->first);
+            indices.push_back(it->second);
+        }
     }
 
     // remove duplicates
