@@ -143,6 +143,10 @@ public:
 
     /** Returns the array of all facets */
     const MeshFacetArray& GetFacets (void) const { return _aclFacetArray; }
+    /** Returns an array of facets to the given indices. The indices
+     * must not be out of range.
+     */
+    MeshFacetArray GetFacets(const std::vector<unsigned long>&) const;
 
     /** Returns the array of all edges.
      *  Notice: The Edgelist will be temporary generated. Changes on the mesh
@@ -379,6 +383,8 @@ public:
     inline void MovePoint (unsigned long ulPtIndex, const Base::Vector3f &rclTrans);
     /** Sets the point at the given index to the new \a rPoint. */
     inline void SetPoint (unsigned long ulPtIndex, const Base::Vector3f &rPoint);
+    /** Sets the point at the given index to the new \a rPoint. */
+    inline void SetPoint (unsigned long ulPtIndex, float x, float y, float z);
     /** Smothes the mesh kernel. */
     void Smooth(int iterations, float d_max);
     /**
@@ -494,6 +500,11 @@ inline void MeshKernel::SetPoint (unsigned long ulPtIndex, const Base::Vector3f
     _aclPointArray[ulPtIndex] = rPoint;
 }
 
+inline void MeshKernel::SetPoint (unsigned long ulPtIndex, float x, float y, float z)
+{
+    _aclPointArray[ulPtIndex].Set(x,y,z);
+}
+
 inline void MeshKernel::AdjustNormal (MeshFacet &rclFacet, const Base::Vector3f &rclNormal)
 {
     Base::Vector3f clN = (_aclPointArray[rclFacet._aulPoints[1]] - _aclPointArray[rclFacet._aulPoints[0]]) %
