@@ -26,6 +26,8 @@
 # include <queue>
 #endif
 
+#include <Base/Console.h>
+#include <Base/Exception.h>
 #include "Triangulation.h"
 #include "Approximation.h"
 #include "MeshKernel.h"
@@ -89,7 +91,8 @@ Base::Matrix4D AbstractPolygonTriangulator::GetTransformToFitPlane() const
     for (std::vector<Base::Vector3f>::const_iterator it = _points.begin(); it!=_points.end(); ++it)
         planeFit.AddPoint(*it);
 
-    planeFit.Fit();
+    if (planeFit.Fit() == FLOAT_MAX)
+        throw Base::Exception("Plane fit failed");
 
     Base::Vector3f bs = planeFit.GetBase();
     Base::Vector3f ex = planeFit.GetDirU();
@@ -135,9 +138,7 @@ void AbstractPolygonTriangulator::ProjectOntoSurface(const std::vector<Base::Vec
         polyFit.AddPoint(pt);
     }
 
-    polyFit.Fit();
-
-    if (polyFit.CountPoints() >= uMinPts) {
+    if (polyFit.CountPoints() >= uMinPts && polyFit.Fit() < FLOAT_MAX) {
         for (std::vector<Base::Vector3f>::iterator pt = _newpoints.begin(); pt != _newpoints.end(); ++pt)
             pt->z = (float)polyFit.Value(pt->x, pt->y);
     }
@@ -145,9 +146,22 @@ void AbstractPolygonTriangulator::ProjectOntoSurface(const std::vector<Base::Vec
 
 bool AbstractPolygonTriangulator::TriangulatePolygon()
 {
-    bool ok = Triangulate();
-    if (ok) Done();
-    return ok;
+    try {
+        bool ok = Triangulate();
+        if (ok) Done();
+        return ok;
+    }
+    catch (const Base::Exception& e) {
+        Base::Console().Log("Triangulation: %s\n", e.what());
+        return false;
+    }
+    catch (const std::exception& e) {
+        Base::Console().Log("Triangulation: %s\n", e.what());
+        return false;
+    }
+    catch (...) {
+        return false;
+    }
 }
 
 std::vector<unsigned long> AbstractPolygonTriangulator::GetInfo() const
@@ -350,7 +364,7 @@ bool EarClippingTriangulator::Triangulate::Process(const std::vector<Base::Vecto
         }
     }
 
-    delete V;
+    delete [] V;
 
     return true;
 }
