@@ -85,24 +85,42 @@ MeshObject::~MeshObject()
 std::vector<const char*> MeshObject::getElementTypes(void) const
 {
     std::vector<const char*> temp;
+    temp.push_back("Face"); // that's the mesh itself
     temp.push_back("Segment");
 
     return temp;
 }
 
+unsigned long MeshObject::countSubElements(const char* Type) const
+{
+    std::string element(Type);
+    if (element == "Face")
+        return 1;
+    else if (element == "Segment")
+        return countSegments();
+    return 0;
+}
+
 Data::Segment* MeshObject::getSubElement(const char* Type, unsigned long n) const
 {
-    //unsigned long i = 1;
-
-    if (strcmp(Type,"Segment") == 0) {
-        // not implemented
-        assert(0);
+    //TODO
+    std::string element(Type);
+    if (element == "Face")
+        return 0;
+    else if (element == "Segment")
         return 0;
-    }
-
     return 0;
 }
 
+void MeshObject::getFacesFromSubelement(const Data::Segment* segm,
+                                        std::vector<Base::Vector3d> &Points,
+                                        std::vector<Base::Vector3d> &PointNormals,
+                                        std::vector<Facet> &faces) const
+{
+    //TODO
+    this->getFaces(Points, faces, 0.0f);
+}
+
 void MeshObject::transformGeometry(const Base::Matrix4D &rclMat)
 {
     MeshCore::MeshKernel kernel;
@@ -227,13 +245,13 @@ MeshPoint MeshObject::getPoint(unsigned long index) const
     return point;
 }
 
-Facet MeshObject::getFacet(unsigned long index) const
+Mesh::Facet MeshObject::getFacet(unsigned long index) const
 {
-    Facet face(_kernel.GetFacets()[index], const_cast<MeshObject*>(this), index);
+    Mesh::Facet face(_kernel.GetFacets()[index], const_cast<MeshObject*>(this), index);
     return face;
 }
 
-void MeshObject::getFaces(std::vector<Base::Vector3d> &Points,std::vector<FacetTopo> &Topo,
+void MeshObject::getFaces(std::vector<Base::Vector3d> &Points,std::vector<Facet> &Topo,
                           float Accuracy, uint16_t flags) const
 {
     unsigned long ctpoints = _kernel.CountPoints();
@@ -246,7 +264,7 @@ void MeshObject::getFaces(std::vector<Base::Vector3d> &Points,std::vector<FacetT
     const MeshCore::MeshFacetArray& ary = _kernel.GetFacets();
     Topo.reserve(ctfacets);
     for (unsigned long i=0; i<ctfacets; i++) {
-        FacetTopo face;
+        Facet face;
         face.I1 = (unsigned int)ary[i]._aulPoints[0];
         face.I2 = (unsigned int)ary[i]._aulPoints[1];
         face.I3 = (unsigned int)ary[i]._aulPoints[2];
@@ -282,16 +300,9 @@ void MeshObject::RestoreDocFile(Base::Reader &reader)
 void MeshObject::save(const char* file, MeshCore::MeshIO::Format f,
                       const MeshCore::Material* mat) const
 {
-    if (this->_Mtrx != Base::Matrix4D()) {
-        MeshCore::MeshKernel kernel(this->_kernel);
-        kernel.Transform(this->_Mtrx);
-        MeshCore::MeshOutput aWriter(kernel, mat);
-        aWriter.SaveAny(file, f);
-    }
-    else {
-        MeshCore::MeshOutput aWriter(this->_kernel, mat);
-        aWriter.SaveAny(file, f);
-    }
+    MeshCore::MeshOutput aWriter(this->_kernel, mat);
+    aWriter.Transform(this->_Mtrx);
+    aWriter.SaveAny(file, f);
 }
 
 void MeshObject::save(std::ostream& out) const
@@ -404,12 +415,12 @@ void MeshObject::addFacets(const std::vector<MeshCore::MeshFacet> &facets,
     _kernel.AddFacets(facets, points);
 }
 
-void MeshObject::addFacets(const std::vector<Data::ComplexGeoData::FacetTopo> &facets,
+void MeshObject::addFacets(const std::vector<Data::ComplexGeoData::Facet> &facets,
                            const std::vector<Base::Vector3d>& points)
 {
     std::vector<MeshCore::MeshFacet> facet_v;
     facet_v.reserve(facets.size());
-    for (std::vector<Data::ComplexGeoData::FacetTopo>::const_iterator it = facets.begin(); it != facets.end(); ++it) {
+    for (std::vector<Data::ComplexGeoData::Facet>::const_iterator it = facets.begin(); it != facets.end(); ++it) {
         MeshCore::MeshFacet f;
         f._aulPoints[0] = it->I1;
         f._aulPoints[1] = it->I2;
@@ -432,12 +443,12 @@ void MeshObject::setFacets(const std::vector<MeshCore::MeshGeomFacet>& facets)
     _kernel = facets;
 }
 
-void MeshObject::setFacets(const std::vector<Data::ComplexGeoData::FacetTopo> &facets,
+void MeshObject::setFacets(const std::vector<Data::ComplexGeoData::Facet> &facets,
                            const std::vector<Base::Vector3d>& points)
 {
     MeshCore::MeshFacetArray facet_v;
     facet_v.reserve(facets.size());
-    for (std::vector<Data::ComplexGeoData::FacetTopo>::const_iterator it = facets.begin(); it != facets.end(); ++it) {
+    for (std::vector<Data::ComplexGeoData::Facet>::const_iterator it = facets.begin(); it != facets.end(); ++it) {
         MeshCore::MeshFacet f;
         f._aulPoints[0] = it->I1;
         f._aulPoints[1] = it->I2;
@@ -995,7 +1006,7 @@ void MeshObject::removeNonManifolds()
     unsigned long count = _kernel.CountFacets();
     MeshCore::MeshEvalTopology cMeshEval(_kernel);
     if (!cMeshEval.Evaluate()) {
-        MeshCore::MeshFixTopology cMeshFix(_kernel, cMeshEval.GetIndices());
+        MeshCore::MeshFixTopology cMeshFix(_kernel, cMeshEval.GetFacets());
         cMeshFix.Fixup();
     }
 
@@ -1011,11 +1022,39 @@ bool MeshObject::hasSelfIntersections() const
 
 void MeshObject::removeSelfIntersections()
 {
-    unsigned long count = _kernel.CountFacets();
-    MeshCore::MeshFixSelfIntersection cMeshFix(_kernel);
-    cMeshFix.Fixup();
-    if (_kernel.CountFacets() < count)
+    std::vector<std::pair<unsigned long, unsigned long> > selfIntersections;
+    MeshCore::MeshEvalSelfIntersection cMeshEval(_kernel);
+    cMeshEval.GetIntersections(selfIntersections);
+
+    if (!selfIntersections.empty()) {
+        MeshCore::MeshFixSelfIntersection cMeshFix(_kernel, selfIntersections);
+        cMeshFix.Fixup();
         this->_segments.clear();
+    }
+}
+
+void MeshObject::removeSelfIntersections(const std::vector<unsigned long>& indices)
+{
+    // make sure that the number of indices is even and are in range
+    if (indices.size() % 2 != 0)
+        return;
+    if (std::find_if(indices.begin(), indices.end(), 
+        std::bind2nd(std::greater_equal<unsigned long>(), _kernel.CountFacets())) < indices.end())
+        return;
+    std::vector<std::pair<unsigned long, unsigned long> > selfIntersections;
+    std::vector<unsigned long>::const_iterator it;
+    for (it = indices.begin(); it != indices.end(); ) {
+        unsigned long id1 = *it; ++it;
+        unsigned long id2 = *it; ++it;
+        selfIntersections.push_back(std::make_pair
+            <unsigned long, unsigned long>(id1,id2));
+    }
+
+    if (!selfIntersections.empty()) {
+        MeshCore::MeshFixSelfIntersection cMeshFix(_kernel, selfIntersections);
+        cMeshFix.Fixup();
+        this->_segments.clear();
+    }
 }
 
 void MeshObject::removeFoldsOnSurface()
@@ -1284,6 +1323,29 @@ MeshObject* MeshObject::createCube(float length, float width, float height)
     return 0;
 }
 
+MeshObject* MeshObject::createCube(float length, float width, float height, float edgelen)
+{
+    // load the 'BuildRegularGeoms' module
+    Base::PyGILStateLocker lock;
+    try {
+        Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        Py::Dict dict = module.getDict();
+        Py::Callable call(dict.getItem("FineCube"));
+        Py::Tuple args(4);
+        args.setItem(0, Py::Float(length));
+        args.setItem(1, Py::Float(width));
+        args.setItem(2, Py::Float(height));
+        args.setItem(3, Py::Float(edgelen));
+        Py::List list(call.apply(args));
+        return createMeshFromList(list);
+    }
+    catch (Py::Exception& e) {
+        e.clear();
+    }
+
+    return 0;
+}
+
 void MeshObject::addSegment(const Segment& s)
 {
     addSegment(s.getIndices());
