@@ -358,7 +358,7 @@ Base::BoundBox3d PropertyMeshKernel::getBoundingBox() const
 }
 
 void PropertyMeshKernel::getFaces(std::vector<Base::Vector3d> &aPoints,
-                                  std::vector<Data::ComplexGeoData::FacetTopo> &aTopo,
+                                  std::vector<Data::ComplexGeoData::Facet> &aTopo,
                                   float accuracy, uint16_t flags) const
 {
     _meshObject->getFaces(aPoints, aTopo, accuracy, flags);
