@@ -653,6 +653,36 @@ PyObject* MeshPy::getSeparateComponents(PyObject *args)
     return Py::new_reference_to(meshesList);
 }
 
+PyObject* MeshPy::getFacetSelection(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return 0;
+
+    Py::List ary;
+    std::vector<unsigned long> facets;
+    getMeshObjectPtr()->getFacetsFromSelection(facets);
+    for (std::vector<unsigned long>::const_iterator it = facets.begin(); it != facets.end(); ++it) {
+        ary.append(Py::Int((int)*it));
+    }
+
+    return Py::new_reference_to(ary);
+}
+
+PyObject* MeshPy::getPointSelection(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return 0;
+
+    Py::List ary;
+    std::vector<unsigned long> points;
+    getMeshObjectPtr()->getPointsFromSelection(points);
+    for (std::vector<unsigned long>::const_iterator it = points.begin(); it != points.end(); ++it) {
+        ary.append(Py::Int((int)*it));
+    }
+
+    return Py::new_reference_to(ary);
+}
+
 PyObject* MeshPy::meshFromSegment(PyObject *args)
 {
     PyObject* list;
@@ -1365,7 +1395,7 @@ Py::List MeshPy::getFacets(void) const
 Py::Tuple MeshPy::getTopology(void) const
 {
     std::vector<Base::Vector3d> Points;
-    std::vector<Data::ComplexGeoData::FacetTopo> Facets;
+    std::vector<Data::ComplexGeoData::Facet> Facets;
     getMeshObjectPtr()->getFaces(Points, Facets, 0.0f);
     Py::Tuple tuple(2);
     Py::List vertex;
@@ -1374,7 +1404,7 @@ Py::Tuple MeshPy::getTopology(void) const
         vertex.append(Py::Object(new Base::VectorPy(*it)));
     tuple.setItem(0, vertex);
     Py::List facet;
-    for (std::vector<Data::ComplexGeoData::FacetTopo>::const_iterator
+    for (std::vector<Data::ComplexGeoData::Facet>::const_iterator
         it = Facets.begin(); it != Facets.end(); ++it) {
         Py::Tuple f(3);
         f.setItem(0,Py::Int((int)it->I1));
