@@ -26,6 +26,9 @@
 #ifndef _PreComp_
 # include <algorithm>
 # include <climits>
+# include <boost/bind.hpp>
+# include <QPushButton>
+# include <Inventor/SbBox2s.h>
 # include <Inventor/SoPickedPoint.h>
 # include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/events/SoMouseButtonEvent.h>
@@ -47,6 +50,7 @@
 #include <Mod/Mesh/App/MeshFeature.h>
 #include <Mod/Mesh/App/Core/Algorithm.h>
 #include <Mod/Mesh/App/Core/MeshKernel.h>
+#include <Mod/Mesh/App/Core/Iterator.h>
 #include <Mod/Mesh/App/Core/TopoAlgorithm.h>
 #include <Mod/Mesh/App/Core/Tools.h>
 
@@ -71,7 +75,7 @@ static unsigned char cross_mask_bitmap[] = {
 };
 
 RemoveComponents::RemoveComponents(QWidget* parent, Qt::WFlags fl)
-  : QDialog(parent, fl),  _interactiveMode(0)
+  : QWidget(parent, fl),  _interactiveMode(0)
 {
     ui = new Ui_RemoveComponents;
     ui->setupUi(this);
@@ -79,12 +83,6 @@ RemoveComponents::RemoveComponents(QWidget* parent, Qt::WFlags fl)
     ui->spSelectComp->setValue(10);
     ui->spDeselectComp->setRange(1, INT_MAX);
     ui->spDeselectComp->setValue(10);
-
-    std::vector<App::DocumentObject*> meshes =
-    Gui::Selection().getObjectsOfType(Mesh::Feature::getClassTypeId());
-    this->_objects.insert(this->_objects.begin(), meshes.begin(), meshes.end());
-
-    this->attachDocument(App::GetApplication().getActiveDocument());
 }
 
 RemoveComponents::~RemoveComponents()
@@ -93,9 +91,12 @@ RemoveComponents::~RemoveComponents()
     delete ui;
 }
 
-void RemoveComponents::cancelObservation()
+void RemoveComponents::changeEvent(QEvent *e)
 {
-    close();
+    if (e->type() == QEvent::LanguageChange) {
+        ui->retranslateUi(this);
+    }
+    QWidget::changeEvent(e);
 }
 
 void RemoveComponents::on_selectRegion_clicked()
@@ -107,7 +108,7 @@ void RemoveComponents::on_selectRegion_clicked()
         stopInteractiveCallback(viewer);
         startInteractiveCallback(viewer, selectGLCallback);
         // set cross cursor
-        viewer->startPicking(Gui::View3DInventorViewer::Rectangle);
+        viewer->startSelection(Gui::View3DInventorViewer::Lasso);
         SoQtCursor::CustomCursor custom;
         custom.dim.setValue(CROSS_WIDTH, CROSS_HEIGHT);
         custom.hotspot.setValue(CROSS_HOT_X, CROSS_HOT_Y);
@@ -126,7 +127,7 @@ void RemoveComponents::on_deselectRegion_clicked()
         stopInteractiveCallback(viewer);
         startInteractiveCallback(viewer, selectGLCallback);
         // set cross cursor
-        viewer->startPicking(Gui::View3DInventorViewer::Rectangle);
+        viewer->startSelection(Gui::View3DInventorViewer::Lasso);
         SoQtCursor::CustomCursor custom;
         custom.dim.setValue(CROSS_WIDTH, CROSS_HEIGHT);
         custom.hotspot.setValue(CROSS_HOT_X, CROSS_HOT_Y);
@@ -139,7 +140,9 @@ void RemoveComponents::on_deselectRegion_clicked()
 void RemoveComponents::on_selectAll_clicked()
 {
     // select the complete meshes
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         Mesh::Feature* mf = static_cast<Mesh::Feature*>((*it)->getObject());
         const Mesh::MeshObject* mo = mf->Mesh.getValuePtr();
@@ -152,7 +155,9 @@ void RemoveComponents::on_selectAll_clicked()
 void RemoveComponents::on_deselectAll_clicked()
 {
     // deselect all meshes
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         (*it)->clearSelection();
     }
@@ -162,7 +167,9 @@ void RemoveComponents::on_selectComponents_clicked()
 {
     // select components upto a certain size
     int size = ui->spSelectComp->value();
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         Mesh::Feature* mf = static_cast<Mesh::Feature*>((*it)->getObject());
         const Mesh::MeshObject* mo = mf->Mesh.getValuePtr();
@@ -185,7 +192,9 @@ void RemoveComponents::on_deselectComponents_clicked()
 {
     // deselect components from a certain size on
     int size = ui->spDeselectComp->value();
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         Mesh::Feature* mf = static_cast<Mesh::Feature*>((*it)->getObject());
         const Mesh::MeshObject* mo = mf->Mesh.getValuePtr();
@@ -204,11 +213,13 @@ void RemoveComponents::on_deselectComponents_clicked()
     }
 }
 
-void RemoveComponents::on_deleteButton_clicked()
+void RemoveComponents::deleteSelection()
 {
     // delete all selected faces
     bool selected = false;
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         Mesh::Feature* mf = static_cast<Mesh::Feature*>((*it)->getObject());
         unsigned long ct = MeshCore::MeshAlgorithm(mf->Mesh.getValue().getKernel()).
@@ -220,7 +231,6 @@ void RemoveComponents::on_deleteButton_clicked()
     }
     if (!selected) return; // nothing todo
 
-    Gui::Document* doc = Gui::Application::Instance->getDocument(this->getDocument());
     doc->openCommand("Delete selection");
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         (*it)->deleteSelection();
@@ -228,9 +238,11 @@ void RemoveComponents::on_deleteButton_clicked()
     doc->commitCommand();
 }
 
-void RemoveComponents::on_invertButton_clicked()
+void RemoveComponents::invertSelection()
 {
-    std::list<ViewProviderMesh*> views = getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         Mesh::Feature* mf = static_cast<Mesh::Feature*>((*it)->getObject());
         const Mesh::MeshObject* mo = mf->Mesh.getValuePtr();
@@ -280,16 +292,16 @@ void RemoveComponents::reject()
             stopInteractiveCallback(viewer);
     }
     on_deselectAll_clicked();
-    QDialog::reject();
 }
 
-std::list<ViewProviderMesh*> RemoveComponents::getViewProviders() const
+std::list<ViewProviderMesh*> RemoveComponents::getViewProviders(const Gui::Document* doc) const
 {
     std::list<ViewProviderMesh*> vps;
-    for (std::list<App::DocumentObject*>::const_iterator it = _objects.begin(); it != _objects.end(); ++it) {
-        App::Document* ad = (*it)->getDocument();
-        Gui::Document* gd = Gui::Application::Instance->getDocument(ad);
-        vps.push_back(static_cast<ViewProviderMesh*>(gd->getViewProvider(*it)));
+    std::vector<Mesh::Feature*> mesh = doc->getDocument()->getObjectsOfType<Mesh::Feature>();
+    for (std::vector<Mesh::Feature*>::iterator it = mesh.begin(); it != mesh.end(); ++it) {
+        Gui::ViewProvider* vp = doc->getViewProvider(*it);
+        if (vp->isVisible())
+            vps.push_back(static_cast<ViewProviderMesh*>(vp));
     }
 
     return vps;
@@ -297,9 +309,7 @@ std::list<ViewProviderMesh*> RemoveComponents::getViewProviders() const
 
 Gui::View3DInventorViewer* RemoveComponents::getViewer() const
 {
-    App::Document* app = this->getDocument();
-    if (!app) return 0;
-    Gui::Document* doc = Gui::Application::Instance->getDocument(app);
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
     if (!doc) return 0;
     Gui::MDIView* view = doc->getActiveView();
     if (view && view->getTypeId().isDerivedFrom(Gui::View3DInventor::getClassTypeId())) {
@@ -337,72 +347,62 @@ void RemoveComponents::selectGLCallback(void * ud, SoEventCallback * n)
     RemoveComponents* that = reinterpret_cast<RemoveComponents*>(ud);
     that->stopInteractiveCallback(view);
     n->setHandled();
-    std::vector<SbVec2f> clPoly = view->getPickedPolygon();
-    if (clPoly.size() != 1)
+    std::vector<SbVec2f> polygon = view->getGLPolygon();
+    if (polygon.size() < 3)
         return;
-    const SoEvent* ev = n->getEvent();
-
-    // get the pixel coordinates
-    SbVec2f pos = clPoly[0];
-    float pX,pY; pos.getValue(pX,pY);
-    const SbVec2s& sz = view->getViewportRegion().getViewportSizePixels();
-    float fRatio = view->getViewportRegion().getViewportAspectRatio();
-    if (fRatio > 1.0f) {
-        pX = (pX - 0.5f) / fRatio + 0.5f;
-        pos.setValue(pX,pY);
-    }
-    else if (fRatio < 1.0f) {
-        pY = (pY - 0.5f) * fRatio + 0.5f;
-        pos.setValue(pX,pY);
-    }
-
-    short x1 = (short)(pX * sz[0] + 0.5f);
-    short y1 = (short)(pY * sz[1] + 0.5f);
-    SbVec2s loc = ev->getPosition();
-    short x2 = loc[0];
-    short y2 = loc[1];
-
-    short x = (x1+x2)/2;
-    short y = (y1+y2)/2;
-    short w = (x2-x1);
-    short h = (y2-y1);
-    if (w<0) w = -w;
-    if (h<0) h = -h;
+    if (polygon.front() != polygon.back())
+        polygon.push_back(polygon.front());
 
     SbVec3f pnt, dir;
     view->getNearPlane(pnt, dir);
     Base::Vector3f point (pnt[0],pnt[1],pnt[2]);
     Base::Vector3f normal(dir[0],dir[1],dir[2]);
 
-    std::list<ViewProviderMesh*> views = that->getViewProviders();
+    Gui::Document* doc = Gui::Application::Instance->activeDocument();
+    if (!doc) return;
+    std::list<ViewProviderMesh*> views = that->getViewProviders(doc);
     for (std::list<ViewProviderMesh*>::iterator it = views.begin(); it != views.end(); ++it) {
         ViewProviderMesh* vp = static_cast<ViewProviderMesh*>(*it);
-        Gui::SoGLSelectAction gl;
-        gl.x = x; gl.y = y;
-        gl.w = w; gl.h = h;
-        gl.apply(vp->getRoot());
 
+        std::vector<unsigned long> faces;
         const Mesh::MeshObject& mesh = static_cast<Mesh::Feature*>((*it)->getObject())->Mesh.getValue();
         const MeshCore::MeshKernel& kernel = mesh.getKernel();
 
-        // get the nearest facet to the user (using front clipping plane)
-        MeshCore::MeshNearestIndexToPlane<MeshCore::MeshFaceIterator> p =
-            std::for_each(gl.indices.begin(), gl.indices.end(),
-                MeshCore::MeshNearestIndexToPlane<MeshCore::MeshFaceIterator>
-                (kernel, point, normal));
+        // simply get all triangles under the polygon
+        vp->getFacetsFromPolygon(polygon, *view, true, faces);
+        if (that->ui->frontTriangles->isChecked()) {
+            const SbVec2s& sz = view->getViewportRegion().getWindowSize();
+            short width,height; sz.getValue(width,height);
+            std::vector<SbVec2s> pixelPoly = view->getPolygon();
+            SbBox2s rect;
+            for (std::vector<SbVec2s>::iterator it = pixelPoly.begin(); it != pixelPoly.end(); ++it) {
+                const SbVec2s& p = *it;
+                rect.extendBy(SbVec2s(p[0],height-p[1]));
+            }
+            std::vector<unsigned long> rf; rf.swap(faces);
+            std::vector<unsigned long> vf = vp->getVisibleFacetsAfterZoom
+                (rect, view->getViewportRegion(), view->getCamera());
 
-        // succeeded
-        std::vector<unsigned long> faces;
-        if (p.nearest_index != ULONG_MAX) {
-            // set VISIT flag to all outer facets
-            MeshCore::MeshAlgorithm alg(kernel);
-            alg.SetFacetFlag(MeshCore::MeshFacet::VISIT);
-            alg.ResetFacetsFlag(gl.indices, MeshCore::MeshFacet::VISIT);
+            // get common facets of the viewport and the visible one
+            std::sort(vf.begin(), vf.end());
+            std::sort(rf.begin(), rf.end());
+            std::back_insert_iterator<std::vector<unsigned long> > biit(faces);
+            std::set_intersection(vf.begin(), vf.end(), rf.begin(), rf.end(), biit);
+        }
 
-            MeshCore::MeshTopFacetVisitor visitor(faces);
-            kernel.VisitNeighbourFacets(visitor, p.nearest_index);
-            // append also the start facet
-            faces.push_back(p.nearest_index);
+        // if set filter out all triangles which do not point into user direction
+        if (that->ui->screenTriangles->isChecked()) {
+            std::vector<unsigned long> screen;
+            screen.reserve(faces.size());
+            MeshCore::MeshFacetIterator it_f(kernel);
+            for (std::vector<unsigned long>::iterator it = faces.begin(); it != faces.end(); ++it) {
+                it_f.Set(*it);
+                if (it_f->GetNormal() * normal > 0.0f) {
+                    screen.push_back(*it);
+                }
+            }
+
+            faces.swap(screen);
         }
 
         if (that->selectRegion)
@@ -439,7 +439,9 @@ void RemoveComponents::pickFaceCallback(void * ud, SoEventCallback * n)
                 return;
             ViewProviderMesh* that = static_cast<ViewProviderMesh*>(vp);
             RemoveComponents* dlg = reinterpret_cast<RemoveComponents*>(ud);
-            std::list<ViewProviderMesh*> views = dlg->getViewProviders();
+            Gui::Document* doc = Gui::Application::Instance->activeDocument();
+            if (!doc) return;
+            std::list<ViewProviderMesh*> views = dlg->getViewProviders(doc);
             if (std::find(views.begin(), views.end(), that) == views.end())
                 return;
             const SoDetail* detail = point->getDetail(/*that->getShapeNode()*/);
@@ -464,4 +466,95 @@ void RemoveComponents::pickFaceCallback(void * ud, SoEventCallback * n)
     }
 }
 
+// ---------------------------------------
+
+RemoveComponentsDialog::RemoveComponentsDialog(QWidget* parent, Qt::WFlags fl)
+  : QDialog(parent, fl)
+{
+    widget = new RemoveComponents(this);
+    this->setWindowTitle(widget->windowTitle());
+
+    QVBoxLayout* hboxLayout = new QVBoxLayout(this);
+    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
+    buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Ok);
+    QPushButton* okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setText(MeshGui::TaskRemoveComponents::tr("Delete"));
+    buttonBox->addButton(MeshGui::TaskRemoveComponents::tr("Invert"),
+        QDialogButtonBox::ActionRole);
+    
+    connect(buttonBox, SIGNAL(clicked(QAbstractButton*)),
+            this, SLOT(clicked(QAbstractButton*)));
+
+    hboxLayout->addWidget(widget);
+    hboxLayout->addWidget(buttonBox);
+}
+
+RemoveComponentsDialog::~RemoveComponentsDialog()
+{
+}
+
+void RemoveComponentsDialog::reject()
+{
+    widget->reject();
+    QDialog::reject();
+}
+
+void RemoveComponentsDialog::clicked(QAbstractButton* btn)
+{
+    QDialogButtonBox* buttonBox = qobject_cast<QDialogButtonBox*>(sender());
+    QDialogButtonBox::StandardButton id = buttonBox->standardButton(btn);
+    if (id == QDialogButtonBox::Ok) {
+        widget->deleteSelection();
+    }
+    else if (id == QDialogButtonBox::Close) {
+        this->reject();
+    }
+    else if (id == QDialogButtonBox::NoButton) {
+        widget->invertSelection();
+    }
+}
+
+// ---------------------------------------
+
+/* TRANSLATOR MeshGui::TaskRemoveComponents */
+
+TaskRemoveComponents::TaskRemoveComponents()
+{
+    widget = new RemoveComponents();
+    taskbox = new Gui::TaskView::TaskBox(
+        QPixmap(), widget->windowTitle(), false, 0);
+    taskbox->groupLayout()->addWidget(widget);
+    Content.push_back(taskbox);
+}
+
+TaskRemoveComponents::~TaskRemoveComponents()
+{
+    // automatically deleted in the sub-class
+}
+
+void TaskRemoveComponents::modifyStandardButtons(QDialogButtonBox* box)
+{
+    QPushButton* btn = box->button(QDialogButtonBox::Ok);
+    btn->setText(tr("Delete"));
+    box->addButton(tr("Invert"), QDialogButtonBox::ActionRole);
+}
+
+bool TaskRemoveComponents::accept()
+{
+    return false;
+}
+
+void TaskRemoveComponents::clicked(int id)
+{
+    if (id == QDialogButtonBox::Ok) {
+        widget->deleteSelection();
+    }
+    else if (id == QDialogButtonBox::Close) {
+        widget->reject();
+    }
+    else if (id == QDialogButtonBox::NoButton) {
+        widget->invertSelection();
+    }
+}
+
 #include "moc_RemoveComponents.cpp"
