@@ -484,11 +484,15 @@ std::vector<std::string> ViewProviderMesh::getDisplayModes(void) const
 
 bool ViewProviderMesh::setEdit(int ModNum)
 {
+    if (ModNum == ViewProvider::Transform)
+        return ViewProviderGeometryObject::setEdit(ModNum);
     return true;
 }
 
 void ViewProviderMesh::unsetEdit(int ModNum)
 {
+    if (ModNum == ViewProvider::Transform)
+        ViewProviderGeometryObject::unsetEdit(ModNum);
 }
 
 bool ViewProviderMesh::createToolMesh(const std::vector<SbVec2f>& rclPoly, const SbViewVolume& vol,
@@ -1315,7 +1319,6 @@ void ViewProviderMesh::selectFacet(unsigned long facet)
 
     // Colorize the selection
     pcMatBinding->value = SoMaterialBinding::PER_FACE;
-    App::Color c = ShapeColor.getValue();
     int uCtFacets = (int)rMesh.countFacets();
 
     if (uCtFacets != pcShapeMaterial->diffuseColor.getNum()) {
@@ -1336,7 +1339,6 @@ void ViewProviderMesh::deselectFacet(unsigned long facet)
 
     // Colorize the selection
     pcMatBinding->value = SoMaterialBinding::PER_FACE;
-    App::Color c = ShapeColor.getValue();
     int uCtFacets = (int)rMesh.countFacets();
 
     if (uCtFacets != pcShapeMaterial->diffuseColor.getNum()) {
