@@ -58,7 +58,6 @@
 #include <Gui/Document.h>
 #include <Gui/SoFCSelection.h>
 #include <Gui/MainWindow.h>
-#include <Gui/MouseModel.h>
 #include <Gui/Selection.h>
 #include <Gui/WaitCursor.h>
 #include <Gui/Window.h>
@@ -91,7 +90,7 @@ PROPERTY_SOURCE(MeshGui::ViewProviderMeshFaceSet, MeshGui::ViewProviderMesh)
 ViewProviderMeshFaceSet::ViewProviderMeshFaceSet()
 {
     directRendering = false;
-    triangleCount = 500000;
+    triangleCount = 2500000;
 
     pcMeshNode = new SoFCMeshObjectNode;
     pcMeshNode->ref();
@@ -161,6 +160,7 @@ void ViewProviderMeshFaceSet::updateData(const App::Property* prop)
         }
 
         showOpenEdges(OpenEdges.getValue());
+        highlightSelection();
     }
 }
 
@@ -212,3 +212,10 @@ SoShape* ViewProviderMeshFaceSet::getShapeNode() const
         return this->pcMeshShape;
     return this->pcMeshFaces;
 }
+
+SoNode* ViewProviderMeshFaceSet::getCoordNode() const
+{
+    if (directRendering)
+        return this->pcMeshNode;
+    return this->pcMeshCoord;
+}
