@@ -30,6 +30,7 @@
 # include <BRepPrimAPI_MakeCylinder.hxx>
 # include <BRepPrimAPI_MakeSphere.hxx>
 # include <BRepPrimAPI_MakeRevolution.hxx>
+# include <BRepPrim_Wedge.hxx>
 # include <BRep_Builder.hxx>
 # include <BRep_Tool.hxx>
 # include <BRepBuilderAPI_MakeFace.hxx>
@@ -81,6 +82,7 @@
 #include <GeomFill_Pipe.hxx>
 #include <GeomFill_SectionGenerator.hxx>
 #include <NCollection_List.hxx>
+#include <BRepFill_Filling.hxx>
 
 #include <Base/Console.h>
 #include <Base/PyObjectBase.h>
@@ -111,6 +113,7 @@
 #include "FeaturePartImportStep.h"
 #include "FeaturePartImportIges.h"
 #include "FeaturePartImportBrep.h"
+#include "ImportIges.h"
 #include "ImportStep.h"
 #include "edgecluster.h"
 
@@ -154,6 +157,13 @@ static PyObject * open(PyObject *self, PyObject *args)
 #endif 
             pcDoc->recompute();
         }
+#if 1
+        else if (file.hasExtension("igs") || file.hasExtension("iges")) {
+            App::Document *pcDoc = App::GetApplication().newDocument("Unnamed");
+            ImportIgesParts(pcDoc,Name);
+            pcDoc->recompute();
+        }
+#endif
         else {
             try {
                 TopoShape shape;
@@ -205,6 +215,12 @@ static PyObject * insert(PyObject *self, PyObject *args)
 #endif 
             pcDoc->recompute();
         }
+#if 1
+        else if (file.hasExtension("igs") || file.hasExtension("iges")) {
+            ImportIgesParts(pcDoc,Name);
+            pcDoc->recompute();
+        }
+#endif
         else {
             try {
                 TopoShape shape;
@@ -248,6 +264,9 @@ static PyObject * exporter(PyObject *self, PyObject *args)
                     if (!shape.IsNull())
                         builder.Add(comp, shape);
                 }
+                else {
+                    Base::Console().Message("'%s' is not a shape, export will be ignored.\n", obj->Label.getValue());
+                }
             }
         }
     } PY_CATCH;
@@ -326,6 +345,53 @@ makeCompound(PyObject *self, PyObject *args)
     } PY_CATCH;
 }
 
+static PyObject * makeFilledFace(PyObject *self, PyObject *args)
+{
+    // http://opencascade.blogspot.com/2010/03/surface-modeling-part6.html
+    // TODO: GeomPlate_BuildPlateSurface
+    PyObject *obj;
+    if (!PyArg_ParseTuple(args, "O!", &(PyList_Type), &obj))
+        return NULL;
+
+    PY_TRY {
+        BRepFill_Filling builder;
+        
+        try {
+            Py::List list(obj);
+            int countEdges = 0;
+            for (Py::List::iterator it = list.begin(); it != list.end(); ++it) {
+                if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapeEdgePy::Type))) {
+                    const TopoDS_Shape& sh = static_cast<TopoShapeEdgePy*>((*it).ptr())->
+                        getTopoShapePtr()->_Shape;
+                    if (!sh.IsNull()) {
+                        builder.Add(TopoDS::Edge(sh), GeomAbs_C0);
+                        countEdges++;
+                    }
+                }
+            }
+
+            if (countEdges == 0) {
+                PyErr_SetString(PyExc_Exception, "Failed to created face with no edges");
+                return 0;
+            }
+
+            builder.Build();
+            if (builder.IsDone()) {
+                return new TopoShapeFacePy(new TopoShape(builder.Face()));
+            }
+            else {
+                PyErr_SetString(PyExc_Exception, "Failed to created face by filling edges");
+                return 0;
+            }
+        }
+        catch (Standard_Failure) {
+            Handle_Standard_Failure e = Standard_Failure::Caught();
+            PyErr_SetString(PyExc_Exception, e->GetMessageString());
+            return 0;
+        }
+    } PY_CATCH;
+}
+
 static PyObject * makeShell(PyObject *self, PyObject *args)
 {
     PyObject *obj;
@@ -478,6 +544,62 @@ static PyObject * makeBox(PyObject *self, PyObject *args)
     }
 }
 
+static PyObject * makeWedge(PyObject *self, PyObject *args)
+{
+    double xmin, ymin, zmin, z2min, x2min, xmax, ymax, zmax, z2max, x2max;
+    PyObject *pPnt=0, *pDir=0;
+    if (!PyArg_ParseTuple(args, "dddddddddd|O!O!",
+        &xmin, &ymin, &zmin, &z2min, &x2min, &xmax, &ymax, &zmax, &z2max, &x2max,
+        &(Base::VectorPy::Type), &pPnt, &(Base::VectorPy::Type), &pDir))
+        return NULL;
+
+    double dx = xmax-xmin;
+    double dy = ymax-ymin;
+    double dz = zmax-zmin;
+    double dz2 = z2max-z2min;
+    double dx2 = x2max-x2min;
+    if (dx < Precision::Confusion()) {
+        PyErr_SetString(PyExc_Exception, "delta x of wedge too small");
+        return NULL;
+    }
+    if (dy < Precision::Confusion()) {
+        PyErr_SetString(PyExc_Exception, "delta y of wedge too small");
+        return NULL;
+    }
+    if (dz < Precision::Confusion()) {
+        PyErr_SetString(PyExc_Exception, "delta z of wedge too small");
+        return NULL;
+    }
+    if (dz2 < 0) {
+        PyErr_SetString(PyExc_Exception, "delta z2 of wedge is negative");
+        return NULL;
+    }
+    if (dx2 < 0) {
+        PyErr_SetString(PyExc_Exception, "delta x2 of wedge is negative");
+        return NULL;
+    }
+
+    try {
+        gp_Pnt p(0,0,0);
+        gp_Dir d(0,0,1);
+        if (pPnt) {
+            Base::Vector3d pnt = static_cast<Base::VectorPy*>(pPnt)->value();
+            p.SetCoord(pnt.x, pnt.y, pnt.z);
+        }
+        if (pDir) {
+            Base::Vector3d vec = static_cast<Base::VectorPy*>(pDir)->value();
+            d.SetCoord(vec.x, vec.y, vec.z);
+        }
+        BRepPrim_Wedge mkWedge(gp_Ax2(p,d), xmin, ymin, zmin, z2min, x2min, xmax, ymax, zmax, z2max, x2max);
+        TopoDS_Shape resultShape = mkWedge.Shell();
+        return new TopoShapeShellPy(new TopoShape(resultShape)); 
+    }
+    catch (Standard_DomainError) {
+        PyErr_SetString(PyExc_Exception, "creation of wedge failed");
+        return NULL;
+    }
+}
+
 static PyObject * makeCircle(PyObject *self, PyObject *args)
 {
     double radius, angle1=0.0, angle2=360;
@@ -646,38 +768,8 @@ static PyObject * makeHelix(PyObject *self, PyObject *args)
         return 0;
 
     try {
-        if (pitch < Precision::Confusion())
-            Standard_Failure::Raise("Pitch of helix too small");
-
-        if (height < Precision::Confusion())
-            Standard_Failure::Raise("Height of helix too small");
-
-        gp_Ax2 cylAx2(gp_Pnt(0.0,0.0,0.0) , gp::DZ());
-        Handle_Geom_Surface surf;
-        if (angle < 0) {
-            if (radius < Precision::Confusion())
-                Standard_Failure::Raise("Radius of helix too small");
-            surf = new Geom_CylindricalSurface(cylAx2, radius);
-        }
-        else {
-            angle = angle*(M_PI/180);
-            if (angle < Precision::Confusion())
-                Standard_Failure::Raise("Angle of helix too small");
-            surf = new Geom_ConicalSurface(gp_Ax3(cylAx2), angle, radius);
-        }
-
-        gp_Pnt2d aPnt(0, 0);
-        gp_Dir2d aDir(2. * PI, pitch);
-        gp_Ax2d aAx2d(aPnt, aDir);
-
-        Handle_Geom2d_Line line = new Geom2d_Line(aAx2d);
-        gp_Pnt2d beg = line->Value(0);
-        gp_Pnt2d end = line->Value(2.0*PI*(height/pitch));
-        Handle_Geom2d_TrimmedCurve segm = GCE2d_MakeSegment(beg , end);
-
-        TopoDS_Edge edgeOnSurf = BRepBuilderAPI_MakeEdge(segm , surf);
-        TopoDS_Wire wire = BRepBuilderAPI_MakeWire(edgeOnSurf);
-        BRepLib::BuildCurves3d(wire);
+        TopoShape helix;
+        TopoDS_Shape wire = helix.makeHelix(pitch, height, radius, angle);
         return new TopoShapeWirePy(new TopoShape(wire));
     }
     catch (Standard_Failure) {
@@ -884,6 +976,7 @@ static PyObject * makeRevolution(PyObject *self, PyObject *args)
 
 static PyObject * makeRuledSurface(PyObject *self, PyObject *args)
 {
+    // http://opencascade.blogspot.com/2009/10/surface-modeling-part1.html
     PyObject *sh1, *sh2;
     if (!PyArg_ParseTuple(args, "O!O!", &(TopoShapePy::Type), &sh1,
                                         &(TopoShapePy::Type), &sh2))
@@ -917,68 +1010,20 @@ static PyObject * makeSweepSurface(PyObject *self, PyObject *args)
     PyObject *path, *profile;
     double tolerance=0.001;
     int fillMode = 0;
+
+    // Path + profile
     if (!PyArg_ParseTuple(args, "O!O!|di", &(TopoShapePy::Type), &path,
                                            &(TopoShapePy::Type), &profile,
                                            &tolerance, &fillMode))
         return 0;
 
-    const TopoDS_Shape& path_shape = static_cast<TopoShapePy*>(path)->getTopoShapePtr()->_Shape;
-    const TopoDS_Shape& profile_shape = static_cast<TopoShapePy*>(profile)->getTopoShapePtr()->_Shape;
-    if (path_shape.IsNull()) {
-        PyErr_SetString(PyExc_Exception, "path shape is empty");
-        return 0;
-    }
-    if (profile_shape.IsNull()) {
-        PyErr_SetString(PyExc_Exception, "profile shape is empty");
-        return 0;
-    }
-
     try {
-        if (path_shape.ShapeType() == TopAbs_EDGE && 
-            profile_shape.ShapeType() == TopAbs_EDGE) {
-            const TopoDS_Edge& path_edge = TopoDS::Edge(path_shape);
-            BRepAdaptor_Curve path_adapt(path_edge);
-            double umin = path_adapt.FirstParameter();
-            double umax = path_adapt.LastParameter();
-            Handle_Geom_Curve hPath = path_adapt.Curve().Curve();
+        const TopoDS_Shape& path_shape = static_cast<TopoShapePy*>(path)->getTopoShapePtr()->_Shape;
+        const TopoDS_Shape& prof_shape = static_cast<TopoShapePy*>(profile)->getTopoShapePtr()->_Shape;
 
-            // Apply placement of the shape to the curve
-            TopLoc_Location loc1 = path_edge.Location();
-            hPath = Handle_Geom_Curve::DownCast(hPath->Transformed(loc1.Transformation()));
-
-            if (hPath.IsNull()) {
-                PyErr_SetString(PyExc_Exception, "invalid curve in path edge");
-                return 0;
-            }
-
-            const TopoDS_Edge& prof_edge = TopoDS::Edge(profile_shape);
-            BRepAdaptor_Curve prof_adapt(prof_edge);
-            double vmin = prof_adapt.FirstParameter();
-            double vmax = prof_adapt.LastParameter();
-            Handle_Geom_Curve hProfile = prof_adapt.Curve().Curve();
-
-            // Apply placement of the shape to the curve
-            TopLoc_Location loc2 = prof_edge.Location();
-            hProfile = Handle_Geom_Curve::DownCast(hProfile->Transformed(loc2.Transformation()));
-
-            if (hProfile.IsNull()) {
-                PyErr_SetString(PyExc_Exception, "invalid curve in profile edge");
-                return 0;
-            }
-
-            GeomFill_Pipe mkSweep(hPath, hProfile, (GeomFill_Trihedron)fillMode);
-            mkSweep.GenerateParticularCase(Standard_True);
-            mkSweep.Perform(tolerance, Standard_False, GeomAbs_C1, BSplCLib::MaxDegree(), 1000);
-
-            const Handle_Geom_Surface& surf = mkSweep.Surface();
-            BRepBuilderAPI_MakeFace mkBuilder(surf, umin, umax, vmin, vmax);
-            const TopoDS_Face& face = mkBuilder.Face();
-            return new TopoShapeFacePy(new TopoShape(face));
-        }
-        else {
-            PyErr_SetString(PyExc_Exception, "path and profile must be an edge");
-            return 0;
-        }
+        TopoShape myShape(path_shape);
+        TopoDS_Shape face = myShape.makeSweep(prof_shape, tolerance, fillMode);
+        return new TopoShapeFacePy(new TopoShape(face));
     }
     catch (Standard_Failure) {
         Handle_Standard_Failure e = Standard_Failure::Caught();
@@ -991,45 +1036,16 @@ static PyObject * makeTube(PyObject *self, PyObject *args)
 {
     PyObject *pshape;
     double radius;
+    double tolerance=0.001;
+
+    // Path + radius
     if (!PyArg_ParseTuple(args, "O!d", &(TopoShapePy::Type), &pshape, &radius))
         return 0;
-
-    const TopoDS_Shape& shape = static_cast<TopoShapePy*>(pshape)->getTopoShapePtr()->_Shape;
-    if (shape.IsNull()) {
-        PyErr_SetString(PyExc_Exception, "path shape is empty");
-        return 0;
-    }
-
     try {
-        if (shape.ShapeType() == TopAbs_EDGE) {
-            const TopoDS_Edge& edge = TopoDS::Edge(shape);
-            BRepAdaptor_Curve adapt(edge);
-            double umin = adapt.FirstParameter();
-            double umax = adapt.LastParameter();
-
-            Handle_Geom_Curve hCurve = adapt.Curve().Curve();
-            // Apply placement of the shape to the curve
-            TopLoc_Location loc = edge.Location();
-            hCurve = Handle_Geom_Curve::DownCast(hCurve->Transformed(loc.Transformation()));
-            if (hCurve.IsNull()) {
-                PyErr_SetString(PyExc_Exception, "invalid curve in edge");
-                return 0;
-            }
-            GeomFill_Pipe mkTube(hCurve, radius);
-            mkTube.Perform();
-
-            const Handle_Geom_Surface& surf = mkTube.Surface();
-            double u1,u2,v1,v2;
-            surf->Bounds(u1,u2,v1,v2);
-
-            BRepBuilderAPI_MakeFace mkBuilder(surf, umin, umax, v1, v2);
-            const TopoDS_Face& face = mkBuilder.Face();
-            return new TopoShapeFacePy(new TopoShape(face));
-        }
-        else {
-            PyErr_SetString(PyExc_Exception, "path must be an edge");
-            return 0;
-        }
+        const TopoDS_Shape& path_shape = static_cast<TopoShapePy*>(pshape)->getTopoShapePtr()->_Shape;
+        TopoShape myShape(path_shape);
+        TopoDS_Shape face = myShape.makeTube(radius, tolerance);
+        return new TopoShapeFacePy(new TopoShape(face));
     }
     catch (Standard_Failure) {
         Handle_Standard_Failure e = Standard_Failure::Caught();
@@ -1085,42 +1101,28 @@ static PyObject * makeLoft(PyObject *self, PyObject *args)
     return new BSplineSurfacePy(new GeomBSplineSurface(aRes));
 #else
     PyObject *pcObj;
-    if (!PyArg_ParseTuple(args, "O!", &(PyList_Type), &pcObj))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    PyObject *psolid=0;
+    PyObject *pruled=0;
+    if (!PyArg_ParseTuple(args, "O!|O!O!", &(PyList_Type), &pcObj,
+                                           &(PyBool_Type), &psolid,
+                                           &(PyBool_Type), &pruled))
+        return NULL;
 
     try {
-        Standard_Boolean anIsSolid = Standard_False;
-        Standard_Boolean anIsRuled = Standard_False;
-        BRepOffsetAPI_ThruSections aGenerator (anIsSolid,anIsRuled);
-
-        int countWires = 0;
+        TopTools_ListOfShape profiles;
         Py::List list(pcObj);
         for (Py::List::iterator it = list.begin(); it != list.end(); ++it) {
             if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapePy::Type))) {
                 const TopoDS_Shape& sh = static_cast<TopoShapePy*>((*it).ptr())->
                     getTopoShapePtr()->_Shape;
-                if (!sh.IsNull() && sh.ShapeType() == TopAbs_WIRE) {
-                    aGenerator.AddWire(TopoDS::Wire (sh));
-                    countWires++;
-                }
+                profiles.Append(sh);
             }
         }
 
-        // need at least two wires
-        if (countWires < 2) {
-            PyErr_SetString(PyExc_Exception, "Need at least two wires to create loft face");
-            return 0;
-        }
-
-        Standard_Boolean anIsCheck = Standard_True;
-        aGenerator.CheckCompatibility (anIsCheck);
-        aGenerator.Build();
-        if (!aGenerator.IsDone()) {
-            PyErr_SetString(PyExc_Exception, "Failed to create loft face");
-            return 0;
-        }
-
-        const TopoDS_Shape& aResult = aGenerator.Shape();
+        TopoShape myShape;
+        Standard_Boolean anIsSolid = (psolid == Py_True) ? Standard_True : Standard_False;
+        Standard_Boolean anIsRuled = (pruled == Py_True) ? Standard_True : Standard_False;
+        TopoDS_Shape aResult = myShape.makeLoft(profiles, anIsSolid, anIsRuled);
         return new TopoShapePy(new TopoShape(aResult));
     }
     catch (Standard_Failure) {
@@ -1171,79 +1173,80 @@ static PyObject * fromPythonOCC(PyObject *self, PyObject *args)
 }
 
 namespace Part {
-struct HashEdge {
-    int v1, v2;
+struct EdgePoints {
+    gp_Pnt v1, v2;
     TopoDS_Edge edge;
 };
 
-static std::list<TopoDS_Edge> sort_Edges(const std::vector<TopoDS_Edge>& edges)
+static std::list<TopoDS_Edge> sort_Edges(double tol3d, const std::vector<TopoDS_Edge>& edges)
 {
-    std::list<HashEdge>  hash_edge;
+    tol3d = tol3d * tol3d;
+    std::list<EdgePoints>  edge_points;
     TopExp_Explorer xp;
     for (std::vector<TopoDS_Edge>::const_iterator it = edges.begin(); it != edges.end(); ++it) {
-        HashEdge he;
+        EdgePoints ep;
         xp.Init(*it,TopAbs_VERTEX);
-        he.v1 = xp.Current().HashCode(IntegerLast());
+        ep.v1 = BRep_Tool::Pnt(TopoDS::Vertex(xp.Current()));
         xp.Next();
-        he.v2 = xp.Current().HashCode(IntegerLast());
-        he.edge = *it;
-        hash_edge.push_back(he);
+        ep.v2 = BRep_Tool::Pnt(TopoDS::Vertex(xp.Current()));
+        ep.edge = *it;
+        edge_points.push_back(ep);
     }
 
-    if (hash_edge.empty())
+    if (edge_points.empty())
         return std::list<TopoDS_Edge>();
 
     std::list<TopoDS_Edge> sorted;
-    int first, last;
-    first = hash_edge.front().v1;
-    last  = hash_edge.front().v2;
+    gp_Pnt first, last;
+    first = edge_points.front().v1;
+    last  = edge_points.front().v2;
 
-    sorted.push_back(hash_edge.front().edge);
-    hash_edge.erase(hash_edge.begin());
+    sorted.push_back(edge_points.front().edge);
+    edge_points.erase(edge_points.begin());
 
-    while (!hash_edge.empty()) {
+    while (!edge_points.empty()) {
         // search for adjacent edge
-        std::list<HashEdge>::iterator pEI;
-        for (pEI = hash_edge.begin(); pEI != hash_edge.end(); ++pEI) {
-            if (pEI->v1 == last) {
+        std::list<EdgePoints>::iterator pEI;
+        for (pEI = edge_points.begin(); pEI != edge_points.end(); ++pEI) {
+            if (pEI->v1.SquareDistance(last) <= tol3d) {
                 last = pEI->v2;
                 sorted.push_back(pEI->edge);
-                hash_edge.erase(pEI);
+                edge_points.erase(pEI);
                 break;
             }
-            else if (pEI->v2 == first) {
+            else if (pEI->v2.SquareDistance(first) <= tol3d) {
                 first = pEI->v1;
                 sorted.push_front(pEI->edge);
-                hash_edge.erase(pEI);
+                edge_points.erase(pEI);
                 break;
             }
-            else if (pEI->v2 == last) {
+            else if (pEI->v2.SquareDistance(last) <= tol3d) {
                 last = pEI->v1;
                 sorted.push_back(pEI->edge);
-                hash_edge.erase(pEI);
+                edge_points.erase(pEI);
                 break;
             }
-            else if (pEI->v1 == first) {
+            else if (pEI->v1.SquareDistance(first) <= tol3d) {
                 first = pEI->v2;
                 sorted.push_front(pEI->edge);
-                hash_edge.erase(pEI);
+                edge_points.erase(pEI);
                 break;
             }
         }
 
-        if ((pEI == hash_edge.end()) || (last == first)) {
+        if ((pEI == edge_points.end()) || (last.SquareDistance(first) <= tol3d)) {
             // no adjacent edge found or polyline is closed
             return sorted;
             /*
             rclBorders.push_back(std::vector<TopoDS_Edge>(sorted.begin(), sorted.end()));
             sorted.clear();
 
-            if (!hash_edge.empty()) {
+            if (!edge_points.empty()) {
                 // new wire
-                first = hash_edge.front()->v1;
-                last  = hash_edge.front()->v2;
-                sorted.push_back(hash_edge.front().edge);
-                hash_edge.erase(hash_edge.begin());
+                first = edge_points.front()->v1;
+                last  = edge_points.front()->v2;
+                sorted.push_back(edge_points.front().edge);
+                edge_points.erase(edge_points.begin());
             }*/
         }
     }
@@ -1323,7 +1326,7 @@ static PyObject * sortEdges(PyObject *self, PyObject *args)
         }
     }
 
-    std::list<TopoDS_Edge> sorted = sort_Edges(edges);
+    std::list<TopoDS_Edge> sorted = sort_Edges(Precision::Confusion(), edges);
 
     Py::List sorted_list;
     for (std::list<TopoDS_Edge>::iterator it = sorted.begin(); it != sorted.end(); ++it) {
@@ -1396,6 +1399,9 @@ struct PyMethodDef Part_methods[] = {
     {"makeShell"  ,makeShell ,METH_VARARGS,
      "makeShell(list) -- Create a shell out of a list of faces."},
 
+    {"makeFilledFace"  ,makeFilledFace ,METH_VARARGS,
+     "makeFilledFace(list) -- Create a face out of a list of edges."},
+
     {"makeSolid"  ,makeSolid ,METH_VARARGS,
      "makeSolid(shape) -- Create a solid out of the shells inside a shape."},
 
@@ -1408,6 +1414,12 @@ struct PyMethodDef Part_methods[] = {
      "in pnt with the dimensions (length,width,height)\n"
      "By default pnt=Vector(0,0,0) and dir=Vector(0,0,1)"},
 
+    {"makeWedge"    ,makeWedge ,METH_VARARGS,
+     "makeWedge(xmin, ymin, zmin, z2min, x2min,\n"
+     "xmax, ymax, zmax, z2max, x2max,[pnt,dir])\n"
+     " -- Make a wedge located in pnt\n"
+     "By default pnt=Vector(0,0,0) and dir=Vector(0,0,1)"},
+
     {"makeLine"   ,makeLine  ,METH_VARARGS,
      "makeLine((x1,y1,z1),(x2,y2,z2)) -- Make a line of two points"},
 
@@ -1437,7 +1449,7 @@ struct PyMethodDef Part_methods[] = {
     {"makeHelix" ,makeHelix,METH_VARARGS,
      "makeHelix(pitch,height,radius,[angle]) -- Make a helix with a given pitch, height and radius\n"
      "By default a cylindrical surface is used to create the helix. If the fourth parameter is set\n"
-     "a conical surface is used instead"},
+     "(the apex given in degree) a conical surface is used instead"},
 
     {"makeRevolution" ,makeRevolution,METH_VARARGS,
      "makeRevolution(Curve,[vmin,vmax,angle,pnt,dir]) -- Make a revolved shape\n"
