@@ -26,12 +26,14 @@
 # include <Geom_BSplineCurve.hxx>
 # include <GeomAPI_PointsToBSpline.hxx>
 # include <GeomAPI_Interpolate.hxx>
+# include <GeomConvert_BSplineCurveToBezierCurve.hxx>
 # include <gp_Pnt.hxx>
 # include <TColStd_Array1OfReal.hxx>
 # include <TColgp_Array1OfPnt.hxx>
 # include <TColgp_HArray1OfPnt.hxx>
 # include <TColStd_Array1OfInteger.hxx>
 # include <Handle_TColgp_HArray1OfPnt.hxx>
+# include <Precision.hxx>
 #endif
 
 #include <Base/VectorPy.h>
@@ -40,6 +42,7 @@
 #include "Geometry.h"
 #include "BSplineCurvePy.h"
 #include "BSplineCurvePy.cpp"
+#include "BezierCurvePy.h"
 
 using namespace Part;
 
@@ -728,7 +731,7 @@ PyObject* BSplineCurvePy::approximate(PyObject *args)
 PyObject* BSplineCurvePy::interpolate(PyObject *args)
 {
     PyObject* obj;
-    double tol3d = 0.0001;
+    double tol3d = Precision::Approximation();
     PyObject* closed = Py_False;
     PyObject* t1=0; PyObject* t2=0;
     if (!PyArg_ParseTuple(args, "O!|O!dO!O!",&(PyList_Type), &obj, &PyBool_Type, &closed, &tol3d,
@@ -768,7 +771,9 @@ PyObject* BSplineCurvePy::interpolate(PyObject *args)
     }
     catch (Standard_Failure) {
         Handle_Standard_Failure e = Standard_Failure::Caught();
-        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        std::string err = e->GetMessageString();
+        if (err.empty()) err = e->DynamicType()->Name();
+        PyErr_SetString(PyExc_Exception, err.c_str());
         return 0;
     }
 }
@@ -819,6 +824,69 @@ PyObject* BSplineCurvePy::buildFromPoles(PyObject *args)
     }
 }
 
+PyObject* BSplineCurvePy::toBezier(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return 0;
+
+    Handle_Geom_BSplineCurve spline = Handle_Geom_BSplineCurve::DownCast
+        (this->getGeomBSplineCurvePtr()->handle());
+    GeomConvert_BSplineCurveToBezierCurve crt(spline);
+
+    Py::List list;
+    Standard_Integer arcs = crt.NbArcs();
+    for (Standard_Integer i=1; i<=arcs; i++) {
+        Handle_Geom_BezierCurve bezier = crt.Arc(i);
+        list.append(Py::asObject(new BezierCurvePy(new GeomBezierCurve(bezier))));
+    }
+
+    return Py::new_reference_to(list);
+}
+
+PyObject* BSplineCurvePy::join(PyObject *args)
+{
+    PyObject* c;
+    if (!PyArg_ParseTuple(args, "O!", &BSplineCurvePy::Type, &c))
+        return 0;
+
+    GeomBSplineCurve* curve1 = this->getGeomBSplineCurvePtr();
+    BSplineCurvePy* curve2 = static_cast<BSplineCurvePy*>(c);
+    Handle_Geom_BSplineCurve spline = Handle_Geom_BSplineCurve::DownCast
+        (curve2->getGeomBSplineCurvePtr()->handle());
+
+    bool ok = curve1->join(spline);
+
+    if (ok) {
+        Py_INCREF(Py_True);
+        return Py_True;
+    }
+    else {
+        Py_INCREF(Py_False);
+        return Py_False;
+    }
+}
+
+PyObject* BSplineCurvePy::makeC1Continuous(PyObject *args)
+{
+    double tol = Precision::Approximation();
+    double ang_tol = 1.0e-7;
+    if (!PyArg_ParseTuple(args, "|dd", &tol, &ang_tol))
+        return 0;
+
+    try {
+        GeomBSplineCurve* spline = this->getGeomBSplineCurvePtr();
+        spline->makeC1Continuous(tol, ang_tol);
+        Py_Return;
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        std::string err = e->GetMessageString();
+        if (err.empty()) err = e->DynamicType()->Name();
+        PyErr_SetString(PyExc_Exception, err.c_str());
+        return 0;
+    }
+}
+
 PyObject* BSplineCurvePy::getCustomAttributes(const char* /*attr*/) const
 {
     return 0;
