@@ -37,7 +37,7 @@ class Fillet : public Part::Feature
 public:
     Fillet();
 
-    App::PropertyLinkWeak Base;
+    App::PropertyLink   Base;
     PropertyFilletEdges Edges;
 
     /** @name methods override feature */
@@ -46,9 +46,9 @@ public:
     App::DocumentObjectExecReturn *execute(void);
     short mustExecute() const;
     /// returns the type name of the view provider
-    //const char* getViewProviderName(void) const {
-    //    return "PartGui::ViewProviderFillet";
-    //}
+    const char* getViewProviderName(void) const {
+        return "PartGui::ViewProviderFillet";
+    }
     //@}
 };
 
