@@ -45,6 +45,28 @@ protected:
     //@}
 };
 
+class MultiCommon : public Part::Feature
+{
+    PROPERTY_HEADER(Part::MultiCommon);
+
+public:
+    MultiCommon();
+
+    App::PropertyLinkList Shapes;
+
+    /** @name methods override feature */
+    //@{
+    /// recalculate the Feature
+    App::DocumentObjectExecReturn *execute(void);
+    short mustExecute() const;
+    //@}
+    /// returns the type name of the ViewProvider
+    const char* getViewProviderName(void) const {
+        return "PartGui::ViewProviderMultiCommon";
+    }
+
+};
+
 }
 
 #endif // PART_FEATUREPARTCOMMON_H
