@@ -24,6 +24,7 @@
 #ifndef PART_GEOMETRY_H
 #define PART_GEOMETRY_H
 
+#include <Handle_Geom_CartesianPoint.hxx>
 #include <Handle_Geom_BezierCurve.hxx>
 #include <Handle_Geom_BSplineCurve.hxx>
 #include <Handle_Geom_Circle.hxx>
@@ -62,16 +63,47 @@ public:
     virtual TopoDS_Shape toShape() const = 0;
     virtual const Handle_Geom_Geometry& handle() const = 0;
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     /// returns a cloned object 
-    virtual Geometry *clone(void)const = 0;
+    virtual Geometry *clone(void) const = 0;
     /// construction geometry (means no impact on a later built topo)
     bool Construction;
 
 protected:
     Geometry();
+
+private:
+    Geometry(const Geometry&);
+    Geometry& operator = (const Geometry&);
+};
+
+class PartExport GeomPoint : public Geometry
+{
+    TYPESYSTEM_HEADER();
+public:
+    GeomPoint();
+    GeomPoint(const Handle_Geom_CartesianPoint&);
+    GeomPoint(const Base::Vector3d&);
+    virtual ~GeomPoint();
+    virtual Geometry *clone(void) const;
+    virtual TopoDS_Shape toShape() const;
+
+   // Persistence implementer ---------------------
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
+    virtual void Restore(Base::XMLReader &/*reader*/);
+    // Base implementer ----------------------------
+    virtual PyObject *getPyObject(void);
+
+    const Handle_Geom_Geometry& handle() const;
+
+    Base::Vector3d getPoint(void)const;
+    void setPoint(const Base::Vector3d&);
+
+private:
+    Handle_Geom_CartesianPoint myPoint;
 };
 
 class PartExport GeomCurve : public Geometry
@@ -92,7 +124,7 @@ public:
     GeomBezierCurve();
     GeomBezierCurve(const Handle_Geom_BezierCurve&);
     virtual ~GeomBezierCurve();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
     virtual unsigned int getMemSize (void) const;
@@ -101,7 +133,7 @@ public:
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
 
-
+    void setHandle(const Handle_Geom_BezierCurve&);
     const Handle_Geom_Geometry& handle() const;
 
 private:
@@ -115,11 +147,17 @@ public:
     GeomBSplineCurve();
     GeomBSplineCurve(const Handle_Geom_BSplineCurve&);
     virtual ~GeomBSplineCurve();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
+
+    int countPoles() const;
+    void setPole(int index, const Base::Vector3d&, double weight=-1);
+    std::vector<Base::Vector3d> getPoles() const;
+    bool join(const Handle_Geom_BSplineCurve&);
+    void makeC1Continuous(double, double);
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -138,14 +176,16 @@ public:
     GeomCircle();
     GeomCircle(const Handle_Geom_Circle&);
     virtual ~GeomCircle();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     Base::Vector3d getCenter(void) const;
     double getRadius(void) const;
+    void setCenter(const Base::Vector3d& Center);
+    void setRadius(double Radius);
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -156,6 +196,39 @@ private:
     Handle_Geom_Circle myCurve;
 };
 
+class PartExport GeomArcOfCircle : public GeomCurve
+{
+    TYPESYSTEM_HEADER();
+public:
+    GeomArcOfCircle();
+    GeomArcOfCircle(const Handle_Geom_Circle&);
+    virtual ~GeomArcOfCircle();
+    virtual Geometry *clone(void) const;
+
+    Base::Vector3d getStartPoint() const;
+    Base::Vector3d getEndPoint() const;
+
+    Base::Vector3d getCenter(void) const;
+    double getRadius(void) const;
+    void setCenter(const Base::Vector3d& Center);
+    void setRadius(double Radius);
+    void getRange(double& u, double& v) const;
+    void setRange(double u, double v);
+
+    // Persistence implementer ---------------------
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
+    virtual void Restore(Base::XMLReader &/*reader*/);
+    // Base implementer ----------------------------
+    virtual PyObject *getPyObject(void);
+
+    void setHandle(const Handle_Geom_TrimmedCurve&);
+    const Handle_Geom_Geometry& handle() const;
+
+private:
+    Handle_Geom_TrimmedCurve myCurve;
+};
+
 class PartExport GeomEllipse : public GeomCurve
 {
     TYPESYSTEM_HEADER();
@@ -163,11 +236,11 @@ public:
     GeomEllipse();
     GeomEllipse(const Handle_Geom_Ellipse&);
     virtual ~GeomEllipse();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -185,11 +258,11 @@ public:
     GeomHyperbola();
     GeomHyperbola(const Handle_Geom_Hyperbola&);
     virtual ~GeomHyperbola();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -207,11 +280,11 @@ public:
     GeomParabola();
     GeomParabola(const Handle_Geom_Parabola&);
     virtual ~GeomParabola();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -228,12 +301,17 @@ class PartExport GeomLine : public GeomCurve
 public:
     GeomLine();
     GeomLine(const Handle_Geom_Line&);
+    GeomLine(const Base::Vector3d& Pos, const Base::Vector3d& Dir);
     virtual ~GeomLine();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
-   // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    void setLine(const Base::Vector3d& Pos, const Base::Vector3d& Dir);
+    Base::Vector3d getPos(void) const;
+    Base::Vector3d getDir(void) const;
+
+    // Persistence implementer ---------------------
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -250,7 +328,7 @@ class PartExport GeomLineSegment : public GeomCurve
 public:
     GeomLineSegment();
     virtual ~GeomLineSegment();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     Base::Vector3d getStartPoint() const;
     Base::Vector3d getEndPoint() const;
@@ -258,13 +336,14 @@ public:
     void setPoints(const Base::Vector3d& p1, 
                    const Base::Vector3d& p2);
 
-     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    // Persistence implementer ---------------------
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
 
+    void setHandle(const Handle_Geom_TrimmedCurve&);
     const Handle_Geom_Geometry& handle() const;
 
 private:
@@ -279,11 +358,11 @@ public:
     GeomOffsetCurve(const Handle_Geom_Curve&, double, const gp_Dir&);
     GeomOffsetCurve(const Handle_Geom_OffsetCurve&);
     virtual ~GeomOffsetCurve();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -302,11 +381,11 @@ public:
     GeomTrimmedCurve();
     GeomTrimmedCurve(const Handle_Geom_TrimmedCurve&);
     virtual ~GeomTrimmedCurve();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -337,11 +416,11 @@ public:
     GeomBezierSurface();
     GeomBezierSurface(const Handle_Geom_BezierSurface&);
     virtual ~GeomBezierSurface();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -360,11 +439,11 @@ public:
     GeomBSplineSurface();
     GeomBSplineSurface(const Handle_Geom_BSplineSurface&);
     virtual ~GeomBSplineSurface();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -381,11 +460,11 @@ class PartExport GeomCylinder : public GeomSurface
 public:
     GeomCylinder();
     virtual ~GeomCylinder();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -402,11 +481,11 @@ class PartExport GeomCone : public GeomSurface
 public:
     GeomCone();
     virtual ~GeomCone();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -423,11 +502,11 @@ class PartExport GeomSphere : public GeomSurface
 public:
     GeomSphere();
     virtual ~GeomSphere();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -444,11 +523,11 @@ class PartExport GeomToroid : public GeomSurface
 public:
     GeomToroid();
     virtual ~GeomToroid();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -465,11 +544,11 @@ class PartExport GeomPlane : public GeomSurface
 public:
     GeomPlane();
     virtual ~GeomPlane();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -480,7 +559,7 @@ private:
     Handle_Geom_Plane mySurface;
 };
 
-class GeomOffsetSurface : public GeomSurface
+class PartExport GeomOffsetSurface : public GeomSurface
 {
     TYPESYSTEM_HEADER();
 public:
@@ -488,11 +567,11 @@ public:
     GeomOffsetSurface(const Handle_Geom_Surface&, double);
     GeomOffsetSurface(const Handle_Geom_OffsetSurface&);
     virtual ~GeomOffsetSurface();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -504,18 +583,18 @@ private:
     Handle_Geom_OffsetSurface mySurface;
 };
 
-class GeomTrimmedSurface : public GeomSurface
+class PartExport GeomTrimmedSurface : public GeomSurface
 {
     TYPESYSTEM_HEADER();
 public:
     GeomTrimmedSurface();
     GeomTrimmedSurface(const Handle_Geom_RectangularTrimmedSurface&);
     virtual ~GeomTrimmedSurface();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -527,7 +606,7 @@ private:
     Handle_Geom_RectangularTrimmedSurface mySurface;
 };
 
-class GeomSurfaceOfRevolution : public GeomSurface
+class PartExport GeomSurfaceOfRevolution : public GeomSurface
 {
     TYPESYSTEM_HEADER();
 public:
@@ -535,11 +614,11 @@ public:
     GeomSurfaceOfRevolution(const Handle_Geom_Curve&, const gp_Ax1&);
     GeomSurfaceOfRevolution(const Handle_Geom_SurfaceOfRevolution&);
     virtual ~GeomSurfaceOfRevolution();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -551,7 +630,7 @@ private:
     Handle_Geom_SurfaceOfRevolution mySurface;
 };
 
-class GeomSurfaceOfExtrusion : public GeomSurface
+class PartExport GeomSurfaceOfExtrusion : public GeomSurface
 {
     TYPESYSTEM_HEADER();
 public:
@@ -559,11 +638,11 @@ public:
     GeomSurfaceOfExtrusion(const Handle_Geom_Curve&, const gp_Dir&);
     GeomSurfaceOfExtrusion(const Handle_Geom_SurfaceOfLinearExtrusion&);
     virtual ~GeomSurfaceOfExtrusion();
-    virtual Geometry *clone(void)const;
+    virtual Geometry *clone(void) const;
 
     // Persistence implementer ---------------------
-    virtual unsigned int getMemSize (void) const;
-    virtual void Save (Base::Writer &/*writer*/) const;
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
     // Base implementer ----------------------------
     virtual PyObject *getPyObject(void);
@@ -575,6 +654,28 @@ private:
     Handle_Geom_SurfaceOfLinearExtrusion mySurface;
 };
 
+
+// Helper functions for fillet tools
+PartExport 
+bool find2DLinesIntersection(const Base::Vector3d &orig1, const Base::Vector3d &dir1,
+                             const Base::Vector3d &orig2, const Base::Vector3d &dir2,
+                             Base::Vector3d &point);
+PartExport
+bool find2DLinesIntersection(const GeomLineSegment *lineSeg1, const GeomLineSegment *lineSeg2,
+                             Base::Vector3d &point);
+PartExport
+bool findFilletCenter(const GeomLineSegment *lineSeg1, const GeomLineSegment *lineSeg2, double radius,
+                      Base::Vector3d &center);
+PartExport
+bool findFilletCenter(const GeomLineSegment *lineSeg1, const GeomLineSegment *lineSeg2, double radius,
+                      const Base::Vector3d& refPnt1, const Base::Vector3d& refPnt2,
+                      Base::Vector3d &center);
+PartExport
+double suggestFilletRadius(const GeomLineSegment *lineSeg1, const GeomLineSegment *lineSeg2,
+                           const Base::Vector3d &refPnt1, const Base::Vector3d &refPnt2);
+PartExport
+GeomArcOfCircle *createFilletGeometry(const GeomLineSegment *lineSeg1, const GeomLineSegment *lineSeg2,
+                                      const Base::Vector3d &center, double radius);
 }
 
 #endif // PART_GEOMETRY_H
