@@ -69,6 +69,7 @@
 
 #include <Base/Console.h>
 #include <Base/Sequencer.h>
+#include <App/Application.h>
 #include <App/Document.h>
 
 #include "ImportStep.h"
@@ -90,11 +91,11 @@ int Part::ImportStepParts(App::Document *pcDoc, const char* Name)
 
     if (!fi.isReadable()) {
         Base::Console().Log("ImportStep() not able to open %s!\n",Name);
-        throw Base::Exception("Cannot open file Step file");
+        throw Base::Exception("Cannot open STEP file");
     }
 
     if (aReader.ReadFile((Standard_CString)Name) != IFSelect_RetDone) {
-        throw Base::Exception("Cannot open file Step file");
+        throw Base::Exception("Cannot open STEP file");
     }
 
     Handle_Message_ProgressIndicator pi = new ProgressIndicator(100);
@@ -142,7 +143,8 @@ int Part::ImportStepParts(App::Document *pcDoc, const char* Name)
                 //    name += ws->Model()->StringLabel(ent)->ToCString();
                 //}
 
-                Part::Feature *pcFeature = static_cast<Part::Feature*>(pcDoc->addObject("Part::Feature", name.c_str()));
+                Part::Feature *pcFeature;
+                pcFeature = static_cast<Part::Feature*>(pcDoc->addObject("Part::Feature", name.c_str()));
                 pcFeature->Shape.setValue(aSolid);
 
                 // This is a trick to access the GUI via Python and set the color property
@@ -158,7 +160,7 @@ int Part::ImportStepParts(App::Document *pcDoc, const char* Name)
                         col.setItem(1, Py::Float(it->second.Green()));
                         col.setItem(2, Py::Float(it->second.Blue()));
                         vp.setAttr("ShapeColor", col);
-                        Base::Console().Message("Set color to shape\n");
+                        //Base::Console().Message("Set color to shape\n");
                     }
                     catch (Py::Exception& e) {
                         e.clear();
