@@ -30,13 +30,6 @@
 #include <App/FeaturePython.h>
 #include <App/PropertyGeo.h>
 
-class PyObjectBase;
-class FeaturePy;
-
-namespace Base{
-  class PyObjectBase;
-}
-
 namespace Part
 {
 
@@ -44,7 +37,7 @@ class PartFeaturePy;
 
 /** Base class of all shape feature classes in FreeCAD
  */
-class AppPartExport Feature : public App::GeoFeature
+class PartExport Feature : public App::GeoFeature
 {
     PROPERTY_HEADER(Part::Feature);
 
@@ -63,9 +56,7 @@ public:
     //@}
 
     /// returns the type name of the ViewProvider
-    virtual const char* getViewProviderName(void) const {
-        return "PartGui::ViewProviderPart";
-    }
+    virtual const char* getViewProviderName(void) const;
 
     virtual PyObject* getPyObject(void);
     virtual std::vector<PyObject *> getPySubObjects(const std::vector<std::string>&) const;
@@ -79,6 +70,19 @@ protected:
 
 typedef App::FeaturePythonT<Feature> FeaturePython;
 
+
+/** Base class of all shape feature classes in FreeCAD
+ */
+class PartExport FeatureExt : public Feature
+{
+    PROPERTY_HEADER(Part::FeatureExt);
+
+public:
+    const char* getViewProviderName(void) const {
+        return "PartGui::ViewProviderPartExt";
+    }
+};
+
 } //namespace Part
 
 
