@@ -23,18 +23,25 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <cfloat>
 # include <BRepLib.hxx>
 # include <BRepPrimAPI_MakeCone.hxx>
 # include <BRepPrimAPI_MakeCylinder.hxx>
+# include <BRepPrimAPI_MakeRevol.hxx>
 # include <BRepPrimAPI_MakeSphere.hxx>
 # include <BRepPrimAPI_MakeTorus.hxx>
+# include <BRepPrim_Wedge.hxx>
 # include <BRepBuilderAPI_MakeEdge.hxx>
 # include <BRepBuilderAPI_MakeFace.hxx>
+# include <BRepBuilderAPI_MakeVertex.hxx>
 # include <BRepBuilderAPI_MakeWire.hxx>
+# include <BRepBuilderAPI_MakeSolid.hxx>
 # include <BRepBuilderAPI_GTransform.hxx>
+# include <gp_Circ.hxx>
 # include <gp_GTrsf.hxx>
 # include <GCE2d_MakeSegment.hxx>
 # include <Geom_Plane.hxx>
+# include <Geom_ConicalSurface.hxx>
 # include <Geom_CylindricalSurface.hxx>
 # include <Geom2d_Line.hxx>
 # include <Geom2d_TrimmedCurve.hxx>
@@ -44,15 +51,23 @@
 # include <Handle_Geom2d_TrimmedCurve.hxx>
 # include <Precision.hxx>
 # include <Standard_Real.hxx>
+# include <TopoDS.hxx>
 # include <TopoDS_Solid.hxx>
+# include <TopoDS_Vertex.hxx>
 #endif
 
 
 #include "PrimitiveFeature.h"
+#include <Base/Tools.h>
+
+#ifndef M_PI
+#define M_PI       3.14159265358979323846
+#endif
 
 
 namespace Part {
-    const App::PropertyFloatConstraint::Constraints floatRange = {0.0f,1000.0f,0.1f};
+    const App::PropertyFloatConstraint::Constraints floatRange  = {0.0f,FLT_MAX,0.1f};
+    const App::PropertyFloatConstraint::Constraints apexRange   = {0.0f,90.0f,0.1f};
     const App::PropertyFloatConstraint::Constraints angleRangeU = {0.0f,360.0f,1.0f};
     const App::PropertyFloatConstraint::Constraints angleRangeV = {-90.0f,90.0f,1.0f};
     const App::PropertyFloatConstraint::Constraints torusRangeV = {-180.0f,180.0f,1.0f};
@@ -65,6 +80,7 @@ PROPERTY_SOURCE_ABSTRACT(Part::Primitive, Part::Feature)
 
 Primitive::Primitive(void) 
 {
+    touch();
 }
 
 Primitive::~Primitive()
@@ -94,6 +110,58 @@ void Primitive::onChanged(const App::Property* prop)
     Part::Feature::onChanged(prop);
 }
 
+PROPERTY_SOURCE(Part::Vertex, Part::Primitive)
+
+Vertex::Vertex()
+{
+    ADD_PROPERTY(X,(0.0f));
+    ADD_PROPERTY(Y,(0.0f));
+    ADD_PROPERTY(Z,(0.0f));
+}
+
+Vertex::~Vertex()
+{
+}
+
+short Vertex::mustExecute() const
+{
+    if (X.isTouched() ||
+        Y.isTouched() ||
+        Z.isTouched())
+        return 1;
+    return Part::Feature::mustExecute();
+}
+
+App::DocumentObjectExecReturn *Vertex::execute(void)
+{
+    gp_Pnt point;
+    point.SetX(this->X.getValue());
+    point.SetY(this->Y.getValue());
+    point.SetZ(this->Z.getValue());
+    
+    BRepBuilderAPI_MakeVertex MakeVertex(point);
+    const TopoDS_Vertex& vertex = MakeVertex.Vertex();
+    this->Shape.setValue(vertex);
+
+    return App::DocumentObject::StdReturn;
+}
+
+
+void Vertex::onChanged(const App::Property* prop)
+{
+    if (!isRestoring()) {
+        if (prop == &X || prop == &Y || prop == &Z){
+            try {
+                App::DocumentObjectExecReturn *ret = recompute();
+                delete ret;
+            }
+            catch (...) {
+            }
+        }
+    }
+    Part::Feature::onChanged(prop);
+}
+
 PROPERTY_SOURCE(Part::Plane, Part::Primitive)
 
 Plane::Plane()
@@ -191,6 +259,8 @@ short Sphere::mustExecute() const
 App::DocumentObjectExecReturn *Sphere::execute(void)
 {
     // Build a sphere
+    if (Radius.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of sphere too small");
     try {
         BRepPrimAPI_MakeSphere mkSphere(Radius.getValue(),
                                         Angle1.getValue()/180.0f*Standard_PI,
@@ -241,6 +311,10 @@ short Ellipsoid::mustExecute() const
 App::DocumentObjectExecReturn *Ellipsoid::execute(void)
 {
     // Build a sphere
+    if (Radius1.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of ellipsoid too small");
+    if (Radius2.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of ellipsoid too small");
     try {
         gp_Pnt pnt(0.0,0.0,0.0);
         gp_Dir dir(0.0,0.0,1.0);
@@ -299,6 +373,10 @@ short Cylinder::mustExecute() const
 App::DocumentObjectExecReturn *Cylinder::execute(void)
 {
     // Build a cylinder
+    if (Radius.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of cylinder too small");
+    if (Height.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Height of cylinder too small");
     try {
         BRepPrimAPI_MakeCylinder mkCylr(Radius.getValue(),
                                         Height.getValue(),
@@ -340,6 +418,12 @@ short Cone::mustExecute() const
 
 App::DocumentObjectExecReturn *Cone::execute(void)
 {
+    if (Radius1.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of cone too small");
+    if (Radius2.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of cone too small");
+    if (Height.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Height of cone too small");
     try {
         // Build a cone
         BRepPrimAPI_MakeCone mkCone(Radius1.getValue(),
@@ -390,14 +474,35 @@ short Torus::mustExecute() const
 
 App::DocumentObjectExecReturn *Torus::execute(void)
 {
+    if (Radius1.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of torus too small");
+    if (Radius2.getValue() < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("Radius of torus too small");
     try {
+#if 1
         // Build a torus
+        gp_Circ circle;
+        circle.SetRadius(Radius2.getValue());
+        gp_Pnt pos(Radius1.getValue(),0,0);
+        gp_Dir dir(0,1,0);
+        circle.SetAxis(gp_Ax1(pos, dir));
+
+        BRepBuilderAPI_MakeEdge mkEdge(circle, Base::toRadians<double>(Angle1.getValue()+180.0f),
+                                               Base::toRadians<double>(Angle2.getValue()+180.0f));
+        BRepBuilderAPI_MakeWire mkWire;
+        mkWire.Add(mkEdge.Edge());
+        BRepBuilderAPI_MakeFace mkFace(mkWire.Wire());
+        BRepPrimAPI_MakeRevol mkRevol(mkFace.Face(), gp_Ax1(gp_Pnt(0,0,0), gp_Dir(0,0,1)),
+            Base::toRadians<double>(Angle3.getValue()), Standard_True);
+        TopoDS_Shape ResultShape = mkRevol.Shape();
+#else
         BRepPrimAPI_MakeTorus mkTorus(Radius1.getValue(),
                                       Radius2.getValue(),
                                       Angle1.getValue()/180.0f*Standard_PI,
                                       Angle2.getValue()/180.0f*Standard_PI,
                                       Angle3.getValue()/180.0f*Standard_PI);
         const TopoDS_Solid& ResultShape = mkTorus.Solid();
+#endif
         this->Shape.setValue(ResultShape);
     }
     catch (Standard_Failure) {
@@ -418,6 +523,8 @@ Helix::Helix(void)
     Height.setConstraints(&floatRange);
     ADD_PROPERTY_TYPE(Radius,(1.0),"Helix",App::Prop_None,"The radius of the helix");
     Radius.setConstraints(&floatRange);
+    ADD_PROPERTY_TYPE(Angle,(0.0),"Helix",App::Prop_None,"If angle is > 0 a conical otherwise a cylindircal surface is used");
+    Angle.setConstraints(&apexRange);
 }
 
 short Helix::mustExecute() const
@@ -428,6 +535,8 @@ short Helix::mustExecute() const
         return 1;
     if (Radius.isTouched())
         return 1;
+    if (Angle.isTouched())
+        return 1;
     return Primitive::mustExecute();
 }
 
@@ -437,32 +546,9 @@ App::DocumentObjectExecReturn *Helix::execute(void)
         Standard_Real myPitch  = Pitch.getValue();
         Standard_Real myHeight = Height.getValue();
         Standard_Real myRadius = Radius.getValue();
-
-        if (myPitch < Precision::Confusion())
-            return new App::DocumentObjectExecReturn("Pitch of helix too small");
-
-        if (myHeight < Precision::Confusion())
-            return new App::DocumentObjectExecReturn("Height of helix too small");
-
-        if (myRadius < Precision::Confusion())
-            return new App::DocumentObjectExecReturn("Radius of helix too small");
-
-        gp_Ax2 cylAx2(gp_Pnt(0.0,0.0,0.0) , gp::DZ());
-        Handle(Geom_CylindricalSurface) cyl = new Geom_CylindricalSurface(cylAx2 , myRadius);
-
-        gp_Pnt2d aPnt(0, 0);
-        gp_Dir2d aDir(2. * PI, myPitch);
-        gp_Ax2d aAx2d(aPnt, aDir);
-
-        Handle(Geom2d_Line) line = new Geom2d_Line(aAx2d);
-        gp_Pnt2d beg = line->Value(0);
-        gp_Pnt2d end = line->Value(2.0*PI*(myHeight/myPitch));
-        Handle(Geom2d_TrimmedCurve) segm = GCE2d_MakeSegment(beg , end);
-
-        TopoDS_Edge edgeOnSurf = BRepBuilderAPI_MakeEdge(segm , cyl);
-        TopoDS_Wire wire = BRepBuilderAPI_MakeWire(edgeOnSurf);
-        BRepLib::BuildCurves3d(wire);
-        this->Shape.setValue(wire);
+        Standard_Real myAngle  = Angle.getValue();
+        TopoShape helix;
+        this->Shape.setValue(helix.makeHelix(myPitch, myHeight, myRadius, myAngle));
     }
     catch (Standard_Failure) {
         Handle_Standard_Failure e = Standard_Failure::Caught();
@@ -471,3 +557,102 @@ App::DocumentObjectExecReturn *Helix::execute(void)
 
     return App::DocumentObject::StdReturn;
 }
+
+PROPERTY_SOURCE(Part::Wedge, Part::Primitive)
+
+Wedge::Wedge()
+{
+    ADD_PROPERTY_TYPE(Xmin,(0.0f),"Wedge",App::Prop_None,"Xmin of the wedge");
+    ADD_PROPERTY_TYPE(Ymin,(0.0f),"Wedge",App::Prop_None,"Ymin of the wedge");
+    ADD_PROPERTY_TYPE(Zmin,(0.0f),"Wedge",App::Prop_None,"Zmin of the wedge");
+    ADD_PROPERTY_TYPE(X2min,(2.0f),"Wedge",App::Prop_None,"X2min of the wedge");
+    ADD_PROPERTY_TYPE(Z2min,(2.0f),"Wedge",App::Prop_None,"Z2min of the wedge");
+    ADD_PROPERTY_TYPE(Xmax,(10.0f),"Wedge",App::Prop_None,"Xmax of the wedge");
+    ADD_PROPERTY_TYPE(Ymax,(10.0f),"Wedge",App::Prop_None,"Ymax of the wedge");
+    ADD_PROPERTY_TYPE(Zmax,(10.0f),"Wedge",App::Prop_None,"Zmax of the wedge");
+    ADD_PROPERTY_TYPE(X2max,(8.0f),"Wedge",App::Prop_None,"X2max of the wedge");
+    ADD_PROPERTY_TYPE(Z2max,(8.0f),"Wedge",App::Prop_None,"Z2max of the wedge");
+}
+
+short Wedge::mustExecute() const
+{
+    if (Xmin.isTouched() ||
+        Ymin.isTouched() ||
+        Zmin.isTouched() ||
+        X2min.isTouched() ||
+        Z2min.isTouched() ||
+        Xmax.isTouched() ||
+        Ymax.isTouched() ||
+        Zmax.isTouched() ||
+        X2max.isTouched() ||
+        Z2max.isTouched())
+        return 1;
+    return Primitive::mustExecute();
+}
+
+App::DocumentObjectExecReturn *Wedge::execute(void)
+{
+    double xmin = Xmin.getValue();
+    double ymin = Ymin.getValue();
+    double zmin = Zmin.getValue();
+    double z2min = Z2min.getValue();
+    double x2min = X2min.getValue();
+    double xmax = Xmax.getValue();
+    double ymax = Ymax.getValue();
+    double zmax = Zmax.getValue();
+    double z2max = Z2max.getValue();
+    double x2max = X2max.getValue();
+
+
+    double dx = xmax-xmin;
+    double dy = ymax-ymin;
+    double dz = zmax-zmin;
+    double dz2 = z2max-z2min;
+    double dx2 = x2max-x2min;
+
+    if (dx < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("delta x of wedge too small");
+
+    if (dy < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("delta y of wedge too small");
+
+    if (dz < Precision::Confusion())
+        return new App::DocumentObjectExecReturn("delta z of wedge too small");
+
+    if (dz2 < 0)
+        return new App::DocumentObjectExecReturn("delta z2 of wedge is negative");
+
+    if (dx2 < 0)
+        return new App::DocumentObjectExecReturn("delta x2 of wedge is negative");
+
+    try {
+        gp_Pnt pnt(0.0,0.0,0.0);
+        gp_Dir dir(0.0,0.0,1.0);
+        BRepPrim_Wedge mkWedge(gp_Ax2(pnt,dir),
+            xmin, ymin, zmin, z2min, x2min,
+            xmax, ymax, zmax, z2max, x2max);
+        BRepBuilderAPI_MakeSolid mkSolid;
+        mkSolid.Add(mkWedge.Shell());
+        this->Shape.setValue(mkSolid.Solid());
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        return new App::DocumentObjectExecReturn(e->GetMessageString());
+    }
+
+    return App::DocumentObject::StdReturn;
+}
+
+void Wedge::onChanged(const App::Property* prop)
+{
+    if (prop == &Xmin || prop == &Ymin || prop == &Zmin ||
+        prop == &X2min || prop == &Z2min ||
+        prop == &Xmax || prop == &Ymax || prop == &Zmax ||
+        prop == &X2max || prop == &Z2max) {
+        if (!isRestoring()) {
+            App::DocumentObjectExecReturn *ret = recompute();
+            delete ret;
+        }
+    }
+    Part::Primitive::onChanged(prop);
+}
