@@ -24,7 +24,7 @@
 #ifndef PART_PRIMITIVEFEATURE_H
 #define PART_PRIMITIVEFEATURE_H
 
-#include <App/PropertyStandard.h>
+#include <App/PropertyUnits.h>
 #include "PartFeature.h"
 
 namespace Part
@@ -49,6 +49,27 @@ protected:
     void onChanged (const App::Property* prop);
 };
 
+class PartExport Vertex : public Part::Primitive
+{
+    PROPERTY_HEADER(Part::Vertex);
+
+public:
+    Vertex();
+    virtual ~Vertex();
+
+    App::PropertyFloat X;
+    App::PropertyFloat Y;
+    App::PropertyFloat Z;
+
+    /** @name methods override feature */
+    //@{
+    /// recalculate the Feature
+    App::DocumentObjectExecReturn *execute(void);
+    short mustExecute() const;
+    void onChanged(const App::Property*);
+    //@}
+};
+
 class PartExport Plane : public Primitive
 {
     PROPERTY_HEADER(Part::Plane);
@@ -181,6 +202,7 @@ public:
     App::PropertyFloatConstraint Pitch;
     App::PropertyFloatConstraint Height;
     App::PropertyFloatConstraint Radius;
+    App::PropertyFloatConstraint Angle;
 
     /** @name methods override feature */
     //@{
@@ -190,6 +212,35 @@ public:
     //@}
 };
 
+class PartExport Wedge : public Primitive
+{
+    PROPERTY_HEADER(Part::Wedge);
+
+public:
+    Wedge();
+
+    App::PropertyFloat Xmin;
+    App::PropertyFloat Ymin;
+    App::PropertyFloat Zmin;
+    App::PropertyFloat Z2min;
+    App::PropertyFloat X2min;
+    App::PropertyFloat Xmax;
+    App::PropertyFloat Ymax;
+    App::PropertyFloat Zmax;
+    App::PropertyFloat Z2max;
+    App::PropertyFloat X2max;
+
+    /** @name methods override feature */
+    //@{
+    /// recalculate the feature
+    App::DocumentObjectExecReturn *execute(void);
+    short mustExecute() const;
+    //@}
+
+protected:
+    void onChanged(const App::Property* prop);
+};
+
 } //namespace Part
 
 
