@@ -26,40 +26,66 @@
 #ifndef _PreComp_
 # include <cstdlib>
 # include <sstream>
+# include <BRepLib.hxx>
+# include <BSplCLib.hxx>
 # include <Bnd_Box.hxx>
 # include <BRep_Builder.hxx>
 # include <BRep_Tool.hxx>
 # include <BRepAdaptor_Curve.hxx>
+# include <BRepAdaptor_HCurve.hxx>
 # include <BRepAdaptor_Surface.hxx>
 # include <BRepAlgoAPI_Common.hxx>
 # include <BRepAlgoAPI_Cut.hxx>
 # include <BRepAlgoAPI_Fuse.hxx>
+# include <BRepAlgo_Fuse.hxx>
 # include <BRepAlgoAPI_Section.hxx>
 # include <BRepBndLib.hxx>
 # include <BRepBuilderAPI_GTransform.hxx>
+# include <BRepBuilderAPI_MakeEdge.hxx>
 # include <BRepBuilderAPI_MakeFace.hxx>
 # include <BRepBuilderAPI_MakePolygon.hxx>
 # include <BRepBuilderAPI_MakeVertex.hxx>
+# include <BRepBuilderAPI_MakeWire.hxx>
 # include <BRepBuilderAPI_NurbsConvert.hxx>
 # include <BRepBuilderAPI_FaceError.hxx>
 # include <BRepBuilderAPI_Copy.hxx>
 # include <BRepBuilderAPI_Transform.hxx>
 # include <BRepCheck_Analyzer.hxx>
+# include <BRepCheck_ListIteratorOfListOfStatus.hxx>
+# include <BRepCheck_Result.hxx>
 # include <BRepFilletAPI_MakeFillet.hxx>
 # include <BRepMesh.hxx>
 # include <BRepMesh_IncrementalMesh.hxx>
 # include <BRepMesh_Triangle.hxx>
 # include <BRepMesh_Edge.hxx>
 # include <BRepOffsetAPI_MakeThickSolid.hxx>
+# include <BRepOffsetAPI_MakeOffsetShape.hxx>
 # include <BRepOffsetAPI_MakePipe.hxx>
 # include <BRepOffsetAPI_MakePipeShell.hxx>
 # include <BRepOffsetAPI_Sewing.hxx>
+# include <BRepOffsetAPI_ThruSections.hxx>
 # include <BRepPrimAPI_MakePrism.hxx>
 # include <BRepPrimAPI_MakeRevol.hxx>
 # include <BRepTools.hxx>
 # include <BRepTools_ReShape.hxx>
 # include <BRepTools_ShapeSet.hxx>
+# include <GCE2d_MakeSegment.hxx>
+# include <Geom2d_Line.hxx>
+# include <Geom2d_TrimmedCurve.hxx>
+# include <GeomLProp_SLProps.hxx>
+# include <GeomAPI_ProjectPointOnSurf.hxx>
+# include <GeomFill_CorrectedFrenet.hxx>
+# include <GeomFill_CurveAndTrihedron.hxx>
+# include <GeomFill_EvolvedSection.hxx>
+# include <GeomFill_Pipe.hxx>
+# include <GeomFill_SectionLaw.hxx>
+# include <GeomFill_Sweep.hxx>
+# include <Handle_Law_BSpFunc.hxx>
+# include <Handle_Law_BSpline.hxx>
 # include <Handle_TopTools_HSequenceOfShape.hxx>
+# include <Law_BSpFunc.hxx>
+# include <Law_Linear.hxx>
+# include <Law_S.hxx>
 # include <TopTools_HSequenceOfShape.hxx>
 # include <Interface_Static.hxx>
 # include <IGESControl_Controller.hxx>
@@ -99,10 +125,12 @@
 # include <gp_GTrsf.hxx>
 # include <ShapeAnalysis_Shell.hxx>
 # include <ShapeBuild_ReShape.hxx>
+# include <ShapeFix_Edge.hxx>
 # include <ShapeFix_Face.hxx>
 # include <ShapeFix_Shell.hxx>
 # include <ShapeFix_Solid.hxx>
 # include <ShapeUpgrade_ShellSewing.hxx>
+# include <ShapeUpgrade_RemoveInternalWires.hxx>
 #endif
 # include <Poly_Polygon3D.hxx>
 # include <Poly_PolygonOnTriangulation.hxx>
@@ -116,6 +144,7 @@
 #include <Base/Builder3D.h>
 #include <Base/FileInfo.h>
 #include <Base/Exception.h>
+#include <Base/Tools.h>
 
 #include "TopoShape.h"
 #include "CrossSection.h"
@@ -148,6 +177,7 @@ const char* BRepBuilderAPI_FaceErrorText(BRepBuilderAPI_FaceError et)
         return "Unknown creation error";
     }
 }
+
 // ------------------------------------------------
 
 TYPESYSTEM_SOURCE(Part::ShapeSegment , Data::Segment);
@@ -189,6 +219,11 @@ std::vector<const char*> TopoShape::getElementTypes(void) const
     return temp;
 }
 
+unsigned long TopoShape::countSubElements(const char* Type) const
+{
+    return countSubShapes(Type);
+}
+
 Data::Segment* TopoShape::getSubElement(const char* Type, unsigned long n) const
 {
     std::stringstream str;
@@ -197,6 +232,123 @@ Data::Segment* TopoShape::getSubElement(const char* Type, unsigned long n) const
     return new ShapeSegment(getSubShape(temp.c_str()));
 }
 
+void TopoShape::getLinesFromSubelement(const Data::Segment* element,
+                                       std::vector<Base::Vector3d> &Points,
+                                       std::vector<Line> &lines) const
+{
+}
+
+void TopoShape::getFacesFromSubelement(const Data::Segment* element,
+                                       std::vector<Base::Vector3d> &Points,
+                                       std::vector<Base::Vector3d> &PointNormals,
+                                       std::vector<Facet> &faces) const
+{
+    if (element->getTypeId() == ShapeSegment::getClassTypeId()) {
+        const TopoDS_Shape& shape = static_cast<const ShapeSegment*>(element)->Shape;
+        if (shape.IsNull() || shape.ShapeType() != TopAbs_FACE)
+            return;
+    
+        TopLoc_Location aLoc;
+        // doing the meshing and checking the result
+        Handle(Poly_Triangulation) aPoly = BRep_Tool::Triangulation(TopoDS::Face(shape),aLoc);
+        if (aPoly.IsNull())
+            return;
+
+        // geting the transformation of the shape/face
+        gp_Trsf myTransf;
+        Standard_Boolean identity = true;
+        if (!aLoc.IsIdentity())  {
+            identity = false;
+            myTransf = aLoc.Transformation();
+        }
+
+        Standard_Integer i;
+        // geting size and create the array
+        int nbNodesInFace = aPoly->NbNodes();
+        int nbTriInFace = aPoly->NbTriangles();
+        Points.resize(nbNodesInFace);
+        PointNormals.resize(nbNodesInFace); // fills up already the array
+        faces.resize(nbTriInFace);
+
+        // check orientation
+        TopAbs_Orientation orient = shape.Orientation();
+
+        // cycling through the poly mesh
+        const Poly_Array1OfTriangle& Triangles = aPoly->Triangles();
+        const TColgp_Array1OfPnt& Nodes = aPoly->Nodes();
+        for (i=1; i<=nbTriInFace; i++) {
+            // Get the triangle
+            Standard_Integer N1,N2,N3;
+            Triangles(i).Get(N1,N2,N3);
+
+            // change orientation of the triangles
+            if (orient != TopAbs_FORWARD) {
+                Standard_Integer tmp = N1;
+                N1 = N2;
+                N2 = tmp;
+            }
+
+            gp_Pnt V1 = Nodes(N1);
+            gp_Pnt V2 = Nodes(N2);
+            gp_Pnt V3 = Nodes(N3);
+
+            // transform the vertices to the place of the face
+            if (!identity) {
+                V1.Transform(myTransf);
+                V2.Transform(myTransf);
+                V3.Transform(myTransf);
+            }
+
+            // Calculate triangle normal
+            gp_Vec v1(V1.X(),V1.Y(),V1.Z()),v2(V2.X(),V2.Y(),V2.Z()),v3(V3.X(),V3.Y(),V3.Z());
+            gp_Vec Normal = (v2-v1)^(v3-v1);
+
+            //Standard_Real Area = 0.5 * Normal.Magnitude();
+
+            // add the triangle normal to the vertex normal for all points of this triangle
+            PointNormals[N1-1] += Base::Vector3d(Normal.X(),Normal.Y(),Normal.Z());
+            PointNormals[N2-1] += Base::Vector3d(Normal.X(),Normal.Y(),Normal.Z());
+            PointNormals[N3-1] += Base::Vector3d(Normal.X(),Normal.Y(),Normal.Z());
+
+            Points[N1-1].Set(V1.X(),V1.Y(),V1.Z());
+            Points[N2-1].Set(V2.X(),V2.Y(),V2.Z());
+            Points[N3-1].Set(V3.X(),V3.Y(),V3.Z());
+
+            int j = i - 1;
+            N1--;
+            N2--;
+            N3--;
+            faces[j].I1 = N1;
+            faces[j].I2 = N2;
+            faces[j].I3 = N3;
+        }
+
+        // normalize all vertex normals
+        for (i=0; i < nbNodesInFace; i++) {
+            gp_Dir clNormal;
+            try {
+                Handle_Geom_Surface Surface = BRep_Tool::Surface(TopoDS::Face(shape));
+
+                gp_Pnt vertex(Base::convertTo<gp_Pnt>(Points[i]));
+                GeomAPI_ProjectPointOnSurf ProPntSrf(vertex, Surface);
+                Standard_Real fU, fV;
+                ProPntSrf.Parameters(1, fU, fV);
+
+                GeomLProp_SLProps clPropOfFace(Surface, fU, fV, 2, gp::Resolution());
+
+                clNormal = clPropOfFace.Normal();
+                Base::Vector3d temp = Base::convertTo<Base::Vector3d>(clNormal);
+                if (temp * Points[i] < 0)
+                    temp = -temp;
+                Points[i] = temp;
+            }
+            catch (...) {
+            }
+            Points[i].Normalize();
+        }
+    }
+}
+
 TopoDS_Shape TopoShape::getSubShape(const char* Type) const
 {
     if (!Type) return TopoDS_Shape();
@@ -223,6 +375,28 @@ TopoDS_Shape TopoShape::getSubShape(const char* Type) const
     return TopoDS_Shape();
 }
 
+unsigned long TopoShape::countSubShapes(const char* Type) const
+{
+    std::string shapetype(Type);
+    if (shapetype == "Face") {
+        TopTools_IndexedMapOfShape anIndices;
+        TopExp::MapShapes(this->_Shape, TopAbs_FACE, anIndices);
+        return anIndices.Extent();
+    }
+    else if (shapetype == "Edge") {
+        TopTools_IndexedMapOfShape anIndices;
+        TopExp::MapShapes(this->_Shape, TopAbs_EDGE, anIndices);
+        return anIndices.Extent();
+    }
+    else if (shapetype == "Vertex") {
+        TopTools_IndexedMapOfShape anIndices;
+        TopExp::MapShapes(this->_Shape, TopAbs_VERTEX, anIndices);
+        return anIndices.Extent();
+    }
+
+    return 0;
+}
+
 PyObject * TopoShape::getPySubShape(const char* Type) const
 {
     // get the shape
@@ -353,6 +527,9 @@ void TopoShape::importIges(const char *FileName)
 {
     try {
         // read iges file
+        // http://www.opencascade.org/org/forum/thread_20801/
+        IGESControl_Controller::Init();
+        Interface_Static::SetIVal("read.surfacecurve.mode",3);
         IGESControl_Reader aReader;
         if (aReader.ReadFile((const Standard_CString)FileName) != IFSelect_RetDone)
             throw Base::Exception("Error in reading IGES");
@@ -598,7 +775,6 @@ void TopoShape::exportLineSet(std::ostream& str) const
     {
         const TopoDS_Edge& aEdge = TopoDS::Edge(M(i+1));
         gp_Trsf myTransf;
-        Standard_Boolean identity = true;
         TopLoc_Location aLoc;
 
         // try to triangulate the edge
@@ -610,7 +786,6 @@ void TopoShape::exportLineSet(std::ostream& str) const
         // triangulation succeeded?
         if (!aPoly.IsNull()) {
             if (!aLoc.IsIdentity()) {
-                identity = false;
                 myTransf = aLoc.Transformation();
             }
             nbNodesInFace = aPoly->NbNodes();
@@ -635,7 +810,6 @@ void TopoShape::exportLineSet(std::ostream& str) const
             // take the face's triangulation instead
             Handle(Poly_Triangulation) aPolyTria = BRep_Tool::Triangulation(aFace,aLoc);
             if (!aLoc.IsIdentity()) {
-                identity = false;
                 myTransf = aLoc.Transformation();
             }
 
@@ -854,6 +1028,184 @@ bool TopoShape::isValid() const
     return aChecker.IsValid() ? true : false;
 }
 
+bool TopoShape::analyze(std::ostream& str) const
+{
+    if (!this->_Shape.IsNull()) {
+        BRepCheck_Analyzer aChecker(this->_Shape);
+        if (!aChecker.IsValid()) {
+            std::vector<TopoDS_Shape> shapes;
+
+            TopTools_IndexedMapOfShape vertexOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_VERTEX, vertexOfShape);
+            for (int i = 1; i <= vertexOfShape.Extent();++i)
+                shapes.push_back(vertexOfShape(i));
+
+            TopTools_IndexedMapOfShape edgeOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_EDGE, edgeOfShape);
+            for (int i = 1; i <= edgeOfShape.Extent();++i)
+                shapes.push_back(edgeOfShape(i));
+
+            TopTools_IndexedMapOfShape wireOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_WIRE, wireOfShape);
+            for (int i = 1; i <= wireOfShape.Extent();++i)
+                shapes.push_back(wireOfShape(i));
+
+            TopTools_IndexedMapOfShape faceOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_FACE, faceOfShape);
+            for (int i = 1; i <= faceOfShape.Extent();++i)
+                shapes.push_back(faceOfShape(i));
+
+            TopTools_IndexedMapOfShape shellOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_SHELL, shellOfShape);
+            for (int i = 1; i <= shellOfShape.Extent();++i)
+                shapes.push_back(shellOfShape(i));
+
+            TopTools_IndexedMapOfShape solidOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_SOLID, solidOfShape);
+            for (int i = 1; i <= solidOfShape.Extent();++i)
+                shapes.push_back(solidOfShape(i));
+
+            TopTools_IndexedMapOfShape compOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_COMPOUND, compOfShape);
+            for (int i = 1; i <= compOfShape.Extent();++i)
+                shapes.push_back(compOfShape(i));
+
+            TopTools_IndexedMapOfShape compsOfShape;
+            TopExp::MapShapes(this->_Shape, TopAbs_COMPSOLID, compsOfShape);
+            for (int i = 1; i <= compsOfShape.Extent();++i)
+                shapes.push_back(compsOfShape(i));
+
+            for (std::vector<TopoDS_Shape>::iterator xp = shapes.begin(); xp != shapes.end(); ++xp) {
+                if (!aChecker.IsValid(*xp)) {
+                    const Handle_BRepCheck_Result& result = aChecker.Result(*xp);
+                    if (result.IsNull())
+                        continue;
+                    const BRepCheck_ListOfStatus& status = result->StatusOnShape(*xp);
+
+                    BRepCheck_ListIteratorOfListOfStatus it(status);
+                    while (it.More()) {
+                        BRepCheck_Status& val = it.Value();
+                        switch (val)
+                        {
+                        case BRepCheck_NoError:
+                            str << "No error" << std::endl;
+                            break;
+                        case BRepCheck_InvalidPointOnCurve:
+                            str << "Invalid point on curve" << std::endl;
+                            break;
+                        case BRepCheck_InvalidPointOnCurveOnSurface:
+                            str << "Invalid point on curve on surface" << std::endl;
+                            break;
+                        case BRepCheck_InvalidPointOnSurface:
+                            str << "Invalid point on surface" << std::endl;
+                            break;
+                        case BRepCheck_No3DCurve:
+                            str << "No 3D curve" << std::endl;
+                            break;
+                        case BRepCheck_Multiple3DCurve:
+                            str << "Multiple 3D curve" << std::endl;
+                            break;
+                        case BRepCheck_Invalid3DCurve:
+                            str << "Invalid 3D curve" << std::endl;
+                            break;
+                        case BRepCheck_NoCurveOnSurface:
+                            str << "No curve on surface" << std::endl;
+                            break;
+                        case BRepCheck_InvalidCurveOnSurface:
+                            str << "Invalid curve on surface" << std::endl;
+                            break;
+                        case BRepCheck_InvalidCurveOnClosedSurface:
+                            str << "Invalid curve on closed surface" << std::endl;
+                            break;
+                        case BRepCheck_InvalidSameRangeFlag:
+                            str << "Invalid same-range flag" << std::endl;
+                            break;
+                        case BRepCheck_InvalidSameParameterFlag:
+                            str << "Invalid same-parameter flag" << std::endl;
+                            break;
+                        case BRepCheck_InvalidDegeneratedFlag:
+                            str << "Invalid degenerated flag" << std::endl;
+                            break;
+                        case BRepCheck_FreeEdge:
+                            str << "Free edge" << std::endl;
+                            break;
+                        case BRepCheck_InvalidMultiConnexity:
+                            str << "Invalid multi-connexity" << std::endl;
+                            break;
+                        case BRepCheck_InvalidRange:
+                            str << "Invalid range" << std::endl;
+                            break;
+                        case BRepCheck_EmptyWire:
+                            str << "Empty wire" << std::endl;
+                            break;
+                        case BRepCheck_RedundantEdge:
+                            str << "Redundant edge" << std::endl;
+                            break;
+                        case BRepCheck_SelfIntersectingWire:
+                            str << "Self-intersecting wire" << std::endl;
+                            break;
+                        case BRepCheck_NoSurface:
+                            str << "No surface" << std::endl;
+                            break;
+                        case BRepCheck_InvalidWire:
+                            str << "Invalid wires" << std::endl;
+                            break;
+                        case BRepCheck_RedundantWire:
+                            str << "Redundant wires" << std::endl;
+                            break;
+                        case BRepCheck_IntersectingWires:
+                            str << "Intersecting wires" << std::endl;
+                            break;
+                        case BRepCheck_InvalidImbricationOfWires:
+                            str << "Invalid imbrication of wires" << std::endl;
+                            break;
+                        case BRepCheck_EmptyShell:
+                            str << "Empty shell" << std::endl;
+                            break;
+                        case BRepCheck_RedundantFace:
+                            str << "Redundant face" << std::endl;
+                            break;
+                        case BRepCheck_UnorientableShape:
+                            str << "Unorientable shape" << std::endl;
+                            break;
+                        case BRepCheck_NotClosed:
+                            str << "Not closed" << std::endl;
+                            break;
+                        case BRepCheck_NotConnected:
+                            str << "Not connected" << std::endl;
+                            break;
+                        case BRepCheck_SubshapeNotInShape:
+                            str << "Sub-shape not in shape" << std::endl;
+                            break;
+                        case BRepCheck_BadOrientation:
+                            str << "Bad orientation" << std::endl;
+                            break;
+                        case BRepCheck_BadOrientationOfSubshape:
+                            str << "Bad orientation of sub-shape" << std::endl;
+                            break;
+                        case BRepCheck_InvalidToleranceValue:
+                            str << "Invalid tolerance value" << std::endl;
+                            break;
+                        case BRepCheck_CheckFail:
+                            str << "Check failed" << std::endl;
+                            break;
+                        default:
+                            str << "Undetermined error" << std::endl;
+                            break;
+                        }
+
+                        it.Next();
+                    }
+                }
+            }
+
+            return false; // errors detected
+        }
+    }
+
+    return true;
+}
+
 bool TopoShape::isClosed() const
 {
     return BRep_Tool::IsClosed(this->_Shape) ? true : false;
@@ -877,6 +1229,12 @@ TopoDS_Shape TopoShape::fuse(TopoDS_Shape shape) const
     return mkFuse.Shape();
 }
 
+TopoDS_Shape TopoShape::oldFuse(TopoDS_Shape shape) const
+{
+    BRepAlgo_Fuse mkFuse(this->_Shape, shape);
+    return mkFuse.Shape();
+}
+
 TopoDS_Shape TopoShape::section(TopoDS_Shape shape) const
 {
     BRepAlgoAPI_Section mkSection(this->_Shape, shape);
@@ -925,7 +1283,9 @@ TopoDS_Shape TopoShape::makePipe(const TopoDS_Shape& profile) const
     return mkPipe.Shape();
 }
 
-TopoDS_Shape TopoShape::makePipeShell(const TopTools_ListOfShape& profiles, const Standard_Boolean make_solid) const
+TopoDS_Shape TopoShape::makePipeShell(const TopTools_ListOfShape& profiles,
+                                      const Standard_Boolean make_solid,
+                                      const Standard_Boolean isFrenet) const
 {
     if (this->_Shape.IsNull())
         Standard_Failure::Raise("Cannot sweep along empty spine");
@@ -933,6 +1293,7 @@ TopoDS_Shape TopoShape::makePipeShell(const TopTools_ListOfShape& profiles, cons
         Standard_Failure::Raise("Spine shape is not a wire");
 
     BRepOffsetAPI_MakePipeShell mkPipeShell(TopoDS::Wire(this->_Shape));
+    mkPipeShell.SetMode(isFrenet);
     TopTools_ListIteratorOfListOfShape it;
     for (it.Initialize(profiles); it.More(); it.Next()) {
         mkPipeShell.Add(TopoDS_Shape(it.Value()));
@@ -946,6 +1307,215 @@ TopoDS_Shape TopoShape::makePipeShell(const TopTools_ListOfShape& profiles, cons
     return mkPipeShell.Shape();
 }
 
+TopoDS_Shape TopoShape::makeTube(double radius, double tol) const
+{
+    // http://opencascade.blogspot.com/2009/11/surface-modeling-part3.html
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Cannot sweep along empty spine");
+    if (this->_Shape.ShapeType() != TopAbs_EDGE)
+        Standard_Failure::Raise("Spine shape is not an edge");
+
+    const TopoDS_Edge& path_edge = TopoDS::Edge(this->_Shape);
+    BRepAdaptor_Curve path_adapt(path_edge);
+    double umin = path_adapt.FirstParameter();
+    double umax = path_adapt.LastParameter();
+    Handle_Geom_Curve hPath = path_adapt.Curve().Curve();
+
+    // Apply placement of the shape to the curve
+    TopLoc_Location loc1 = path_edge.Location();
+    hPath = Handle_Geom_Curve::DownCast(hPath->Transformed(loc1.Transformation()));
+
+    if (hPath.IsNull())
+        Standard_Failure::Raise("Invalid curve in path edge");
+
+    GeomFill_Pipe mkTube(hPath, radius);
+    mkTube.Perform(tol, Standard_False, GeomAbs_C1, BSplCLib::MaxDegree(), 1000);
+
+    const Handle_Geom_Surface& surf = mkTube.Surface();
+    double u1,u2,v1,v2;
+    surf->Bounds(u1,u2,v1,v2);
+
+    BRepBuilderAPI_MakeFace mkBuilder(surf, umin, umax, v1, v2);
+    return mkBuilder.Face();
+}
+
+// for testing
+static Handle(Law_Function) CreateBsFunction (const Standard_Real theFirst, const Standard_Real theLast)
+{
+    //Handle_Law_BSpline aBs;
+    //Handle_Law_BSpFunc aFunc = new Law_BSpFunc (aBs, theFirst, theLast);
+    Handle_Law_Linear aFunc = new Law_Linear();
+    aFunc->Set(theFirst, 2.0, theLast, 3.0);
+    return aFunc;
+}
+
+// for testing
+TopoDS_Shape TopoShape::makeTube() const
+{
+    // http://opencascade.blogspot.com/2009/11/surface-modeling-part3.html
+    Standard_Real theTol = 0.001;
+    Standard_Boolean theIsPolynomial = Standard_True;
+    Standard_Boolean myIsElem = Standard_True;
+    GeomAbs_Shape theContinuity = GeomAbs_G1;
+    Standard_Integer theMaxDegree = 3;
+    Standard_Integer theMaxSegment = 1000;
+
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Cannot sweep along empty spine");
+    if (this->_Shape.ShapeType() != TopAbs_EDGE)
+        Standard_Failure::Raise("Spine shape is not an edge");
+
+    const TopoDS_Edge& path_edge = TopoDS::Edge(this->_Shape);
+    BRepAdaptor_Curve path_adapt(path_edge);
+
+    //circular profile
+    Handle(Geom_Circle) aCirc = new Geom_Circle (gp::XOY(), 1.0);
+    aCirc->Rotate (gp::OZ(), Standard_PI/2.);
+
+    //perpendicular section
+    Handle(BRepAdaptor_HCurve) myPath = new BRepAdaptor_HCurve(path_adapt);
+    Handle(Law_Function) myEvol = ::CreateBsFunction (myPath->FirstParameter(), myPath->LastParameter());
+    Handle(GeomFill_SectionLaw) aSec = new GeomFill_EvolvedSection(aCirc, myEvol);
+    Handle(GeomFill_LocationLaw) aLoc = new GeomFill_CurveAndTrihedron(new GeomFill_CorrectedFrenet);
+    aLoc->SetCurve (myPath);
+
+    GeomFill_Sweep mkSweep (aLoc, myIsElem);
+    mkSweep.SetTolerance (theTol);
+    mkSweep.Build (aSec, GeomFill_Location, theContinuity, theMaxDegree, theMaxSegment);
+    if (mkSweep.IsDone()) {
+        Handle_Geom_Surface mySurface = mkSweep.Surface();
+        Standard_Real myError = mkSweep.ErrorOnSurface();
+
+        Standard_Real u1,u2,v1,v2;
+        mySurface->Bounds(u1,u2,v1,v2);
+        BRepBuilderAPI_MakeFace mkBuilder(mySurface, u1, u2, v1, v2);
+        return mkBuilder.Shape();
+    }
+
+    return TopoDS_Shape();
+}
+
+TopoDS_Shape TopoShape::makeSweep(const TopoDS_Shape& profile, double tol, int fillMode) const
+{
+    // http://opencascade.blogspot.com/2009/10/surface-modeling-part2.html
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Cannot sweep along empty spine");
+    if (this->_Shape.ShapeType() != TopAbs_EDGE)
+        Standard_Failure::Raise("Spine shape is not an edge");
+
+    if (profile.IsNull())
+        Standard_Failure::Raise("Cannot sweep with empty profile");
+    if (profile.ShapeType() != TopAbs_EDGE)
+        Standard_Failure::Raise("Profile shape is not an edge");
+
+    const TopoDS_Edge& path_edge = TopoDS::Edge(this->_Shape);
+    const TopoDS_Edge& prof_edge = TopoDS::Edge(profile);
+
+    BRepAdaptor_Curve path_adapt(path_edge);
+    double umin = path_adapt.FirstParameter();
+    double umax = path_adapt.LastParameter();
+    Handle_Geom_Curve hPath = path_adapt.Curve().Curve();
+
+    // Apply placement of the shape to the curve
+    TopLoc_Location loc1 = path_edge.Location();
+    hPath = Handle_Geom_Curve::DownCast(hPath->Transformed(loc1.Transformation()));
+
+    if (hPath.IsNull())
+        Standard_Failure::Raise("invalid curve in path edge");
+
+    BRepAdaptor_Curve prof_adapt(prof_edge);
+    double vmin = prof_adapt.FirstParameter();
+    double vmax = prof_adapt.LastParameter();
+    Handle_Geom_Curve hProfile = prof_adapt.Curve().Curve();
+
+    // Apply placement of the shape to the curve
+    TopLoc_Location loc2 = prof_edge.Location();
+    hProfile = Handle_Geom_Curve::DownCast(hProfile->Transformed(loc2.Transformation()));
+
+    if (hProfile.IsNull())
+        Standard_Failure::Raise("invalid curve in profile edge");
+
+    GeomFill_Pipe mkSweep(hPath, hProfile, (GeomFill_Trihedron)fillMode);
+    mkSweep.GenerateParticularCase(Standard_True);
+    mkSweep.Perform(tol, Standard_False, GeomAbs_C1, BSplCLib::MaxDegree(), 1000);
+
+    const Handle_Geom_Surface& surf = mkSweep.Surface();
+    BRepBuilderAPI_MakeFace mkBuilder(surf, umin, umax, vmin, vmax);
+    return mkBuilder.Face();
+}
+
+TopoDS_Shape TopoShape::makeHelix(Standard_Real pitch, Standard_Real height,
+                                  Standard_Real radius, Standard_Real angle) const
+{
+        if (pitch < Precision::Confusion())
+            Standard_Failure::Raise("Pitch of helix too small");
+
+        if (height < Precision::Confusion())
+            Standard_Failure::Raise("Height of helix too small");
+
+        if (radius < Precision::Confusion())
+            Standard_Failure::Raise("Radius of helix too small");
+
+        gp_Ax2 cylAx2(gp_Pnt(0.0,0.0,0.0) , gp::DZ());
+        Handle_Geom_Surface surf;
+        if (angle < Precision::Confusion()) {
+            surf = new Geom_CylindricalSurface(cylAx2, radius);
+        }
+        else {
+            angle = Base::toRadians(angle);
+            if (angle < Precision::Confusion())
+                Standard_Failure::Raise("Angle of helix too small");
+            surf = new Geom_ConicalSurface(gp_Ax3(cylAx2), angle, radius);
+        }
+
+        gp_Pnt2d aPnt(0, 0);
+        gp_Dir2d aDir(2. * PI, pitch);
+        gp_Ax2d aAx2d(aPnt, aDir);
+
+        Handle(Geom2d_Line) line = new Geom2d_Line(aAx2d);
+        gp_Pnt2d beg = line->Value(0);
+        gp_Pnt2d end = line->Value(sqrt(4.0*PI*PI+pitch*pitch)*(height/pitch));
+        Handle(Geom2d_TrimmedCurve) segm = GCE2d_MakeSegment(beg , end);
+
+        TopoDS_Edge edgeOnSurf = BRepBuilderAPI_MakeEdge(segm , surf);
+        TopoDS_Wire wire = BRepBuilderAPI_MakeWire(edgeOnSurf);
+        BRepLib::BuildCurves3d(wire);
+        return wire;
+}
+
+TopoDS_Shape TopoShape::makeLoft(const TopTools_ListOfShape& profiles, 
+                                 Standard_Boolean isSolid,
+                                 Standard_Boolean isRuled) const
+{
+    // http://opencascade.blogspot.com/2010/01/surface-modeling-part5.html
+    BRepOffsetAPI_ThruSections aGenerator (isSolid,isRuled);
+
+    int countShapes = 0;
+    TopTools_ListIteratorOfListOfShape it;
+    for (it.Initialize(profiles); it.More(); it.Next()) {
+        const TopoDS_Shape& item = it.Value();
+        if (!item.IsNull() && item.ShapeType() == TopAbs_VERTEX) {
+            aGenerator.AddVertex(TopoDS::Vertex (item));
+            countShapes++;
+        }
+        else if (!item.IsNull() && item.ShapeType() == TopAbs_WIRE) {
+            aGenerator.AddWire(TopoDS::Wire (item));
+            countShapes++;
+        }
+    }
+
+    if (countShapes < 2)
+        Standard_Failure::Raise("Need at least two vertexes or wires to create loft face");
+
+    Standard_Boolean anIsCheck = Standard_True;
+    aGenerator.CheckCompatibility (anIsCheck);
+    aGenerator.Build();
+    if (!aGenerator.IsDone())
+        Standard_Failure::Raise("Failed to create loft face");
+
+    return aGenerator.Shape();
+}
+
 TopoDS_Shape TopoShape::makePrism(const gp_Vec& vec) const
 {
     if (this->_Shape.IsNull()) Standard_Failure::Raise("cannot sweep empty shape");
@@ -967,6 +1537,16 @@ TopoDS_Shape TopoShape::makeThickSolid(const TopTools_ListOfShape& remFace,
     return mkThick.Shape();
 }
 
+TopoDS_Shape TopoShape::makeOffset(double offset, double tol, bool intersection,
+                                   bool selfInter, short offsetMode, short join)
+{
+    BRepOffsetAPI_MakeOffsetShape mkOffset(this->_Shape, offset, tol, BRepOffset_Mode(offsetMode),
+        intersection ? Standard_True : Standard_False,
+        selfInter ? Standard_True : Standard_False,
+        GeomAbs_JoinType(join));
+    return mkOffset.Shape();
+}
+
 void TopoShape::transformGeometry(const Base::Matrix4D &rclMat)
 {
     this->_Shape = transformGShape(rclMat);
@@ -1080,58 +1660,74 @@ void TopoShape::sewShape()
 {
     //ShapeFix_Shape fixer(this->_Shape);
     //fixer.Perform();
-
     BRepBuilderAPI_Sewing sew;
-    sew.Add(this->_Shape/*fixer.Shape()*/);
+    sew.Load(this->_Shape/*fixer.Shape()*/);
     sew.Perform();
 
     //shape = ShapeUpgrade_ShellSewing().ApplySewing(shape);
     this->_Shape = sew.SewedShape();
 }
 
-bool TopoShape::fix()
+bool TopoShape::fix(double precision, double mintol, double maxtol)
 {
-    bool ret = false;
     if (this->_Shape.IsNull())
         return false;
+
     TopAbs_ShapeEnum type = this->_Shape.ShapeType();
+
+    ShapeFix_Shape fix(this->_Shape);
+    fix.SetPrecision(precision);
+    fix.SetMaxTolerance(mintol);
+    fix.SetMaxTolerance(maxtol);
+
+    fix.Perform();
+
     if (type == TopAbs_SOLID) {
-        ShapeFix_Solid fix(TopoDS::Solid(this->_Shape));
-        ret = fix.Perform() ? true : false;
-        this->_Shape = fix.Shape();
+        //fix.FixEdgeTool();
+        fix.FixWireTool()->Perform();
+        fix.FixFaceTool()->Perform();
+        fix.FixShellTool()->Perform();
+        fix.FixSolidTool()->Perform();
+        this->_Shape = fix.FixSolidTool()->Shape();
     }
     else if (type == TopAbs_SHELL) {
-        //ShapeAnalysis_Shell eval;
-        //eval.LoadShells(this->_Shape);
-        ShapeFix_Shell fix(TopoDS::Shell(this->_Shape));
-        ret = fix.Perform() ? true : false;
-        this->_Shape = fix.Shape();
+        fix.FixWireTool()->Perform();
+        fix.FixFaceTool()->Perform();
+        fix.FixShellTool()->Perform();
+        this->_Shape = fix.FixShellTool()->Shape();
     }
     else if (type == TopAbs_FACE) {
-        ShapeFix_Face fix(TopoDS::Face(this->_Shape));
-        ret = fix.Perform() ? true : false;
-        this->_Shape = fix.Result();
+        fix.FixWireTool()->Perform();
+        fix.FixFaceTool()->Perform();
+        this->_Shape = fix.Shape();
     }
     else {
-        ShapeFix_Shape fix(this->_Shape);
-        ret = fix.Perform() ? true : false;
         this->_Shape = fix.Shape();
     }
 
-    return ret;
+    return isValid();
+}
+
+bool TopoShape::removeInternalWires(double minArea)
+{
+    ShapeUpgrade_RemoveInternalWires fix(this->_Shape);
+    fix.MinArea() = minArea;
+    bool ok = fix.Perform() ? true : false;
+    this->_Shape = fix.GetResult();
+    return ok;
 }
 
 namespace Part {
-struct Vertex
+struct MeshVertex
 {
     Standard_Real x,y,z;
     Standard_Integer i;
 
-    Vertex(Standard_Real X, Standard_Real Y, Standard_Real Z)
+    MeshVertex(Standard_Real X, Standard_Real Y, Standard_Real Z)
         : x(X),y(Y),z(Z)
     {
     }
-    Vertex(const gp_Pnt& p)
+    MeshVertex(const gp_Pnt& p)
         : x(p.X()),y(p.Y()),z(p.Z())
     {
     }
@@ -1139,7 +1735,7 @@ struct Vertex
     gp_Pnt toPoint() const
     { return gp_Pnt(x,y,z); }
 
-    bool operator < (const Vertex &rclPt) const
+    bool operator < (const MeshVertex &rclPt) const
     {
         if (fabs ( this->x - rclPt.x) >= MESH_MIN_PT_DIST)
             return this->x < rclPt.x;
@@ -1157,18 +1753,20 @@ private:
 }
 
 //const double Vertex::MESH_MIN_PT_DIST = 1.0e-6;
-const double Vertex::MESH_MIN_PT_DIST = gp::Resolution();
+const double MeshVertex::MESH_MIN_PT_DIST = gp::Resolution();
 
 #include <StlTransfer.hxx>
 #include <StlMesh_Mesh.hxx>
 #include <StlMesh_MeshExplorer.hxx>
 
 void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
-                         std::vector<FacetTopo> &aTopo,
+                         std::vector<Facet> &aTopo,
                          float accuracy, uint16_t flags) const
 {
 #if 1
-    std::set<Vertex> vertices;
+    if (this->_Shape.IsNull())
+        return;
+    std::set<MeshVertex> vertices;
     Standard_Real x1, y1, z1;
     Standard_Real x2, y2, z2;
     Standard_Real x3, y3, z3;
@@ -1179,11 +1777,11 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
     for (Standard_Integer nbd=1;nbd<=aMesh->NbDomains();nbd++) {
         for (xp.InitTriangle (nbd); xp.MoreTriangle (); xp.NextTriangle ()) {
             xp.TriangleVertices (x1,y1,z1,x2,y2,z2,x3,y3,z3);
-            Data::ComplexGeoData::FacetTopo face;
-            std::set<Vertex>::iterator it;
+            Data::ComplexGeoData::Facet face;
+            std::set<MeshVertex>::iterator it;
 
             // 1st vertex
-            Vertex v1(x1,y1,z1);
+            MeshVertex v1(x1,y1,z1);
             it = vertices.find(v1);
             if (it == vertices.end()) {
                 v1.i = vertices.size();
@@ -1195,7 +1793,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
             }
 
             // 2nd vertex
-            Vertex v2(x2,y2,z2);
+            MeshVertex v2(x2,y2,z2);
             it = vertices.find(v2);
             if (it == vertices.end()) {
                 v2.i = vertices.size();
@@ -1207,7 +1805,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
             }
 
             // 3rd vertex
-            Vertex v3(x3,y3,z3);
+            MeshVertex v3(x3,y3,z3);
             it = vertices.find(v3);
             if (it == vertices.end()) {
                 v3.i = vertices.size();
@@ -1228,14 +1826,14 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
 
     std::vector<gp_Pnt> points;
     points.resize(vertices.size());
-    for (std::set<Vertex>::iterator it = vertices.begin(); it != vertices.end(); ++it)
+    for (std::set<MeshVertex>::iterator it = vertices.begin(); it != vertices.end(); ++it)
         points[it->i] = it->toPoint();
     for (std::vector<gp_Pnt>::iterator it = points.begin(); it != points.end(); ++it)
         aPoints.push_back(Base::Vector3d(it->X(),it->Y(),it->Z()));
 #endif
 #if 0
     BRepMesh::Mesh (this->_Shape, accuracy);
-    std::set<Vertex> vertices;
+    std::set<MeshVertex> vertices;
     for (TopExp_Explorer xp(this->_Shape,TopAbs_FACE); xp.More(); xp.Next()) {
         TopoDS_Face face = TopoDS::Face(xp.Current());
         TopAbs_Orientation orient = face.Orientation();
@@ -1274,13 +1872,13 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
                 if (reversed)
                     std::swap(V1,V2);
                 gp_Pnt P1, P2, P3;
-                Data::ComplexGeoData::FacetTopo face;
-                std::set<Vertex>::iterator it;
+                Data::ComplexGeoData::Facet face;
+                std::set<MeshVertex>::iterator it;
 
                 // 1st vertex
                 P1 = Nodes(V1);
                 P1.Transform(myTransf);
-                Vertex v1(P1);
+                MeshVertex v1(P1);
                 it = vertices.find(v1);
                 if (it == vertices.end()) {
                     v1.i = vertices.size();
@@ -1294,7 +1892,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
                 // 2nd vertex
                 P2 = Nodes(V2);
                 P2.Transform(myTransf);
-                Vertex v2(P2);
+                MeshVertex v2(P2);
                 it = vertices.find(v2);
                 if (it == vertices.end()) {
                     v2.i = vertices.size();
@@ -1308,7 +1906,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
                 // 3rd vertex
                 P3 = Nodes(V3);
                 P3.Transform(myTransf);
-                Vertex v3(P3);
+                MeshVertex v3(P3);
                 it = vertices.find(v3);
                 if (it == vertices.end()) {
                     v3.i = vertices.size();
@@ -1331,7 +1929,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
     }
 
     std::map<Standard_Integer,gp_Pnt> points;
-    for (std::set<Vertex>::iterator it = vertices.begin(); it != vertices.end(); ++it)
+    for (std::set<MeshVertex>::iterator it = vertices.begin(); it != vertices.end(); ++it)
         points[it->i] = it->toPoint();
     for (std::map<Standard_Integer,gp_Pnt>::iterator it = points.begin(); it != points.end(); ++it)
         aPoints.push_back(Base::Vector3d(it->second.X(),it->second.Y(),it->second.Z()));
@@ -1339,7 +1937,7 @@ void TopoShape::getFaces(std::vector<Base::Vector3d> &aPoints,
 }
 
 void TopoShape::setFaces(const std::vector<Base::Vector3d> &Points,
-                         const std::vector<FacetTopo> &Topo, float Accuracy)
+                         const std::vector<Facet> &Topo, float Accuracy)
 {
     gp_XYZ p1, p2, p3;
     TopoDS_Vertex Vertex1, Vertex2, Vertex3;
@@ -1357,7 +1955,7 @@ void TopoShape::setFaces(const std::vector<Base::Vector3d> &Points,
     BuildTool.MakeCompound(aComp);
 
     unsigned int ctPoints = Points.size();
-    for (std::vector<FacetTopo>::const_iterator it = Topo.begin(); it != Topo.end(); ++it) {
+    for (std::vector<Facet>::const_iterator it = Topo.begin(); it != Topo.end(); ++it) {
         if (it->I1 >= ctPoints || it->I2 >= ctPoints || it->I3 >= ctPoints)
             continue;
         x1 = Points[it->I1].x; y1 = Points[it->I1].y; z1 = Points[it->I1].z;
