@@ -23,6 +23,7 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <BRep_Builder.hxx>
 # include <BRep_Tool.hxx>
 # include <BRepTools.hxx>
 # include <BRepBuilderAPI_MakeFace.hxx>
@@ -50,6 +51,7 @@
 #endif
 
 #include <BRepTopAdaptor_FClass2d.hxx>
+#include <BRepPrimAPI_MakeHalfSpace.hxx>
 #include <BRepGProp.hxx>
 #include <GProp_GProps.hxx>
 #include <BRepLProp_SurfaceTool.hxx>
@@ -392,6 +394,35 @@ PyObject* TopoShapeFacePy::isPartOfDomain(PyObject *args)
     }
 }
 
+PyObject* TopoShapeFacePy::makeHalfSpace(PyObject *args)
+{
+    PyObject* pPnt;
+    if (!PyArg_ParseTuple(args, "O!",&(Base::VectorPy::Type),&pPnt))
+        return 0;
+
+    try {
+        Base::Vector3d pt = Py::Vector(pPnt,false).toVector();
+        BRepPrimAPI_MakeHalfSpace mkHS(TopoDS::Face(this->getTopoShapePtr()->_Shape), gp_Pnt(pt.x,pt.y,pt.z));
+        return new TopoShapeSolidPy(new TopoShape(mkHS.Solid()));
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return 0;
+    }
+}
+
+PyObject* TopoShapeFacePy::setTolerance(PyObject *args)
+{
+    double tol;
+    if (!PyArg_ParseTuple(args, "d", &tol))
+        return 0;
+    BRep_Builder aBuilder;
+    const TopoDS_Face& f = TopoDS::Face(getTopoShapePtr()->_Shape);
+    aBuilder.UpdateFace(f, tol);
+    Py_Return;
+}
+
 Py::Object TopoShapeFacePy::getSurface() const
 {
     const TopoDS_Face& f = TopoDS::Face(getTopoShapePtr()->_Shape);
