@@ -26,11 +26,10 @@
 # include <sstream>
 # include <BRepMesh.hxx>
 # include <BRepBuilderAPI_Copy.hxx>
-# include <BRepCheck_Analyzer.hxx>
-# include <BRepCheck_ListIteratorOfListOfStatus.hxx>
-# include <BRepCheck_Result.hxx>
+# include <BRepBuilderAPI_Sewing.hxx>
 # include <BRepClass3d_SolidClassifier.hxx>
 # include <BRepFilletAPI_MakeFillet.hxx>
+# include <BRepFilletAPI_MakeChamfer.hxx>
 # include <BRepOffsetAPI_MakePipe.hxx>
 # include <BRepOffsetAPI_MakePipeShell.hxx>
 # include <BRepTools.hxx>
@@ -44,6 +43,7 @@
 # include <TopoDS_Iterator.hxx>
 # include <TopTools_IndexedMapOfShape.hxx>
 # include <TopLoc_Location.hxx>
+# include <TopExp.hxx>
 # include <Precision.hxx>
 #endif
 
@@ -446,129 +446,10 @@ PyObject*  TopoShapePy::check(PyObject *args)
     if (!PyArg_ParseTuple(args, ""))
         return NULL;
     if (!getTopoShapePtr()->_Shape.IsNull()) {
-        BRepCheck_Analyzer aChecker(getTopoShapePtr()->_Shape);
-        if (!aChecker.IsValid()) {
-            TopoDS_Iterator it(getTopoShapePtr()->_Shape);
-            for (;it.More(); it.Next()) {
-                if (!aChecker.IsValid(it.Value())) {
-                    const Handle_BRepCheck_Result& result = aChecker.Result(it.Value());
-                    const BRepCheck_ListOfStatus& status = result->StatusOnShape(it.Value());
-
-                    BRepCheck_ListIteratorOfListOfStatus it(status);
-                    while (it.More()) {
-                        BRepCheck_Status& val = it.Value();
-                        switch (val)
-                        {
-                        case BRepCheck_NoError:
-                            PyErr_SetString(PyExc_StandardError, "No error");
-                            break;
-                        case BRepCheck_InvalidPointOnCurve:
-                            PyErr_SetString(PyExc_StandardError, "Invalid point on curve");
-                            break;
-                        case BRepCheck_InvalidPointOnCurveOnSurface:
-                            PyErr_SetString(PyExc_StandardError, "Invalid point on curve on surface");
-                            break;
-                        case BRepCheck_InvalidPointOnSurface:
-                            PyErr_SetString(PyExc_StandardError, "Invalid point on surface");
-                            break;
-                        case BRepCheck_No3DCurve:
-                            PyErr_SetString(PyExc_StandardError, "No 3D curve");
-                            break;
-                        case BRepCheck_Multiple3DCurve:
-                            PyErr_SetString(PyExc_StandardError, "Multiple 3D curve");
-                            break;
-                        case BRepCheck_Invalid3DCurve:
-                            PyErr_SetString(PyExc_StandardError, "Invalid 3D curve");
-                            break;
-                        case BRepCheck_NoCurveOnSurface:
-                            PyErr_SetString(PyExc_StandardError, "No curve on surface");
-                            break;
-                        case BRepCheck_InvalidCurveOnSurface:
-                            PyErr_SetString(PyExc_StandardError, "Invalid curve on surface");
-                            break;
-                        case BRepCheck_InvalidCurveOnClosedSurface:
-                            PyErr_SetString(PyExc_StandardError, "Invalid curve on closed surface");
-                            break;
-                        case BRepCheck_InvalidSameRangeFlag:
-                            PyErr_SetString(PyExc_StandardError, "Invalid same-range flag");
-                            break;
-                        case BRepCheck_InvalidSameParameterFlag:
-                            PyErr_SetString(PyExc_StandardError, "Invalid same-parameter flag");
-                            break;
-                        case BRepCheck_InvalidDegeneratedFlag:
-                            PyErr_SetString(PyExc_StandardError, "Invalid degenerated flag");
-                            break;
-                        case BRepCheck_FreeEdge:
-                            PyErr_SetString(PyExc_StandardError, "Free edge");
-                            break;
-                        case BRepCheck_InvalidMultiConnexity:
-                            PyErr_SetString(PyExc_StandardError, "Invalid multi-connexity");
-                            break;
-                        case BRepCheck_InvalidRange:
-                            PyErr_SetString(PyExc_StandardError, "Invalid range");
-                            break;
-                        case BRepCheck_EmptyWire:
-                            PyErr_SetString(PyExc_StandardError, "Empty wire");
-                            break;
-                        case BRepCheck_RedundantEdge:
-                            PyErr_SetString(PyExc_StandardError, "Redundant edge");
-                            break;
-                        case BRepCheck_SelfIntersectingWire:
-                            PyErr_SetString(PyExc_StandardError, "Self-intersecting wire");
-                            break;
-                        case BRepCheck_NoSurface:
-                            PyErr_SetString(PyExc_StandardError, "No surface");
-                            break;
-                        case BRepCheck_InvalidWire:
-                            PyErr_SetString(PyExc_StandardError, "Invalid wires");
-                            break;
-                        case BRepCheck_RedundantWire:
-                            PyErr_SetString(PyExc_StandardError, "Redundant wires");
-                            break;
-                        case BRepCheck_IntersectingWires:
-                            PyErr_SetString(PyExc_StandardError, "Intersecting wires");
-                            break;
-                        case BRepCheck_InvalidImbricationOfWires:
-                            PyErr_SetString(PyExc_StandardError, "Invalid imbrication of wires");
-                            break;
-                        case BRepCheck_EmptyShell:
-                            PyErr_SetString(PyExc_StandardError, "Empty shell");
-                            break;
-                        case BRepCheck_RedundantFace:
-                            PyErr_SetString(PyExc_StandardError, "Redundant face");
-                            break;
-                        case BRepCheck_UnorientableShape:
-                            PyErr_SetString(PyExc_StandardError, "Unorientable shape");
-                            break;
-                        case BRepCheck_NotClosed:
-                            PyErr_SetString(PyExc_StandardError, "Not closed");
-                            break;
-                        case BRepCheck_NotConnected:
-                            PyErr_SetString(PyExc_StandardError, "Not connected");
-                            break;
-                        case BRepCheck_SubshapeNotInShape:
-                            PyErr_SetString(PyExc_StandardError, "Sub-shape not in shape");
-                            break;
-                        case BRepCheck_BadOrientation:
-                            PyErr_SetString(PyExc_StandardError, "Bad orientation");
-                            break;
-                        case BRepCheck_BadOrientationOfSubshape:
-                            PyErr_SetString(PyExc_StandardError, "Bad orientation of sub-shape");
-                            break;
-                        case BRepCheck_InvalidToleranceValue:
-                            PyErr_SetString(PyExc_StandardError, "Invalid tolerance value");
-                            break;
-                        case BRepCheck_CheckFail:
-                            PyErr_SetString(PyExc_StandardError, "Check failed");
-                            break;
-                        }
-
-                        if (PyErr_Occurred())
-                            PyErr_Print();
-                        it.Next();
-                    }
-                }
-            }
+        std::stringstream str;
+        if (!getTopoShapePtr()->analyze(str)) {
+            PyErr_SetString(PyExc_StandardError, str.str().c_str());
+            PyErr_Print();
         }
     }
 
@@ -598,6 +479,29 @@ PyObject*  TopoShapePy::fuse(PyObject *args)
     }
 }
 
+PyObject*  TopoShapePy::oldFuse(PyObject *args)
+{
+    PyObject *pcObj;
+    if (!PyArg_ParseTuple(args, "O!", &(TopoShapePy::Type), &pcObj))
+        return NULL;
+
+    TopoDS_Shape shape = static_cast<TopoShapePy*>(pcObj)->getTopoShapePtr()->_Shape;
+    try {
+        // Let's call algorithm computing a fuse operation:
+        TopoDS_Shape fusShape = this->getTopoShapePtr()->oldFuse(shape);
+        return new TopoShapePy(new TopoShape(fusShape));
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return NULL;
+    }
+    catch (const std::exception& e) {
+        PyErr_SetString(PyExc_Exception, e.what());
+        return NULL;
+    }
+}
+
 PyObject*  TopoShapePy::common(PyObject *args)
 {
     PyObject *pcObj;
@@ -739,6 +643,25 @@ PyObject*  TopoShapePy::sewShape(PyObject *args)
     }
 }
 
+PyObject*  TopoShapePy::removeInternalWires(PyObject *args)
+{
+    double minArea;
+    if (!PyArg_ParseTuple(args, "d",&minArea))
+        return NULL;
+
+    try {
+        bool ok = getTopoShapePtr()->removeInternalWires(minArea);
+        PyObject* ret = ok ? Py_True : Py_False;
+        Py_INCREF(ret);
+        return ret;
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return NULL;
+    }
+}
+
 PyObject*  TopoShapePy::mirror(PyObject *args)
 {
     PyObject *v1, *v2;
@@ -945,6 +868,76 @@ PyObject* TopoShapePy::makeFillet(PyObject *args)
     return NULL;
 }
 
+PyObject* TopoShapePy::makeChamfer(PyObject *args)
+{
+    // use one radius for all edges
+    double radius;
+    PyObject *obj;
+    if (PyArg_ParseTuple(args, "dO!", &radius, &(PyList_Type), &obj)) {
+        try {
+            const TopoDS_Shape& shape = this->getTopoShapePtr()->_Shape;
+            BRepFilletAPI_MakeChamfer mkChamfer(shape);
+            TopTools_IndexedMapOfShape mapOfEdges;
+            TopTools_IndexedDataMapOfShapeListOfShape mapEdgeFace;
+            TopExp::MapShapesAndAncestors(shape, TopAbs_EDGE, TopAbs_FACE, mapEdgeFace);
+            TopExp::MapShapes(shape, TopAbs_EDGE, mapOfEdges);
+            Py::List list(obj);
+            for (Py::List::iterator it = list.begin(); it != list.end(); ++it) {
+                if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapePy::Type))) {
+                    const TopoDS_Shape& edge = static_cast<TopoShapePy*>((*it).ptr())->getTopoShapePtr()->_Shape;
+                    if (edge.ShapeType() == TopAbs_EDGE) {
+                        //Add edge to fillet algorithm
+                        const TopoDS_Face& face = TopoDS::Face(mapEdgeFace.FindFromKey(edge).First());
+                        mkChamfer.Add(radius, TopoDS::Edge(edge), face);
+                    }
+                }
+            }
+            return new TopoShapePy(new TopoShape(mkChamfer.Shape()));
+        }
+        catch (Standard_Failure) {
+            Handle_Standard_Failure e = Standard_Failure::Caught();
+            PyErr_SetString(PyExc_Exception, e->GetMessageString());
+            return NULL;
+        }
+    }
+
+    // use two radii for all edges
+    PyErr_Clear();
+    double radius1, radius2;
+    if (PyArg_ParseTuple(args, "ddO!", &radius1, &radius2, &(PyList_Type), &obj)) {
+        try {
+            const TopoDS_Shape& shape = this->getTopoShapePtr()->_Shape;
+            BRepFilletAPI_MakeChamfer mkChamfer(shape);
+            TopTools_IndexedMapOfShape mapOfEdges;
+            TopTools_IndexedDataMapOfShapeListOfShape mapEdgeFace;
+            TopExp::MapShapesAndAncestors(shape, TopAbs_EDGE, TopAbs_FACE, mapEdgeFace);
+            TopExp::MapShapes(shape, TopAbs_EDGE, mapOfEdges);
+            Py::List list(obj);
+            for (Py::List::iterator it = list.begin(); it != list.end(); ++it) {
+                if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapePy::Type))) {
+                    const TopoDS_Shape& edge = static_cast<TopoShapePy*>((*it).ptr())->getTopoShapePtr()->_Shape;
+                    if (edge.ShapeType() == TopAbs_EDGE) {
+                        //Add edge to fillet algorithm
+                        const TopoDS_Face& face = TopoDS::Face(mapEdgeFace.FindFromKey(edge).First());
+                        mkChamfer.Add(radius1, radius2, TopoDS::Edge(edge), face);
+                    }
+                }
+            }
+            return new TopoShapePy(new TopoShape(mkChamfer.Shape()));
+        }
+        catch (Standard_Failure) {
+            Handle_Standard_Failure e = Standard_Failure::Caught();
+            PyErr_SetString(PyExc_Exception, e->GetMessageString());
+            return NULL;
+        }
+    }
+
+    PyErr_SetString(PyExc_TypeError, "This method accepts:\n"
+        "-- one radius and a list of edges\n"
+        "-- two radii and a list of edges");
+    return NULL;
+}
+
 PyObject* TopoShapePy::makeThickness(PyObject *args)
 {
     PyObject *obj;
@@ -972,6 +965,31 @@ PyObject* TopoShapePy::makeThickness(PyObject *args)
     }
 }
 
+PyObject* TopoShapePy::makeOffsetShape(PyObject *args)
+{
+    double offset, tolerance;
+    PyObject* inter = Py_False;
+    PyObject* self_inter = Py_False;
+    short offsetMode = 0, join = 0;
+    if (!PyArg_ParseTuple(args, "dd|O!O!hh",
+        &offset, &tolerance,
+        &(PyBool_Type), &inter,
+        &(PyBool_Type), &self_inter,
+        &offsetMode, &join))
+        return 0;
+
+    try {
+        TopoDS_Shape shape = this->getTopoShapePtr()->makeOffset(offset, tolerance,
+            (inter == Py_True), (self_inter == Py_True), offsetMode, join);
+        return new TopoShapePy(new TopoShape(shape));
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return NULL;
+    }
+}
+
 PyObject*  TopoShapePy::reverse(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
@@ -1055,6 +1073,20 @@ PyObject*  TopoShapePy::isValid(PyObject *args)
     }
 }
 
+PyObject*  TopoShapePy::fix(PyObject *args)
+{
+    double prec, mintol, maxtol;
+    if (!PyArg_ParseTuple(args, "ddd", &prec, &mintol, &maxtol))
+        return NULL;
+    try {
+        return Py_BuildValue("O", (getTopoShapePtr()->fix(prec, mintol, maxtol) ? Py_True : Py_False));
+    }
+    catch (...) {
+        PyErr_SetString(PyExc_RuntimeError, "check failed, shape may be empty");
+        return NULL;
+    }
+}
+
 PyObject* TopoShapePy::hashCode(PyObject *args)
 {
     int upper = IntegerLast();
@@ -1071,7 +1103,7 @@ PyObject* TopoShapePy::tessellate(PyObject *args)
         if (!PyArg_ParseTuple(args, "f",&tolerance))
             return 0;
         std::vector<Base::Vector3d> Points;
-        std::vector<Data::ComplexGeoData::FacetTopo> Facets;
+        std::vector<Data::ComplexGeoData::Facet> Facets;
         getTopoShapePtr()->getFaces(Points, Facets,tolerance);
         Py::Tuple tuple(2);
         Py::List vertex;
@@ -1080,7 +1112,7 @@ PyObject* TopoShapePy::tessellate(PyObject *args)
             vertex.append(Py::Object(new Base::VectorPy(*it)));
         tuple.setItem(0, vertex);
         Py::List facet;
-        for (std::vector<Data::ComplexGeoData::FacetTopo>::const_iterator
+        for (std::vector<Data::ComplexGeoData::Facet>::const_iterator
             it = Facets.begin(); it != Facets.end(); ++it) {
             Py::Tuple f(3);
             f.setItem(0,Py::Int((int)it->I1));
@@ -1147,9 +1179,9 @@ PyObject* TopoShapePy::makeShapeFromMesh(PyObject *args)
             Py::Vector vec(*it);
             Points.push_back(vec.toVector());
         }
-        std::vector<Data::ComplexGeoData::FacetTopo> Facets;
+        std::vector<Data::ComplexGeoData::Facet> Facets;
         for (Py::List::iterator it = facets.begin(); it != facets.end(); ++it) {
-            Data::ComplexGeoData::FacetTopo face;
+            Data::ComplexGeoData::Facet face;
             Py::Tuple f(*it);
             face.I1 = (int)Py::Int(f[0]);
             face.I2 = (int)Py::Int(f[1]);
