@@ -26,17 +26,24 @@
 # include <gp_Ax1.hxx>
 # include <BRep_Builder.hxx>
 # include <BRepCheck_Analyzer.hxx>
+# include <TopoDS.hxx>
 # include <TopoDS_Shell.hxx>
 # include <ShapeUpgrade_ShellSewing.hxx>
+# include <ShapeAnalysis_Shell.hxx>
 #endif
 
+#include <BRepPrimAPI_MakeHalfSpace.hxx>
+
 #include <Base/VectorPy.h>
+#include <Base/GeometryPyCXX.h>
 
 #include "TopoShape.h"
+#include "TopoShapeCompoundPy.h"
 #include "TopoShapeCompSolidPy.h"
 #include "TopoShapeFacePy.h"
 #include "TopoShapeShellPy.h"
 #include "TopoShapeShellPy.cpp"
+#include "TopoShapeSolidPy.h"
 
 using namespace Part;
 
@@ -136,6 +143,54 @@ PyObject*  TopoShapeShellPy::add(PyObject *args)
     Py_Return;
 }
 
+PyObject*  TopoShapeShellPy::getFreeEdges(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return NULL;
+    ShapeAnalysis_Shell as;
+    as.LoadShells(getTopoShapePtr()->_Shape);
+#if OCC_HEX_VERSION < 0x060500
+    as.CheckOrientedShells(getTopoShapePtr()->_Shape, Standard_True);
+#else
+    as.CheckOrientedShells(getTopoShapePtr()->_Shape, Standard_True, Standard_True);
+#endif
+    TopoDS_Compound comp = as.FreeEdges();
+    return new TopoShapeCompoundPy(new TopoShape(comp));
+}
+
+PyObject*  TopoShapeShellPy::getBadEdges(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return NULL;
+    ShapeAnalysis_Shell as;
+    as.LoadShells(getTopoShapePtr()->_Shape);
+#if OCC_HEX_VERSION < 0x060500
+    as.CheckOrientedShells(getTopoShapePtr()->_Shape, Standard_True);
+#else
+    as.CheckOrientedShells(getTopoShapePtr()->_Shape, Standard_True, Standard_True);
+#endif
+    TopoDS_Compound comp = as.BadEdges();
+    return new TopoShapeCompoundPy(new TopoShape(comp));
+}
+
+PyObject* TopoShapeShellPy::makeHalfSpace(PyObject *args)
+{
+    PyObject* pPnt;
+    if (!PyArg_ParseTuple(args, "O!",&(Base::VectorPy::Type),&pPnt))
+        return 0;
+
+    try {
+        Base::Vector3d pt = Py::Vector(pPnt,false).toVector();
+        BRepPrimAPI_MakeHalfSpace mkHS(TopoDS::Face(this->getTopoShapePtr()->_Shape), gp_Pnt(pt.x,pt.y,pt.z));
+        return new TopoShapeSolidPy(new TopoShape(mkHS.Solid()));
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return 0;
+    }
+}
+
 PyObject *TopoShapeShellPy::getCustomAttributes(const char* /*attr*/) const
 {
     return 0;
