@@ -57,6 +57,8 @@
 #include "CrossSections.h"
 #include "Mirroring.h"
 #include "ViewProvider.h"
+#include "TaskShapeBuilder.h"
+#include "TaskLoft.h"
 
 
 //++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -76,7 +78,6 @@ CmdPartPickCurveNet::CmdPartPickCurveNet()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Test1";
-    iAccel        = 0;
 }
 
 void CmdPartPickCurveNet::activated(int iMsg)
@@ -99,7 +100,6 @@ CmdPartNewDoc::CmdPartNewDoc()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "New";
-    iAccel        = 0;
 }
 
 void CmdPartNewDoc::activated(int iMsg)
@@ -123,7 +123,6 @@ CmdPartBox2::CmdPartBox2()
     sWhatsThis    = "Part_Box2";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Box";
-    iAccel        = 0;
 }
 
 
@@ -165,7 +164,6 @@ CmdPartBox3::CmdPartBox3()
     sWhatsThis    = "Part_Box3";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Box";
-    iAccel        = 0;
 }
 
 void CmdPartBox3::activated(int iMsg)
@@ -205,8 +203,7 @@ CmdPartPrimitives::CmdPartPrimitives()
     sToolTipText  = QT_TR_NOOP("Creation of parametrized geometric primitives");
     sWhatsThis    = "Part_Primitives";
     sStatusTip    = sToolTipText;
-    //sPixmap       = "Part_Box";
-    iAccel        = 0;
+    sPixmap       = "Part_CreatePrimitives";
 }
 
 void CmdPartPrimitives::activated(int iMsg)
@@ -238,7 +235,6 @@ CmdPartCut::CmdPartCut()
     sWhatsThis    = "Part_Cut";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Cut";
-    iAccel        = 0;
 }
 
 void CmdPartCut::activated(int iMsg)
@@ -262,6 +258,7 @@ void CmdPartCut::activated(int iMsg)
     doCommand(Doc,"App.activeDocument().%s.Tool = App.activeDocument().%s",FeatName.c_str(),ToolName.c_str());
     doCommand(Gui,"Gui.activeDocument().hide('%s')",BaseName.c_str());
     doCommand(Gui,"Gui.activeDocument().hide('%s')",ToolName.c_str());
+    doCommand(Gui,"Gui.activeDocument().%s.ShapeColor = Gui.activeDocument().%s.ShapeColor", FeatName.c_str(),BaseName.c_str());
     updateActive();
     commitCommand();
 }
@@ -286,7 +283,6 @@ CmdPartCommon::CmdPartCommon()
     sWhatsThis    = "Part_Common";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Common";
-    iAccel        = 0;
 }
 
 void CmdPartCommon::activated(int iMsg)
@@ -314,6 +310,7 @@ void CmdPartCommon::activated(int iMsg)
     doCommand(Doc,"App.activeDocument().%s.Shapes = [%s]",FeatName.c_str(),ObjectBuf.c_str());
     for (std::vector<std::string>::iterator it = tempSelNames.begin(); it != tempSelNames.end(); ++it)
         doCommand(Gui,"Gui.activeDocument().%s.Visibility=False",it->c_str());
+    doCommand(Gui,"Gui.activeDocument().%s.ShapeColor = Gui.activeDocument().%s.ShapeColor", FeatName.c_str(),tempSelNames.front().c_str());
     updateActive();
     commitCommand();
 }
@@ -338,7 +335,6 @@ CmdPartFuse::CmdPartFuse()
     sWhatsThis    = "Part_Fuse";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Fuse";
-    iAccel        = 0;
 }
 
 void CmdPartFuse::activated(int iMsg)
@@ -366,6 +362,7 @@ void CmdPartFuse::activated(int iMsg)
     doCommand(Doc,"App.activeDocument().%s.Shapes = [%s]",FeatName.c_str(),ObjectBuf.c_str());
     for (std::vector<std::string>::iterator it = tempSelNames.begin(); it != tempSelNames.end(); ++it)
         doCommand(Gui,"Gui.activeDocument().%s.Visibility=False",it->c_str());
+    doCommand(Gui,"Gui.activeDocument().%s.ShapeColor = Gui.activeDocument().%s.ShapeColor", FeatName.c_str(),tempSelNames.front().c_str());
     updateActive();
     commitCommand();
 }
@@ -390,7 +387,6 @@ CmdPartSection::CmdPartSection()
     sWhatsThis    = "Part_Section";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Section";
-    iAccel        = 0;
 }
 
 
@@ -403,16 +399,18 @@ void CmdPartSection::activated(int iMsg)
         return;
     }
 
-    std::string FeatName = getUniqueObjectName("Section");
-
     std::vector<Gui::SelectionSingleton::SelObj> Sel = getSelection().getSelection();
+    std::string FeatName = getUniqueObjectName("Section");
+    std::string BaseName  = Sel[0].FeatName;
+    std::string ToolName  = Sel[1].FeatName;
 
     openCommand("Section");
     doCommand(Doc,"App.activeDocument().addObject(\"Part::Section\",\"%s\")",FeatName.c_str());
-    doCommand(Doc,"App.activeDocument().%s.Base = App.activeDocument().%s",FeatName.c_str(),Sel[0].FeatName);
-    doCommand(Doc,"App.activeDocument().%s.Tool = App.activeDocument().%s",FeatName.c_str(),Sel[1].FeatName);
-    doCommand(Gui,"Gui.activeDocument().hide('%s')",Sel[0].FeatName);
-    doCommand(Gui,"Gui.activeDocument().hide('%s')",Sel[1].FeatName);
+    doCommand(Doc,"App.activeDocument().%s.Base = App.activeDocument().%s",FeatName.c_str(),BaseName.c_str());
+    doCommand(Doc,"App.activeDocument().%s.Tool = App.activeDocument().%s",FeatName.c_str(),ToolName.c_str());
+    doCommand(Gui,"Gui.activeDocument().hide('%s')",BaseName.c_str());
+    doCommand(Gui,"Gui.activeDocument().hide('%s')",ToolName.c_str());
+    doCommand(Gui,"Gui.activeDocument().%s.LineColor = Gui.activeDocument().%s.ShapeColor", FeatName.c_str(),BaseName.c_str());
     updateActive();
     commitCommand();
 }
@@ -437,7 +435,6 @@ CmdPartImport::CmdPartImport()
     sWhatsThis    = "Part_Import";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Import";
-    iAccel        = 0;
 }
 
 
@@ -454,9 +451,19 @@ void CmdPartImport::activated(int iMsg)
     if (!fn.isEmpty()) {
         App::Document* pDoc = getDocument();
         if (!pDoc) return; // no document
-        openCommand("Part Import Create");
-        doCommand(Doc, "import Part");
-        doCommand(Doc, "Part.insert(\"%s\",\"%s\")", (const char*)fn.toAscii(), pDoc->getName());
+        openCommand("Import Part");
+        QString ext = QFileInfo(fn).suffix().toLower();
+        if (ext == QLatin1String("step") || 
+            ext == QLatin1String("stp")  ||
+            ext == QLatin1String("iges") ||
+            ext == QLatin1String("igs")) {
+            doCommand(Doc, "import ImportGui");
+            doCommand(Doc, "ImportGui.insert(\"%s\",\"%s\")", (const char*)fn.toUtf8(), pDoc->getName());
+        }
+        else {
+            doCommand(Doc, "import Part");
+            doCommand(Doc, "Part.insert(\"%s\",\"%s\")", (const char*)fn.toUtf8(), pDoc->getName());
+        }
         commitCommand();
     }
 }
@@ -469,6 +476,56 @@ bool CmdPartImport::isActive(void)
         return false;
 }
 
+//===========================================================================
+// CmdPartExport
+//===========================================================================
+DEF_STD_CMD_A(CmdPartExport);
+
+CmdPartExport::CmdPartExport()
+  : Command("Part_Export")
+{
+    sAppModule    = "Part";
+    sGroup        = QT_TR_NOOP("Part");
+    sMenuText     = QT_TR_NOOP("Export CAD...");
+    sToolTipText  = QT_TR_NOOP("Exports to a CAD file");
+    sWhatsThis    = "Part_Export";
+    sStatusTip    = sToolTipText;
+  //sPixmap       = "Part_Export";
+}
+
+void CmdPartExport::activated(int iMsg)
+{
+    QStringList filter;
+    filter << QObject::tr("All CAD Files (*.stp *.step *.igs *.iges *.brp *.brep)");
+    filter << QObject::tr("STEP (*.stp *.step)");
+    filter << QObject::tr("IGES (*.igs *.iges)");
+    filter << QObject::tr("BREP (*.brp *.brep)");
+    filter << QObject::tr("All Files (*.*)");
+
+    QString fn = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(), QString(), QString(), filter.join(QLatin1String(";;")));
+    if (!fn.isEmpty()) {
+        App::Document* pDoc = getDocument();
+        if (!pDoc) return; // no document
+        openCommand("Import Part");
+        QString ext = QFileInfo(fn).suffix().toLower();
+        if (ext == QLatin1String("step") || 
+            ext == QLatin1String("stp")  ||
+            ext == QLatin1String("iges") ||
+            ext == QLatin1String("igs")) {
+            Gui::Application::Instance->exportTo((const char*)fn.toUtf8(),pDoc->getName(),"ImportGui");
+        }
+        else {
+            Gui::Application::Instance->exportTo((const char*)fn.toUtf8(),pDoc->getName(),"Part");
+        }
+        commitCommand();
+    }
+}
+
+bool CmdPartExport::isActive(void)
+{
+    return Gui::Selection().countObjectsOfType(Part::Feature::getClassTypeId()) > 0;
+}
+
 //===========================================================================
 // PartImportCurveNet
 //===========================================================================
@@ -484,7 +541,6 @@ CmdPartImportCurveNet::CmdPartImportCurveNet()
     sWhatsThis  = "Part_ImportCurveNet";
     sStatusTip  = sToolTipText;
     sPixmap     = "Part_Box";
-    iAccel      = 0;
 }
 
 void CmdPartImportCurveNet::activated(int iMsg)
@@ -529,7 +585,6 @@ CmdPartMakeSolid::CmdPartMakeSolid()
     sToolTipText  = QT_TR_NOOP("Create solid from a shell or compound");
     sWhatsThis    = "Part_MakeSolid";
     sStatusTip    = sToolTipText;
-    iAccel        = 0;
 }
 
 void CmdPartMakeSolid::activated(int iMsg)
@@ -607,7 +662,6 @@ CmdPartReverseShape::CmdPartReverseShape()
     sToolTipText  = QT_TR_NOOP("Reverse orientation of shapes");
     sWhatsThis    = "Part_ReverseShape";
     sStatusTip    = sToolTipText;
-    iAccel        = 0;
 }
 
 void CmdPartReverseShape::activated(int iMsg)
@@ -619,7 +673,7 @@ void CmdPartReverseShape::activated(int iMsg)
         const TopoDS_Shape& shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
         if (!shape.IsNull()) {
             QString str = QString::fromAscii(
-                "__s__=App.ActiveDocument.%1.Shape\n"
+                "__s__=App.ActiveDocument.%1.Shape.copy()\n"
                 "__s__.reverse()\n"
                 "__o__=App.ActiveDocument.addObject(\"Part::Feature\",\"%1_rev\")\n"
                 "__o__.Label=\"%2 (Rev)\"\n"
@@ -662,7 +716,6 @@ CmdPartBoolean::CmdPartBoolean()
     sWhatsThis    = "Part_Boolean";
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Booleans";
-    iAccel        = 0;
 }
 
 void CmdPartBoolean::activated(int iMsg)
@@ -693,7 +746,6 @@ CmdPartExtrude::CmdPartExtrude()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Extrude";
-    iAccel        = 0;
 }
 
 void CmdPartExtrude::activated(int iMsg)
@@ -721,7 +773,6 @@ CmdPartRevolve::CmdPartRevolve()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Revolve";
-    iAccel        = 0;
 }
 
 void CmdPartRevolve::activated(int iMsg)
@@ -749,7 +800,6 @@ CmdPartFillet::CmdPartFillet()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Fillet";
-    iAccel        = 0;
 }
 
 void CmdPartFillet::activated(int iMsg)
@@ -777,7 +827,6 @@ CmdPartMirror::CmdPartMirror()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_MirrorPNG";
-    iAccel        = 0;
 }
 
 void CmdPartMirror::activated(int iMsg)
@@ -805,7 +854,6 @@ CmdPartCrossSections::CmdPartCrossSections()
     sWhatsThis    = "Part_CrossSections";
     sStatusTip    = sToolTipText;
 //  sPixmap       = "Part_Booleans";
-    iAccel        = 0;
 }
 
 void CmdPartCrossSections::activated(int iMsg)
@@ -831,6 +879,57 @@ bool CmdPartCrossSections::isActive(void)
 
 //--------------------------------------------------------------------------------------
 
+DEF_STD_CMD_A(CmdPartBuilder);
+
+CmdPartBuilder::CmdPartBuilder()
+  :Command("Part_Builder")
+{
+    sAppModule    = "Part";
+    sGroup        = QT_TR_NOOP("Part");
+    sMenuText     = QT_TR_NOOP("Shape builder...");
+    sToolTipText  = QT_TR_NOOP("Advanced utility to create shapes");
+    sWhatsThis    = sToolTipText;
+    sStatusTip    = sToolTipText;
+    sPixmap       = "Part_Shapebuilder";
+}
+
+void CmdPartBuilder::activated(int iMsg)
+{
+    Gui::Control().showDialog(new PartGui::TaskShapeBuilder());
+}
+
+bool CmdPartBuilder::isActive(void)
+{
+    return (hasActiveDocument() && !Gui::Control().activeDialog());
+}
+
+//--------------------------------------------------------------------------------------
+
+DEF_STD_CMD_A(CmdPartLoft);
+
+CmdPartLoft::CmdPartLoft()
+  : Command("Part_Loft")
+{
+    sAppModule    = "Part";
+    sGroup        = QT_TR_NOOP("Part");
+    sMenuText     = QT_TR_NOOP("Loft...");
+    sToolTipText  = QT_TR_NOOP("Advanced utility to lofts");
+    sWhatsThis    = sToolTipText;
+    sStatusTip    = sToolTipText;
+}
+
+void CmdPartLoft::activated(int iMsg)
+{
+    Gui::Control().showDialog(new PartGui::TaskLoft());
+}
+
+bool CmdPartLoft::isActive(void)
+{
+    return (hasActiveDocument() && !Gui::Control().activeDialog());
+}
+
+//--------------------------------------------------------------------------------------
+
 DEF_STD_CMD_A(CmdShapeInfo);
 
 CmdShapeInfo::CmdShapeInfo()
@@ -842,6 +941,7 @@ CmdShapeInfo::CmdShapeInfo()
     sToolTipText  = "Info about shape";
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
+    sPixmap       = "Part_ShapeInfo";
 }
 
 void CmdShapeInfo::activated(int iMsg)
@@ -900,12 +1000,12 @@ void CmdShapeInfo::activated(int iMsg)
 
     Gui::Document* doc = Gui::Application::Instance->activeDocument();
     Gui::View3DInventor* view = static_cast<Gui::View3DInventor*>(doc->getActiveView());
-    if (view) {
-        Gui::View3DInventorViewer* viewer = view->getViewer();
-        viewer->setEditing(true);
-        viewer->getWidget()->setCursor(QCursor(QPixmap(part_pipette),4,29));
-        viewer->addEventCallback(SoMouseButtonEvent::getClassTypeId(), PartGui::ViewProviderPart::shapeInfoCallback);
-     }
+    //if (view) {
+    //    Gui::View3DInventorViewer* viewer = view->getViewer();
+    //    viewer->setEditing(true);
+    //    viewer->getWidget()->setCursor(QCursor(QPixmap(part_pipette),4,29));
+    //    viewer->addEventCallback(SoMouseButtonEvent::getClassTypeId(), PartGui::ViewProviderPart::shapeInfoCallback);
+    // }
 }
 
 bool CmdShapeInfo::isActive(void)
@@ -934,6 +1034,7 @@ CmdPartRuledSurface::CmdPartRuledSurface()
     sToolTipText    = QT_TR_NOOP("Create a ruled surface from two curves");
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
+    sPixmap         = "Part_RuledSurface";
 }
 
 void CmdPartRuledSurface::activated(int iMsg)
@@ -1055,9 +1156,12 @@ void CreatePartCommands(void)
     rcCmdMgr.addCommand(new CmdPartPrimitives());
 
     rcCmdMgr.addCommand(new CmdPartImport());
+    rcCmdMgr.addCommand(new CmdPartExport());
     rcCmdMgr.addCommand(new CmdPartImportCurveNet());
     rcCmdMgr.addCommand(new CmdPartPickCurveNet());
     rcCmdMgr.addCommand(new CmdShapeInfo());
     rcCmdMgr.addCommand(new CmdPartRuledSurface());
+    rcCmdMgr.addCommand(new CmdPartBuilder());
+    rcCmdMgr.addCommand(new CmdPartLoft());
 } 
 
