@@ -56,6 +56,7 @@
 #include <Gui/Command.h>
 #include <Gui/WaitCursor.h>
 #include <Gui/Selection.h>
+#include <Gui/SelectionFilter.h>
 #include <Gui/ViewProvider.h>
 
 using namespace PartGui;
@@ -122,7 +123,7 @@ bool FilletRadiusModel::setData (const QModelIndex & index, const QVariant & val
 {
     bool ok = QStandardItemModel::setData(index, value, role);
     if (role == Qt::CheckStateRole) {
-        toogleCheckState(index);
+        toggleCheckState(index);
     }
     return ok;
 }
@@ -130,10 +131,29 @@ bool FilletRadiusModel::setData (const QModelIndex & index, const QVariant & val
 // --------------------------------------------------------------
 
 namespace PartGui {
+    class EdgeSelection : public Gui::SelectionFilterGate
+    {
+        App::DocumentObject*& object;
+    public:
+        EdgeSelection(App::DocumentObject*& obj)
+            : Gui::SelectionFilterGate((Gui::SelectionFilter*)0), object(obj)
+        {
+        }
+        bool allow(App::Document*pDoc, App::DocumentObject*pObj, const char*sSubName)
+        {
+            if (pObj != this->object)
+                return false;
+            if (!sSubName || sSubName[0] == '\0')
+                return false;
+            std::string element(sSubName);
+            return element.substr(0,4) == "Edge";
+        }
+    };
     class DlgFilletEdgesP
     {
     public:
         App::DocumentObject* object;
+        EdgeSelection* selection;
         Part::Fillet* fillet;
         typedef boost::signals::connection Connection;
         Connection connectApplicationDeletedObject;
@@ -149,6 +169,9 @@ DlgFilletEdges::DlgFilletEdges(Part::Fillet* fillet, QWidget* parent, Qt::WFlags
     ui->setupUi(this);
 
     d->object = 0;
+    d->selection = new EdgeSelection(d->object);
+    Gui::Selection().addSelectionGate(d->selection);
+
     d->fillet = fillet;
     d->connectApplicationDeletedObject = App::GetApplication().signalDeletedObject
         .connect(boost::bind(&DlgFilletEdges::onDeleteObject, this, _1));
@@ -156,8 +179,8 @@ DlgFilletEdges::DlgFilletEdges(Part::Fillet* fillet, QWidget* parent, Qt::WFlags
         .connect(boost::bind(&DlgFilletEdges::onDeleteDocument, this, _1));
     // set tree view with three columns
     QStandardItemModel* model = new FilletRadiusModel(this);
-    connect(model, SIGNAL(toogleCheckState(const QModelIndex&)),
-            this, SLOT(toogleCheckState(const QModelIndex&)));
+    connect(model, SIGNAL(toggleCheckState(const QModelIndex&)),
+            this, SLOT(toggleCheckState(const QModelIndex&)));
     model->insertColumns(0,3);
     model->setHeaderData(0, Qt::Horizontal, tr("Edges to fillet"), Qt::DisplayRole);
     model->setHeaderData(1, Qt::Horizontal, tr("Start radius"), Qt::DisplayRole);
@@ -182,6 +205,7 @@ DlgFilletEdges::~DlgFilletEdges()
     // no need to delete child widgets, Qt does it all for us
     d->connectApplicationDeletedDocument.disconnect();
     d->connectApplicationDeletedObject.disconnect();
+    Gui::Selection().rmvSelectionGate();
 }
 
 void DlgFilletEdges::onSelectionChanged(const Gui::SelectionChanges& msg)
@@ -263,7 +287,7 @@ void DlgFilletEdges::onDeleteDocument(const App::Document& doc)
     }
 }
 
-void DlgFilletEdges::toogleCheckState(const QModelIndex& index)
+void DlgFilletEdges::toggleCheckState(const QModelIndex& index)
 {
     if (!d->object)
         return;
@@ -586,6 +610,12 @@ bool DlgFilletEdges::accept()
         vp = Gui::Application::Instance->getViewProvider(d->fillet);
         if (vp) vp->show();
     }
+
+    QByteArray to = name.toAscii();
+    QByteArray from = shape.toAscii();
+    Gui::Command::copyVisual(to, "ShapeColor", from);
+    Gui::Command::copyVisual(to, "LineColor", from);
+    Gui::Command::copyVisual(to, "PointColor", from);
     return true;
 }
 
@@ -645,11 +675,15 @@ void TaskFilletEdges::clicked(int)
 
 bool TaskFilletEdges::accept()
 {
-    return widget->accept();
+    bool ok = widget->accept();
+    if (ok)
+        Gui::Command::doCommand(Gui::Command::Gui,"Gui.activeDocument().resetEdit()");
+    return ok;
 }
 
 bool TaskFilletEdges::reject()
 {
+    Gui::Command::doCommand(Gui::Command::Gui,"Gui.activeDocument().resetEdit()");
     return true;
 }
 
