@@ -77,10 +77,40 @@ DlgPrimitives::DlgPrimitives(QWidget* parent, Qt::WFlags fl)
     // torus
     ui.torusRadius1->setMaximum(INT_MAX);
     ui.torusRadius2->setMaximum(INT_MAX);
+    // wedge
+    ui.wedgeXmin->setMinimum(INT_MIN);
+    ui.wedgeXmin->setMaximum(INT_MAX);
+    ui.wedgeYmin->setMinimum(INT_MIN);
+    ui.wedgeYmin->setMaximum(INT_MAX);
+    ui.wedgeZmin->setMinimum(INT_MIN);
+    ui.wedgeZmin->setMaximum(INT_MAX);
+    ui.wedgeX2min->setMinimum(INT_MIN);
+    ui.wedgeX2min->setMaximum(INT_MAX);
+    ui.wedgeZ2min->setMinimum(INT_MIN);
+    ui.wedgeZ2min->setMaximum(INT_MAX);
+    ui.wedgeXmax->setMinimum(INT_MIN);
+    ui.wedgeXmax->setMaximum(INT_MAX);
+    ui.wedgeYmax->setMinimum(INT_MIN);
+    ui.wedgeYmax->setMaximum(INT_MAX);
+    ui.wedgeZmax->setMinimum(INT_MIN);
+    ui.wedgeZmax->setMaximum(INT_MAX);
+    ui.wedgeX2max->setMinimum(INT_MIN);
+    ui.wedgeX2max->setMaximum(INT_MAX);
+    ui.wedgeZ2max->setMinimum(INT_MIN);
+    ui.wedgeZ2max->setMaximum(INT_MAX);
     // helix
     ui.helixPitch->setMaximum(INT_MAX);
     ui.helixHeight->setMaximum(INT_MAX);
     ui.helixRadius->setMaximum(INT_MAX);
+    // circle
+    ui.circleRadius->setMaximum(INT_MAX);
+    // vertex
+    ui.VertexXAxisValue->setMaximum(INT_MAX);
+    ui.VertexYAxisValue->setMaximum(INT_MAX);
+    ui.VertexZAxisValue->setMaximum(INT_MAX);
+    ui.VertexXAxisValue->setMinimum(-INT_MAX);
+    ui.VertexYAxisValue->setMinimum(-INT_MAX);
+    ui.VertexZAxisValue->setMinimum(-INT_MAX);
 }
 
 /*  
@@ -176,7 +206,6 @@ void DlgPrimitives::accept()
                 .arg(ui.comboBox1->currentText()), tr("No active document"));
             return;
         }
-        Base::Vector3f dir = ui.getDirection();
         if (ui.comboBox1->currentIndex() == 0) {         // plane
             name = QString::fromAscii(doc->getUniqueObjectName("Plane").c_str());
             cmd = QString::fromAscii(
@@ -285,18 +314,76 @@ void DlgPrimitives::accept()
                 .arg(ui.torusAngle3->value(),0,'f',2)
                 .arg(this->toPlacement());
         }
-        else if (ui.comboBox1->currentIndex() == 7) {  // helix
+        else if (ui.comboBox1->currentIndex() == 7) {  // wedge
+            name = QString::fromAscii(doc->getUniqueObjectName("Wedge").c_str());
+            cmd = QString::fromAscii(
+                "App.ActiveDocument.addObject(\"Part::Wedge\",\"%1\")\n"
+                "App.ActiveDocument.%1.Xmin=%2\n"
+                "App.ActiveDocument.%1.Ymin=%3\n"
+                "App.ActiveDocument.%1.Zmin=%4\n"
+                "App.ActiveDocument.%1.X2min=%5\n"
+                "App.ActiveDocument.%1.Z2min=%6\n"
+                "App.ActiveDocument.%1.Xmax=%7\n"
+                "App.ActiveDocument.%1.Ymax=%8\n"
+                "App.ActiveDocument.%1.Zmax=%9\n"
+                "App.ActiveDocument.%1.X2max=%10\n"
+                "App.ActiveDocument.%1.Z2max=%11\n"
+                "App.ActiveDocument.%1.Placement=%12\n")
+                .arg(name)
+                .arg(ui.wedgeXmin->value(),0,'f',2)
+                .arg(ui.wedgeYmin->value(),0,'f',2)
+                .arg(ui.wedgeZmin->value(),0,'f',2)
+                .arg(ui.wedgeX2min->value(),0,'f',2)
+                .arg(ui.wedgeZ2min->value(),0,'f',2)
+                .arg(ui.wedgeXmax->value(),0,'f',2)
+                .arg(ui.wedgeYmax->value(),0,'f',2)
+                .arg(ui.wedgeZmax->value(),0,'f',2)
+                .arg(ui.wedgeX2max->value(),0,'f',2)
+                .arg(ui.wedgeZ2max->value(),0,'f',2)
+                .arg(this->toPlacement());
+        }
+        else if (ui.comboBox1->currentIndex() == 8) {  // helix
             name = QString::fromAscii(doc->getUniqueObjectName("Helix").c_str());
             cmd = QString::fromAscii(
                 "App.ActiveDocument.addObject(\"Part::Helix\",\"%1\")\n"
                 "App.ActiveDocument.%1.Pitch=%2\n"
                 "App.ActiveDocument.%1.Height=%3\n"
                 "App.ActiveDocument.%1.Radius=%4\n"
-                "App.ActiveDocument.%1.Placement=%5\n")
+                "App.ActiveDocument.%1.Angle=%5\n"
+                "App.ActiveDocument.%1.Placement=%6\n")
                 .arg(name)
                 .arg(ui.helixPitch->value(),0,'f',2)
                 .arg(ui.helixHeight->value(),0,'f',2)
                 .arg(ui.helixRadius->value(),0,'f',2)
+                .arg(ui.helixAngle->value(),0,'f',2)
+                .arg(this->toPlacement());
+        }
+        else if (ui.comboBox1->currentIndex() == 9) {  // circle
+            name = QString::fromAscii(doc->getUniqueObjectName("Circle").c_str());
+            cmd = QString::fromAscii(
+                "App.ActiveDocument.addObject(\"Part::Circle\",\"%1\")\n"
+                "App.ActiveDocument.%1.Radius=%2\n"
+                "App.ActiveDocument.%1.Angle0=%3\n"
+                "App.ActiveDocument.%1.Angle1=%4\n"
+                "App.ActiveDocument.%1.Placement=%5\n")
+                .arg(name)
+                .arg(ui.circleRadius->value(),0,'f',2)
+                .arg(ui.circleAngle0->value(),0,'f',2)
+                .arg(ui.circleAngle1->value(),0,'f',2)
+                .arg(this->toPlacement());
+        }
+        else if (ui.comboBox1->currentIndex() == 10) {  // vertex
+            name = QString::fromAscii(doc->getUniqueObjectName("Vertex").c_str());
+            cmd = QString::fromAscii(
+                "App.ActiveDocument.addObject(\"Part::Vertex\",\"%1\")\n"
+                "App.ActiveDocument.%1.X=%2\n"
+                "App.ActiveDocument.%1.Y=%3\n"
+                "App.ActiveDocument.%1.Z=%4\n"
+                "App.ActiveDocument.%1.Placement=%5\n")
+                .arg(name)
+                .arg(ui.VertexXAxisValue->value(),0,'f',2)
+                .arg(ui.VertexYAxisValue->value(),0,'f',2)
+                .arg(ui.VertexZAxisValue->value(),0,'f',2)
                 .arg(this->toPlacement());
         }
 
