@@ -95,6 +95,33 @@
 
 using namespace PartGui;
 
+#if defined(FC_USE_FAST_SHAPE_RENDERING)
+
+PROPERTY_SOURCE(PartGui::ViewProviderPart, PartGui::ViewProviderPartExt)
+
+
+ViewProviderPart::ViewProviderPart()
+{
+}
+
+ViewProviderPart::~ViewProviderPart()
+{
+}
+#else
+PROPERTY_SOURCE(PartGui::ViewProviderPart, PartGui::ViewProviderPartBase)
+
+
+ViewProviderPart::ViewProviderPart()
+{
+}
+
+ViewProviderPart::~ViewProviderPart()
+{
+}
+#endif
+
+// ----------------------------------------------------------------------------
+
 void ViewProviderShapeBuilder::buildNodes(const App::Property* prop, std::vector<SoNode*>& nodes) const
 {
 }
@@ -104,16 +131,16 @@ void ViewProviderShapeBuilder::createShape(const App::Property* prop, SoSeparato
 }
 
 
-PROPERTY_SOURCE(PartGui::ViewProviderPart, Gui::ViewProviderGeometryObject)
+PROPERTY_SOURCE(PartGui::ViewProviderPartBase, Gui::ViewProviderGeometryObject)
 
 
 //**************************************************************************
 // Construction/Destruction
 
-App::PropertyFloatConstraint::Constraints ViewProviderPart::floatRange = {1.0f,64.0f,1.0f};
-const char* ViewProviderPart::LightingEnums[]= {"One side","Two side",NULL};
+App::PropertyFloatConstraint::Constraints ViewProviderPartBase::floatRange = {1.0f,64.0f,1.0f};
+const char* ViewProviderPartBase::LightingEnums[]= {"One side","Two side",NULL};
 
-ViewProviderPart::ViewProviderPart() : pcControlPoints(0)
+ViewProviderPartBase::ViewProviderPartBase() : pcControlPoints(0)
 {
     App::Material mat;
     mat.ambientColor.set(0.2f,0.2f,0.2f);
@@ -167,7 +194,7 @@ ViewProviderPart::ViewProviderPart() : pcControlPoints(0)
     loadParameter();
 }
 
-ViewProviderPart::~ViewProviderPart()
+ViewProviderPartBase::~ViewProviderPartBase()
 {
     EdgeRoot->unref();
     FaceRoot->unref();
@@ -179,7 +206,7 @@ ViewProviderPart::~ViewProviderPart()
     pShapeHints->unref();
 }
 
-void ViewProviderPart::onChanged(const App::Property* prop)
+void ViewProviderPartBase::onChanged(const App::Property* prop)
 {
     if (prop == &LineWidth) {
         pcLineStyle->lineWidth = LineWidth.getValue();
@@ -237,7 +264,7 @@ void ViewProviderPart::onChanged(const App::Property* prop)
     }
 }
 
-void ViewProviderPart::attach(App::DocumentObject *pcFeat)
+void ViewProviderPartBase::attach(App::DocumentObject *pcFeat)
 {
     // call parent attach method
     ViewProviderGeometryObject::attach(pcFeat);
@@ -280,7 +307,7 @@ void ViewProviderPart::attach(App::DocumentObject *pcFeat)
     addDisplayMaskMode(pcPointsRoot, "Point");
 }
 
-void ViewProviderPart::setDisplayMode(const char* ModeName)
+void ViewProviderPartBase::setDisplayMode(const char* ModeName)
 {
     if ( strcmp("Flat Lines",ModeName)==0 )
         setDisplayMaskMode("Flat Lines");
@@ -294,7 +321,7 @@ void ViewProviderPart::setDisplayMode(const char* ModeName)
     ViewProviderGeometryObject::setDisplayMode( ModeName );
 }
 
-std::vector<std::string> ViewProviderPart::getDisplayModes(void) const
+std::vector<std::string> ViewProviderPartBase::getDisplayModes(void) const
 {
     // get the modes of the father
     std::vector<std::string> StrList = ViewProviderGeometryObject::getDisplayModes();
@@ -308,7 +335,7 @@ std::vector<std::string> ViewProviderPart::getDisplayModes(void) const
     return StrList;
 }
 
-void ViewProviderPart::shapeInfoCallback(void * ud, SoEventCallback * n)
+void ViewProviderPartBase::shapeInfoCallback(void * ud, SoEventCallback * n)
 {
     const SoMouseButtonEvent * mbe = (SoMouseButtonEvent *)n->getEvent();
     Gui::View3DInventorViewer* view  = reinterpret_cast<Gui::View3DInventorViewer*>(n->getUserData());
@@ -333,9 +360,9 @@ void ViewProviderPart::shapeInfoCallback(void * ud, SoEventCallback * n)
         // By specifying the indexed mesh node 'pcFaceSet' we make sure that the picked point is
         // really from the mesh we render and not from any other geometry
         Gui::ViewProvider* vp = static_cast<Gui::ViewProvider*>(view->getViewProviderByPath(point->getPath()));
-        if (!vp || !vp->getTypeId().isDerivedFrom(ViewProviderPart::getClassTypeId()))
+        if (!vp || !vp->getTypeId().isDerivedFrom(ViewProviderPartBase::getClassTypeId()))
             return;
-        ViewProviderPart* that = static_cast<ViewProviderPart*>(vp);
+        ViewProviderPartBase* that = static_cast<ViewProviderPartBase*>(vp);
         TopoDS_Shape sh = that->getShape(point);
         if (!sh.IsNull()) {
             SbVec3f pt = point->getPoint();
@@ -344,7 +371,7 @@ void ViewProviderPart::shapeInfoCallback(void * ud, SoEventCallback * n)
     }
 }
 
-TopoDS_Shape ViewProviderPart::getShape(const SoPickedPoint* point) const
+TopoDS_Shape ViewProviderPartBase::getShape(const SoPickedPoint* point) const
 {
     if (point && point->getPath()->getTail()->getTypeId().isDerivedFrom(SoVertexShape::getClassTypeId())) {
         SoVertexShape* vs = static_cast<SoVertexShape*>(point->getPath()->getTail());
@@ -356,7 +383,7 @@ TopoDS_Shape ViewProviderPart::getShape(const SoPickedPoint* point) const
     return TopoDS_Shape();
 }
 
-bool ViewProviderPart::loadParameter()
+bool ViewProviderPartBase::loadParameter()
 {
     bool changed = false;
     ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath
@@ -381,7 +408,7 @@ bool ViewProviderPart::loadParameter()
     return changed;
 }
 
-void ViewProviderPart::reload()
+void ViewProviderPartBase::reload()
 {
     if (loadParameter()) {
         App::Property* shape     = pcObject->getPropertyByName("Shape");
@@ -389,9 +416,8 @@ void ViewProviderPart::reload()
     }
 }
 
-void ViewProviderPart::updateData(const App::Property* prop)
+void ViewProviderPartBase::updateData(const App::Property* prop)
 {
-    Gui::ViewProviderGeometryObject::updateData(prop);
     if (prop->getTypeId() == Part::PropertyPartShape::getClassTypeId()) {
         TopoDS_Shape cShape = static_cast<const Part::PropertyPartShape*>(prop)->getValue();
 
@@ -446,9 +472,10 @@ void ViewProviderPart::updateData(const App::Property* prop)
 #endif
         }
     }
+    Gui::ViewProviderGeometryObject::updateData(prop);
 }
 
-Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS_Shape &myShape)
+Standard_Boolean ViewProviderPartBase::computeEdges(SoGroup* EdgeRoot, const TopoDS_Shape &myShape)
 {
     //TopExp_Explorer ex;
 
@@ -465,9 +492,7 @@ Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS
 
     //int i=1;
     //for (ex.Init(myShape, TopAbs_EDGE); ex.More(); ex.Next(),i++) {
-    for (int i=0; i<M.Extent(); i++)
-    {
-
+    for (int i=0; i < M.Extent(); i++) {
         //if(i>12)continue;
         // get the shape and mesh it
         //const TopoDS_Edge& aEdge = TopoDS::Edge(ex.Current());
@@ -475,7 +500,6 @@ Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS
 
         // getting the transformation of the shape/face
         gp_Trsf myTransf;
-        Standard_Boolean identity = true;
         TopLoc_Location aLoc;
 
         // try to triangulate the edge
@@ -487,7 +511,6 @@ Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS
         // triangulation succeeded?
         if (!aPoly.IsNull()) {
             if (!aLoc.IsIdentity()) {
-                identity = false;
                 myTransf = aLoc.Transformation();
             }
             // take the edge's triangulation
@@ -515,7 +538,6 @@ Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS
             // take the face's triangulation instead
             Handle(Poly_Triangulation) aPolyTria = BRep_Tool::Triangulation(aFace,aLoc);
             if (!aLoc.IsIdentity()) {
-                identity = false;
                 myTransf = aLoc.Transformation();
             }
 
@@ -571,7 +593,7 @@ Standard_Boolean ViewProviderPart::computeEdges (SoGroup* EdgeRoot, const TopoDS
     return true;
 }
 
-Standard_Boolean ViewProviderPart::computeVertices(SoGroup* VertexRoot, const TopoDS_Shape &myShape)
+Standard_Boolean ViewProviderPartBase::computeVertices(SoGroup* VertexRoot, const TopoDS_Shape &myShape)
 {
 #if 0 // new implementation of computeVertice
     VertexRoot->addChild(pcPointMaterial);  
@@ -664,7 +686,7 @@ Standard_Boolean ViewProviderPart::computeVertices(SoGroup* VertexRoot, const To
 #endif
 }
 
-Standard_Boolean ViewProviderPart::computeFaces(SoGroup* FaceRoot, const TopoDS_Shape &myShape, double defl)
+Standard_Boolean ViewProviderPartBase::computeFaces(SoGroup* FaceRoot, const TopoDS_Shape &myShape, double defl)
 {
     TopExp_Explorer ex;
 
@@ -750,8 +772,8 @@ Standard_Boolean ViewProviderPart::computeFaces(SoGroup* FaceRoot, const TopoDS_
     return true;
 }
 
-void ViewProviderPart::transferToArray(const TopoDS_Face& aFace,SbVec3f** vertices,SbVec3f** vertexnormals,
-                                       int32_t** cons,int &nbNodesInFace,int &nbTriInFace )
+void ViewProviderPartBase::transferToArray(const TopoDS_Face& aFace,SbVec3f** vertices,SbVec3f** vertexnormals,
+                                           int32_t** cons,int &nbNodesInFace,int &nbTriInFace )
 {
     TopLoc_Location aLoc;
 
@@ -863,7 +885,7 @@ void ViewProviderPart::transferToArray(const TopoDS_Face& aFace,SbVec3f** vertic
     }
 }
 
-void ViewProviderPart::showControlPoints(bool show, const App::Property* prop)
+void ViewProviderPartBase::showControlPoints(bool show, const App::Property* prop)
 {
     if (!pcControlPoints && show) {
         pcControlPoints = new SoSwitch();
@@ -905,37 +927,70 @@ void ViewProviderPart::showControlPoints(bool show, const App::Property* prop)
     }
 }
 
-void ViewProviderPart::showControlPointsOfEdge(const TopoDS_Edge& edge)
+void ViewProviderPartBase::showControlPointsOfEdge(const TopoDS_Edge& edge)
 {
     std::list<gp_Pnt> poles, knots; 
-    gp_Pnt start, end;
+    Standard_Integer nCt=0;
     BRepAdaptor_Curve curve(edge);
     switch (curve.GetType())
     {
     case GeomAbs_BezierCurve:
         {
             Handle(Geom_BezierCurve) hBezier = curve.Bezier();
-            for (Standard_Integer i = 1; i <= hBezier->NbPoles(); i++)
+            nCt = hBezier->NbPoles();
+            for (Standard_Integer i = 1; i <= nCt; i++)
                 poles.push_back(hBezier->Pole(i));
-            start = hBezier->StartPoint();
-            end   = hBezier->EndPoint();
+            if (hBezier->IsClosed()) {
+                nCt++;
+                poles.push_back(hBezier->Pole(1));
+            }
         }   break;
     case GeomAbs_BSplineCurve:
         {
             Handle(Geom_BSplineCurve) hBSpline = curve.BSpline();
-            for (Standard_Integer i = 1; i <= hBSpline->NbPoles(); i++)
+            nCt = hBSpline->NbPoles();
+            for (Standard_Integer i = 1; i <= nCt; i++)
                 poles.push_back(hBSpline->Pole(i));
-            start = hBSpline->StartPoint();
-            end   = hBSpline->EndPoint();
+            if (hBSpline->IsClosed()) {
+                nCt++;
+                poles.push_back(hBSpline->Pole(1));
+            }
             for (Standard_Integer i = hBSpline->FirstUKnotIndex()+1; i <= hBSpline->LastUKnotIndex()-1; i++)
                 knots.push_back(hBSpline->Value(hBSpline->Knot(i)));
         }   break;
     default:
         break;
     }
+
+    if (poles.empty())
+        return; // nothing to do
+
+    SoCoordinate3 * coords = new SoCoordinate3;
+    coords->point.setNum(nCt + knots.size());
+
+    int index=0;
+    SbVec3f* verts = coords->point.startEditing();
+    for (std::list<gp_Pnt>::iterator p = poles.begin(); p != poles.end(); ++p) {
+        verts[index++].setValue((float)p->X(), (float)p->Y(), (float)p->Z());
+    }
+    for (std::list<gp_Pnt>::iterator k = knots.begin(); k != knots.end(); ++k) {
+        verts[index++].setValue((float)k->X(), (float)k->Y(), (float)k->Z());
+    }
+    coords->point.finishEditing();
+
+
+    SoFCControlPoints* control = new SoFCControlPoints();
+    control->numPolesU = nCt;
+    control->numPolesV = 1;
+
+    SoSeparator* nodes = new SoSeparator();
+    nodes->addChild(coords);
+    nodes->addChild(control);
+
+    pcControlPoints->addChild(nodes);
 }
 
-void ViewProviderPart::showControlPointsOfWire(const TopoDS_Wire& wire)
+void ViewProviderPartBase::showControlPointsOfWire(const TopoDS_Wire& wire)
 {
     TopoDS_Iterator it;
     for (it.Initialize(wire); it.More(); it.Next()) {
@@ -972,12 +1027,11 @@ void ViewProviderPart::showControlPointsOfWire(const TopoDS_Wire& wire)
     }
 }
 
-void ViewProviderPart::showControlPointsOfFace(const TopoDS_Face& face)
+void ViewProviderPartBase::showControlPointsOfFace(const TopoDS_Face& face)
 {
     std::list<gp_Pnt> knots;
     std::vector<std::vector<gp_Pnt> > poles;
     Standard_Integer nCtU=0, nCtV=0;
-    Standard_Integer nKnU=0, nKnV=0;
     BRepAdaptor_Surface surface(face); 
 
     BRepAdaptor_Surface clSurface(face); 
@@ -1007,8 +1061,8 @@ void ViewProviderPart::showControlPointsOfFace(const TopoDS_Face& face)
                     poles[u-1][v-1] = hBSpline->Pole(u, v);
             }
 
-            nKnU = hBSpline->NbUKnots();
-            nKnV = hBSpline->NbVKnots();
+            //Standard_Integer nKnU = hBSpline->NbUKnots();
+            //Standard_Integer nKnV = hBSpline->NbVKnots();
             for (Standard_Integer u = 1; u <= hBSpline->NbUKnots(); u++) {
                 for (Standard_Integer v = 1; v <= hBSpline->NbVKnots(); v++)
                     knots.push_back(hBSpline->Value(hBSpline->UKnot(u), hBSpline->VKnot(v)));
@@ -1055,7 +1109,7 @@ void ViewProviderPart::showControlPointsOfFace(const TopoDS_Face& face)
 
 // ----------------------------------------------------------------------------
 
-PROPERTY_SOURCE(PartGui::ViewProviderEllipsoid, PartGui::ViewProviderPart)
+PROPERTY_SOURCE(PartGui::ViewProviderEllipsoid, PartGui::ViewProviderPartBase)
 
 ViewProviderEllipsoid::ViewProviderEllipsoid()
 {
@@ -1101,7 +1155,7 @@ void ViewProviderEllipsoid::updateData(const App::Property* prop)
         }
 
         // if not a full ellipsoid do it the general way
-        ViewProviderPart::updateData(prop);
+        ViewProviderPartBase::updateData(prop);
     }
     else {
         Gui::ViewProviderGeometryObject::updateData(prop);
