@@ -23,16 +23,17 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <Bnd_Box.hxx>
-# include <gp_Pln.hxx>
+//# include <Bnd_Box.hxx>
+//# include <gp_Pln.hxx>
 # include <BRep_Builder.hxx>
 # include <BRepBndLib.hxx>
 # include <BRepPrimAPI_MakePrism.hxx>
 # include <BRepBuilderAPI_Copy.hxx>
 # include <BRepBuilderAPI_MakeFace.hxx>
-# include <Geom_Plane.hxx>
+//# include <Geom_Plane.hxx>
 # include <Handle_Geom_Surface.hxx>
 # include <TopoDS.hxx>
+# include <TopoDS_Solid.hxx>
 # include <TopoDS_Face.hxx>
 # include <TopoDS_Wire.hxx>
 # include <TopExp_Explorer.hxx>
@@ -47,18 +48,26 @@
 
 using namespace PartDesign;
 
+const char* Pad::SideEnums[]= {"Positive","Negative",NULL};
 
-PROPERTY_SOURCE(PartDesign::Pad, PartDesign::SketchBased)
+PROPERTY_SOURCE(PartDesign::Pad, PartDesign::Additive)
 
 Pad::Pad()
 {
+    //ADD_PROPERTY(Side,((long)0));
+    //Side.setEnums(SideEnums);
     ADD_PROPERTY(Length,(100.0));
+    ADD_PROPERTY(Reversed,(0));
+    ADD_PROPERTY(MirroredExtent,(0));
+    
 }
 
 short Pad::mustExecute() const
 {
     if (Sketch.isTouched() ||
-        Length.isTouched())
+        Length.isTouched() ||
+        MirroredExtent.isTouched() ||
+        Reversed.isTouched())
         return 1;
     return 0;
 }
@@ -76,17 +85,16 @@ App::DocumentObjectExecReturn *Pad::execute(void)
 
     // this is a workaround for an obscure OCC bug which leads to empty tessellations
     // for some faces. Making an explicit copy of the linked shape seems to fix it.
-    // The error only happens when re-computing the shape.
-    if (!this->Shape.getValue().IsNull()) {
-        BRepBuilderAPI_Copy copy(shape);
-        shape = copy.Shape();
-        if (shape.IsNull())
-            return new App::DocumentObjectExecReturn("Linked shape object is empty");
-    }
+    // The error almost happens when re-computing the shape but sometimes also for the
+    // first time
+    BRepBuilderAPI_Copy copy(shape);
+    shape = copy.Shape();
+    if (shape.IsNull())
+        return new App::DocumentObjectExecReturn("Linked shape object is empty");
 
     TopExp_Explorer ex;
     std::vector<TopoDS_Wire> wires;
-    for (ex.Init(shape, TopAbs_WIRE, TopAbs_FACE); ex.More(); ex.Next()) {
+    for (ex.Init(shape, TopAbs_WIRE); ex.More(); ex.Next()) {
         wires.push_back(TopoDS::Wire(ex.Current()));
     }
     if (/*shape.ShapeType() != TopAbs_WIRE*/wires.empty()) // there can be several wires
@@ -96,84 +104,78 @@ App::DocumentObjectExecReturn *Pad::execute(void)
     Base::Placement SketchPos = static_cast<Part::Part2DObject*>(link)->Placement.getValue();
     Base::Rotation SketchOrientation = SketchPos.getRotation();
     Base::Vector3d SketchOrientationVector(0,0,1);
+    if (Reversed.getValue()) // negative direction
+        SketchOrientationVector *= -1;
     SketchOrientation.multVec(SketchOrientationVector,SketchOrientationVector);
 
     // get the support of the Sketch if any
     App::DocumentObject* SupportLink = static_cast<Part::Part2DObject*>(link)->Support.getValue();
     Part::Feature *SupportObject = 0;
-    if(SupportLink && SupportLink->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId()))
+    if (SupportLink && SupportLink->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId()))
         SupportObject = static_cast<Part::Feature*>(SupportLink);
 
-	/* Version from the blog
-	Handle(Geom_Surface) aSurf = new Geom_Plane (gp::XOY());
-	//anti-clockwise circles if too look from surface normal
-	Handle(Geom_Curve) anExtC = new Geom_Circle (gp::XOY(), 10.);
-	Handle(Geom_Curve) anIntC = new Geom_Circle (gp::XOY(), 5.);
-	TopoDS_Edge anExtE = BRepBuilderAPI_MakeEdge (anExtC);
-	TopoDS_Edge anIntE = BRepBuilderAPI_MakeEdge (anExtC);
-	TopoDS_Wire anExtW = BRepBuilderAPI_MakeWire (anExtE);
-	TopoDS_Wire anIntW = BRepBuilderAPI_MakeWire (anIntE);
-	BRep_Builder aB;
-	TopoDS_Face aFace;
-	aB.MakeFace (aFace, aSurf, Precision::Confusion());
-	//aB. (aFace, aSurf);
-	aB.Add (aFace, anExtW);
-	//aB.Add (aFace, anIntW.Reversed()); //material should lie on the right of the inner wire
 
-	this->Shape.setValue(aFace);
-	*/
-
-	/* Version from First Application
-    Base::Vector3f v = Dir.getValue();
-    gp_Vec vec(v.x,v.y,v.z);
-	gp_Pln Pln(gp_Pnt(0,0,0),gp_Dir(0,0,1));
-
-    // Now, let's get the TopoDS_Shape
-	TopoDS_Wire theWire = TopoDS::Wire(Shape.getShape()._Shape);
-	BRepBuilderAPI_MakeFace FaceBuilder = BRepBuilderAPI_MakeFace(Pln,theWire);
-	if(FaceBuilder.IsDone()){
-		TopoDS_Face FaceProfile = FaceBuilder.Face();
-		// Make a solid out of the face
-		BRepPrimAPI_MakePrism PrismMaker = BRepPrimAPI_MakePrism(FaceProfile , vec);
-		if(PrismMaker.IsDone()){
-			this->Shape.setValue(PrismMaker.Shape());
-		}
-	}
-	*/
-
-    Handle(Geom_Surface) aSurf = new Geom_Plane (gp_Pln(gp_Pnt(0,0,0),gp_Dir(0,0,1)));
-    //anti-clockwise circles if too look from surface normal
-#if 0
-    //TopoDS_Wire theWire = TopoDS::Wire(shape);
-    //TopoDS_Face aFace = BRepBuilderAPI_MakeFace(theWire);
-#else
     TopoDS_Shape aFace = makeFace(wires);
     if (aFace.IsNull())
         return new App::DocumentObjectExecReturn("Creating a face from sketch failed");
-#endif
+
     // lengthen the vector
     SketchOrientationVector *= Length.getValue();
 
-    // extrude the face to a solid
-    gp_Vec vec(SketchOrientationVector.x,SketchOrientationVector.y,SketchOrientationVector.z);
-    BRepPrimAPI_MakePrism PrismMaker(aFace,vec,0,1);
-    if (PrismMaker.IsDone()) {
-        // if the sketch has a support fuse them to get one result object (PAD!)
-        if (SupportObject) {
-            // Let's call algorithm computing a fuse operation:
-            BRepAlgoAPI_Fuse mkFuse(SupportObject->Shape.getShape()._Shape, PrismMaker.Shape());
-            // Let's check if the fusion has been successful
-            if (!mkFuse.IsDone()) 
-                throw Base::Exception("Fusion with support failed");
-            this->Shape.setValue(mkFuse.Shape());
-        }
-        else{
-            this->Shape.setValue(PrismMaker.Shape());
-        }
-    }
-    else
-        return new App::DocumentObjectExecReturn("Could not extrude the sketch!");
+    try {
+        // extrude the face to a solid
+        gp_Vec vec(SketchOrientationVector.x,SketchOrientationVector.y,SketchOrientationVector.z);
+        BRepPrimAPI_MakePrism PrismMaker(aFace,vec,0,1);
+        if (PrismMaker.IsDone()) {
+            // if the sketch has a support fuse them to get one result object (PAD!)
+            if (SupportObject) {
+                // At this point the prism can be a compound
+                TopoDS_Shape result = PrismMaker.Shape();
+                // set the additive shape property for later usage in e.g. pattern
+                this->AddShape.setValue(result);
 
-    return App::DocumentObject::StdReturn;
+                const TopoDS_Shape& support = SupportObject->Shape.getValue();
+                bool isSolid = false;
+                if (!support.IsNull()) {
+                    TopExp_Explorer xp;
+                    xp.Init(support,TopAbs_SOLID);
+                    for (;xp.More(); xp.Next()) {
+                        isSolid = true;
+                        break;
+                    }
+                }
+                if (isSolid) {
+                    // Let's call algorithm computing a fuse operation:
+                    BRepAlgoAPI_Fuse mkFuse(support, result);
+                    // Let's check if the fusion has been successful
+                    if (!mkFuse.IsDone()) 
+                        return new App::DocumentObjectExecReturn("Fusion with support failed");
+                    result = mkFuse.Shape();
+                    // we have to get the solids (fuse create seldomly compounds)
+                    TopoDS_Shape solRes = this->getSolid(result);
+                    // lets check if the result is a solid
+                    if (solRes.IsNull())
+                        return new App::DocumentObjectExecReturn("Resulting shape is not a solid");
+                    this->Shape.setValue(solRes);
+                }
+                else
+                    return new App::DocumentObjectExecReturn("Support is not a solid");
+            }
+            else {
+                TopoDS_Shape result = this->getSolid(PrismMaker.Shape());
+                // set the additive shape property for later usage in e.g. pattern
+                this->AddShape.setValue(result);
+                this->Shape.setValue(result);
+            }
+        }
+        else
+            return new App::DocumentObjectExecReturn("Could not extrude the sketch!");
+
+        return App::DocumentObject::StdReturn;
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        return new App::DocumentObjectExecReturn(e->GetMessageString());
+    }
 }
 
