@@ -24,13 +24,14 @@
 #ifndef PARTDESIGN_Pad_H
 #define PARTDESIGN_Pad_H
 
+#include <App/PropertyUnits.h>
 #include <App/PropertyStandard.h>
-#include "FeatureSketchBased.h"
+#include "FeatureAdditive.h"
 
 namespace PartDesign
 {
 
-class Pad : public SketchBased
+class Pad : public Additive
 {
     PROPERTY_HEADER(PartDesign::Pad);
 
@@ -38,6 +39,9 @@ public:
     Pad();
 
     App::PropertyLength Length;
+    //App::PropertyEnumeration Side;
+    App::PropertyBool Reversed;
+    App::PropertyBool MirroredExtent;
 
     /** @name methods override feature */
     //@{
@@ -49,6 +53,8 @@ public:
         return "PartDesignGui::ViewProviderPad";
     }
     //@}
+private:
+    static const char* SideEnums[];
 };
 
 } //namespace PartDesign
