@@ -86,7 +86,7 @@ using namespace std;
 //
 
 //===========================================================================
-// Part_Pad
+// PartDesign_Pad
 //===========================================================================
 DEF_STD_CMD_A(CmdPartDesignPad);
 
@@ -100,7 +100,6 @@ CmdPartDesignPad::CmdPartDesignPad()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "PartDesign_Pad";
-    iAccel        = 0;
 }
 
 void CmdPartDesignPad::activated(int iMsg)
@@ -126,7 +125,7 @@ void CmdPartDesignPad::activated(int iMsg)
     // count free wires
     int ctWires=0;
     TopExp_Explorer ex;
-    for (ex.Init(shape, TopAbs_WIRE, TopAbs_FACE); ex.More(); ex.Next()) {
+    for (ex.Init(shape, TopAbs_WIRE); ex.More(); ex.Next()) {
         ctWires++;
     }
     if (ctWires == 0) {
@@ -137,17 +136,26 @@ void CmdPartDesignPad::activated(int iMsg)
 
     App::DocumentObject* support = sketch->Support.getValue();
 
-
     openCommand("Make Pad");
     doCommand(Doc,"App.activeDocument().addObject(\"PartDesign::Pad\",\"%s\")",FeatName.c_str());
     doCommand(Doc,"App.activeDocument().%s.Sketch = App.activeDocument().%s",FeatName.c_str(),sketch->getNameInDocument());
     doCommand(Doc,"App.activeDocument().%s.Length = 10.0",FeatName.c_str());
-    doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",sketch->getNameInDocument());
-    if(support)
-        doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",support->getNameInDocument());
     updateActive();
-    commitCommand();
+    if (isActiveObjectValid()) {
+        doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",sketch->getNameInDocument());
+        if (support)
+            doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",support->getNameInDocument());
+    }
+    doCommand(Gui,"Gui.activeDocument().setEdit('%s')",FeatName.c_str());
+
+    //commitCommand();
     adjustCameraPosition();
+
+    if (support) {
+        copyVisual(FeatName.c_str(), "ShapeColor", support->getNameInDocument());
+        copyVisual(FeatName.c_str(), "LineColor", support->getNameInDocument());
+        copyVisual(FeatName.c_str(), "PointColor", support->getNameInDocument());
+    }
 }
 
 bool CmdPartDesignPad::isActive(void)
@@ -156,7 +164,7 @@ bool CmdPartDesignPad::isActive(void)
 }
 
 //===========================================================================
-// Part_Pocket
+// PartDesign_Pocket
 //===========================================================================
 DEF_STD_CMD_A(CmdPartDesignPocket);
 
@@ -170,7 +178,6 @@ CmdPartDesignPocket::CmdPartDesignPocket()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "PartDesign_Pocket";
-    iAccel        = 0;
 }
 
 void CmdPartDesignPocket::activated(int iMsg)
@@ -196,7 +203,7 @@ void CmdPartDesignPocket::activated(int iMsg)
     // count free wires
     int ctWires=0;
     TopExp_Explorer ex;
-    for (ex.Init(shape, TopAbs_WIRE, TopAbs_FACE); ex.More(); ex.Next()) {
+    for (ex.Init(shape, TopAbs_WIRE); ex.More(); ex.Next()) {
         ctWires++;
     }
     if (ctWires == 0) {
@@ -215,10 +222,16 @@ void CmdPartDesignPocket::activated(int iMsg)
     doCommand(Doc,"App.activeDocument().addObject(\"PartDesign::Pocket\",\"%s\")",FeatName.c_str());
     doCommand(Doc,"App.activeDocument().%s.Sketch = App.activeDocument().%s",FeatName.c_str(),sketch->getNameInDocument());
     doCommand(Doc,"App.activeDocument().%s.Length = 5.0",FeatName.c_str());
-    doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",sketch->getNameInDocument());
-    doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",support->getNameInDocument());
     updateActive();
-    commitCommand();
+    if (isActiveObjectValid()) {
+        doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",sketch->getNameInDocument());
+        doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",support->getNameInDocument());
+    }
+    doCommand(Gui,"Gui.activeDocument().setEdit('%s')",FeatName.c_str());
+
+    copyVisual(FeatName.c_str(), "ShapeColor", support->getNameInDocument());
+    copyVisual(FeatName.c_str(), "LineColor", support->getNameInDocument());
+    copyVisual(FeatName.c_str(), "PointColor", support->getNameInDocument());
 }
 
 bool CmdPartDesignPocket::isActive(void)
@@ -226,6 +239,82 @@ bool CmdPartDesignPocket::isActive(void)
     return hasActiveDocument();
 }
 
+//===========================================================================
+// PartDesign_Revolution
+//===========================================================================
+DEF_STD_CMD_A(CmdPartDesignRevolution);
+
+CmdPartDesignRevolution::CmdPartDesignRevolution()
+  : Command("PartDesign_Revolution")
+{
+    sAppModule    = "PartDesign";
+    sGroup        = QT_TR_NOOP("PartDesign");
+    sMenuText     = QT_TR_NOOP("Revolution");
+    sToolTipText  = QT_TR_NOOP("Revolve a selected sketch");
+    sWhatsThis    = sToolTipText;
+    sStatusTip    = sToolTipText;
+    sPixmap       = "PartDesign_Revolution";
+}
+
+void CmdPartDesignRevolution::activated(int iMsg)
+{
+    unsigned int n = getSelection().countObjectsOfType(Part::Part2DObject::getClassTypeId());
+    if (n != 1) {
+        QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
+            QObject::tr("Select a sketch or 2D object."));
+        return;
+    }
+
+    std::string FeatName = getUniqueObjectName("Revolution");
+
+    std::vector<App::DocumentObject*> Sel = getSelection().getObjectsOfType(Part::Part2DObject::getClassTypeId());
+    Part::Part2DObject* sketch = static_cast<Part::Part2DObject*>(Sel.front());
+    const TopoDS_Shape& shape = sketch->Shape.getValue();
+    if (shape.IsNull()) {
+        QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
+            QObject::tr("The shape of the selected object is empty."));
+        return;
+    }
+
+    // count free wires
+    int ctWires=0;
+    TopExp_Explorer ex;
+    for (ex.Init(shape, TopAbs_WIRE); ex.More(); ex.Next()) {
+        ctWires++;
+    }
+    if (ctWires == 0) {
+        QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
+            QObject::tr("The shape of the selected object is not a wire."));
+        return;
+    }
+
+    App::DocumentObject* support = sketch->Support.getValue();
+
+    openCommand("Make Revolution");
+    doCommand(Doc,"App.activeDocument().addObject(\"PartDesign::Revolution\",\"%s\")",FeatName.c_str());
+    doCommand(Doc,"App.activeDocument().%s.Sketch = App.activeDocument().%s",FeatName.c_str(),sketch->getNameInDocument());
+    doCommand(Doc,"App.activeDocument().%s.Axis = App.Vector(0,1,0)",FeatName.c_str());
+    doCommand(Doc,"App.activeDocument().%s.Angle = 360.0",FeatName.c_str());
+    updateActive();
+    if (isActiveObjectValid()) {
+        doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",sketch->getNameInDocument());
+        if (support)
+            doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",support->getNameInDocument());
+    }
+    doCommand(Gui,"Gui.activeDocument().setEdit('%s')",FeatName.c_str());
+
+    if (support) {
+        copyVisual(FeatName.c_str(), "ShapeColor", support->getNameInDocument());
+        copyVisual(FeatName.c_str(), "LineColor", support->getNameInDocument());
+        copyVisual(FeatName.c_str(), "PointColor", support->getNameInDocument());
+    }
+}
+
+bool CmdPartDesignRevolution::isActive(void)
+{
+    return hasActiveDocument();
+}
+
 //===========================================================================
 // PartDesign_Fillet
 //===========================================================================
@@ -241,14 +330,11 @@ CmdPartDesignFillet::CmdPartDesignFillet()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Fillet";
-    iAccel        = 0;
 }
 
 void CmdPartDesignFillet::activated(int iMsg)
 {
-    //unsigned int n = getSelection().countObjectsOfType(Part::Feature::getClassTypeId());
-
-	std::vector<Gui::SelectionObject> selection = getSelection().getSelectionEx();
+    std::vector<Gui::SelectionObject> selection = getSelection().getSelectionEx();
 
     if (selection.size() != 1) {
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
@@ -256,20 +342,23 @@ void CmdPartDesignFillet::activated(int iMsg)
         return;
     }
 
-	if ( ! selection[0].isObjectTypeOf(Part::Feature::getClassTypeId())){
+    if (!selection[0].isObjectTypeOf(Part::Feature::getClassTypeId())){
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong object type"),
             QObject::tr("Fillet works only on parts"));
         return;
     }
-	std::string SelString = selection[0].getAsPropertyLinkSubString();
+    std::string SelString = selection[0].getAsPropertyLinkSubString();
     std::string FeatName = getUniqueObjectName("Fillet");
 
     openCommand("Make Fillet");
     doCommand(Doc,"App.activeDocument().addObject(\"PartDesign::Fillet\",\"%s\")",FeatName.c_str());
     doCommand(Doc,"App.activeDocument().%s.Base = %s",FeatName.c_str(),SelString.c_str());
     doCommand(Gui,"Gui.activeDocument().hide(\"%s\")",selection[0].getFeatName());
-    updateActive();
-    commitCommand();
+    doCommand(Gui,"Gui.activeDocument().setEdit('%s')",FeatName.c_str());
+
+    copyVisual(FeatName.c_str(), "ShapeColor", selection[0].getFeatName());
+    copyVisual(FeatName.c_str(), "LineColor",  selection[0].getFeatName());
+    copyVisual(FeatName.c_str(), "PointColor", selection[0].getFeatName());
 }
 
 bool CmdPartDesignFillet::isActive(void)
@@ -292,7 +381,6 @@ CmdPartDesignChamfer::CmdPartDesignChamfer()
     sWhatsThis    = sToolTipText;
     sStatusTip    = sToolTipText;
     sPixmap       = "Part_Chamfer";
-    iAccel        = 0;
 }
 
 void CmdPartDesignChamfer::activated(int iMsg)
@@ -312,6 +400,7 @@ void CreatePartDesignCommands(void)
 
     rcCmdMgr.addCommand(new CmdPartDesignPad());
     rcCmdMgr.addCommand(new CmdPartDesignPocket());
+    rcCmdMgr.addCommand(new CmdPartDesignRevolution());
     rcCmdMgr.addCommand(new CmdPartDesignFillet());
     //rcCmdMgr.addCommand(new CmdPartDesignNewSketch());
     rcCmdMgr.addCommand(new CmdPartDesignChamfer());
