@@ -54,6 +54,7 @@
 #include <Gui/Command.h>
 #include <Gui/WaitCursor.h>
 #include <Gui/Selection.h>
+#include <Gui/SelectionFilter.h>
 
 using namespace PartDesignGui;
 
@@ -121,7 +122,7 @@ bool ChamferDistanceModel::setData (const QModelIndex & index, const QVariant &
 {
     bool ok = QStandardItemModel::setData(index, value, role);
     if (role == Qt::CheckStateRole) {
-        toogleCheckState(index);
+        toggleCheckState(index);
     }
     return ok;
 }
@@ -129,10 +130,29 @@ bool ChamferDistanceModel::setData (const QModelIndex & index, const QVariant &
 // --------------------------------------------------------------
 
 namespace PartDesignGui {
+    class EdgeSelection : public Gui::SelectionFilterGate
+    {
+        App::DocumentObject*& object;
+    public:
+        EdgeSelection(App::DocumentObject*& obj)
+            : Gui::SelectionFilterGate((Gui::SelectionFilter*)0), object(obj)
+        {
+        }
+        bool allow(App::Document*pDoc, App::DocumentObject*pObj, const char*sSubName)
+        {
+            if (pObj != this->object)
+                return false;
+            if (!sSubName || sSubName[0] == '\0')
+                return false;
+            std::string element(sSubName);
+            return element.substr(0,4) == "Edge";
+        }
+    };
     class ChamferWidgetP
     {
     public:
         App::DocumentObject* object;
+        EdgeSelection* selection;
         typedef boost::signals::connection Connection;
         Connection connectApplicationDeletedObject;
         Connection connectApplicationDeletedDocument;
@@ -147,14 +167,17 @@ ChamferWidget::ChamferWidget(QWidget* parent, Qt::WFlags fl)
     ui->setupUi(this);
 
     d->object = 0;
+    d->selection = new EdgeSelection(d->object);
+    Gui::Selection().addSelectionGate(d->selection);
+
     d->connectApplicationDeletedObject = App::GetApplication().signalDeletedObject
         .connect(boost::bind(&ChamferWidget::onDeleteObject, this, _1));
     d->connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument
         .connect(boost::bind(&ChamferWidget::onDeleteDocument, this, _1));
     // set tree view with three columns
     QStandardItemModel* model = new ChamferDistanceModel(this);
-    connect(model, SIGNAL(toogleCheckState(const QModelIndex&)),
-            this, SLOT(toogleCheckState(const QModelIndex&)));
+    connect(model, SIGNAL(toggleCheckState(const QModelIndex&)),
+            this, SLOT(toggleCheckState(const QModelIndex&)));
     model->insertColumns(0,3);
     model->setHeaderData(0, Qt::Horizontal, tr("Edges to chamfer"), Qt::DisplayRole);
     model->setHeaderData(1, Qt::Horizontal, tr("Start distance"), Qt::DisplayRole);
@@ -179,6 +202,7 @@ ChamferWidget::~ChamferWidget()
     // no need to delete child widgets, Qt does it all for us
     d->connectApplicationDeletedDocument.disconnect();
     d->connectApplicationDeletedObject.disconnect();
+    Gui::Selection().rmvSelectionGate();
 }
 
 void ChamferWidget::onSelectionChanged(const Gui::SelectionChanges& msg)
@@ -251,7 +275,7 @@ void ChamferWidget::onDeleteDocument(const App::Document& doc)
     }
 }
 
-void ChamferWidget::toogleCheckState(const QModelIndex& index)
+void ChamferWidget::toggleCheckState(const QModelIndex& index)
 {
     if (!d->object)
         return;
@@ -527,6 +551,13 @@ bool ChamferWidget::accept()
     Gui::Application::Instance->runPythonCode((const char*)code.toAscii());
     activeDoc->commitTransaction();
     activeDoc->recompute();
+
+    QByteArray to = name.toAscii();
+    QByteArray from = shape.toAscii();
+    Gui::Command::copyVisual(to, "ShapeColor", from);
+    Gui::Command::copyVisual(to, "LineColor", from);
+    Gui::Command::copyVisual(to, "PointColor", from);
+
     return true;
 }
 
