@@ -50,6 +50,11 @@ std::vector<const char*> PointKernel::getElementTypes(void) const
     return temp;
 }
 
+unsigned long PointKernel::countSubElements(const char* Type) const
+{
+    return 0;
+}
+
 Data::Segment* PointKernel::getSubElement(const char* Type, unsigned long n) const
 {
     //unsigned long i = 1;
@@ -158,6 +163,16 @@ void PointKernel::save(std::ostream& out) const
     //kernel.Write(out);
 }
 
+void PointKernel::getFaces(std::vector<Base::Vector3d> &Points,std::vector<Facet> &Topo,
+                           float Accuracy, uint16_t flags) const
+{
+    unsigned long ctpoints = _Points.size();
+    Points.reserve(ctpoints);
+    for (unsigned long i=0; i<ctpoints; i++) {
+        Points.push_back(this->getPoint(i));
+    }
+}
+
 // ----------------------------------------------------------------------------
 
 PointKernel::const_point_iterator::const_point_iterator
