@@ -41,7 +41,7 @@ namespace Points
 
 /** Point kernel
  */
-class PointsAppExport PointKernel : public Data::ComplexGeoData
+class PointsExport PointKernel : public Data::ComplexGeoData
 {
     TYPESYSTEM_HEADER();
 
@@ -66,6 +66,7 @@ public:
      *  its NOT a list of the subelements itself
      */
     virtual std::vector<const char*> getElementTypes(void) const;
+    virtual unsigned long countSubElements(const char* Type) const;
     /// get the subelement by type and number
     virtual Data::Segment* getSubElement(const char* Type, unsigned long) const;
     //@}
@@ -76,6 +77,8 @@ public:
     { return this->_Points; }
     const std::vector<Base::Vector3f>& getBasicPoints() const
     { return this->_Points; }
+    void getFaces(std::vector<Base::Vector3d> &Points,std::vector<Facet> &Topo,
+        float Accuracy, uint16_t flags=0) const;
 
     virtual void transformGeometry(const Base::Matrix4D &rclMat);
     virtual Base::BoundBox3d getBoundBox(void)const;
@@ -126,7 +129,7 @@ public:
         _Points.push_back(transformToInside(point));
     }
 
-    class PointsAppExport const_point_iterator
+    class PointsExport const_point_iterator
     {
     public:
         typedef std::vector<Base::Vector3f>::const_iterator iter_type;
