@@ -77,10 +77,10 @@ Base::BoundBox3d PropertyPointKernel::getBoundingBox() const
 }
 
 void PropertyPointKernel::getFaces(std::vector<Base::Vector3d> &Points,
-                                   std::vector<Data::ComplexGeoData::FacetTopo> &Topo,
+                                   std::vector<Data::ComplexGeoData::Facet> &Topo,
                                    float Accuracy, uint16_t flags) const
 {
-    // no 3d triangulator implemented ==> do nothing
+    _cPoints->getFaces(Points, Topo, Accuracy, flags);
 }
 
 PyObject *PropertyPointKernel::getPyObject(void)
@@ -144,7 +144,7 @@ void PropertyPointKernel::RestoreDocFile(Base::Reader &reader)
 App::Property *PropertyPointKernel::Copy(void) const 
 {
     PropertyPointKernel* prop = new PropertyPointKernel();
-    prop->_cPoints = this->_cPoints;
+    (*prop->_cPoints) = (*this->_cPoints);
     return prop;
 }
 
@@ -152,7 +152,7 @@ void PropertyPointKernel::Paste(const App::Property &from)
 {
     aboutToSetValue();
     const PropertyPointKernel& prop = dynamic_cast<const PropertyPointKernel&>(from);
-    this->_cPoints = prop._cPoints;
+    *(this->_cPoints) = *(prop._cPoints);
     hasSetValue();
 }
 
