@@ -4,17 +4,15 @@
   <context>
     <name>CmdRaytracingExportProject</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+452"/>
       <source>File</source>
       <translation>File</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;Export project...</source>
       <translation>&amp;Esporta progetto...</translation>
     </message>
     <message>
-      <location/>
       <source>Export the Povray project file</source>
       <translation>Esporta il file di progetto Povray</translation>
     </message>
@@ -22,17 +20,14 @@
   <context>
     <name>CmdRaytracingNewPartSegment</name>
     <message>
-      <location/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
       <source>Insert part</source>
       <translation>Inserisci parte</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a new part object into a Povray project</source>
       <translation>Inserisci un nuovo oggetto parte in un progetto Povray</translation>
     </message>
@@ -40,51 +35,29 @@
   <context>
     <name>CmdRaytracingNewPovrayProject</name>
     <message>
-      <location/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
       <source>New Povray project</source>
       <translation>Nuovo progetto Povray</translation>
     </message>
     <message>
-      <location/>
       <source>Insert new Povray project into the document</source>
       <translation>Inserisce un nuovo progetto Povray nel documento</translation>
     </message>
   </context>
-  <context>
-    <name>CmdRaytracingNewProject</name>
-    <message>
-      <location/>
-      <source>Raytracing</source>
-      <translation>Raytracing</translation>
-    </message>
-  </context>
-  <context>
-    <name>CmdRaytracingQuickRender</name>
-    <message>
-      <location/>
-      <source>Raytracing</source>
-      <translation>Raytracing</translation>
-    </message>
-  </context>
   <context>
     <name>CmdRaytracingWriteCamera</name>
     <message>
-      <location/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
-      <source>Export camera to povray</source>
-      <translation>Esporta la fotocamera in povray</translation>
+      <source>Export camera to povray...</source>
+      <translation>Esporta la camera a povray...</translation>
     </message>
     <message>
-      <location/>
       <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
       <translation>Esporta la posizione della telecamera della vista 3D attiva in un file in formato PovRay</translation>
     </message>
@@ -92,17 +65,14 @@
   <context>
     <name>CmdRaytracingWritePart</name>
     <message>
-      <location/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
       <source>Export part to povray...</source>
       <translation>Esporta la parte in povray...</translation>
     </message>
     <message>
-      <location/>
       <source>Write the selected Part (object) as a povray file</source>
       <translation>Scrive la parte selezionata (oggetto) come un file povray</translation>
     </message>
@@ -110,17 +80,14 @@
   <context>
     <name>CmdRaytracingWriteView</name>
     <message>
-      <location/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
       <source>Export view to povray...</source>
       <translation>Esporta la vista in povray...</translation>
     </message>
     <message>
-      <location/>
       <source>Write the active 3D view with camera and all its content to a povray file</source>
       <translation>Salva la vista 3D attiva con la camera e tutto il suo contenuto in un file povray</translation>
     </message>
@@ -128,42 +95,34 @@
   <context>
     <name>QObject</name>
     <message>
-      <location/>
       <source>Povray(*.pov)</source>
       <translation>Povray (*.pov)</translation>
     </message>
     <message>
-      <location/>
       <source>All Files (*.*)</source>
       <translation>Tutti i file (*.*)</translation>
     </message>
     <message>
-      <location/>
       <source>Export page</source>
       <translation>Esporta pagina</translation>
     </message>
     <message>
-      <location/>
       <source>Wrong selection</source>
       <translation>Selezione errata</translation>
     </message>
     <message>
-      <location/>
       <source>Select a Part object.</source>
       <translation>Seleziona un oggetto Part.</translation>
     </message>
     <message>
-      <location/>
       <source>No Povray project to insert</source>
       <translation>Nessun progetto Povray da inserire</translation>
     </message>
     <message>
-      <location/>
       <source>Create a Povray project to insert a view.</source>
       <translation>Crea un progetto Povray per inserire una vista.</translation>
     </message>
     <message>
-      <location/>
       <source>Select one Povray project object.</source>
       <translation>Seleziona un progetto Povray.</translation>
     </message>
@@ -171,65 +130,55 @@
   <context>
     <name>RaytracingGui::DlgSettingsRay</name>
     <message>
-      <location/>
+      <location filename="../../DlgSettingsRay.ui" line="+16"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location/>
       <source>Directories</source>
       <translation>Cartelle</translation>
     </message>
     <message>
-      <location/>
       <source>Default Project dir:</source>
       <translation>Cartella di default del progetto:</translation>
     </message>
     <message>
-      <location/>
       <source>Camera file name:</source>
       <translation>Nome del file della telecamera:</translation>
     </message>
     <message>
-      <location/>
       <source>Part file name:</source>
       <translation>Nome del file della parte:</translation>
     </message>
     <message>
-      <location/>
       <source>TempCamera.inc</source>
       <translation>TempCamera.inc</translation>
     </message>
     <message>
-      <location/>
       <source>TempPart.inc</source>
       <translation>TempPart.inc</translation>
     </message>
     <message>
-      <location/>
       <source>Mesh export settings</source>
       <translation>Impostazioni di esportazione mesh</translation>
     </message>
     <message>
-      <location/>
       <source>max mesh deviation:</source>
       <translation>Massima deviazione della mesh:</translation>
     </message>
     <message>
-      <location/>
       <source>Do not calculate vertex normals</source>
       <translation>Non calcolare le normali ai vertici</translation>
     </message>
     <message>
-      <location/>
       <source>Write u,v coordinates</source>
       <translation>Salva le coordinate u,v</translation>
     </message>
   </context>
   <context>
-    <name>RaytracingGui::Workbench</name>
+    <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+37"/>
       <source>&amp;Raytracing</source>
       <translation>&amp;Raytracing</translation>
     </message>
