@@ -4,17 +4,15 @@
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
-      <location/>
+      <location filename="../../CommandInsertRobot.cpp" line="+215"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Add tool</source>
       <translation>新增工具</translation>
     </message>
     <message>
-      <location/>
       <source>Add a tool shape to the robot</source>
       <translation>将工具形状添加到机器人</translation>
     </message>
@@ -22,17 +20,15 @@
   <context>
     <name>CmdRobotConstraintAxle</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+158"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Place robot...</source>
       <translation>机器人区域...</translation>
     </message>
     <message>
-      <location/>
       <source>Place a robot (experimental!)</source>
       <translation>放置机器人(实验!)</translation>
     </message>
@@ -40,17 +36,15 @@
   <context>
     <name>CmdRobotCreateTrajectory</name>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="+61"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Create trajectory</source>
       <translation>创建轨迹</translation>
     </message>
     <message>
-      <location/>
       <source>Create a new empty trajectory </source>
       <translation>创建新的空轨迹 </translation>
     </message>
@@ -58,17 +52,14 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Edge to Trajectory...</source>
       <translation>边缘到轨迹...</translation>
     </message>
     <message>
-      <location/>
       <source>Generate a Trajectory from a set of edges</source>
       <translation>从一组边生成轨迹</translation>
     </message>
@@ -76,17 +67,15 @@
   <context>
     <name>CmdRobotExportKukaCompact</name>
     <message>
-      <location/>
+      <location filename="../../CommandExport.cpp" line="+50"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka compact subroutine...</source>
       <translation>Kuka压缩子例程...</translation>
     </message>
     <message>
-      <location/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
       <translation>导出轨迹为压缩 KRL 子例程.</translation>
     </message>
@@ -94,17 +83,14 @@
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka full subroutine...</source>
       <translation>Kuka完整子例程...</translation>
     </message>
     <message>
-      <location/>
       <source>Export the trajectory as a full KRL subroutine.</source>
       <translation>导出轨迹为完整 KRL 子例程.</translation>
     </message>
@@ -112,17 +98,15 @@
   <context>
     <name>CmdRobotInsertKukaIR125</name>
     <message>
-      <location/>
+      <location filename="../../CommandInsertRobot.cpp" line="-43"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a Kuka IR125 into the document.</source>
       <translation>将Kuka IR125导入文档.</translation>
     </message>
@@ -130,17 +114,14 @@
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a Kuka IR16 into the document.</source>
       <translation>将Kuka IR16导入文档.</translation>
     </message>
@@ -148,17 +129,14 @@
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a Kuka IR210 into the document.</source>
       <translation>将Kuka IR210导入文档.</translation>
     </message>
@@ -166,17 +144,14 @@
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
-      <location/>
       <source>Insert a Kuka IR500 into the document.</source>
       <translation>将Kuka IR500导入文档.</translation>
     </message>
@@ -184,17 +159,15 @@
   <context>
     <name>CmdRobotInsertWaypoint</name>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="-228"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Insert in trajectory</source>
       <translation>在轨迹中插入</translation>
     </message>
     <message>
-      <location/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>导入机器人工具位置到轨迹</translation>
     </message>
@@ -202,17 +175,14 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Insert in trajectory</source>
       <translation>在轨迹中插入</translation>
     </message>
     <message>
-      <location/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>预选位置插入轨迹(W)</translation>
     </message>
@@ -220,12 +190,11 @@
   <context>
     <name>CmdRobotRestoreHomePos</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-56"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Move to home</source>
       <translation>移动到初始</translation>
     </message>
@@ -233,17 +202,15 @@
   <context>
     <name>CmdRobotSetDefaultOrientation</name>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="+62"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Set default orientation</source>
       <translation>设置默认方向</translation>
     </message>
     <message>
-      <location/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
       <translation>为后续创建路径点命令设置默认方向</translation>
     </message>
@@ -251,17 +218,14 @@
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Set default values</source>
       <translation>设置默认值</translation>
     </message>
     <message>
-      <location/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
       <translation>为后续创建路径点命令设置默认速度,加速度和连续性</translation>
     </message>
@@ -269,12 +233,11 @@
   <context>
     <name>CmdRobotSetHomePos</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-51"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Set the home position</source>
       <translation>设置初始位置</translation>
     </message>
@@ -282,17 +245,14 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Simulate a trajectory</source>
       <translation>模拟轨迹</translation>
     </message>
     <message>
-      <location/>
       <source>Run a simulation on a trajectory</source>
       <translation>在轨迹上模拟</translation>
     </message>
@@ -300,17 +260,15 @@
   <context>
     <name>CmdRobotTrajectoryCompound</name>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="+175"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Trajectory compound...</source>
       <translation>复合轨迹...</translation>
     </message>
     <message>
-      <location/>
       <source>Group and connect some trajectories to one</source>
       <translation>将轨迹组合并连接成一个</translation>
     </message>
@@ -318,125 +276,128 @@
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
-      <location/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Dress up trajectory...</source>
       <translation>修饰轨迹...</translation>
     </message>
     <message>
-      <location/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
       <translation>为轨迹重载创建一个修饰对象</translation>
     </message>
   </context>
+  <context>
+    <name>Gui::TaskView::TaskWatcherCommands</name>
+    <message>
+      <location filename="../../Workbench.cpp" line="+52"/>
+      <source>Trajectory tools</source>
+      <translation>轨迹工具</translation>
+    </message>
+    <message>
+      <source>Robot tools</source>
+      <translation>机器人工具</translation>
+    </message>
+    <message>
+      <source>Insert Robot</source>
+      <translation>插入机器人</translation>
+    </message>
+  </context>
   <context>
     <name>QObject</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-126"/>
       <source>Wrong selection</source>
       <translation>选择错误</translation>
     </message>
     <message>
-      <location/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>选择一个机器人和一个轨迹对象.</translation>
     </message>
     <message>
-      <location/>
       <source>Trajectory not valid</source>
       <translation>无效轨迹</translation>
     </message>
     <message>
-      <location/>
       <source>You need at least two way points in a trajectory to simulate.</source>
       <translation>你至少需要两个路径点以进行轨迹模拟.</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../CommandExport.cpp" line="-43"/>
       <source>KRL file(*.src)</source>
       <translation>KRL文件(*.src)</translation>
     </message>
     <message>
-      <location/>
       <source>All Files (*.*)</source>
       <translation>所有文件(*.*)</translation>
     </message>
     <message>
-      <location/>
       <source>Export program</source>
       <translation>导出程序</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../CommandInsertRobot.cpp" line="+1"/>
       <source>Select one robot and one shape or VRML object.</source>
       <translation>选择一个机器人和一个形状或VRML对象.</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="+79"/>
       <source>No preselection</source>
       <translation>无预选</translation>
     </message>
     <message>
-      <location/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>您必须悬停鼠标于(预选)几何体以使用该命令.详情请参考文档.</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-155"/>
       <source>Select one Robot to set home postion</source>
       <translation>选中一个机器人并设置初始位置</translation>
     </message>
     <message>
-      <location/>
       <source>Select one Robot</source>
       <translation>选择一个机器人</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../CommandTrajectory.cpp" line="-24"/>
       <source>Select one Trajectory object.</source>
       <translation>选择一个轨迹对象.</translation>
     </message>
     <message>
-      <location/>
       <source>set default speed</source>
       <translation>设置默认速度</translation>
     </message>
     <message>
-      <location/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>速度: (如 1 m/s 或 3 cm/s)</translation>
     </message>
     <message>
-      <location/>
       <source>set default continuity</source>
       <translation>设置默认连续性</translation>
     </message>
     <message>
-      <location/>
       <source>continuous ?</source>
       <translation>连续的?</translation>
     </message>
     <message>
-      <location/>
       <source>set default acceleration</source>
       <translation>设置默认加速度</translation>
     </message>
     <message>
-      <location/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
       <translation>加速度: (如 1 m/s^2 或 3 cm/s^2)</translation>
     </message>
     <message>
-      <location/>
+      <source>Select the Trajectory which you want to dress up.</source>
+      <translation>选择您要遵循的轨迹.</translation>
+    </message>
+    <message>
+      <location filename="../../Workbench.cpp" line="+26"/>
       <source>No robot files installed</source>
       <translation>未安装机器人文件</translation>
     </message>
     <message>
-      <location/>
       <source>Please visit %1 and copy the files to %2</source>
       <translation>请访问 %1 并复制文件到 %2</translation>
     </message>
@@ -444,67 +405,55 @@
   <context>
     <name>RobotGui::DlgTrajectorySimulate</name>
     <message>
-      <location/>
+      <location filename="../../TrajectorySimulate.ui" line="+20"/>
       <source>Simulation</source>
       <translation>模拟</translation>
     </message>
     <message>
-      <location/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
-      <location/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
-      <location/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
-      <location/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
-      <location/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
-      <location/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
-      <location/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
-      <location/>
       <source>Type</source>
       <translation>类型</translation>
     </message>
     <message>
-      <location/>
       <source>Name</source>
       <translation>名称</translation>
     </message>
     <message>
-      <location/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
-      <location/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
-      <location/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -512,7 +461,7 @@
   <context>
     <name>RobotGui::TaskEdge2TracParameter</name>
     <message>
-      <location/>
+      <location filename="../../TaskEdge2TracParameter.cpp" line="+47"/>
       <source>TaskEdge2TracParameter</source>
       <translation>边转轨迹任务参数</translation>
     </message>
@@ -520,57 +469,48 @@
   <context>
     <name>RobotGui::TaskRobot6Axis</name>
     <message>
-      <location/>
+      <location filename="../../TaskRobot6Axis.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
-      <location/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
-      <location/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
-      <location/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
-      <location/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
-      <location/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
-      <location/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
-      <location/>
       <source>Tool: (0,0,400,0,0,0)</source>
       <translation>工具：（0,0,400,0,0,0）</translation>
     </message>
     <message>
-      <location/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../TaskRobot6Axis.cpp" line="+52"/>
       <source>TaskRobot6Axis</source>
       <translation>机器人6轴任务</translation>
     </message>
@@ -578,7 +518,7 @@
   <context>
     <name>RobotGui::TaskRobotControl</name>
     <message>
-      <location/>
+      <location filename="../../TaskRobotControl.cpp" line="+46"/>
       <source>TaskRobotControl</source>
       <translation>任务机器人控制</translation>
     </message>
@@ -586,7 +526,7 @@
   <context>
     <name>RobotGui::TaskRobotMessages</name>
     <message>
-      <location/>
+      <location filename="../../TaskRobotMessages.cpp" line="+46"/>
       <source>TaskRobotMessages</source>
       <translation>机器人信息任务</translation>
     </message>
@@ -594,102 +534,84 @@
   <context>
     <name>RobotGui::TaskTrajectory</name>
     <message>
-      <location/>
+      <location filename="../../TaskTrajectory.ui" line="+20"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
-      <location/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
-      <location/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
-      <location/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
-      <location/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
-      <location/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
-      <location/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
-      <location/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
-      <location/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
-      <location/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
-      <location/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
-      <location/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
-      <location/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>位置: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
     </message>
     <message>
-      <location/>
       <source>Type</source>
       <translation>类型</translation>
     </message>
     <message>
-      <location/>
       <source>Name</source>
       <translation>名称</translation>
     </message>
     <message>
-      <location/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
-      <location/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
-      <location/>
       <source>A</source>
       <translation>A</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../TaskTrajectory.cpp" line="+44"/>
       <source>Trajectory</source>
       <translation>轨迹</translation>
     </message>
@@ -697,7 +619,7 @@
   <context>
     <name>RobotGui::TaskTrajectoryDressUpParameter</name>
     <message>
-      <location/>
+      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="+48"/>
       <source>Dress Up Parameter</source>
       <translation>修饰参数</translation>
     </message>
@@ -705,259 +627,249 @@
   <context>
     <name>TaskEdge2TracParameter</name>
     <message>
-      <location/>
+      <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>Hide / Show</source>
       <translation>隐藏/显示</translation>
     </message>
     <message>
-      <location/>
       <source>Edges: 0</source>
       <translation>边：0</translation>
     </message>
     <message>
-      <location/>
       <source>Cluster: 0</source>
       <translation>集群：0</translation>
     </message>
     <message>
-      <location/>
       <source>Sizing Value:</source>
       <translation>调整大小的值:</translation>
     </message>
+    <message>
+      <source>Use orientation of edge</source>
+      <translation>使用边缘的方向</translation>
+    </message>
+    <message>
+      <source>TaskEdge2TracParameter</source>
+      <translation>边转轨迹任务参数</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskRobot6Axis</name>
+    <message>
+      <source>TaskRobot6Axis</source>
+      <translation>机器人6轴任务</translation>
+    </message>
   </context>
   <context>
     <name>TaskRobotControl</name>
     <message>
-      <location/>
+      <location filename="../../TaskRobotControl.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>X+</source>
       <translation>X+</translation>
     </message>
     <message>
-      <location/>
       <source>Y+</source>
       <translation>Y+</translation>
     </message>
     <message>
-      <location/>
       <source>Z+</source>
       <translation>Z+</translation>
     </message>
     <message>
-      <location/>
       <source>A+</source>
       <translation>A+</translation>
     </message>
     <message>
-      <location/>
       <source>B+</source>
       <translation>B+</translation>
     </message>
     <message>
-      <location/>
       <source>C+</source>
       <translation>C+</translation>
     </message>
     <message>
-      <location/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
-      <location/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
-      <location/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
-      <location/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
-      <location/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
-      <location/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
-      <location/>
       <source>Tool 0</source>
       <translation>工具 0</translation>
     </message>
     <message>
-      <location/>
       <source>Tool</source>
       <translation>工具</translation>
     </message>
     <message>
-      <location/>
       <source>Base 0</source>
       <translation>基本 0</translation>
     </message>
     <message>
-      <location/>
       <source>Base</source>
       <translation>基本</translation>
     </message>
     <message>
-      <location/>
       <source>World</source>
       <translation>世界</translation>
     </message>
     <message>
-      <location/>
       <source>50mm / 5°</source>
       <translation>50mm / 5°</translation>
     </message>
     <message>
-      <location/>
       <source>20mm / 2°</source>
       <translation>20mm / 2°</translation>
     </message>
     <message>
-      <location/>
       <source>10mm / 1°</source>
       <translation>10mm / 1°</translation>
     </message>
     <message>
-      <location/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0.5°</translation>
     </message>
     <message>
-      <location/>
       <source>1mm / 0.1°</source>
       <translation>1mm / 0.1°</translation>
     </message>
+    <message>
+      <source>TaskRobotControl</source>
+      <translation>任务机器人控制</translation>
+    </message>
   </context>
   <context>
     <name>TaskRobotMessages</name>
     <message>
-      <location/>
+      <location filename="../../TaskRobotMessages.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>clear</source>
       <translation>清除</translation>
     </message>
+    <message>
+      <source>TaskRobotMessages</source>
+      <translation>机器人信息任务</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskTrajectory</name>
+    <message>
+      <source>Trajectory</source>
+      <translation>轨迹</translation>
+    </message>
   </context>
   <context>
     <name>TaskTrajectoryDressUpParameter</name>
     <message>
-      <location/>
+      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>Speed &amp; Acceleration:</source>
       <translation>速度和加速度:</translation>
     </message>
     <message>
-      <location/>
       <source>Speed:</source>
       <translation>速度:</translation>
     </message>
     <message>
-      <location/>
       <source>Use</source>
       <translation>使用</translation>
     </message>
     <message>
-      <location/>
       <source>Accel:</source>
       <translation>加速:</translation>
     </message>
     <message>
-      <location/>
       <source>Don't change Cont</source>
       <translation>不要更改连续</translation>
     </message>
     <message>
-      <location/>
       <source>Continues</source>
       <translation>连续</translation>
     </message>
     <message>
-      <location/>
       <source>Discontinues</source>
       <translation>中止</translation>
     </message>
     <message>
-      <location/>
       <source>Position and Orientation:</source>
       <translation>位置和方向:</translation>
     </message>
     <message>
-      <location/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
-      <location/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
-      <location/>
       <source>Don't change Position &amp; Orientation</source>
       <translation>不要改变位置和方向</translation>
     </message>
     <message>
-      <location/>
       <source>Use Orientation</source>
       <translation>使用方向</translation>
     </message>
     <message>
-      <location/>
       <source>Add Position</source>
       <translation>添加位置</translation>
     </message>
     <message>
-      <location/>
       <source>Add Orientation</source>
       <translation>添加定位</translation>
     </message>
+    <message>
+      <source>Dress Up Parameter</source>
+      <translation>修饰参数</translation>
+    </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="-33"/>
       <source>Robot</source>
       <translation>机器人</translation>
     </message>
     <message>
-      <location/>
       <source>Insert Robots</source>
       <translation>导入机器人</translation>
     </message>
     <message>
-      <location/>
       <source>&amp;Robot</source>
       <translation>机器人(&amp;R)</translation>
     </message>
     <message>
-      <location/>
       <source>Export trajectory</source>
       <translation>导出轨迹</translation>
     </message>
