@@ -21,7 +21,6 @@
  ***************************************************************************/
 
 
-
 #ifndef SKETCHER_CONSTRAINT_H
 #define SKETCHER_CONSTRAINT_H
 
@@ -37,14 +36,22 @@ enum ConstraintType {
     Horizontal,
     Vertical,
     Parallel,
+    Tangent,
     Distance,
-    Angle
+    DistanceX,
+    DistanceY,
+    Angle,
+    Perpendicular,
+    Radius,
+    Equal,
+    PointOnObject,
+    Symmetric
 };
 
-/// define if you whant to use the end or start point
-enum PointPos {none,start,end,mid };
+/// define if you want to use the end or start point
+enum PointPos { none, start, end, mid };
 
-class Constraint :public Base::Persistence
+class SketcherExport Constraint :public Base::Persistence
 {
     TYPESYSTEM_HEADER();
 
@@ -54,10 +61,11 @@ public:
     Constraint(const Constraint&);
     virtual Constraint *clone(void)const;
 
+    static const int GeoUndef;
 
-	// from base class
-    virtual unsigned int getMemSize (void) const;
-	virtual void Save (Base::Writer &/*writer*/) const;
+    // from base class
+    virtual unsigned int getMemSize(void) const;
+    virtual void Save(Base::Writer &/*writer*/) const;
     virtual void Restore(Base::XMLReader &/*reader*/);
 
     virtual PyObject *getPyObject(void);
@@ -72,10 +80,9 @@ public:
     PointPos FirstPos;
     int Second;
     PointPos SecondPos;
-    int Extern;
-
-
-
+    int Third;
+    PointPos ThirdPos;
+    float LabelDistance;
 };
 
 } //namespace Part
