@@ -25,6 +25,7 @@
 #define SKETCHERGUI_DrawSketchHandler_H
 
 #include <Base/Tools2D.h>
+#include <Mod/Sketcher/App/Constraint.h>
 
 class QPixmap;
 
@@ -42,8 +43,21 @@ namespace SketcherGui {
 
 class ViewProviderSketch;
 
+// A Simple data type to hold basic information for suggested constraints
+struct AutoConstraint
+{
+    Sketcher::ConstraintType Type;
+    int Index;
+};
+
+enum Type
+{
+    VERTEX,
+    CURVE
+};
+
 /** Handler to create new sketch geometry
-  * This class has to be reimplemented to create geometry in the 
+  * This class has to be reimplemented to create geometry in the
   * sketcher while its in editing.
   */
 class SketcherGuiExport DrawSketchHandler
@@ -62,24 +76,30 @@ public:
     friend class ViewProviderSketch;
 
     Sketcher::SketchObject* getObject(void);
-	// get the actual highest vertex index, the next use will be +1
-	int getHighestVertexIndex(void);
-	// get the actual highest edge index, the next use will be +1
-	int getHighestCurveIndex(void);
+    // get the actual highest vertex index, the next use will be +1
+    int getHighestVertexIndex(void);
+    // get the actual highest edge index, the next use will be +1
+    int getHighestCurveIndex(void);
+
+    int seekAutoConstraint(std::vector<AutoConstraint> &suggestedConstraints,
+                           const Base::Vector2D &Pos, const Base::Vector2D &Dir, Type selType = VERTEX);
+    void createAutoConstraints(const std::vector<AutoConstraint> &autoConstrs,
+                               int geoId, Sketcher::PointPos pointPos=Sketcher::none);
 
     void setPositionText(const Base::Vector2D &Pos);
     void resetPositionText(void);
+    void renderSuggestConstraintsCursor(std::vector<AutoConstraint> &suggestedConstraints);
 
 protected:
     // helpers
     void setCursor( const QPixmap &p,int x,int y );
     void unsetCursor(void);
 	void applyCursor(void);
+	void applyCursor(QCursor &newCursor);
 
     ViewProviderSketch *sketchgui;
     QCursor oldCursor;
     QCursor actCursor;
-
 };
 
 
