@@ -2,24 +2,32 @@
 <!DOCTYPE TS>
 <TS>
   <context>
-    <name>CmdSketcherConstrainCoincident</name>
+    <name>CmdSketcherConstrainAngle</name>
     <message>
-      <location/>
+      <location filename="../../CommandConstraints.cpp" line="+1370"/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain lock</source>
-      <translation>Ograniči pomicanje</translation>
+      <source>Constrain angle</source>
+      <translation>Ograniči kut</translation>
+    </message>
+    <message>
+      <source>Fix the angle of a line or the angle between two lines</source>
+      <translation>Fiksiraj kut linije ili kut između dvije linije</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainCoincident</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain coincident</source>
       <translation>Ograničiti zajedničko</translation>
     </message>
     <message>
-      <location/>
       <source>Create a coincident constraint on the selected item</source>
       <translation>Napravi zajedničko ograničenje na odabranim jedinicama</translation>
     </message>
@@ -27,45 +35,74 @@
   <context>
     <name>CmdSketcherConstrainDistance</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain distance</source>
       <translation>Ograniči udaljenost</translation>
     </message>
     <message>
-      <location/>
       <source>Fix a length of a line or the distance between a line and a vertex</source>
       <translation>Ograniči duljinu linije ili udaljenost između linije i vrha</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainHorizontal</name>
+    <name>CmdSketcherConstrainDistanceX</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain orizontal</source>
-      <translation>Ograniči vodoravno</translation>
+      <source>Constrain horizontal distance</source>
+      <translation>Ograniči horizontalnu udaljenost</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a horizontal constrain on the selcted item</source>
-      <translation>Napravi vodoravno ograničenje na odabranoj jedinici</translation>
+      <source>Fix the horizontal distance between two points or line ends</source>
+      <translation>Ograniči horizontalnu udaljenost između dvije točke ili krajeva linije</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainDistanceY</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain horizontal distance</source>
+      <translation>Ograniči horizontalnu udaljenost</translation>
+    </message>
+    <message>
+      <source>Fix the vertical distance between two points or line ends</source>
+      <translation>Ograniči vertikalnu udaljenost između dvije točke ili krajeva linije</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainEqual</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain equal</source>
+      <translation>Ograniči jednaku duljinu</translation>
+    </message>
+    <message>
+      <source>Create an equality constraint between two lines or between circles and arcs</source>
+      <translation>Napravite ograničenje jednakosti između dvije linije ili između kružnica i lukova</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainHorizontal</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain horizontally</source>
       <translation>Ograniči vodoravno</translation>
     </message>
     <message>
-      <location/>
       <source>Create a horizontal constraint on the selected item</source>
       <translation>Napravi vodoravno ograničenje na odabranoj jedinici</translation>
     </message>
@@ -73,73 +110,119 @@
   <context>
     <name>CmdSketcherConstrainLock</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain Lock</source>
-      <translation>Ograniči pomicanje</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a Lock constrain on the selcted item</source>
-      <translation>Napravi ograničiti pomicanja odabrane stavke</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a lock constrain on the selected item</source>
-      <translation>Zaključaj odabranu jedinicu</translation>
-    </message>
-    <message>
-      <location/>
       <source>Constrain lock</source>
       <translation>Ograniči pomicanje</translation>
     </message>
+    <message>
+      <source>Create a lock constraint on the selected item</source>
+      <translation>Napravi ograničenje fiksiranja na odabranim stavkama</translation>
+    </message>
   </context>
   <context>
     <name>CmdSketcherConstrainParallel</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain parallel</source>
       <translation>Ograniči paralelno</translation>
     </message>
     <message>
-      <location/>
       <source>Create a parallel constraint between two lines</source>
       <translation>Napravi paralelno ograničenje između dvije linije</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainVertical</name>
+    <name>CmdSketcherConstrainPerpendicular</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain vertical</source>
+      <source>Constrain perpendicular</source>
       <translation>Ograniči okomito</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a vertical constrain on the selcted item</source>
-      <translation>Napravite horizontalno ograničenje na odabranoj jedinici</translation>
+      <source>Create a Perpendicular constraint between two lines</source>
+      <translation>Napravi okomito ograničenje između dvije linije</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainPointOnObject</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain point onto object</source>
+      <translation>Ograniči točku na objekt</translation>
+    </message>
+    <message>
+      <source>Fix a point onto an object</source>
+      <translation>Fiksiraj točku na objekt</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainRadius</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain radius</source>
+      <translation>Ograniči radijus</translation>
+    </message>
+    <message>
+      <source>Fix the radius of a circle or an arc</source>
+      <translation>Fiksiraj radijus kruga ili luka</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainSymmetric</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain symmetrical</source>
+      <translation>Ograniči simetrijski</translation>
+    </message>
+    <message>
+      <source>Create an symmetry constraint between two points with respect to a line</source>
+      <translation>Napravite simetrijsko ograničenje između dvije točke u odnosu na liniju</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainTangent</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Constrain tangent</source>
+      <translation>Ograniči tangentno</translation>
+    </message>
+    <message>
+      <source>Create a tangent constraint between two entities</source>
+      <translation>Napravi tangentno ograničenje između dva entiteta</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainVertical</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain vertically</source>
       <translation>Ograniči okomito</translation>
     </message>
     <message>
-      <location/>
       <source>Create a vertical constraint on the selected item</source>
       <translation>Napravi okomito ograničenje na odabranoj jedinici</translation>
     </message>
@@ -147,53 +230,30 @@
   <context>
     <name>CmdSketcherCreateArc</name>
     <message>
-      <location/>
+      <location filename="../../CommandCreateGeo.cpp" line="+870"/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create arc</source>
       <translation>Napravi luk</translation>
     </message>
     <message>
-      <location/>
       <source>Create an arc in the sketch</source>
       <translation>Napravite luk u skici</translation>
     </message>
   </context>
-  <context>
-    <name>CmdSketcherCreateBox</name>
-    <message>
-      <location/>
-      <source>Sketcher</source>
-      <translation>Skica</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create box</source>
-      <translation>Napravi okvir</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a box in the sketch</source>
-      <translation>Napravi okvir u skici</translation>
-    </message>
-  </context>
   <context>
     <name>CmdSketcherCreateCircle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create circle</source>
       <translation>Napravi krug</translation>
     </message>
     <message>
-      <location/>
       <source>Create a circle in the sketch</source>
       <translation>Napravi krug u skici</translation>
     </message>
@@ -201,35 +261,44 @@
   <context>
     <name>CmdSketcherCreateDraftLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create draft line</source>
       <translation>Napravi liniju</translation>
     </message>
     <message>
-      <location/>
       <source>Create a draft line in the sketch</source>
       <translation>Napravi liniju u skici</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherCreateFillet</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Create fillet</source>
+      <translation>Napravi obrub</translation>
+    </message>
+    <message>
+      <source>Create a fillet between to lines or at a coincident point</source>
+      <translation>Napravi obrub između linija ili u podudarnoj točki</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherCreateLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create line</source>
       <translation>Napravi liniju</translation>
     </message>
     <message>
-      <location/>
       <source>Create a line in the sketch</source>
       <translation>Napravi liniju u skici</translation>
     </message>
@@ -237,17 +306,14 @@
   <context>
     <name>CmdSketcherCreatePoint</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create point</source>
       <translation>Napravi točku</translation>
     </message>
     <message>
-      <location/>
       <source>Create a point in the sketch</source>
       <translation>Napravi točku u skici</translation>
     </message>
@@ -255,17 +321,14 @@
   <context>
     <name>CmdSketcherCreatePolyline</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create polyline</source>
       <translation>Napravi poliliniju</translation>
     </message>
     <message>
-      <location/>
       <source>Create a polyline in the sketch</source>
       <translation>Napravite poliliniju u skici</translation>
     </message>
@@ -273,17 +336,14 @@
   <context>
     <name>CmdSketcherCreateRectangle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create rectangle</source>
       <translation>Napravi pravokutnik</translation>
     </message>
     <message>
-      <location/>
       <source>Create a rectangle in the sketch</source>
       <translation>Napravi pravokutnik u skici</translation>
     </message>
@@ -291,22 +351,14 @@
   <context>
     <name>CmdSketcherCreateText</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create text</source>
       <translation>Napravi tekst</translation>
     </message>
     <message>
-      <location/>
-      <source>Create text in the scetch</source>
-      <translation>Napravi tekst u skici</translation>
-    </message>
-    <message>
-      <location/>
       <source>Create text in the sketch</source>
       <translation>Napravi tekst u skici</translation>
     </message>
@@ -314,35 +366,49 @@
   <context>
     <name>CmdSketcherLeaveSketch</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+270"/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Leave sketch</source>
       <translation>Zatvori skicu</translation>
     </message>
     <message>
-      <location/>
       <source>Close the editing of the sketch</source>
       <translation>Zatvori uređivanje skice</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherMapSketch</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Map sketch to face...</source>
+      <translation>Povezuje skicu sa površinom ...</translation>
+    </message>
+    <message>
+      <source>Map a sketch to a face</source>
+      <translation>Mapiraj skicu na površinu</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherNewSketch</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create sketch</source>
       <translation>Napravite skicu</translation>
     </message>
     <message>
-      <location/>
+      <source>Create a new or edit the selected sketch</source>
+      <translation>Create a new or edit the selected sketch</translation>
+    </message>
+    <message>
       <source>Create a new sketch</source>
       <translation>Napravi novu skicu</translation>
     </message>
@@ -350,25 +416,70 @@
   <context>
     <name>CmdSketcherNewSketchSF</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
       <source>Sketchflat sketch</source>
       <translation>Sketchflat skica</translation>
     </message>
     <message>
-      <location/>
       <source>Create a new sketchflat sketch by starting externel editor</source>
       <translation>Napravi novu sketchflat skicu pokretanjem vanjskog urednika</translation>
     </message>
   </context>
+  <context>
+    <name>CmdSketcherToggleConstruction</name>
+    <message>
+      <location filename="../../CommandAlterGeometry.cpp" line="+67"/>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Toggle construction line</source>
+      <translation>Prebaci liniju u konstrukciju</translation>
+    </message>
+    <message>
+      <source>Toggles the currently selected lines to/from construction mode</source>
+      <translation>Prebacuje trenutno odabrane linije u/iz konstrukcijske linije</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherTrimming</name>
+    <message>
+      <location filename="../../CommandCreateGeo.cpp" line="+425"/>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>Trim edge</source>
+      <translation>Skrati rub</translation>
+    </message>
+    <message>
+      <source>Trims an edge with respect to the picked position</source>
+      <translation>Presjeca rub s obzirom na odabranu poziciju</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherViewSketch</name>
+    <message>
+      <location filename="../../Command.cpp" line="+244"/>
+      <source>Sketcher</source>
+      <translation>Skica</translation>
+    </message>
+    <message>
+      <source>View sketch</source>
+      <translation>Pregledaj skicu</translation>
+    </message>
+    <message>
+      <source>View sketch perpendicular to sketch plane</source>
+      <translation>Vidi skicu okomitu na ravninu skice</translation>
+    </message>
+  </context>
   <context>
     <name>Gui::TaskView::TaskSketcherCreateCommands</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherCreateCommands.cpp" line="+40"/>
       <source>Appearance</source>
       <translation>Izgled</translation>
     </message>
@@ -376,115 +487,235 @@
   <context>
     <name>QObject</name>
     <message>
-      <location/>
+      <location filename="../../CommandAlterGeometry.cpp" line="+15"/>
       <source>Wrong selection</source>
       <translation>Pogrešan odabir</translation>
     </message>
     <message>
-      <location/>
+      <source>Select edge(s) from the sketch.</source>
+      <translation>Odaberite rub(ove) iz skice.</translation>
+    </message>
+    <message>
+      <location filename="../../CommandConstraints.cpp" line="-1518"/>
       <source>Select an edge from the sketch.</source>
       <translation>Odaberite rub skice.</translation>
     </message>
     <message>
-      <location/>
       <source>Double constraint</source>
       <translation>Ograničenje dvaput</translation>
     </message>
     <message>
-      <location/>
       <source>The selected edge has already a horizontal constraint!</source>
       <translation>Odabrani rub već ima vodoravno ograničenje!</translation>
     </message>
     <message>
-      <location/>
       <source>Impossible constraint</source>
       <translation>Nemoguće ograničenje</translation>
     </message>
     <message>
-      <location/>
+      <source>Only sketch and its support is allowed to select</source>
+      <translation>Dopušteno je odabrati samo skicu i njenu podršku</translation>
+    </message>
+    <message>
+      <source>One of the selected has to be on the sketch</source>
+      <translation>Jedan od odabranih mora biti na skici</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a line segment</source>
+      <translation>Odabrani rub nije linija</translation>
+    </message>
+    <message>
       <source>The selected edge has already a vertical constraint!</source>
       <translation>Odabrani rub već ima okomito ograničenje!</translation>
     </message>
     <message>
-      <location/>
+      <source>Select entities from the sketch.</source>
+      <translation>Odaberite entitet iz skice.</translation>
+    </message>
+    <message>
+      <source>Select exactly one entity from the sketch.</source>
+      <translation>Odaberite točno jedan entitet iz skice.</translation>
+    </message>
+    <message>
       <source>Select vertexes from the sketch.</source>
       <translation>Odaberite vrhove sa skice.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two vertexes from the sketch.</source>
       <translation>Odaberite točno dva vrha iz skice.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select exactly one line or one point and one line or two points from the sketch.</source>
+      <translation>Odaberite točno jednu liniju ili jednu točku i jednu liniju ili dvije točke iz skice.</translation>
+    </message>
+    <message>
+      <source>Select exactly one point and one object from the sketch.</source>
+      <translation>Odaberite točno jednu točku i jedan objekt iz skice.</translation>
+    </message>
+    <message>
+      <source>Select exactly one line or up to two points from the sketch.</source>
+      <translation>Odaberite točno jednu liniju ili do dvije točke iz skice.</translation>
+    </message>
+    <message>
+      <source>Select two or more lines from the sketch.</source>
+      <translation>Odaberite dvije ili više linija iz skice.</translation>
+    </message>
+    <message>
+      <source>Select at least two lines from the sketch.</source>
+      <translation>Odaberite barem dvije linije iz skice.</translation>
+    </message>
+    <message>
+      <source>Select a valid line</source>
+      <translation>Odaberite valjanu liniju</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a valid line</source>
+      <translation>Odabrani rub nije valjana linija</translation>
+    </message>
+    <message>
+      <source>Select exactly one arc or circle from the sketch.</source>
+      <translation>Odaberite točno jedan luk ili krug iz skica.</translation>
+    </message>
+    <message>
+      <source>Select exactly one or two lines from the sketch.</source>
+      <translation>Odaberite točno jednu ili dvije linije iz skice.</translation>
+    </message>
+    <message>
+      <source>Select two edges from the sketch.</source>
+      <translation>Odaberite dva ruba iz skice.</translation>
+    </message>
+    <message>
+      <source>Select atleast two lines from the sketch.</source>
+      <translation>Odaberite barem dvije linije iz skice.</translation>
+    </message>
+    <message>
+      <source>Select exactly two same geometries</source>
+      <translation>Odaberite točno dvije iste geometrije</translation>
+    </message>
+    <message>
+      <source>Select valid geometries</source>
+      <translation>Odaberite valjane geometrije</translation>
+    </message>
+    <message>
+      <source>Select geometry of similar type</source>
+      <translation>Odaberite geometriju sličnog tipa</translation>
+    </message>
+    <message>
+      <source>Select two points and one line from the sketch.</source>
+      <translation>Odaberite dvije točke i jednu liniju iz skice.</translation>
+    </message>
+    <message>
       <source>Select exactly one line from the sketch.</source>
       <translation>Odaberite samo jednu liniju iz skice.</translation>
     </message>
     <message>
-      <location/>
       <source>Select two lines from the sketch.</source>
       <translation>Odaberite dvije linije iz skice.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two lines from the sketch.</source>
       <translation>Odaberite točno dvije linije iz skice.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select two entities from the sketch.</source>
+      <translation>Odaberite dva entiteta iz skice.</translation>
+    </message>
+    <message>
+      <source>Select exactly two entities from the sketch.</source>
+      <translation>Odaberite točno dva entiteta iz skice.</translation>
+    </message>
+    <message>
+      <location filename="../../ViewProviderSketch.cpp" line="+2591"/>
       <source>Edit sketch</source>
       <translation>Uredi skicu</translation>
     </message>
     <message>
-      <location/>
       <source>A dialog is already open in the task panel</source>
       <translation>Dijalog je već otvoren u ploči zadataka</translation>
     </message>
     <message>
-      <location/>
       <source>Do you want to close this dialog?</source>
-      <translation>Da li želite zatvoriti ovaj dijalog?</translation>
+      <translation>Želite li zatvoriti ovaj dijalog?</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-223"/>
       <source>Several sub-elements selected</source>
       <translation>Nekoliko pod-elemenata odabrano</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a single face as support for a sketch!</source>
       <translation>Morate odabrati jednu površinu kao podršku za skicu!</translation>
     </message>
     <message>
-      <location/>
       <source>No support face selected</source>
       <translation>Nije odabrana površina za podršku</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a face as support for a sketch!</source>
       <translation>Morate odabrati površinu kao podršku za skicu!</translation>
     </message>
     <message>
-      <location/>
       <source>No planar support</source>
       <translation>Nema planarni podršku</translation>
     </message>
     <message>
-      <location/>
       <source>You need a planar face as support for a sketch!</source>
       <translation>Trebate planarnu površinu kao podršku za skicu!</translation>
     </message>
+    <message>
+      <location filename="../../EditDatumDialog.cpp" line="+72"/>
+      <source>Distance constraint</source>
+      <translation>Ograničenje udaljenosti</translation>
+    </message>
+    <message>
+      <source>Not allowed to edit the datum because the sketch contains conflicting constraints</source>
+      <translation>Nije dopušteno mijenjati podatak, jer skica sadrži proturječna ograničenja</translation>
+    </message>
+    <message>
+      <source>Dimensional constraint</source>
+      <translation>Dimensional constraint</translation>
+    </message>
+  </context>
+  <context>
+    <name>SketchOrientationDialog</name>
+    <message>
+      <location filename="../../SketchOrientationDialog.ui" line="+14"/>
+      <source>Choose orientation</source>
+      <translation>Odaberite orijentaciju</translation>
+    </message>
+    <message>
+      <source>Sketch orientation</source>
+      <translation>Orijentacija skice</translation>
+    </message>
+    <message>
+      <source>XY-Plane</source>
+      <translation>XY ravnina</translation>
+    </message>
+    <message>
+      <source>XZ-Plane</source>
+      <translation>XZ-Ravnina</translation>
+    </message>
+    <message>
+      <source>YZ-Plane</source>
+      <translation>YZ-Ravnina</translation>
+    </message>
+    <message>
+      <source>Reverse direction</source>
+      <translation>Obrnutim smjerom</translation>
+    </message>
+    <message>
+      <source>Offset:</source>
+      <translation>Odmak:</translation>
+    </message>
   </context>
   <context>
     <name>SketcherGui::InsertDatum</name>
     <message>
-      <location/>
+      <location filename="../../InsertDatum.ui" line="+17"/>
       <source>Insert datum</source>
       <translation>Umetni datum</translation>
     </message>
     <message>
-      <location/>
       <source>datum:</source>
       <translation>datum:</translation>
     </message>
@@ -492,37 +723,32 @@
   <context>
     <name>SketcherGui::TaskSketcherConstrains</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.ui" line="+14"/>
       <source>Form</source>
       <translation>Obrazac</translation>
     </message>
     <message>
-      <location/>
       <source>Filter:</source>
       <translation>Filter:</translation>
     </message>
     <message>
-      <location/>
       <source>All</source>
       <translation>Sve</translation>
     </message>
     <message>
-      <location/>
       <source>Normal</source>
       <translation>Normalno</translation>
     </message>
     <message>
-      <location/>
       <source>Datums</source>
       <translation>Datumima</translation>
     </message>
     <message>
-      <location/>
       <source>Named</source>
       <translation>Imenovan</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.cpp" line="+60"/>
       <source>Constraints</source>
       <translation>Ograničenja</translation>
     </message>
@@ -530,143 +756,169 @@
   <context>
     <name>SketcherGui::TaskSketcherGeneral</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherGeneral.ui" line="+14"/>
       <source>Form</source>
       <translation>Obrazac</translation>
     </message>
     <message>
-      <location/>
+      <source>Grid size:</source>
+      <translation>Grid size:</translation>
+    </message>
+    <message>
+      <source>Grid snap</source>
+      <translation>Grid snap</translation>
+    </message>
+    <message>
       <source>Unsolved</source>
       <translation>Neriješen</translation>
     </message>
     <message>
-      <location/>
       <source>Grid Snap</source>
       <translation>Ograničenje sa rešetkom</translation>
     </message>
     <message>
-      <location/>
       <source>0.1 mm</source>
       <translation>0.1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.2 mm</source>
       <translation>0.2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.5 mm</source>
       <translation>0.5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 mm</source>
       <translation>1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>2 mm</source>
       <translation>2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>5 mm</source>
       <translation>5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>10 mm</source>
       <translation>10 mm</translation>
     </message>
     <message>
-      <location/>
       <source>20 mm</source>
       <translation>20 mm</translation>
     </message>
     <message>
-      <location/>
       <source>50 mm</source>
       <translation>50 mm</translation>
     </message>
     <message>
-      <location/>
       <source>100 mm</source>
       <translation>100 mm</translation>
     </message>
     <message>
-      <location/>
       <source>200 mm</source>
       <translation>200 mm</translation>
     </message>
     <message>
-      <location/>
       <source>500 mm</source>
       <translation>500 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 m</source>
       <translation>1 m</translation>
     </message>
     <message>
-      <location/>
       <source>2 m</source>
       <translation>2 m</translation>
     </message>
     <message>
-      <location/>
       <source>5 m</source>
       <translation>5 m</translation>
     </message>
     <message>
-      <location/>
       <source>10 m</source>
       <translation>10 m</translation>
     </message>
     <message>
-      <location/>
       <source>20 m</source>
       <translation>20 m</translation>
     </message>
     <message>
-      <location/>
-      <source>Edit controls</source>
-      <translation>Uredi kontrole</translation>
+      <source>Auto constraints</source>
+      <translation>Auto ograničenja</translation>
     </message>
     <message>
-      <location/>
       <source>auto constraints</source>
       <translation>automatska ograničenja</translation>
     </message>
+    <message>
+      <location filename="../../TaskSketcherGeneral.cpp" line="+44"/>
+      <source>Edit controls</source>
+      <translation>Uredi kontrole</translation>
+    </message>
   </context>
   <context>
-    <name>SketcherGui::Workbench</name>
+    <name>SketcherGui::TaskSketcherMessages</name>
     <message>
-      <location/>
-      <source>Sketcher geoms</source>
-      <translation>Geometrije skice</translation>
+      <location filename="../../TaskSketcherMessages.cpp" line="+46"/>
+      <source>Solver messages</source>
+      <translation>Poruke Solvera</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherConstrains</name>
+    <message>
+      <source>Constraints</source>
+      <translation>Ograničenja</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherCreateCommands</name>
+    <message>
+      <source>Appearance</source>
+      <translation>Izgled</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherGeneral</name>
+    <message>
+      <source>Edit controls</source>
+      <translation>Uredi kontrole</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherMessages</name>
+    <message>
+      <location filename="../../TaskSketcherMessages.ui" line="+14"/>
+      <source>Form</source>
+      <translation>Obrazac</translation>
     </message>
     <message>
-      <location/>
-      <source>Sketcher constrains</source>
-      <translation>Ograničenja u skici</translation>
+      <source>Undefined degrees of freedom</source>
+      <translation>Neodređeno stupnjeva slobode</translation>
+    </message>
+    <message>
+      <source>Not solved yet</source>
+      <translation>Još nije riješeno</translation>
     </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+37"/>
       <source>Sketcher</source>
       <translation>Skica</translation>
     </message>
     <message>
-      <location/>
+      <source>Sketcher geometries</source>
+      <translation>Geometrije skice</translation>
+    </message>
+    <message>
       <source>Sketcher geoms</source>
       <translation>Geometrije skice</translation>
     </message>
     <message>
-      <location/>
       <source>Sketcher constraints</source>
       <translation>Ograničenja u skici</translation>
     </message>
