@@ -2,24 +2,32 @@
 <!DOCTYPE TS>
 <TS>
   <context>
-    <name>CmdSketcherConstrainCoincident</name>
+    <name>CmdSketcherConstrainAngle</name>
     <message>
-      <location/>
+      <location filename="../../CommandConstraints.cpp" line="+1370"/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain lock</source>
-      <translation>Vincolo bloccato</translation>
+      <source>Constrain angle</source>
+      <translation>Vincolo di angolo</translation>
+    </message>
+    <message>
+      <source>Fix the angle of a line or the angle between two lines</source>
+      <translation>Fissa l'angolo di una linea o l'angolo tra due linee</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainCoincident</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain coincident</source>
       <translation>Vincolo di coincidenza</translation>
     </message>
     <message>
-      <location/>
       <source>Create a coincident constraint on the selected item</source>
       <translation>Crea un vincolo di coincidenza sull'elemento selezionato</translation>
     </message>
@@ -27,45 +35,74 @@
   <context>
     <name>CmdSketcherConstrainDistance</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain distance</source>
       <translation>Vincolo di distanza</translation>
     </message>
     <message>
-      <location/>
       <source>Fix a length of a line or the distance between a line and a vertex</source>
       <translation>Fissa la lunghezza di una linea o la distanza tra una linea e un vertice</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainHorizontal</name>
+    <name>CmdSketcherConstrainDistanceX</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain orizontal</source>
-      <translation>Vincolo orizzontale</translation>
+      <source>Constrain horizontal distance</source>
+      <translation>Vincolo di distanza orizzontale</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a horizontal constrain on the selcted item</source>
-      <translation>Crea un vincolo orizzontale sull'elemento selezionato</translation>
+      <source>Fix the horizontal distance between two points or line ends</source>
+      <translation>Fissa la distanza orizzontale tra due punti o estremi di una linea</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainDistanceY</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain horizontal distance</source>
+      <translation>Vincolo di distanza orizzontale</translation>
+    </message>
+    <message>
+      <source>Fix the vertical distance between two points or line ends</source>
+      <translation>Fissa la distanza verticale tra due punti o estremi di una linea</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainEqual</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain equal</source>
+      <translation>Vincolo di uguaglianza</translation>
+    </message>
+    <message>
+      <source>Create an equality constraint between two lines or between circles and arcs</source>
+      <translation>Crea un vincolo di uguaglianza tra due linee o tra cerchi e archi</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainHorizontal</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain horizontally</source>
       <translation>Vincolo orizzontale</translation>
     </message>
     <message>
-      <location/>
       <source>Create a horizontal constraint on the selected item</source>
       <translation>Crea un vincolo orizzontale sull'elemento selezionato</translation>
     </message>
@@ -73,73 +110,119 @@
   <context>
     <name>CmdSketcherConstrainLock</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain Lock</source>
-      <translation>Vincolo bloccato</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a Lock constrain on the selcted item</source>
-      <translation>Crea un vincolo bloccato sull'elemento selezionato</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a lock constrain on the selected item</source>
-      <translation>Crea vincolo bloccato sull'elemento selezionato</translation>
-    </message>
-    <message>
-      <location/>
       <source>Constrain lock</source>
       <translation>Vincolo bloccato</translation>
     </message>
+    <message>
+      <source>Create a lock constraint on the selected item</source>
+      <translation>Crea un vincolo bloccato sull'elemento selezionato</translation>
+    </message>
   </context>
   <context>
     <name>CmdSketcherConstrainParallel</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain parallel</source>
       <translation>Vincolo di parallelismo</translation>
     </message>
     <message>
-      <location/>
       <source>Create a parallel constraint between two lines</source>
       <translation>Crea un vincolo di parallelismo tra due linee</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainVertical</name>
+    <name>CmdSketcherConstrainPerpendicular</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain vertical</source>
-      <translation>Vincolo verticale</translation>
+      <source>Constrain perpendicular</source>
+      <translation>Vincolo perpendicolare</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a vertical constrain on the selcted item</source>
-      <translation>Crea un vincolo verticale sull'elemento selezionato</translation>
+      <source>Create a Perpendicular constraint between two lines</source>
+      <translation>Crea un vincolo perpendicolare tra due linee</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainPointOnObject</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain point onto object</source>
+      <translation>Vincolo di punto su oggetto</translation>
+    </message>
+    <message>
+      <source>Fix a point onto an object</source>
+      <translation>Fissa un punto su un oggetto</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainRadius</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain radius</source>
+      <translation>Vincolo di raggio</translation>
+    </message>
+    <message>
+      <source>Fix the radius of a circle or an arc</source>
+      <translation>Fissa il raggio di un cerchio o di un arco</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainSymmetric</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain symmetrical</source>
+      <translation>Vincolo di simmetria</translation>
+    </message>
+    <message>
+      <source>Create an symmetry constraint between two points with respect to a line</source>
+      <translation>Crea un vincolo di simmetria tra due punti rispetto a una linea</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainTangent</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Constrain tangent</source>
+      <translation>Vincolo tangente</translation>
+    </message>
+    <message>
+      <source>Create a tangent constraint between two entities</source>
+      <translation>Crea un vincolo di tangenza tra due entità</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainVertical</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain vertically</source>
       <translation>Vincolo verticale</translation>
     </message>
     <message>
-      <location/>
       <source>Create a vertical constraint on the selected item</source>
       <translation>Crea un vincolo verticale sull'elemento selezionato</translation>
     </message>
@@ -147,53 +230,30 @@
   <context>
     <name>CmdSketcherCreateArc</name>
     <message>
-      <location/>
+      <location filename="../../CommandCreateGeo.cpp" line="+870"/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create arc</source>
       <translation>Crea arco</translation>
     </message>
     <message>
-      <location/>
       <source>Create an arc in the sketch</source>
       <translation>Crea un arco nello schizzo</translation>
     </message>
   </context>
-  <context>
-    <name>CmdSketcherCreateBox</name>
-    <message>
-      <location/>
-      <source>Sketcher</source>
-      <translation>Sketcher</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create box</source>
-      <translation>Creare un prisma</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a box in the sketch</source>
-      <translation>Creare un prisma nello sketch</translation>
-    </message>
-  </context>
   <context>
     <name>CmdSketcherCreateCircle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create circle</source>
       <translation>Crea cerchio</translation>
     </message>
     <message>
-      <location/>
       <source>Create a circle in the sketch</source>
       <translation>Crea un cerchio nello schizzo</translation>
     </message>
@@ -201,35 +261,44 @@
   <context>
     <name>CmdSketcherCreateDraftLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create draft line</source>
       <translation>Crea linea di costruzione</translation>
     </message>
     <message>
-      <location/>
       <source>Create a draft line in the sketch</source>
       <translation>Crea una linea di costruzione nello schizzo</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherCreateFillet</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Create fillet</source>
+      <translation>Crea raccordo</translation>
+    </message>
+    <message>
+      <source>Create a fillet between to lines or at a coincident point</source>
+      <translation>Creare un raccordo tra due linee o in un punto coincidente</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherCreateLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create line</source>
       <translation>Crea linea</translation>
     </message>
     <message>
-      <location/>
       <source>Create a line in the sketch</source>
       <translation>Crea una linea nello schizzo</translation>
     </message>
@@ -237,17 +306,14 @@
   <context>
     <name>CmdSketcherCreatePoint</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create point</source>
       <translation>Crea punto</translation>
     </message>
     <message>
-      <location/>
       <source>Create a point in the sketch</source>
       <translation>Crea un punto nello schizzo</translation>
     </message>
@@ -255,17 +321,14 @@
   <context>
     <name>CmdSketcherCreatePolyline</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create polyline</source>
       <translation>Crea polilinea</translation>
     </message>
     <message>
-      <location/>
       <source>Create a polyline in the sketch</source>
       <translation>Crea una polilinea nello schizzo</translation>
     </message>
@@ -273,17 +336,14 @@
   <context>
     <name>CmdSketcherCreateRectangle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create rectangle</source>
       <translation>Crea rettangolo</translation>
     </message>
     <message>
-      <location/>
       <source>Create a rectangle in the sketch</source>
       <translation>Crea un rettangolo nello schizzo</translation>
     </message>
@@ -291,22 +351,14 @@
   <context>
     <name>CmdSketcherCreateText</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create text</source>
       <translation>Crea testo</translation>
     </message>
     <message>
-      <location/>
-      <source>Create text in the scetch</source>
-      <translation>Crea un testo nello schizzo</translation>
-    </message>
-    <message>
-      <location/>
       <source>Create text in the sketch</source>
       <translation>Crea testo nello sketch</translation>
     </message>
@@ -314,35 +366,49 @@
   <context>
     <name>CmdSketcherLeaveSketch</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+270"/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Leave sketch</source>
       <translation>Esci</translation>
     </message>
     <message>
-      <location/>
       <source>Close the editing of the sketch</source>
       <translation>Chiude la modifica dello schizzo</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherMapSketch</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Map sketch to face...</source>
+      <translation>Mappa schizzo su faccia...</translation>
+    </message>
+    <message>
+      <source>Map a sketch to a face</source>
+      <translation>Mappa uno sketch su una faccia</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherNewSketch</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Create sketch</source>
       <translation>Crea schizzo</translation>
     </message>
     <message>
-      <location/>
+      <source>Create a new or edit the selected sketch</source>
+      <translation>Create a new or edit the selected sketch</translation>
+    </message>
+    <message>
       <source>Create a new sketch</source>
       <translation>Crea un nuovo schizzo</translation>
     </message>
@@ -350,25 +416,70 @@
   <context>
     <name>CmdSketcherNewSketchSF</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Sketchflat sketch</source>
       <translation>Sketchflat sketch</translation>
     </message>
     <message>
-      <location/>
       <source>Create a new sketchflat sketch by starting externel editor</source>
       <translation>Crea un nuovo sketch sketchflat avviando l'editor esterno</translation>
     </message>
   </context>
+  <context>
+    <name>CmdSketcherToggleConstruction</name>
+    <message>
+      <location filename="../../CommandAlterGeometry.cpp" line="+67"/>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Toggle construction line</source>
+      <translation>Attiva/disattiva linea di costruzione</translation>
+    </message>
+    <message>
+      <source>Toggles the currently selected lines to/from construction mode</source>
+      <translation>Attiva/disattiva le linee attualmente selezionate da modalità di costruzione</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherTrimming</name>
+    <message>
+      <location filename="../../CommandCreateGeo.cpp" line="+425"/>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>Trim edge</source>
+      <translation>Taglia spigolo</translation>
+    </message>
+    <message>
+      <source>Trims an edge with respect to the picked position</source>
+      <translation>Taglia uno spigolo rispetto ad una posizione specificata</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherViewSketch</name>
+    <message>
+      <location filename="../../Command.cpp" line="+244"/>
+      <source>Sketcher</source>
+      <translation>Sketcher</translation>
+    </message>
+    <message>
+      <source>View sketch</source>
+      <translation>Visualizza lo sketch</translation>
+    </message>
+    <message>
+      <source>View sketch perpendicular to sketch plane</source>
+      <translation>Vista perpendicolare al piano di sketch</translation>
+    </message>
+  </context>
   <context>
     <name>Gui::TaskView::TaskSketcherCreateCommands</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherCreateCommands.cpp" line="+40"/>
       <source>Appearance</source>
       <translation>Aspetto</translation>
     </message>
@@ -376,115 +487,235 @@
   <context>
     <name>QObject</name>
     <message>
-      <location/>
+      <location filename="../../CommandAlterGeometry.cpp" line="+15"/>
       <source>Wrong selection</source>
       <translation>Selezione errata</translation>
     </message>
     <message>
-      <location/>
+      <source>Select edge(s) from the sketch.</source>
+      <translation>Seleziona spigoli dello sketch.</translation>
+    </message>
+    <message>
+      <location filename="../../CommandConstraints.cpp" line="-1518"/>
       <source>Select an edge from the sketch.</source>
       <translation>Seleziona uno spigolo dallo sketch.</translation>
     </message>
     <message>
-      <location/>
       <source>Double constraint</source>
       <translation>Doppio vincolo</translation>
     </message>
     <message>
-      <location/>
       <source>The selected edge has already a horizontal constraint!</source>
       <translation>Lo spigolo selezionato ha già un vincolo orizzontale!</translation>
     </message>
     <message>
-      <location/>
       <source>Impossible constraint</source>
       <translation>Vincolo Impossible</translation>
     </message>
     <message>
-      <location/>
+      <source>Only sketch and its support is allowed to select</source>
+      <translation>E' consentito selezionare solo lo sketch e il suo supporto</translation>
+    </message>
+    <message>
+      <source>One of the selected has to be on the sketch</source>
+      <translation>Una delle entità selezionate deve essere sullo sketch</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a line segment</source>
+      <translation>Lo spigolo selezionato non è un segmento di linea</translation>
+    </message>
+    <message>
       <source>The selected edge has already a vertical constraint!</source>
       <translation>Lo spigolo selezionato ha già un vincolo verticale!</translation>
     </message>
     <message>
-      <location/>
+      <source>Select entities from the sketch.</source>
+      <translation>Seleziona entità dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly one entity from the sketch.</source>
+      <translation>Seleziona esattamente una entità dello sketch.</translation>
+    </message>
+    <message>
       <source>Select vertexes from the sketch.</source>
       <translation>Seleziona vertici dallo sketch.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two vertexes from the sketch.</source>
       <translation>Seleziona esattamente due vertici dallo sketch.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select exactly one line or one point and one line or two points from the sketch.</source>
+      <translation>Selezionare esattamente una linea o un punto e una linea o due punti dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly one point and one object from the sketch.</source>
+      <translation>Seleziona esattamente un punto e un oggetto dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly one line or up to two points from the sketch.</source>
+      <translation>Seleziona esattamente una linea o fino a due punti dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select two or more lines from the sketch.</source>
+      <translation>Seleziona due o più linee dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select at least two lines from the sketch.</source>
+      <translation>Seleziona almeno due linee dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select a valid line</source>
+      <translation>Seleziona una linea valida</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a valid line</source>
+      <translation>Lo spigolo selezionato non è una linea valida</translation>
+    </message>
+    <message>
+      <source>Select exactly one arc or circle from the sketch.</source>
+      <translation>Seleziona esattamente un arco o cerchio dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly one or two lines from the sketch.</source>
+      <translation>Seleziona esattamente una o due linee dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select two edges from the sketch.</source>
+      <translation>Seleziona due spigoli dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select atleast two lines from the sketch.</source>
+      <translation>Seleziona almeno due linee dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly two same geometries</source>
+      <translation>Seleziona esattamente due geometrie simili</translation>
+    </message>
+    <message>
+      <source>Select valid geometries</source>
+      <translation>Seleziona geometrie valide</translation>
+    </message>
+    <message>
+      <source>Select geometry of similar type</source>
+      <translation>Seleziona una geometria di tipo simile</translation>
+    </message>
+    <message>
+      <source>Select two points and one line from the sketch.</source>
+      <translation>Seleziona due punti e una linea dello sketch.</translation>
+    </message>
+    <message>
       <source>Select exactly one line from the sketch.</source>
       <translation>Seleziona esattamente una linea dallo sketch.</translation>
     </message>
     <message>
-      <location/>
       <source>Select two lines from the sketch.</source>
       <translation>Seleziona due linee dallo sketch.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two lines from the sketch.</source>
       <translation>Selezionare esattamente due linee dallo sketch.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select two entities from the sketch.</source>
+      <translation>Seleziona due entità dello sketch.</translation>
+    </message>
+    <message>
+      <source>Select exactly two entities from the sketch.</source>
+      <translation>Seleziona esattamente due entità dello sketch.</translation>
+    </message>
+    <message>
+      <location filename="../../ViewProviderSketch.cpp" line="+2591"/>
       <source>Edit sketch</source>
       <translation>Modifica sketch</translation>
     </message>
     <message>
-      <location/>
       <source>A dialog is already open in the task panel</source>
       <translation>Una finestra di dialogo è già aperta nel pannello attività</translation>
     </message>
     <message>
-      <location/>
       <source>Do you want to close this dialog?</source>
       <translation>Vuoi chiudere questa finestra di dialogo?</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-223"/>
       <source>Several sub-elements selected</source>
       <translation>Diversi sottoelementi selezionati</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a single face as support for a sketch!</source>
       <translation>Devi selezionare una singola faccia come supporto per uno sketch!</translation>
     </message>
     <message>
-      <location/>
       <source>No support face selected</source>
       <translation>Nessuna faccia di supporto selezionata</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a face as support for a sketch!</source>
       <translation>Devi selezionare una faccia come supporto per uno sketch!</translation>
     </message>
     <message>
-      <location/>
       <source>No planar support</source>
       <translation>Nessun supporto planare</translation>
     </message>
     <message>
-      <location/>
       <source>You need a planar face as support for a sketch!</source>
       <translation>Hai bisogno di una faccia planare come supporto per uno sketch!</translation>
     </message>
+    <message>
+      <location filename="../../EditDatumDialog.cpp" line="+72"/>
+      <source>Distance constraint</source>
+      <translation>Vincolo di distanza</translation>
+    </message>
+    <message>
+      <source>Not allowed to edit the datum because the sketch contains conflicting constraints</source>
+      <translation>Non è consentito modificare il dato perché lo sketch contiene vincoli in conflitto</translation>
+    </message>
+    <message>
+      <source>Dimensional constraint</source>
+      <translation>Dimensional constraint</translation>
+    </message>
+  </context>
+  <context>
+    <name>SketchOrientationDialog</name>
+    <message>
+      <location filename="../../SketchOrientationDialog.ui" line="+14"/>
+      <source>Choose orientation</source>
+      <translation>Scegli l'orientamento</translation>
+    </message>
+    <message>
+      <source>Sketch orientation</source>
+      <translation>Orientamento dello sketch </translation>
+    </message>
+    <message>
+      <source>XY-Plane</source>
+      <translation>Piano XY</translation>
+    </message>
+    <message>
+      <source>XZ-Plane</source>
+      <translation>Piano XZ</translation>
+    </message>
+    <message>
+      <source>YZ-Plane</source>
+      <translation>Piano YZ</translation>
+    </message>
+    <message>
+      <source>Reverse direction</source>
+      <translation>Direzione inversa</translation>
+    </message>
+    <message>
+      <source>Offset:</source>
+      <translation>Offset:</translation>
+    </message>
   </context>
   <context>
     <name>SketcherGui::InsertDatum</name>
     <message>
-      <location/>
+      <location filename="../../InsertDatum.ui" line="+17"/>
       <source>Insert datum</source>
       <translation>Inserisci riferimento</translation>
     </message>
     <message>
-      <location/>
       <source>datum:</source>
       <translation>Riferimento:</translation>
     </message>
@@ -492,37 +723,32 @@
   <context>
     <name>SketcherGui::TaskSketcherConstrains</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.ui" line="+14"/>
       <source>Form</source>
       <translation>Modulo</translation>
     </message>
     <message>
-      <location/>
       <source>Filter:</source>
       <translation>Filtro:</translation>
     </message>
     <message>
-      <location/>
       <source>All</source>
       <translation>Tutto</translation>
     </message>
     <message>
-      <location/>
       <source>Normal</source>
       <translation>Normale</translation>
     </message>
     <message>
-      <location/>
       <source>Datums</source>
       <translation>Riferimenti</translation>
     </message>
     <message>
-      <location/>
       <source>Named</source>
       <translation>Denominato</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.cpp" line="+60"/>
       <source>Constraints</source>
       <translation>Vincoli</translation>
     </message>
@@ -530,143 +756,169 @@
   <context>
     <name>SketcherGui::TaskSketcherGeneral</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherGeneral.ui" line="+14"/>
       <source>Form</source>
       <translation>Modulo</translation>
     </message>
     <message>
-      <location/>
+      <source>Grid size:</source>
+      <translation>Grid size:</translation>
+    </message>
+    <message>
+      <source>Grid snap</source>
+      <translation>Grid snap</translation>
+    </message>
+    <message>
       <source>Unsolved</source>
       <translation>Non risolto</translation>
     </message>
     <message>
-      <location/>
       <source>Grid Snap</source>
       <translation>Snap griglia</translation>
     </message>
     <message>
-      <location/>
       <source>0.1 mm</source>
       <translation>0,1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.2 mm</source>
       <translation>0,2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.5 mm</source>
       <translation>0,5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 mm</source>
       <translation>1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>2 mm</source>
       <translation>2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>5 mm</source>
       <translation>5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>10 mm</source>
       <translation>10 mm</translation>
     </message>
     <message>
-      <location/>
       <source>20 mm</source>
       <translation>20 mm</translation>
     </message>
     <message>
-      <location/>
       <source>50 mm</source>
       <translation>50 mm</translation>
     </message>
     <message>
-      <location/>
       <source>100 mm</source>
       <translation>100 mm</translation>
     </message>
     <message>
-      <location/>
       <source>200 mm</source>
       <translation>200 mm</translation>
     </message>
     <message>
-      <location/>
       <source>500 mm</source>
       <translation>500 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 m</source>
       <translation>1 m</translation>
     </message>
     <message>
-      <location/>
       <source>2 m</source>
       <translation>2 m</translation>
     </message>
     <message>
-      <location/>
       <source>5 m</source>
       <translation>5 m</translation>
     </message>
     <message>
-      <location/>
       <source>10 m</source>
       <translation>10 m</translation>
     </message>
     <message>
-      <location/>
       <source>20 m</source>
       <translation>20 m</translation>
     </message>
     <message>
-      <location/>
-      <source>Edit controls</source>
-      <translation>Modifica controlli</translation>
+      <source>Auto constraints</source>
+      <translation>Autovincoli</translation>
     </message>
     <message>
-      <location/>
       <source>auto constraints</source>
       <translation>vincoli automatici</translation>
     </message>
+    <message>
+      <location filename="../../TaskSketcherGeneral.cpp" line="+44"/>
+      <source>Edit controls</source>
+      <translation>Modifica controlli</translation>
+    </message>
   </context>
   <context>
-    <name>SketcherGui::Workbench</name>
+    <name>SketcherGui::TaskSketcherMessages</name>
     <message>
-      <location/>
-      <source>Sketcher geoms</source>
-      <translation>Geometrie dello Sketcher</translation>
+      <location filename="../../TaskSketcherMessages.cpp" line="+46"/>
+      <source>Solver messages</source>
+      <translation>Messaggi Solver</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherConstrains</name>
+    <message>
+      <source>Constraints</source>
+      <translation>Vincoli</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherCreateCommands</name>
+    <message>
+      <source>Appearance</source>
+      <translation>Aspetto</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherGeneral</name>
+    <message>
+      <source>Edit controls</source>
+      <translation>Modifica controlli</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherMessages</name>
+    <message>
+      <location filename="../../TaskSketcherMessages.ui" line="+14"/>
+      <source>Form</source>
+      <translation>Modulo</translation>
     </message>
     <message>
-      <location/>
-      <source>Sketcher constrains</source>
-      <translation>Vincoli dello Sketcher</translation>
+      <source>Undefined degrees of freedom</source>
+      <translation>Gradi di libertà indefiniti</translation>
+    </message>
+    <message>
+      <source>Not solved yet</source>
+      <translation>Non ancora risolto</translation>
     </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+37"/>
       <source>Sketcher</source>
       <translation>Sketcher</translation>
     </message>
     <message>
-      <location/>
+      <source>Sketcher geometries</source>
+      <translation>Geometrie Sketcher</translation>
+    </message>
+    <message>
       <source>Sketcher geoms</source>
       <translation>Geometrie dello Sketcher</translation>
     </message>
     <message>
-      <location/>
       <source>Sketcher constraints</source>
       <translation>Vincoli dello Sketcher</translation>
     </message>
