@@ -2,24 +2,32 @@
 <!DOCTYPE TS>
 <TS>
   <context>
-    <name>CmdSketcherConstrainCoincident</name>
+    <name>CmdSketcherConstrainAngle</name>
     <message>
-      <location/>
+      <location filename="../../CommandConstraints.cpp" line="+1370"/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain lock</source>
-      <translation>锁定约束</translation>
+      <source>Constrain angle</source>
+      <translation>角度约束</translation>
+    </message>
+    <message>
+      <source>Fix the angle of a line or the angle between two lines</source>
+      <translation>固定一直线角度或两直线夹角</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainCoincident</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain coincident</source>
       <translation>重合约束</translation>
     </message>
     <message>
-      <location/>
       <source>Create a coincident constraint on the selected item</source>
       <translation>在所选对象上创建重合约束</translation>
     </message>
@@ -27,45 +35,74 @@
   <context>
     <name>CmdSketcherConstrainDistance</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain distance</source>
       <translation>距离约束</translation>
     </message>
     <message>
-      <location/>
       <source>Fix a length of a line or the distance between a line and a vertex</source>
       <translation>固定线的长度或者点到线的距离</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainHorizontal</name>
+    <name>CmdSketcherConstrainDistanceX</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain orizontal</source>
-      <translation>水平约束</translation>
+      <source>Constrain horizontal distance</source>
+      <translation>水平距离约束</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a horizontal constrain on the selcted item</source>
-      <translation>在所选对象上创建水平约束</translation>
+      <source>Fix the horizontal distance between two points or line ends</source>
+      <translation>固定两点(或线端点)之间的水平距离</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainDistanceY</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain horizontal distance</source>
+      <translation>水平距离约束</translation>
+    </message>
+    <message>
+      <source>Fix the vertical distance between two points or line ends</source>
+      <translation>固定两点(或线端点)之间的垂直距离</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainEqual</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain equal</source>
+      <translation>相等约束</translation>
+    </message>
+    <message>
+      <source>Create an equality constraint between two lines or between circles and arcs</source>
+      <translation>两直线或圆与圆弧间创建相等约束</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainHorizontal</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain horizontally</source>
       <translation>水平约束</translation>
     </message>
     <message>
-      <location/>
       <source>Create a horizontal constraint on the selected item</source>
       <translation>在所选对象上创建水平约束</translation>
     </message>
@@ -73,73 +110,119 @@
   <context>
     <name>CmdSketcherConstrainLock</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain Lock</source>
-      <translation>锁定约束</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a Lock constrain on the selcted item</source>
-      <translation>在所选对象上创建锁定约束</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a lock constrain on the selected item</source>
-      <translation>在所选对象上创建锁定约束</translation>
-    </message>
-    <message>
-      <location/>
       <source>Constrain lock</source>
       <translation>锁定约束</translation>
     </message>
+    <message>
+      <source>Create a lock constraint on the selected item</source>
+      <translation>对所选物体创建锁定约束</translation>
+    </message>
   </context>
   <context>
     <name>CmdSketcherConstrainParallel</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain parallel</source>
       <translation>平行约束</translation>
     </message>
     <message>
-      <location/>
       <source>Create a parallel constraint between two lines</source>
       <translation>两条线之间创建平行约束</translation>
     </message>
   </context>
   <context>
-    <name>CmdSketcherConstrainVertical</name>
+    <name>CmdSketcherConstrainPerpendicular</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
-      <source>Constrain vertical</source>
+      <source>Constrain perpendicular</source>
       <translation>垂直约束</translation>
     </message>
     <message>
-      <location/>
-      <source>Create a vertical constrain on the selcted item</source>
-      <translation>在所选对象上创建垂直约束</translation>
+      <source>Create a Perpendicular constraint between two lines</source>
+      <translation>在两直线间创建垂直约束</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainPointOnObject</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain point onto object</source>
+      <translation>点约束至对象</translation>
+    </message>
+    <message>
+      <source>Fix a point onto an object</source>
+      <translation>固定点至对象</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainRadius</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain radius</source>
+      <translation>半径约束</translation>
+    </message>
+    <message>
+      <source>Fix the radius of a circle or an arc</source>
+      <translation>固定圆或圆弧的半径</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainSymmetric</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain symmetrical</source>
+      <translation>对称约束</translation>
+    </message>
+    <message>
+      <source>Create an symmetry constraint between two points with respect to a line</source>
+      <translation>相对一直线在两点间创建对称约束</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainTangent</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Constrain tangent</source>
+      <translation>相切约束</translation>
+    </message>
+    <message>
+      <source>Create a tangent constraint between two entities</source>
+      <translation>在两实体间创建相切约束</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherConstrainVertical</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Constrain vertically</source>
       <translation>垂直约束</translation>
     </message>
     <message>
-      <location/>
       <source>Create a vertical constraint on the selected item</source>
       <translation>在所选对象上创建垂直约束</translation>
     </message>
@@ -147,53 +230,30 @@
   <context>
     <name>CmdSketcherCreateArc</name>
     <message>
-      <location/>
+      <location filename="../../CommandCreateGeo.cpp" line="+870"/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create arc</source>
       <translation>创建弧</translation>
     </message>
     <message>
-      <location/>
       <source>Create an arc in the sketch</source>
       <translation>在草绘中创建一个弧</translation>
     </message>
   </context>
-  <context>
-    <name>CmdSketcherCreateBox</name>
-    <message>
-      <location/>
-      <source>Sketcher</source>
-      <translation>草绘</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create box</source>
-      <translation>创建立方体</translation>
-    </message>
-    <message>
-      <location/>
-      <source>Create a box in the sketch</source>
-      <translation>在草绘中创建一个立方体</translation>
-    </message>
-  </context>
   <context>
     <name>CmdSketcherCreateCircle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create circle</source>
       <translation>创建圆</translation>
     </message>
     <message>
-      <location/>
       <source>Create a circle in the sketch</source>
       <translation>在草绘中创建一个圆</translation>
     </message>
@@ -201,35 +261,44 @@
   <context>
     <name>CmdSketcherCreateDraftLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create draft line</source>
       <translation>创建草图线</translation>
     </message>
     <message>
-      <location/>
       <source>Create a draft line in the sketch</source>
       <translation>在草绘中创建一根线</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherCreateFillet</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Create fillet</source>
+      <translation>创建圆角</translation>
+    </message>
+    <message>
+      <source>Create a fillet between to lines or at a coincident point</source>
+      <translation>两直线或重合点处创建圆角</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherCreateLine</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create line</source>
       <translation>创建线</translation>
     </message>
     <message>
-      <location/>
       <source>Create a line in the sketch</source>
       <translation>在草图中创建一根线</translation>
     </message>
@@ -237,17 +306,14 @@
   <context>
     <name>CmdSketcherCreatePoint</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create point</source>
       <translation>创建点</translation>
     </message>
     <message>
-      <location/>
       <source>Create a point in the sketch</source>
       <translation>在草绘中创建一个点</translation>
     </message>
@@ -255,17 +321,14 @@
   <context>
     <name>CmdSketcherCreatePolyline</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create polyline</source>
       <translation>创建多段线</translation>
     </message>
     <message>
-      <location/>
       <source>Create a polyline in the sketch</source>
       <translation>在草图中创建多段线</translation>
     </message>
@@ -273,17 +336,14 @@
   <context>
     <name>CmdSketcherCreateRectangle</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create rectangle</source>
       <translation>创建矩形</translation>
     </message>
     <message>
-      <location/>
       <source>Create a rectangle in the sketch</source>
       <translation>在草绘中创建矩形</translation>
     </message>
@@ -291,22 +351,14 @@
   <context>
     <name>CmdSketcherCreateText</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create text</source>
       <translation>创建文本</translation>
     </message>
     <message>
-      <location/>
-      <source>Create text in the scetch</source>
-      <translation>在草绘中创建文本</translation>
-    </message>
-    <message>
-      <location/>
       <source>Create text in the sketch</source>
       <translation>在草绘中创建文本</translation>
     </message>
@@ -314,35 +366,49 @@
   <context>
     <name>CmdSketcherLeaveSketch</name>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="+270"/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Leave sketch</source>
       <translation>离开草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Close the editing of the sketch</source>
       <translation>关闭草图编辑</translation>
     </message>
   </context>
   <context>
+    <name>CmdSketcherMapSketch</name>
+    <message>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Map sketch to face...</source>
+      <translation>Map sketch to face...</translation>
+    </message>
+    <message>
+      <source>Map a sketch to a face</source>
+      <translation>Map a sketch to a face</translation>
+    </message>
+  </context>
+  <context>
     <name>CmdSketcherNewSketch</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create sketch</source>
       <translation>创建草绘</translation>
     </message>
     <message>
-      <location/>
+      <source>Create a new or edit the selected sketch</source>
+      <translation>Create a new or edit the selected sketch</translation>
+    </message>
+    <message>
       <source>Create a new sketch</source>
       <translation>创建一个新草绘</translation>
     </message>
@@ -350,25 +416,70 @@
   <context>
     <name>CmdSketcherNewSketchSF</name>
     <message>
-      <location/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Sketchflat sketch</source>
       <translation>Sketchflat草绘</translation>
     </message>
     <message>
-      <location/>
       <source>Create a new sketchflat sketch by starting externel editor</source>
       <translation>启动外部编辑器创建一个新sketchflat草绘</translation>
     </message>
   </context>
+  <context>
+    <name>CmdSketcherToggleConstruction</name>
+    <message>
+      <location filename="../../CommandAlterGeometry.cpp" line="+67"/>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Toggle construction line</source>
+      <translation>切换构造线</translation>
+    </message>
+    <message>
+      <source>Toggles the currently selected lines to/from construction mode</source>
+      <translation>切换当前选择线的构造模式</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherTrimming</name>
+    <message>
+      <location filename="../../CommandCreateGeo.cpp" line="+425"/>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>Trim edge</source>
+      <translation>修剪边缘</translation>
+    </message>
+    <message>
+      <source>Trims an edge with respect to the picked position</source>
+      <translation>Trims an edge with respect to the picked position</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdSketcherViewSketch</name>
+    <message>
+      <location filename="../../Command.cpp" line="+244"/>
+      <source>Sketcher</source>
+      <translation>草绘</translation>
+    </message>
+    <message>
+      <source>View sketch</source>
+      <translation>查看草绘</translation>
+    </message>
+    <message>
+      <source>View sketch perpendicular to sketch plane</source>
+      <translation>垂直于草绘平面查看草绘</translation>
+    </message>
+  </context>
   <context>
     <name>Gui::TaskView::TaskSketcherCreateCommands</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherCreateCommands.cpp" line="+40"/>
       <source>Appearance</source>
       <translation>外观</translation>
     </message>
@@ -376,115 +487,235 @@
   <context>
     <name>QObject</name>
     <message>
-      <location/>
+      <location filename="../../CommandAlterGeometry.cpp" line="+15"/>
       <source>Wrong selection</source>
       <translation>选择错误</translation>
     </message>
     <message>
-      <location/>
+      <source>Select edge(s) from the sketch.</source>
+      <translation>从草绘选择边</translation>
+    </message>
+    <message>
+      <location filename="../../CommandConstraints.cpp" line="-1518"/>
       <source>Select an edge from the sketch.</source>
       <translation>从草绘中选择边.</translation>
     </message>
     <message>
-      <location/>
       <source>Double constraint</source>
       <translation>双重约束</translation>
     </message>
     <message>
-      <location/>
       <source>The selected edge has already a horizontal constraint!</source>
       <translation>所选的边已水平约束!</translation>
     </message>
     <message>
-      <location/>
       <source>Impossible constraint</source>
       <translation>不可约束</translation>
     </message>
     <message>
-      <location/>
+      <source>Only sketch and its support is allowed to select</source>
+      <translation>仅允许选择草绘及其支持面</translation>
+    </message>
+    <message>
+      <source>One of the selected has to be on the sketch</source>
+      <translation>选择之一必须在草绘上</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a line segment</source>
+      <translation>所选的边并非一段直线</translation>
+    </message>
+    <message>
       <source>The selected edge has already a vertical constraint!</source>
       <translation>所选的边已垂直约束!</translation>
     </message>
     <message>
-      <location/>
+      <source>Select entities from the sketch.</source>
+      <translation>从草绘选择实体</translation>
+    </message>
+    <message>
+      <source>Select exactly one entity from the sketch.</source>
+      <translation>仅从草绘选择一个实体</translation>
+    </message>
+    <message>
       <source>Select vertexes from the sketch.</source>
       <translation>从草绘中选择顶点.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two vertexes from the sketch.</source>
       <translation>仅从草绘中选择两个顶点.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select exactly one line or one point and one line or two points from the sketch.</source>
+      <translation>仅从草绘选择一直线,或一点和一直线,或两点.</translation>
+    </message>
+    <message>
+      <source>Select exactly one point and one object from the sketch.</source>
+      <translation>仅从草绘选择一点和一对象.</translation>
+    </message>
+    <message>
+      <source>Select exactly one line or up to two points from the sketch.</source>
+      <translation>Select exactly one line or up to two points from the sketch.</translation>
+    </message>
+    <message>
+      <source>Select two or more lines from the sketch.</source>
+      <translation>从草绘选择两条或两条以上直线.</translation>
+    </message>
+    <message>
+      <source>Select at least two lines from the sketch.</source>
+      <translation>至少从草绘选择两直线.</translation>
+    </message>
+    <message>
+      <source>Select a valid line</source>
+      <translation>选择一有效直线</translation>
+    </message>
+    <message>
+      <source>The selected edge is not a valid line</source>
+      <translation>所选的边并非有效直线</translation>
+    </message>
+    <message>
+      <source>Select exactly one arc or circle from the sketch.</source>
+      <translation>仅从草绘中选择一个圆弧或圆.</translation>
+    </message>
+    <message>
+      <source>Select exactly one or two lines from the sketch.</source>
+      <translation>仅从草绘选择一条或两条直线.</translation>
+    </message>
+    <message>
+      <source>Select two edges from the sketch.</source>
+      <translation>从草绘选择两条边.</translation>
+    </message>
+    <message>
+      <source>Select atleast two lines from the sketch.</source>
+      <translation>至少从草绘选择两直线.</translation>
+    </message>
+    <message>
+      <source>Select exactly two same geometries</source>
+      <translation>Select exactly two same geometries</translation>
+    </message>
+    <message>
+      <source>Select valid geometries</source>
+      <translation>选择有效几何体</translation>
+    </message>
+    <message>
+      <source>Select geometry of similar type</source>
+      <translation>选择相似类型的几何体</translation>
+    </message>
+    <message>
+      <source>Select two points and one line from the sketch.</source>
+      <translation>从草绘中选择两点和一线.</translation>
+    </message>
+    <message>
       <source>Select exactly one line from the sketch.</source>
       <translation>仅从草绘中选择一根线.</translation>
     </message>
     <message>
-      <location/>
       <source>Select two lines from the sketch.</source>
       <translation>从草绘中选择两根线.</translation>
     </message>
     <message>
-      <location/>
       <source>Select exactly two lines from the sketch.</source>
       <translation>仅从草绘中选择两根线.</translation>
     </message>
     <message>
-      <location/>
+      <source>Select two entities from the sketch.</source>
+      <translation>从草绘中选择两个实体.</translation>
+    </message>
+    <message>
+      <source>Select exactly two entities from the sketch.</source>
+      <translation>仅从草绘选择两实体.</translation>
+    </message>
+    <message>
+      <location filename="../../ViewProviderSketch.cpp" line="+2591"/>
       <source>Edit sketch</source>
       <translation>编辑草绘</translation>
     </message>
     <message>
-      <location/>
       <source>A dialog is already open in the task panel</source>
       <translation>一个对话框已在任务面板打开</translation>
     </message>
     <message>
-      <location/>
       <source>Do you want to close this dialog?</source>
       <translation>是否要关闭此对话框?</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../Command.cpp" line="-223"/>
       <source>Several sub-elements selected</source>
       <translation>若干子元素被选择</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a single face as support for a sketch!</source>
       <translation>您必须选择一个支持面以绘制草图!</translation>
     </message>
     <message>
-      <location/>
       <source>No support face selected</source>
       <translation>未选中支持面</translation>
     </message>
     <message>
-      <location/>
       <source>You have to select a face as support for a sketch!</source>
       <translation>您必须选择一个支持面以绘制草图!</translation>
     </message>
     <message>
-      <location/>
       <source>No planar support</source>
       <translation>无支持平面</translation>
     </message>
     <message>
-      <location/>
       <source>You need a planar face as support for a sketch!</source>
       <translation>您需要一个支持平面以绘制草图!</translation>
     </message>
+    <message>
+      <location filename="../../EditDatumDialog.cpp" line="+72"/>
+      <source>Distance constraint</source>
+      <translation>距离约束</translation>
+    </message>
+    <message>
+      <source>Not allowed to edit the datum because the sketch contains conflicting constraints</source>
+      <translation>由于草图包含冲突的约束无法编辑基准</translation>
+    </message>
+    <message>
+      <source>Dimensional constraint</source>
+      <translation>Dimensional constraint</translation>
+    </message>
+  </context>
+  <context>
+    <name>SketchOrientationDialog</name>
+    <message>
+      <location filename="../../SketchOrientationDialog.ui" line="+14"/>
+      <source>Choose orientation</source>
+      <translation>选择方向</translation>
+    </message>
+    <message>
+      <source>Sketch orientation</source>
+      <translation>草绘方向</translation>
+    </message>
+    <message>
+      <source>XY-Plane</source>
+      <translation>XY平面</translation>
+    </message>
+    <message>
+      <source>XZ-Plane</source>
+      <translation>XZ平面</translation>
+    </message>
+    <message>
+      <source>YZ-Plane</source>
+      <translation>YZ平面</translation>
+    </message>
+    <message>
+      <source>Reverse direction</source>
+      <translation>反转方向</translation>
+    </message>
+    <message>
+      <source>Offset:</source>
+      <translation>偏移:</translation>
+    </message>
   </context>
   <context>
     <name>SketcherGui::InsertDatum</name>
     <message>
-      <location/>
+      <location filename="../../InsertDatum.ui" line="+17"/>
       <source>Insert datum</source>
       <translation>插入基准</translation>
     </message>
     <message>
-      <location/>
       <source>datum:</source>
       <translation>数据:</translation>
     </message>
@@ -492,37 +723,32 @@
   <context>
     <name>SketcherGui::TaskSketcherConstrains</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
       <source>Filter:</source>
       <translation>过滤器:</translation>
     </message>
     <message>
-      <location/>
       <source>All</source>
       <translation>全部</translation>
     </message>
     <message>
-      <location/>
       <source>Normal</source>
       <translation>法向</translation>
     </message>
     <message>
-      <location/>
       <source>Datums</source>
       <translation>基准</translation>
     </message>
     <message>
-      <location/>
       <source>Named</source>
       <translation>命名</translation>
     </message>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherConstrains.cpp" line="+60"/>
       <source>Constraints</source>
       <translation>约束</translation>
     </message>
@@ -530,143 +756,169 @@
   <context>
     <name>SketcherGui::TaskSketcherGeneral</name>
     <message>
-      <location/>
+      <location filename="../../TaskSketcherGeneral.ui" line="+14"/>
       <source>Form</source>
       <translation>窗体</translation>
     </message>
     <message>
-      <location/>
+      <source>Grid size:</source>
+      <translation>Grid size:</translation>
+    </message>
+    <message>
+      <source>Grid snap</source>
+      <translation>Grid snap</translation>
+    </message>
+    <message>
       <source>Unsolved</source>
       <translation>未解决</translation>
     </message>
     <message>
-      <location/>
       <source>Grid Snap</source>
       <translation>网格捕捉</translation>
     </message>
     <message>
-      <location/>
       <source>0.1 mm</source>
       <translation>0.1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.2 mm</source>
       <translation>0.2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>0.5 mm</source>
       <translation>0.5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 mm</source>
       <translation>1 mm</translation>
     </message>
     <message>
-      <location/>
       <source>2 mm</source>
       <translation>2 mm</translation>
     </message>
     <message>
-      <location/>
       <source>5 mm</source>
       <translation>5 mm</translation>
     </message>
     <message>
-      <location/>
       <source>10 mm</source>
       <translation>10 mm</translation>
     </message>
     <message>
-      <location/>
       <source>20 mm</source>
       <translation>20 mm</translation>
     </message>
     <message>
-      <location/>
       <source>50 mm</source>
       <translation>50 mm</translation>
     </message>
     <message>
-      <location/>
       <source>100 mm</source>
       <translation>100毫米</translation>
     </message>
     <message>
-      <location/>
       <source>200 mm</source>
       <translation>200 mm</translation>
     </message>
     <message>
-      <location/>
       <source>500 mm</source>
       <translation>500 mm</translation>
     </message>
     <message>
-      <location/>
       <source>1 m</source>
       <translation>1 m</translation>
     </message>
     <message>
-      <location/>
       <source>2 m</source>
       <translation>2 m</translation>
     </message>
     <message>
-      <location/>
       <source>5 m</source>
       <translation>5 m</translation>
     </message>
     <message>
-      <location/>
       <source>10 m</source>
       <translation>10 m</translation>
     </message>
     <message>
-      <location/>
       <source>20 m</source>
       <translation>20 m</translation>
     </message>
     <message>
-      <location/>
-      <source>Edit controls</source>
-      <translation>编辑控件</translation>
+      <source>Auto constraints</source>
+      <translation>自动约束</translation>
     </message>
     <message>
-      <location/>
       <source>auto constraints</source>
       <translation>自动约束</translation>
     </message>
+    <message>
+      <location filename="../../TaskSketcherGeneral.cpp" line="+44"/>
+      <source>Edit controls</source>
+      <translation>编辑控件</translation>
+    </message>
   </context>
   <context>
-    <name>SketcherGui::Workbench</name>
+    <name>SketcherGui::TaskSketcherMessages</name>
     <message>
-      <location/>
-      <source>Sketcher geoms</source>
-      <translation>草绘几何</translation>
+      <location filename="../../TaskSketcherMessages.cpp" line="+46"/>
+      <source>Solver messages</source>
+      <translation>求解器信息</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherConstrains</name>
+    <message>
+      <source>Constraints</source>
+      <translation>约束</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherCreateCommands</name>
+    <message>
+      <source>Appearance</source>
+      <translation>外观</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherGeneral</name>
+    <message>
+      <source>Edit controls</source>
+      <translation>编辑控件</translation>
+    </message>
+  </context>
+  <context>
+    <name>TaskSketcherMessages</name>
+    <message>
+      <location filename="../../TaskSketcherMessages.ui" line="+14"/>
+      <source>Form</source>
+      <translation>窗体</translation>
     </message>
     <message>
-      <location/>
-      <source>Sketcher constrains</source>
-      <translation>草绘约束</translation>
+      <source>Undefined degrees of freedom</source>
+      <translation>未定义的自由度</translation>
+    </message>
+    <message>
+      <source>Not solved yet</source>
+      <translation>Not solved yet</translation>
     </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
-      <location/>
+      <location filename="../../Workbench.cpp" line="+37"/>
       <source>Sketcher</source>
       <translation>草绘</translation>
     </message>
     <message>
-      <location/>
+      <source>Sketcher geometries</source>
+      <translation>草绘几何体</translation>
+    </message>
+    <message>
       <source>Sketcher geoms</source>
       <translation>草绘几何</translation>
     </message>
     <message>
-      <location/>
       <source>Sketcher constraints</source>
       <translation>草图约束</translation>
     </message>
