@@ -24,28 +24,25 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <QRegExp>
 # include <QString>
 #endif
 
 #include "ui_TaskSketcherConstrains.h"
-#include "ui_InsertDatum.h"
 #include "TaskSketcherConstrains.h"
+#include "EditDatumDialog.h"
 #include "ViewProviderSketch.h"
 
 #include <Mod/Sketcher/App/SketchObject.h>
 
+#include <Base/Tools.h>
 #include <Gui/Application.h>
 #include <Gui/Document.h>
 #include <Gui/BitmapFactory.h>
 #include <Gui/ViewProvider.h>
-#include <Gui/WaitCursor.h>
 #include <Gui/BitmapFactory.h>
-#include <Gui/Command.h>
-#include <Base/Console.h>
 #include <boost/bind.hpp>
 
-
-
 using namespace SketcherGui;
 using namespace Gui::TaskView;
 
@@ -67,108 +64,120 @@ TaskSketcherConstrains::TaskSketcherConstrains(ViewProviderSketch *sketchView)
     proxy = new QWidget(this);
     ui = new Ui_TaskSketcherConstrains();
     ui->setupUi(proxy);
+    ui->listWidgetConstraints->setSelectionMode(QAbstractItemView::ExtendedSelection);
     //QMetaObject::connectSlotsByName(this);
 
     // connecting the needed signals
     QObject::connect(
-        ui->comboBoxFilter,SIGNAL(currentIndexChanged(int)),
-        this              ,SLOT  (on_comboBoxFilter_currentIndexChanged(int))
+        ui->comboBoxFilter, SIGNAL(currentIndexChanged(int)),
+        this              , SLOT  (on_comboBoxFilter_currentIndexChanged(int))
        );
     QObject::connect(
-        ui->listWidgetConstraints,SIGNAL(itemSelectionChanged ()),
-        this                     ,SLOT  (on_listWidgetConstraints_itemSelectionChanged ())
+        ui->listWidgetConstraints, SIGNAL(itemSelectionChanged()),
+        this                     , SLOT  (on_listWidgetConstraints_itemSelectionChanged())
        );
     QObject::connect(
-        ui->listWidgetConstraints,SIGNAL(itemActivated ( QListWidgetItem *)),
-        this                     ,SLOT  (on_listWidgetConstraints_itemActivated ( QListWidgetItem *) )
+        ui->listWidgetConstraints, SIGNAL(itemActivated(QListWidgetItem *)),
+        this                     , SLOT  (on_listWidgetConstraints_itemActivated(QListWidgetItem *))
        );
     //QObject::connect(
-    //    ui->listWidgetConstraints,SIGNAL(entered(const QModelIndex &)),
-    //    this                     ,SLOT  (on_listWidgetConstraints_entered(const QModelIndex &))
+    //    ui->listWidgetConstraints, SIGNAL(entered(const QModelIndex &)),
+    //    this                     , SLOT  (on_listWidgetConstraints_entered(const QModelIndex &))
     //   );
 
     connectionConstraintsChanged = sketchView->signalConstraintsChanged.connect(boost::bind(&SketcherGui::TaskSketcherConstrains::slotConstraintsChanged, this));
 
     this->groupLayout()->addWidget(proxy);
- 
-    Gui::Selection().Attach(this);
 
     slotConstraintsChanged();
 }
 
 TaskSketcherConstrains::~TaskSketcherConstrains()
 {
-    Gui::Selection().Detach(this);
     connectionConstraintsChanged.disconnect();
     delete ui;
 }
 
-/// @cond DOXERR
-void TaskSketcherConstrains::OnChange(Gui::SelectionSingleton::SubjectType &rCaller,
-                              Gui::SelectionSingleton::MessageType msg)
+void TaskSketcherConstrains::onSelectionChanged(const Gui::SelectionChanges& msg)
 {
     std::string temp;
     if (msg.Type == Gui::SelectionChanges::ClrSelection) {
+        ui->listWidgetConstraints->blockSignals(true);
         ui->listWidgetConstraints->clearSelection ();
+        ui->listWidgetConstraints->blockSignals(false);
     }
-    else if (msg.Type == Gui::SelectionChanges::AddSelection) {
+    else if (msg.Type == Gui::SelectionChanges::AddSelection ||
+             msg.Type == Gui::SelectionChanges::RmvSelection) {
+        bool select = (msg.Type == Gui::SelectionChanges::AddSelection);
         // is it this object??
-        if(strcmp(msg.pDocName,sketchView->getSketchObject()->getDocument()->getName())==0
-            &&strcmp(msg.pObjectName,sketchView->getSketchObject()->getNameInDocument())== 0) {
-                if(msg.pSubName){
-                    std::string shapetype(msg.pSubName);
-                    if (shapetype.size() > 10 && shapetype.substr(0,10) == "Constraint") {
-                        //int index=std::atoi(&shapetype[10]);
-                        //ui->listWidgetConstraints->setCurrentIndex(QModelIndex(0));
+        if (strcmp(msg.pDocName,sketchView->getSketchObject()->getDocument()->getName())==0 &&
+            strcmp(msg.pObjectName,sketchView->getSketchObject()->getNameInDocument())== 0) {
+            if (msg.pSubName) {
+                QRegExp rx(QString::fromAscii("^Constraint(\\d+)$"));
+                QString expr = QString::fromAscii(msg.pSubName);
+                int pos = expr.indexOf(rx);
+                if (pos > -1) {
+                    bool ok;
+                    int index = rx.cap(1).toInt(&ok);
+                    if (ok) {
+                        int countItems = ui->listWidgetConstraints->count();
+                        for (int i=0; i<countItems;i++) {
+                            ConstraintItem* item = static_cast<ConstraintItem*>
+                                (ui->listWidgetConstraints->item(i));
+                            if (item->ConstraintNbr == index) {
+                                ui->listWidgetConstraints->blockSignals(true);
+                                item->setSelected(select);
+                                ui->listWidgetConstraints->blockSignals(false);
+                                break;
+                            }
+                        }
                     }
-
                 }
-        }        
+            }
+        }
+    }
+    else if (msg.Type == Gui::SelectionChanges::SetSelection) {
+        // do nothing here
     }
-    else if (msg.Type == Gui::SelectionChanges::RmvSelection) {}
-    else if (msg.Type == Gui::SelectionChanges::SetSelection) {}       
 }
-/// @endcond DOXERR
 
 void TaskSketcherConstrains::on_comboBoxFilter_currentIndexChanged(int)
 {
     slotConstraintsChanged();
 }
 
-void TaskSketcherConstrains::on_listWidgetConstraints_itemSelectionChanged (void)
+void TaskSketcherConstrains::on_listWidgetConstraints_itemSelectionChanged(void)
 {
-    
+    std::string doc_name = sketchView->getSketchObject()->getDocument()->getName();
+    std::string obj_name = sketchView->getSketchObject()->getNameInDocument();
+
+    bool block = this->blockConnection(true); // avoid to be notified by itself
+    Gui::Selection().clearSelection();
+    QList<QListWidgetItem *> items = ui->listWidgetConstraints->selectedItems();
+    for (QList<QListWidgetItem *>::iterator it = items.begin(); it != items.end(); ++it) {
+        std::stringstream ss;
+        ss << "Constraint" << static_cast<ConstraintItem*>(*it)->ConstraintNbr;
+        Gui::Selection().addSelection(doc_name.c_str(), obj_name.c_str(), ss.str().c_str());
+    }
+    this->blockConnection(block);
 }
 
-void TaskSketcherConstrains::on_listWidgetConstraints_itemActivated ( QListWidgetItem *item)
+void TaskSketcherConstrains::on_listWidgetConstraints_itemActivated(QListWidgetItem *item)
 {
     ConstraintItem *it = dynamic_cast<ConstraintItem*>(item);
 
     // if its the right constraint
-    if (it->Type == Sketcher::Distance) {
-        const std::vector< Sketcher::Constraint * > &vals = sketchView->getSketchObject()->Constraints.getValues();
-        Sketcher::Constraint *Const = vals[it->ConstraintNbr];
-        assert(Const->Type == it->Type);
-        double datum = Const->Value;
+    if (it->Type == Sketcher::Distance ||
+        it->Type == Sketcher::DistanceX || it->Type == Sketcher::DistanceY ||
+        it->Type == Sketcher::Radius || it->Type == Sketcher::Angle) {
 
-        QDialog dlg(this);
-        Ui::InsertDatum ui;
-        ui.setupUi(&dlg);
-
-        ui.lineEdit->setText(QString::number(datum));
-        if (dlg.exec()) {
-            double newDatum = ui.lineEdit->text().toDouble();
-            Gui::Command::openCommand("Add sketch constraints");
-            Gui::Command::doCommand(Gui::Command::Doc,"App.ActiveDocument.%s.setDatum(%f,%i)",
-                      sketchView->getObject()->getNameInDocument(),
-                      newDatum,it->ConstraintNbr);
-            // use recompute() instead of execute() to properly handle placement
-            sketchView->getSketchObject()->recompute();
-        }
+        EditDatumDialog *editDatumDialog = new EditDatumDialog(this->sketchView, it->ConstraintNbr);
+        editDatumDialog->exec(false);
+        delete editDatumDialog;
     }
 }
 
-//void TaskSketcherConstrains::on_listWidgetConstraints_entered    ( const QModelIndex & index )
+//void TaskSketcherConstrains::on_listWidgetConstraints_entered(const QModelIndex &index)
 //{
 //    index;
 //}
@@ -176,12 +185,21 @@ void TaskSketcherConstrains::on_listWidgetConstraints_itemActivated ( QListWidge
 
 void TaskSketcherConstrains::slotConstraintsChanged(void)
 {
+    QIcon hdist( Gui::BitmapFactory().pixmap("Constraint_HorizontalDistance") );
+    QIcon vdist( Gui::BitmapFactory().pixmap("Constraint_VerticalDistance") );
     QIcon horiz( Gui::BitmapFactory().pixmap("Constraint_Horizontal") );
     QIcon vert ( Gui::BitmapFactory().pixmap("Constraint_Vertical") );
     QIcon lock ( Gui::BitmapFactory().pixmap("Sketcher_ConstrainLock") );
     QIcon coinc( Gui::BitmapFactory().pixmap("Constraint_PointOnPoint") );
     QIcon para ( Gui::BitmapFactory().pixmap("Constraint_Parallel") );
+    QIcon perp ( Gui::BitmapFactory().pixmap("Constraint_Perpendicular") );
+    QIcon tang ( Gui::BitmapFactory().pixmap("Constraint_Tangent") );
     QIcon dist ( Gui::BitmapFactory().pixmap("Constraint_Length") );
+    QIcon radi ( Gui::BitmapFactory().pixmap("Constraint_Radius") );
+    QIcon angl ( Gui::BitmapFactory().pixmap("Constraint_InternalAngle") );
+    QIcon equal( Gui::BitmapFactory().pixmap("Constraint_EqualLength") );
+    QIcon pntoo( Gui::BitmapFactory().pixmap("Constraint_PointOnObject") );
+    QIcon symm ( Gui::BitmapFactory().pixmap("Constraint_Symmetric") );
 
     assert(sketchView);
     // Build up ListView with the constraints
@@ -193,11 +211,11 @@ void TaskSketcherConstrains::slotConstraintsChanged(void)
     int Filter = ui->comboBoxFilter->currentIndex();
 
     int i=1;
-	for(std::vector< Sketcher::Constraint * >::const_iterator it= vals.begin();it!=vals.end();++it,++i){
-        if((*it)->Name == ""){
-            name = QString(QString::fromLatin1("Constraint%1")).arg(i);
-        }else
-            name = QString(QString::fromLatin1((*it)->Name.c_str()));
+    for(std::vector< Sketcher::Constraint * >::const_iterator it= vals.begin();it!=vals.end();++it,++i){
+        if ((*it)->Name == "")
+            name = QString::fromLatin1("Constraint%1").arg(i);
+        else
+            name = QString::fromLatin1((*it)->Name.c_str());
 
         switch((*it)->Type){
             case Sketcher::Horizontal:
@@ -212,16 +230,60 @@ void TaskSketcherConstrains::slotConstraintsChanged(void)
                 if(Filter<1 || (*it)->Name != "")
                     ui->listWidgetConstraints->addItem(new ConstraintItem(coinc,name,i-1,(*it)->Type));
                 break;
+            case Sketcher::PointOnObject:
+                if(Filter<2 || (*it)->Name != "")
+                ui->listWidgetConstraints->addItem(new ConstraintItem(pntoo,name,i-1,(*it)->Type));
+                break;
             case Sketcher::Parallel:
                 if(Filter<2 || (*it)->Name != "")
                     ui->listWidgetConstraints->addItem(new ConstraintItem(para,name,i-1,(*it)->Type));
                 break;
+            case Sketcher::Perpendicular:
+                if(Filter<2 || (*it)->Name != "")
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(perp,name,i-1,(*it)->Type));
+                break;
+            case Sketcher::Tangent:
+                if(Filter<2 || (*it)->Name != "")
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(tang,name,i-1,(*it)->Type));
+                break;
+            case Sketcher::Equal:
+                if(Filter<2 || (*it)->Name != "")
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(equal,name,i-1,(*it)->Type));
+                break;
+            case Sketcher::Symmetric:
+                if(Filter<2 || (*it)->Name != "")
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(symm,name,i-1,(*it)->Type));
+                break;
             case Sketcher::Distance:
                 if(Filter<3 || (*it)->Name != ""){
-                    name = QString(QString::fromLatin1("%1 (%2)")).arg(name,14).arg((*it)->Value);
+                    name = QString::fromLatin1("%1 (%2)").arg(name).arg((*it)->Value);
                     ui->listWidgetConstraints->addItem(new ConstraintItem(dist,name,i-1,(*it)->Type));
                 }
                 break;
+            case Sketcher::DistanceX:
+                if(Filter<3 || (*it)->Name != ""){
+                    name = QString::fromLatin1("%1 (%2)").arg(name).arg(std::abs((*it)->Value));
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(hdist,name,i-1,(*it)->Type));
+                }
+                break;
+            case Sketcher::DistanceY:
+                if(Filter<3 || (*it)->Name != ""){
+                    name = QString::fromLatin1("%1 (%2)").arg(name).arg(std::abs((*it)->Value));
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(vdist,name,i-1,(*it)->Type));
+                }
+                break;
+            case Sketcher::Radius:
+                if(Filter<3 || (*it)->Name != ""){
+                    name = QString::fromLatin1("%1 (%2)").arg(name).arg((*it)->Value);
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(radi,name,i-1,(*it)->Type));
+                }
+                break;
+            case Sketcher::Angle:
+                if(Filter<3 || (*it)->Name != ""){
+                    name = QString::fromLatin1("%1 (%2)").arg(name).arg(Base::toDegrees<double>(std::abs((*it)->Value)));
+                    ui->listWidgetConstraints->addItem(new ConstraintItem(angl,name,i-1,(*it)->Type));
+                }
+                break;
             default:
                 ui->listWidgetConstraints->addItem(new ConstraintItem(name,i-1,(*it)->Type));
                 break;
@@ -231,7 +293,6 @@ void TaskSketcherConstrains::slotConstraintsChanged(void)
 
 }
 
-
 void TaskSketcherConstrains::changeEvent(QEvent *e)
 {
     TaskBox::changeEvent(e);
