@@ -33,8 +33,7 @@
 #include <Gui/BitmapFactory.h>
 #include <Gui/ViewProvider.h>
 #include <Gui/WaitCursor.h>
-#include <Base/Console.h>
-#include <boost/bind.hpp>
+#include <Base/UnitsApi.h>
 
 #include "ViewProviderSketch.h"
 
@@ -53,32 +52,47 @@ TaskSketcherGeneral::TaskSketcherGeneral(ViewProviderSketch *sketchView)
 
     this->groupLayout()->addWidget(proxy);
 
-    connectionSolved = sketchView->signalSolved.connect(boost::bind(&SketcherGui::TaskSketcherGeneral::slotSolved, this,_1,_2));
+    // connecting the needed signals
+    QObject::connect(
+        ui->checkBoxGridSnap, SIGNAL(stateChanged(int)),
+        this              , SLOT  (toggleGridSnap(int))
+       );
 
+    QObject::connect(
+        ui->comboBoxGridSize, SIGNAL(currentIndexChanged(QString)),
+        this              , SLOT  (setGridSize(QString))
+       );
+
+    QObject::connect(
+        ui->checkBoxAutoconstraints, SIGNAL(stateChanged(int)),
+        this              , SLOT  (toggleAutoconstraints(int))
+       );
+    
     Gui::Selection().Attach(this);
 }
 
 TaskSketcherGeneral::~TaskSketcherGeneral()
 {
-    connectionSolved.disconnect();
     delete ui;
     Gui::Selection().Detach(this);
 }
 
-void TaskSketcherGeneral::slotSolved(int type,float time)
+void TaskSketcherGeneral::setGridSize(const QString& val)
 {
-    QPalette palette;
-    switch(type){
-        case 0: 
-            ui->labelSolverStatus->setText(QString::fromLatin1("Solved (%1)").arg(time));
-            palette.setBrush(QPalette::Base,QColor(200,250,200));
-            break;
-        case 1: 
-            ui->labelSolverStatus->setText(QString::fromLatin1("Unsolved (%1)").arg(time));
-            palette.setBrush(QPalette::Base,QColor(200,250,200));
-            break;
-    }
-    ui->labelSolverStatus->setPalette(palette);
+    float gridSize = (float) Base::UnitsApi::translateUnit(val);
+    if (gridSize > 0)
+        sketchView->GridSize.setValue(gridSize);
+}
+
+void TaskSketcherGeneral::toggleGridSnap(int state)
+{
+    setGridSize(ui->comboBoxGridSize->currentText()); // Ensure consistency
+    sketchView->GridSnap.setValue(state == Qt::Checked);
+}
+
+void TaskSketcherGeneral::toggleAutoconstraints(int state)
+{
+    sketchView->Autoconstraints.setValue(state == Qt::Checked);
 }
 
 void TaskSketcherGeneral::changeEvent(QEvent *e)
@@ -101,7 +115,4 @@ void TaskSketcherGeneral::OnChange(Gui::SelectionSingleton::SubjectType &rCaller
 }
 /// @endcond DOXERR
 
-
-
-
 #include "moc_TaskSketcherGeneral.cpp"
