@@ -26,10 +26,8 @@
 
 #include <Gui/TaskView/TaskView.h>
 #include <Gui/Selection.h>
-#include <boost/signals.hpp>
 
 class Ui_TaskSketcherGeneral;
-typedef boost::signals::connection Connection;
 
 namespace App {
 class Property;
@@ -39,7 +37,6 @@ namespace SketcherGui {
 
 class ViewProviderSketch;
 
-
 class TaskSketcherGeneral : public Gui::TaskView::TaskBox, public Gui::SelectionSingleton::ObserverType
 {
     Q_OBJECT
@@ -51,16 +48,18 @@ public:
     void OnChange(Gui::SelectionSingleton::SubjectType &rCaller,
                   Gui::SelectionSingleton::MessageType Reason);
 
-    void slotSolved(int type,float time);
-
 Q_SIGNALS:
     void setGridSnap(int Type);
 
+public Q_SLOTS:
+    void setGridSize(const QString& val);
+    void toggleGridSnap(int state);
+    void toggleAutoconstraints(int state);
+
 protected:
     void changeEvent(QEvent *e);
 
     ViewProviderSketch *sketchView;
-    Connection connectionSolved;
 
 private:
     QWidget* proxy;
@@ -69,4 +68,4 @@ private:
 
 } //namespace SketcherGui
 
-#endif // GUI_TASKVIEW_TASKAPPERANCE_H
+#endif // GUI_TASKVIEW_TaskSketcherGerneral_H
