@@ -27,7 +27,8 @@ Examples for a feature class and its view provider.
 
 __author__ = "Werner Mayer <wmayer@users.sourceforge.net>"
 
-import FreeCAD, Part
+import FreeCAD, Part, math
+from FreeCAD import Base
 from pivy import coin
 
 class PartFeature:
@@ -137,9 +138,11 @@ def makeBox():
 	Box(a)
 	ViewProviderBox(a.ViewObject)
 
+# -----------------------------------------------------------------------------
+
 class Line:
 	def __init__(self, obj):
-		''' App two point properties '''
+		''' Add two point properties '''
 		obj.addProperty("App::PropertyVector","p1","Line","Start point")
 		obj.addProperty("App::PropertyVector","p2","Line","End point").p2=FreeCAD.Vector(1,0,0)
 		obj.Proxy = self
@@ -164,6 +167,8 @@ def makeLine():
 	#ViewProviderLine(a.ViewObject)
 	a.ViewObject.Proxy=0 # just set it to something different from None
 
+# -----------------------------------------------------------------------------
+
 class Octahedron:
 	def __init__(self, obj):
 		"Add some custom properties to our box feature"
@@ -341,6 +346,8 @@ def makeOctahedron():
 	Octahedron(a)
 	ViewProviderOctahedron(a.ViewObject)
 
+# -----------------------------------------------------------------------------
+
 class PointFeature:
 	def __init__(self, obj):
 		obj.Proxy = self
@@ -450,6 +457,7 @@ def makePoints():
 	PointFeature(a)
 	ViewProviderPoints(a.ViewObject)
 
+# -----------------------------------------------------------------------------
 
 class MeshFeature:
 	def __init__(self, obj):
@@ -531,10 +539,11 @@ def makeMesh():
 	MeshFeature(a)
 	ViewProviderMesh(a.ViewObject)
 	
+# -----------------------------------------------------------------------------
 
 class Molecule:
 	def __init__(self, obj):
-		''' App two point properties '''
+		''' Add two point properties '''
 		obj.addProperty("App::PropertyVector","p1","Line","Start point")
 		obj.addProperty("App::PropertyVector","p2","Line","End point").p2=FreeCAD.Vector(1,0,0)
 
@@ -586,3 +595,150 @@ def makeMolecule():
 	Molecule(a)
 	ViewProviderMolecule(a.ViewObject)
 
+# -----------------------------------------------------------------------------
+
+class CircleSet:
+	def __init__(self, obj):
+		obj.addProperty("Part::PropertyPartShape","Shape","Circle","Shape")
+		obj.Proxy = self
+
+	def execute(self, fp):
+		pass
+
+
+class ViewProviderCircleSet:
+	def __init__(self, obj):
+		''' Set this object to the proxy object of the actual view provider '''
+		obj.Proxy = self
+
+	def attach(self, obj):
+		self.coords=coin.SoCoordinate3()
+		self.lines=coin.SoLineSet()
+		obj.RootNode.addChild(self.coords)
+		obj.RootNode.addChild(self.lines)
+
+	def updateData(self, fp, prop):
+			if prop == "Shape":
+				edges=p = fp.getPropertyByName("Shape").Edges
+				pts=[]
+				ver=[]
+				for i in edges:
+					length=i.Length
+					ver.append(10)
+					for j in range(10):
+						v=i.valueAt(j/9.0*length)
+						pts.append((v.x,v.y,v.z))
+				
+				self.coords.point.setValues(pts)
+				self.lines.numVertices.setValues(ver)
+
+	def __getstate__(self):
+		return None
+ 
+	def __setstate__(self,state):
+		return None
+
+def makeCircleSet():
+	x=0.5
+	comp=Part.Compound([])
+	for j in range (630):
+		y=0.5
+		for i in range (630):
+			c = Part.makeCircle(0.1, Base.Vector(x,y,0), Base.Vector(0,0,1))
+			#Part.show(c)
+			comp.add(c)
+			y=y+0.5
+		x=x+0.5
+
+	FreeCAD.newDocument()
+	a=FreeCAD.ActiveDocument.addObject("App::FeaturePython","Circles")
+	c=CircleSet(a)
+	v=ViewProviderCircleSet(a.ViewObject)
+	a.Shape=comp
+
+# -----------------------------------------------------------------------------
+
+class EnumTest:
+	def __init__(self, obj):
+		''' Add enum properties '''
+		obj.addProperty("App::PropertyEnumeration","Enum","","Enumeration").Enum=["One","Two","Three"]
+		obj.addProperty("App::PropertyEnumeration","Enum2","","Enumeration2").Enum2=["One","Two","Three"]
+		obj.Proxy = self
+
+	def execute(self, fp):
+		return                                                                            
+                                                                               
+class ViewProviderEnumTest:
+	def __init__(self, obj):
+		''' Set this object to the proxy object of the actual view provider '''           
+		obj.addProperty("App::PropertyEnumeration","Enum3","","Enumeration3").Enum3=["One","Two","Three"]
+		obj.addProperty("App::PropertyEnumeration","Enum4","","Enumeration4").Enum4=["One","Two","Three"]
+		obj.Proxy = self
+
+	def updateData(self, fp, prop):
+		print "prop updated:",prop
+
+	def __getstate__(self):
+		return None
+
+	def __setstate__(self,state):
+		return None
+
+def makeEnumTest():
+	FreeCAD.newDocument()
+	a=FreeCAD.ActiveDocument.addObject("Part::FeaturePython","Enum")
+	EnumTest(a)
+	ViewProviderEnumTest(a.ViewObject)
+
+# -----------------------------------------------------------------------------
+
+class DistanceBolt:
+	def __init__(self, obj):
+		''' Add the properties: Length, Edges, Radius, Height '''
+		obj.addProperty("App::PropertyInteger","Edges","Bolt","Number of edges of the outline").Edges=6
+		obj.addProperty("App::PropertyLength","Length","Bolt","Length of the edges of the outline").Length=10.0
+		obj.addProperty("App::PropertyLength","Radius","Bolt","Radius of the inner circle").Radius=4.0
+		obj.addProperty("App::PropertyLength","Height","Bolt","Height of the extrusion").Height=20.0
+		obj.Proxy = self
+
+	def onChanged(self, fp, prop):
+		if prop == "Edges" or prop == "Length" or prop == "Radius" or prop == "Height":
+			self.execute(fp)
+
+	def execute(self, fp):
+		edges = fp.Edges
+		if edges < 3:
+			edges = 3
+		length = fp.Length
+		radius = fp.Radius
+		height = fp.Height
+
+		m=Base.Matrix()
+		m.rotateZ(math.radians(360.0/edges))
+
+		# create polygon
+		polygon = []
+		v=Base.Vector(length,0,0)
+		for i in range(edges):
+			polygon.append(v)
+			v = m.multiply(v)
+		polygon.append(v)
+		wire = Part.makePolygon(polygon)
+
+		# create circle
+		circ=Part.makeCircle(radius)
+
+		# Create the face with the polygon as outline and the circle as hole
+		face=Part.Face([wire,Part.Wire(circ)])
+
+		# Extrude in z to create the final solid
+		extrude=face.extrude(Base.Vector(0,0,height))
+		fp.Shape = extrude
+
+def makeDistanceBolt():
+	FreeCAD.newDocument()
+	bolt=FreeCAD.ActiveDocument.addObject("Part::FeaturePython","Distance_Bolt")
+	bolt.Label = "Distance bolt"
+	DistanceBolt(bolt)
+	bolt.ViewObject.Proxy=0
+
